(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1244307,      28492]*)
(*NotebookOutlinePosition[   1247926,      28595]*)
(*  CellTagsIndexPosition[   1247387,      28578]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Small finite Groups, Loops & Hoops for non-",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users."
}], "Title",
  PageWidth->WindowWidth,
  CellMargins->{{4, -16}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Small Groups, Moufang Loops, Hoop Algebras;",
  StyleBox[" ", "DisplayFormula"],
  "Demonstrations."
}], "Subtitle",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["R.H.Beresford. 2004. Latest Revision 11/10/2006", "Subsubtitle",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\"To see what is in front of your nose needs a constant struggle.\" (George \
Orwell.)\
\>", "Text",
  PageWidth->WindowWidth,
  TextJustification->0.25],

Cell["\<\
\tSymmetry-conserving partial-fraction-division \"Hoop Algebras\" are closely \
related to Groups and Moufang Loops. (See Figure 1 for examples.) They \
multiply, divide, add and \"split\" generalized vectors with \"generalized \
signs\" and employ many new or neglected mathematical concepts to re-define \
physical mathematics. Do not confuse them with the traditional use of groups \
as coordinate transformation matrices for a single vector or with dot \
multiplication of two vectors to give a scalar. Hoop multiplication or \
division operates on two vectors to produce a third vector and (in many \
cases) one or two \"remainder\" vectors carrying different symmetries.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThis notebook demonstrates the material on small groups, Moufang loops, \
and \"Hoop Algebras\" supplied in the",
  StyleBox[" GroupLoopHoop.m",
    FontSlant->"Italic"],
  " package in ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/4894/"], None},
    ButtonStyle->"Hyperlink"],
  ". Another notebook, ",
  StyleBox["HoopDemo.nb",
    FontSlant->"Italic"],
  ", deals solely with Hoop Algebras. A shorter and simpler account of Hoop \
Algebras (using a much smaller package, and omitting all the material \
specific to groups and loops) is available as ",
  StyleBox["HoopFundamentals.nb",
    FontSlant->"Italic"],
  " in ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/6198/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/6198/"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" .",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tAlgebraic loops are closed binary \"multiplication\" operations with a \
unit. They may involve quantum operators, but usually operate on \"vecs\" \
(generalized vectors), sets of un-signed numerical \"coefficients\". The ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " database includes over 800 loops, as preferred Cayley Table isomorphs or \
\"protoloops\", together with procedures to create, identify, and manipulate \
them. If a loop is associative, xy.z=x.yz for all x,y,z, it is a group. The \
database includes all groups with up to 73 elements, and a few larger groups. \
If the condition is relaxed to the Moufang division property, zx.yz = (z.xy)z \
, it is a Moufang loop. (Groups are associative Moufang loops.) The database \
includes a few non-associative Moufang loops.\n\tAlgebras combine loop \
multiplication with the operations of addition and generalized subtraction. \
This \"folds\" two or more \"directions\" to a \"dimension\", and introduces \
\"generalized signs\". Loops with ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "unsigned coefficients and ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry \"fold\" by equivalence-relationships to algebras with ",
  StyleBox["m/r ",
    FontSlant->"Italic"],
  "coefficients. Two-folding creates real numbers with the signs \"+\" & \
\"-\". One case of four-folding creates complex numbers with the signs \"+\", \
\"\[ImaginaryI]\", \"-\" & \"-\[ImaginaryI]\"; another creates Study numbers \
with a second sign \"\[DoubleStruckK]\" that squares to +1 but differs from \
\"-\". Algebras often have \"signed multiplication tables\" that are not \
loops because some products are signed, and so are not members of the \
defining set. Many algebras, (\[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], \[DoubleStruckCapitalO], \
Clifford, Davenport, Dirac, Lie, Pauli, Study, \"Terplex\", Wedge, etc,) are \
\"Symmetry-conserving Partial-Fraction Division Algebras\" (I call them \
\"Hoops\" - they conserve their \"shapes\" or symmetries) because their \
multiplication tables have the (necessary and sufficient) Frobenius \
determinant conservation property Det[AB]= \[PlusMinus]Det[A] Det[B] for \
vector operations. They also have the (necessary but insufficient) Moufang \
division property, so that every vector has an inverse that (in \
non-degenerate cases) splits into partial fractions. Hoop multiplication \
tables are either unsigned Moufang Loops (including all Groups, Octonions, \
and a few other non-associative Moufang loops) or signed tables. Each entry \
in the Cayley table is a single (possibly signed) element, so they are a very \
restricted sub-set of general algebras; each row and column contains every \
(possibly signed) element once; the first row and column are identical and \
define the unit element\n\t Hoops transcend the limitations of \"rings\", \
\"fields\" & \"real division algebras without divisors of zero\", and \
introduce many new concepts to mathematics and mathematical physics \
(summarized in Section 1.2 and in ",
  StyleBox["HoopGlossary.nb",
    FontSlant->"Italic"],
  ").\n\tThe ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " package also contains many procedures to create, identify, and manipulate \
loops, groups and hoops as Cayley tables. These are demonstrated in this \
notebook (",
  StyleBox["GroupLoopDemo.nb",
    FontSlant->"Italic"],
  "); the associated ",
  StyleBox["HoopDemo.nb",
    FontSlant->"Italic"],
  " notebook demonstrates hoop procedures. The demonstrations are designed to \
be read (using ",
  StyleBox["MathReader ",
    FontSlant->"Italic"],
  "[1]) by non-users of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The subject is developed by many examples, starting with Cayley tables \
and ending with applications in mathematical physics. The output of the \
examples is meant to be self-explanatory and the (probably incomprehensible) \
input statements are hidden in \"closed cells\". If you wish to inspect these \
cells, click on their (tiny) cell bracket and then on ",
  StyleBox["Cell, Cell Properties",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["Cell Open",
    FontSlant->"Italic"],
  ".\n\tIf you are a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " user and wish to check the examples, to test them with changed data, or \
to investigate any other aspects of groups, loops, or hoops, activate the ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " notebook. This provides a database of over 800 Cayley tables, including \
all groups with up to 73 elements, together with the relevant procedures.\n\t\
Please inform me by e-mail to ",
  StyleBox["rhberesford@btinternet.com",
    FontSlant->"Italic"],
  " of any errors or infelicities."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["1. Preamble",
    FontFamily->"Times New Roman"],
  "."
}], "Section",
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["1.1 Summary. ", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\t\"Primal\" (unsigned continuous) numbers, \"Generalized Signs\" \
(orthogonal roots of unity) and \"Hoops\" (Symmetry-conserving \
Partial-fraction-division Algebras) re-write much of mathematics. Hoops \
multiply, divide, add and split sets of operators or primal coefficients. \
They are defined by having Cayley tables with Frobenius determinant-factor \
conservation. They also have the Moufang properties [2, p92] , ",
  StyleBox["including ",
    FontWeight->"Plain"],
  StyleBox["zx.yz=(z.xy)z,",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Plain"],
  "left & right units, & multiplicative inverses for \"vecs\" (sets of \
operators or coefficients, generalized vectors). They conserve symmetries or \
\"sizes\" (factors of the symbolic conjugate table determinant) on \
multiplication and division. The existence of multiplicative inverses makes \
vector division the same operation as vector multiplication; this creates \
\"remainders\" to maintain size conservation when the operands have disparate \
sizes.\n\tRoots of unity provide generalized signs that \"fold\" groups and \
many Moufang loops to \"Hoop algebras\" with vector multiplication and \
generalized negation. Simple negation \"-\" is an equivalence relation on ",
  StyleBox["pairs",
    FontSlant->"Italic"],
  " of unsigned numbers. Generalized signs ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^r\)]],
  " involve equivalence relations on indexed ",
  StyleBox["sets ",
    FontSlant->"Italic"],
  "of ",
  StyleBox["r",
    FontSlant->"Italic"],
  " unsigned numbers, and extend many aspects of standard mathematics - they \
generate groups and multi-phase sinusoids; complex & quaternion algebras are \
degenerate mono-sized hoop algebras, minus one is not unique, etc.\n\tSome \
hoops with quadratic sizes have polar or hyperbolic duals, generalized powers \
and roots, and deBroglie-wave-like continuous \"orbits\" (polar duals with \
unit determinant). A few orbits have stable Planck-area-like squared \
amplitudes, possibly related to stable particles. Elements in these algebras \
act as unit-spin and half-spin quantum operators. Indirect composition of \
\"supersymmetric\" commutative algebras creates \"subsymmetric\" \
non-commutative algebras with more symmetries. (Physicists originated this \
nomenclature, wrongly assuming it to be one-to-one.)\n\t\"Zero-sized vecs\" \
have some sizes equal to zero; multiplication and division by them \"projects\
\" the result into a sub-algebra with these sizes zeroed, whilst \"ejecting\" \
size-conserving \"remainders\". Thus A*B = P(product) + Rl + Rr (remainders) \
and P/B + Rl = A,  P/A + Rr = B; the sizes of Rl & Rr are those that are zero \
in B & A respectively. This generalizes integer division, where A/B gives Q \
(quotient) + R (remainder) with R\[LessSlantEqual]B and Q*B+R=A. Remainders \
provide \"renormalization\" and eliminate vector division-by-zero.\n\tThe ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " package provides a database of over 800 loops including over 80 hoops, \
all groups with up to 73 elements, and the 12 smallest non-associative \
Moufang loops. It also includes procedures to create, test, identify and \
manipulate groups, loops & hoops."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
1.2 New and Neglected Mathematical Concepts Related to Hoops.\
\>", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.625}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tMany new, and some neglected, mathematical concepts are developed below, \
in ",
  StyleBox["bold",
    FontWeight->"Bold"],
  " when first mentioned; they are related to hoop algebras (and summarized \
in the companion notebook ",
  StyleBox["HoopGlossary.nb",
    FontSlant->"Italic"],
  ").\n\tAlgebraic loops are closed binary operations with a unit. If they \
are finite, they can be expressed as indexed Cayley tables, with the first \
row and column being {1,2,...,m} (the unit) and with every row and column \
containing each index once. A ",
  StyleBox["Protoloop",
    FontWeight->"Bold"],
  " has been chosen for each loop in the database; this is a preferred \
isomorph that is related to the protoloops of similar loops.\n\tLoops that \
are associative, with x(yz) = (xy)z (for all elements x,y,z in the table), \
are Groups. If they have the slightly less restrictive Moufang division \
property zx.yz = (z.xy)z they are \"Moufang Loops\" [2, p92] . (Other Moufang \
properties are equivalent to this division property.) All groups are Moufang \
Loops, and all non-associative Moufang Loops are \"square associative\" or \
\"alternative\", with xx.y = x(xy).\n\tFrobenius showed that all groups have \
",
  StyleBox["Frobenius conservation,",
    FontWeight->"Bold"],
  " Det[A] Det[B] = \[PlusMinus] Det[AB]. Here, A = {",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_1\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  ", ..",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  "} and B = {",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\_2\)]],
  ", ..",
  Cell[BoxData[
      \(TraditionalForm\`b\_m\)]],
  "} are ",
  StyleBox["vecs",
    FontWeight->"Bold"],
  " (generalized vectors), sets of unsigned operators or coefficients (loops \
can be defined without recourse to negation) and AB is the product {",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  ",.., ",
  Cell[BoxData[
      \(TraditionalForm\`c\_m\)]],
  "} obtained by ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)]],
  "=\[Sum]",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  ", where ",
  StyleBox["i.j=k",
    FontSlant->"Italic"],
  " in the table. Det[A] is that of the protoloop table mapped with the ",
  StyleBox["generalized conjugate",
    FontWeight->"Bold"],
  " of A. All groups, Octonions and a few other non-associative Moufang Loops \
have this ",
  StyleBox["conservative ",
    FontWeight->"Bold"],
  "property (most loops do not). The division property guarantees that ",
  StyleBox["every vec A has an inverse",
    FontWeight->"Bold"],
  ", Ai = {",
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`d\_2\)]],
  ",..",
  Cell[BoxData[
      \(TraditionalForm\`d\_m\)]],
  "} /Det[A] with Ai.A={1,0,...}. Hence multiplication is invertible, and \
division is defined for Moufang Loops. The inverse can be calculated by \
Cramer's rule. An important feature of Moufang Loops is that ",
  StyleBox["the inverse splits into partial fractions",
    FontWeight->"Bold"],
  " because Det[A] always factorises (",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  "+..+",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  " must be a first factor of a quasigroup determinant). Note that the \
multiplication operation involves two vectors; it is not matrix \
multiplication, which transforms a single vector to a different coordinate \
system."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tConservative loops have two operations, multiplication and division; \
they become algebras when ",
  StyleBox["generalized signs",
    FontWeight->"Bold"],
  " (and generalized subtraction) are defined. The traditional signs {+,\
\[ImaginaryI],-,-\[ImaginaryI]} are created by equivalence relations on ",
  StyleBox["sets",
    FontSlant->"Italic"],
  " of unsigned numbers. Integers are created [8, p20 et seq] when ",
  StyleBox["pairs",
    FontSlant->"Italic"],
  " of Natural (unsigned) numbers {",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "} & {",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  "} are equivalenced to a single integer ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "if ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "+",
  StyleBox["d=b+c",
    FontSlant->"Italic"],
  ". Unsigned continuous numbers (I call them \"Primal numbers\") can be \
created via an axiom of continuity on unsigned rational numbers. If the \
cyclic group of 2 elements, C2, is used as a multiplication table for ordered \
pairs of primals, {",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  "} and {",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\_2\)]],
  "}, the result is the ordered pair {",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`b\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`b\_2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  "}. Equivalencing then gives the rules of Real Algebra, {\"+\"\[Times]\"+\" \
= \"+\", \"-\"\[Times]\"-\" = \"+\", \"+\"\[Times]\"-\" = \"-\", \
\"-\"\[Times]\"+\" = \"-\"}, and these rules give a division algebra because \
C2 has the Moufang property. I use the term \"folding\" for equivalencing \
from ",
  StyleBox["m",
    FontSlant->"Italic"],
  " elements to ",
  StyleBox["m/r",
    FontSlant->"Italic"],
  " elements for loops with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry. Many mathematical properties can be extended to handle \
generalized signs.\n\tUsing the C4 multiplication table to multiply sets of \
four unsigned numbers give Complex algebra after folding to a pair of \
\"real\" coefficients, the real and imaginary parts. (These are \"real\" \
because they can be positive, zero, or negative.) The rules of Complex \
arithmetic include those of real algebra, together with \"\[ImaginaryI]\"\
\[Times]\"\[ImaginaryI]\" = \"-\", \"-\"\[Times]\"\[ImaginaryI]\" = \"-\
\[ImaginaryI]\", etc.; they originate in the properties of C4. Four unsigned \
coefficients have been folded to one complex number.\n\tFolding the Klein \
4-group K gives \"Study numbers\" or \"double algebra\" [3, p24] describing \
the hyperbolic plane instead of the complex plane. K has three elements that \
square to +1, i.e. \"j\", \"k\" and \"jk\"; so \"minus one is not unique\".\n\
\tSimilarly, the eight-element Quaternion group provides the rules for \
Quaternion algebra, with four \"real\" coefficients that are folded from the \
eight unsigned elements. \"+1\" has three different fourth roots in \
Quaternion algebra.\n\tOctonion algebra involves eight \"real\" coefficients \
and seven fourth roots of +1, but there is no group to provide the \
multiplication table for the 16 un-equivalenced elements. The relevant \
multiplication table \"Oct\" is not a group (it is only square-associative), \
but it is folded from a \"non-associative Moufang Loop\".\n\tHamilton noted \
the two-to-one relationships between the quaternion and octonion tables and \
their multiplication tables. (Reference lost. ?? in Lectures on Quaternions, \
Dublin 1853.) He distinguished between the (unsigned) \"",
  StyleBox["directions",
    FontWeight->"Bold"],
  "\" of the larger tables and the (signed) \"",
  StyleBox["dimensions",
    FontWeight->"Bold"],
  "\" of the smaller tables.\n\t Sets of ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "unsigned coefficients are folded to ",
  StyleBox["vecs",
    FontWeight->"Bold"],
  " (generalized vectors) with ",
  StyleBox["m/2",
    FontSlant->"Italic"],
  " signed coefficients on 2-fold equivalencing. Conservative ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " loops, with 2-fold symmetry, are folded to algebras with multiplication \
tables of size ",
  StyleBox["(m/2)\[Times](m/2)",
    FontSlant->"Italic"],
  ". The Frobenius determinant-conservation property Det[A] Det[B] = Det[AB] \
and the Moufang division property zx.yz = (z.xy)z (relaxed to \"up to a \
sign\") survive the folding process, and so are shared by all Hoop \
algebras.",
  StyleBox[" ",
    FontWeight->"Bold"],
  "The conservation property makes them relevant to physics, via Noether's \
law. (Non-Moufang algebras, and most non-associative Moufang algebras, do not \
provide consistent conservation laws.) The division property ensures that",
  StyleBox[" every vec has a multiplicative inverse",
    FontWeight->"Bold"],
  " (making multiplication and division a single operation). In most cases, \
the inverse splits into partial fractions with the determinant factors as \
denominators.\n\t I propose the name ",
  StyleBox["Hoops",
    FontWeight->"Bold"],
  " for these ",
  StyleBox["symmetry-",
    FontWeight->"Bold"],
  StyleBox["conserving partial-fraction division algebras.",
    FontWeight->"Bold"],
  " (Hoops are rings or loops that conserve their shape, and come between \
groups and loops.) A single procedure ",
  StyleBox["hoopTimes[A,B,table]",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " performs multiplication of the vecs A & B according to the specified \
table, and makes ",
  StyleBox["table",
    FontSlant->"Italic"],
  " the ",
  StyleBox["Target algebra",
    FontWeight->"Bold"],
  ". Another procedure ",
  StyleBox["hoopInverse[A]",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " calculates the inverse of A in the target algebra.\n\tFolding can be \
generalized to use other symmetries. As all groups are hoops, ",
  StyleBox["every group with r-fold symmetry can be folded to an r-signed \
algebra",
    FontWeight->"Bold"],
  ". Figure 1 shows protoloops for three Moufang Loops (the C4C2, quaternion, \
and C9 groups). The top left corner is repeated in the tables; it also occurs \
with offsets of 3, 4, or 6, showing the symmetry. It is then shown as folded \
tables, with the indices replaced by the usual complex or quaternion symbols, \
or (in the C9j algebra) by signed indices, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^3\)]],
  "=1 providing a new sign \[DoubleStruckCapitalJ] so that indices 4 & 5 \
becoming \[DoubleStruckCapitalJ]1 and \[DoubleStruckCapitalJ]2. The last \
table has {a,b,c} mapped onto {1,2,3}, to give the symbolic table, with the \
determinant ",
  Cell[BoxData[
      \(\(-c\^3\) - b\^3\ \[DoubleStruckCapitalJ] + 
        3\ a\ b\ c\ \[DoubleStruckCapitalJ] - 
        a\^3\ \[DoubleStruckCapitalJ]\^2\)]],
  ". Note also that the C4C2 table can be folded a second time, to give the \
Complex multiplication table \"C4c\" with \[ImaginaryI].\[ImaginaryI]=-1. "
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 1.",
    FontWeight->"Bold"],
  " Two-fold and three-fold ",
  "Folding",
  StyleBox[" ",
    FontWeight->"Bold"],
  "of Moufang Loops\n            and the resulting signed algebras."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "   C4C2 group          Quaternion group       C9 Group\n\n",
  Cell[BoxData[
      TagBox[
        FormBox[
          RowBox[{GridBox[{
                {
                  StyleBox["1",
                    FontWeight->"Bold"], 
                  StyleBox["2",
                    FontWeight->"Bold"], 
                  StyleBox["3",
                    FontWeight->"Bold"], 
                  StyleBox["4",
                    FontWeight->"Bold"], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["2",
                    FontWeight->"Bold"], 
                  StyleBox["3",
                    FontWeight->"Bold"], 
                  StyleBox["4",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontWeight->"Bold"], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["3",
                    FontWeight->"Bold"], 
                  StyleBox["4",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontWeight->"Bold"], 
                  StyleBox["2",
                    FontWeight->"Bold"], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["4",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontWeight->"Bold"], 
                  StyleBox["2",
                    FontWeight->"Bold"], 
                  StyleBox["3",
                    FontWeight->"Bold"], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["1",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["2",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["3",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["2",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["3",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["1",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["3",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["1",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["2",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["1",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["2",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["3",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]"}],
          "TraditionalForm"],
        TraditionalForm,
        Editable->True]],
    PageWidth->PaperWidth,
    Evaluatable->False,
    FontSize->9],
  ", ",
  Cell[BoxData[
      RowBox[{
        TagBox[
          FormBox[
            RowBox[{"\[NoBreak]", GridBox[{
                  {
                    StyleBox["1",
                      FontWeight->"Bold"], 
                    StyleBox["2",
                      FontWeight->"Bold"], 
                    StyleBox["3",
                      FontWeight->"Bold"], 
                    StyleBox["4",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["2",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Bold"], 
                    StyleBox["8",
                      FontWeight->"Bold"], 
                    StyleBox["3",
                      FontWeight->"Bold"], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["3",
                      FontWeight->"Bold"], 
                    StyleBox["4",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Bold"], 
                    StyleBox["6",
                      FontWeight->"Bold"], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["4",
                      FontWeight->"Bold"], 
                    StyleBox["7",
                      FontWeight->"Bold"], 
                    StyleBox["2",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Bold"], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["5",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["5",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["5",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["5",
                      FontWeight->"Bold",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak] "}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ","}]],
    PageWidth->PaperWidth,
    Evaluatable->False,
    FontSize->9],
  " ",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox["1",
                FontWeight->"Bold"], 
              StyleBox["2",
                FontWeight->"Bold"], 
              StyleBox["3",
                FontWeight->"Bold"], 
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["2",
                FontWeight->"Bold"], 
              StyleBox["3",
                FontWeight->"Bold"], 
              StyleBox["4",
                FontWeight->"Bold"], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["3",
                FontWeight->"Bold"], 
              StyleBox["4",
                FontWeight->"Bold"], 
              StyleBox["5",
                FontWeight->"Bold"], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Bold",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]}
            },
          ColumnAlignments->{Decimal}], 
        TagBox[
          FormBox["\[NoBreak]",
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], " "}]]],
  "\n\n  C4 & Complex    Quaternion        C9J      Symbolic\n    algebra     \
   algebra         algebra     C9J  \n",
  Cell[BoxData[{
      RowBox[{
        TagBox[
          FormBox[
            RowBox[{"\[NoBreak]", GridBox[{
                  {
                    StyleBox["1",
                      FontWeight->"Bold"], 
                    StyleBox["\[ImaginaryI]",
                      FontWeight->"Bold"], \(-1\), \(-\[ImaginaryI]\)},
                  {
                    StyleBox["\[ImaginaryI]",
                      FontWeight->"Bold"], 
                    StyleBox[\(-1\),
                      FontWeight->"Bold"], \(-\[ImaginaryI]\), "1"},
                  {\(-1\), \(-\[ImaginaryI]\), "1", "\[ImaginaryI]"},
                  {\(-\[ImaginaryI]\), "1", "\[ImaginaryI]", \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", " ", 
        TagBox[
          FormBox[
            RowBox[{"\[NoBreak]", GridBox[{
                  {"1", 
                    StyleBox["i",
                      FontSlant->"Plain"], 
                    StyleBox["j",
                      FontSlant->"Plain"], "ij"},
                  {
                    StyleBox["i",
                      FontSlant->"Plain"], \(-1\), \(-ij\), 
                    StyleBox["j",
                      FontSlant->"Plain"]},
                  {
                    StyleBox["j",
                      FontSlant->"Plain"], "ij", \(-1\), 
                    RowBox[{"-", 
                      StyleBox["i",
                        FontSlant->"Plain"]}]},
                  {"ij", 
                    RowBox[{"-", 
                      StyleBox["j",
                        FontSlant->"Plain"]}], 
                    StyleBox["i",
                      FontSlant->"Plain"], \(-1\)}
                  },
                ColumnAlignments->{Decimal}]}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "     ", 
        RowBox[{
          TagBox[
            FormBox[
              RowBox[{"\[NoBreak]", 
                RowBox[{GridBox[{
                      {"1", "2", "3"},
                      {"2", \(\(3\)\(\ \)\), "\[DoubleStruckCapitalJ]1"},
                      {"3", "\[DoubleStruckCapitalJ]1", 
                        "\[DoubleStruckCapitalJ]2"}
                      }], ",", "\[NoBreak]"}]}],
              "TraditionalForm"],
            TraditionalForm,
            Editable->True], GridBox[{
              {"a", "b", "c"},
              {"b", "c", \(\(\[DoubleStruckCapitalJ]a\)\(\ \)\)},
              {"c", "\[DoubleStruckCapitalJ]a", "\[DoubleStruckCapitalJ]b"}
              }]}]}], "\[IndentingNewLine]", 
      RowBox[{"   "}]}], "Input",
    PageWidth->PaperWidth,
    FontSize->9,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  PageWidth->WindowWidth,
  FontFamily->"Courier New",
  FontSize->9],

Cell[TextData[{
  "\tI call the symbolic determinant factors ",
  StyleBox["sizes",
    FontWeight->"Bold"],
  ", and the list of sizes are the ",
  StyleBox["shape",
    FontWeight->"Bold"],
  ". (Hoops conserve their shape.)  ",
  StyleBox["One or more determinant factor is destroyed on folding",
    FontWeight->"Bold"],
  ". C4C2 has 6 sizes, C4 has 3, and C4c a single factor. The quaternion \
group has four linear and one (repeated) quadratic factor whilst the \
quaternion algebra loses the linear factors. C9 has 3 factors, C9J only one. \
\n\tAs each factor is a symmetry, each signed algebra is super-symmetric \
(sic, by an accident of nomenclature) to the (larger) parent Moufang loop. \
A",
  StyleBox[" ",
    FontWeight->"Bold"],
  "few Hoops (including \[DoubleStruckCapitalR], \[DoubleStruckCapitalC], \
\[DoubleStruckCapitalH] & \[DoubleStruckCapitalO]) are ",
  StyleBox["degenerate",
    FontWeight->"Bold"],
  " because they have lost all but one factor and so the inverses cannot \
split into partial fractions. Sizes can be zero, and division by a vec with a \
zero size would appear to give an infinite result. This is eliminated by the \
convention that a zero-sized vector ",
  StyleBox["projects",
    FontWeight->"Bold"],
  " vecs into a ",
  StyleBox["sub-algebra",
    FontWeight->"Bold"],
  " in which this size is constrained to be zero. Consequently, the inverse \
is also in the sub-algebra. Conic sections provide an analogy - their \
distance from a plane is zero and the 3D cone is reduced to a 2D figure of \
reduced symmetry. (Projection reduces symmetry.) To maintain the key \
conservative property, ",
  StyleBox["remainders",
    FontWeight->"Bold"],
  " have to be introduced. If multiplication (or division, which is \
multiplication by an inverse) would give a result which has lost some sizes, \
these sizes are ",
  StyleBox["ejected",
    FontWeight->"Bold"],
  " as remainders. This has physical analogies. When \"particles\" decay or \
interact, various symmetries are conserved by ejecting other \"particles\". \
In the case of ",
  StyleBox["Dozal",
    FontWeight->"Bold"],
  " algebra, different 12-element groups provide different (but overlapping) \
sets of symmetries resembling those of fundamental particles; this may \
correspond to different \"forces\" with different conservation laws.\n\tSome \
hoops conserve quadratic sizes (complex-conjugate factors are not conserved) \
that lead to ",
  StyleBox["polar or hyperbolic duals",
    FontWeight->"Bold"],
  ", and provide ",
  StyleBox["generalized powers and roots",
    FontWeight->"Bold"],
  ", with deBroglie-like continuous ",
  StyleBox["orbits",
    FontWeight->"Bold"],
  " and Planck-area-like squared radii or ",
  StyleBox["ulnae",
    FontWeight->"Bold"],
  ".\n\tHoops are fundamental to mathematical physics because they alone \
possess the conservation properties that lead (via Noether's theorem) to \
particles and forces. Groups are relevant because they are conservative, not \
because they are associative. The mathematical physicist's emphasis on \
symmetries as transformations using continuous groups (often based on complex \
matrices) appears to be unduly restrictive. Hoop symmetries act via \
operations, as well as transformations."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tHoop Algebras unify many traditional algebras. Some mathematical \"facts\
\" (such as \"minus one is unique\", which is proved by a circular argument \
using a rarely acknowledged axiom) are only true in the restricted context of \
the degenerate hoops \[DoubleStruckCapitalR], \[DoubleStruckCapitalC], \
\[DoubleStruckCapitalH], \[DoubleStruckCapitalO]. ",
  StyleBox["Primal numbers",
    FontWeight->"Bold"],
  " (unsigned continuous numbers, the half-line) can be developed from set \
theory via Natural numbers \[DoubleStruckCapitalN], unsigned Rational numbers \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DoubleStruckCapitalQ]\^+\)\)]],
  ", and a continuity axiom. Negation, subtraction, signed integers \
\[DoubleStruckCapitalZ], and signed continuous Reals \[DoubleStruckCapitalR] \
should NOT be introduced until indexed sets have been developed. As \
mathematics is widely thought of as operations on rings & fields (because \
they are easy to handle) integers and reals are (implicitly or explicitly) \
assumed to exist on page 1 of most mathematical texts. Negation and \
subtraction constitute a \"blind spot\" for many mathematicians; few texts \
even index the topics and only a handful consider their axiomatic definition. \
However, they are the special first case of ",
  StyleBox["generalized negation",
    FontWeight->"Bold"],
  " which uses equivalence relations on indexed ",
  StyleBox["sets",
    FontSlant->"Italic"],
  " to create ",
  StyleBox["generalized signs",
    FontWeight->"Bold"],
  ", orthogonal roots of unity. \[DoubleStruckCapitalZ] & \
\[DoubleStruckCapitalR] are the simplest examples, being equivalence \
relations on indexed ",
  StyleBox["pairs",
    FontSlant->"Italic"],
  " of natural or primal numbers; the C2 group provides the multiplication \
table. \[DoubleStruckCapitalC] is one equivalence relation on indexed ",
  StyleBox["quads",
    FontSlant->"Italic"],
  " of primal numbers; the C4 group provides the multiplication table. The C3 \
group provides (chiral) ",
  StyleBox["Terplex numbers",
    FontWeight->"Bold"],
  "; the Klein 4-group provides \"Study numbers\" aka \"Double numbers\"; the \
8-element Quaternion group provides the 4-element quaternion algebra, etc. \
Every \"real\" number is obtained from a pair of primal numbers; every \
\"terplex\" number is obtained from a triple of primal numbers, etc."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " package provides a database of over 800 entries - all the groups with up \
to 73 elements, some larger groups, octonions, and a number of other tables. \
Procedures are provided to create, identify, and investigate small groups, \
loops, and hoops. Key properties are provided for the hoop algebras for which \
compact symbolic inverses have been found. ",
  StyleBox["GroupLoopTest.nb",
    FontSlant->"Italic"],
  " contains general test procedures that confirm the correctness of the \
database and procedures.\n\tThe database entries relate to ordered quasigroup \
\"indexTables\" i.e. ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " Cayley multiplication tables with the first row and column containing the \
element indices {1,2,..,m} and with each (possibly signed) index occuring \
once in each row and column. Note that \"Cayley table multiplication\" is not \
\"Matrix Multiplication\", which transforms a single vector. It is \
implemented by the ",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  " procedure and operates on two vecs to create another vec and two \
(possibly null) remainders. \n\tMost loops in the database have at least one \
compact \"incantation\" that generates the Cayley table as a ",
  StyleBox["protoloop",
    FontWeight->"Bold"],
  " (a preferred isomorph). Different incantations use formulae, relators, \
permutations, matrix multiplication, and generalized Cayley-Dickson or \
Clifford procedures to create the tables. Apart from a few counter-examples \
with names ending in ",
  StyleBox["n",
    FontSlant->"Italic"],
  ", all the entries have the conservation property, making them Hoops. Many \
are loops, unsigned tables that multiply and divide sets of primal numbers; \
negation is not initially defined for them. They become Hoop Algebras when a \
second operation introduces some form of negation via generalized signs such \
as \"-\" , \"\[DoubleStruckCapitalJ]\" and \"\[ImaginaryI]\" (second, third \
and fourth roots of unity that create real, terplex and complex numbers). ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " loops can be folded to ",
  StyleBox["m/r\[Times]m/r",
    FontSlant->"Italic"],
  " multiplication tables under r-fold negation if the loop has r-fold \
symmetry. This often creates ",
  StyleBox["signed tables",
    FontWeight->"Bold"],
  " such as Complex algebra C4c, in which \[ImaginaryI].\[ImaginaryI] = -1, \
and the Quaternion Algebra Qr, in which i.j = k but j.i = -k. Many signed \
tables, with names ending in ",
  StyleBox["r, c,",
    FontSlant->"Italic"],
  " or ",
  StyleBox["J",
    FontSlant->"Italic"],
  ", are included. Every (unsigned) group ",
  StyleBox["G",
    FontSlant->"Italic"],
  " also defines algebras over the fields \[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC] etc. because the compositions ",
  StyleBox["GC2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["GC4",
    FontSlant->"Italic"],
  ", etc are also groups that fold to ",
  StyleBox["G",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tGeneralized signs ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^j\)]],
  " are distinct orthogonal ",
  StyleBox["r",
    FontSlant->"Italic"],
  "'th roots of unity. Projecting them onto the complex unit circle (as \
\"cyclotomic numbers\") distorts their properties and loses information. They \
occur as loop generators, as elements of generator matrices, in the bodies of \
\"signed tables\", in the definition of multi-phase sinusoids, and in ",
  StyleBox["generalizations of many functions that involve \[ImaginaryI] ",
    FontWeight->"Bold"],
  "in traditional mathematics. Some algebras involve more than one instance \
of an ",
  StyleBox["r",
    FontSlant->"Italic"],
  "'th root; in particular, \"-1\" is not the only square root of unity in \
many algebras and it is absent from some others."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe database includes some small group, loop, and signed tables that are \
pre-defined for use in prescriptions for larger loops. Procedures are \
supplied to generate tables, using several descriptions:- (1) an explicit \
table, (2) the GAP Group Atlas [6] identifier ",
  StyleBox["g",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["mmnn",
    FontSlant->"Italic"],
  " corresponding to ",
  StyleBox["GAP>SmallGroups(mm,nn) ",
    FontSlant->"Italic"],
  "(this Atlas is extended in the database to include many non-groups), (3) a \
mnemonic such as \"D3\", (4) incantations ca[], cd[], cl[], co[], ge[], ma[], \
md[],mg[], mp[], & ms[] that create index tables in different ways. (These \
two-letter abbreviations are used to reduce clutter in the database.)"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tProcedures are supplied to identify, characterise and manipulate Cayley \
tables. Any isomorphic Cayley table can be identified for most of the \
database tables. Group and subgroup properties can be tested. Functions that \
are conserved on multiplication (which I call ",
  StyleBox["sizes",
    FontWeight->"Bold"],
  "; the list of sizes is the ",
  StyleBox["shape",
    FontWeight->"Bold"],
  " of a vector in a specific hoop) are identified for over 80 small tables. \
They are the factors of a symbolic table determinant; sizes have not been \
found for larger tables because of computational limitations. Generalised \
multiplication and inversion procedures ",
  StyleBox["hoopTi",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["mes, ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["hoopIn",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["verse",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " are defined for algebras with conservative multiplication tables."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tWherever one or more sizes are zero (to within an arbitrary ",
  StyleBox["hmin",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "), ",
  StyleBox["hoopTi",
    FontSlant->"Italic"],
  StyleBox["mes",
    FontSlant->"Italic"],
  " implements ",
  StyleBox["conservative multiplication & division",
    FontWeight->"Bold"],
  "; results are constrained to a sub-space or sub-algebra and remainders are \
created to maintain conservation. The result is ",
  StyleBox["projected",
    FontWeight->"Bold"],
  " onto a sub-algebra with these sizes zeroed, and the lost sizes are ",
  StyleBox["ejected",
    FontWeight->"Bold"],
  " as ",
  StyleBox["remainders",
    FontWeight->"Bold"],
  " to maintain conservation. ",
  StyleBox["Division-by-zero is eliminated",
    FontWeight->"Bold"],
  " by this process; when one or more zero size of the denominator is \
non-zero in the numerator the result of division is a dividend (with the same \
zeroes) together with remainders containing the sizes that would otherwise be \
lost. This appears to be related to particle interactions and decays, where \
properties are similarly conserved."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tSome hoops have ",
  StyleBox["sinusoidal and/or hyperbolic dual forms",
    FontWeight->"Bold"],
  " that lead to generalized powers and generalized roots. Polar-duals \
generalize the polar description of the complex plane. Hoops with polar-dual \
forms have ",
  StyleBox["continuous orbits",
    FontWeight->"Bold"],
  " related to the \"discrete orbits\" of groups. Quadratic sizes become \
squared radii (releasing a degree of freedom); linear sizes displace the \
centre of rotation from zero. Orbit angle-parameters are \"hidden variables\" \
for the cartesian (vector-like) form; in the polar form they take up the \
degrees of freedom released by the squared radii. Constraining the \
determinants (ignoring any zero sizes) to be 1 defines ",
  StyleBox["unital sub-algebras",
    FontWeight->"Bold"],
  ". Their orbits resemble multi-phase deBroglie waves. A few hoops appear to \
have orbits with ",
  StyleBox["stable squared radii",
    FontWeight->"Bold"],
  " that resemble Planck areas. I conjecture that this relates to the limited \
number of stable particles. The ",
  StyleBox["Hexal and Dozal",
    FontWeight->"Bold"],
  " algebras (having 6 and 12 elements) are in a \"super/subsymmetric\" \
relationship; they have elements that act as unit spin and half-spin quantum \
operators that are neither real nor complex. Their Planck-scale orbits may \
correspond to lepton wave packets with 4 phases and quark wave packets with \
3, 6, & 12 phases, giving a non-point-like description of particles. A ",
  StyleBox["unit-velocity equation",
    FontWeight->"Bold"],
  " leads to stable wave-packet formulations for particles; mass corresponds \
to orbital velocities in Kaluza-Klein dimensions (rather than spatial \
velocities). Indirect composition of commutative loops such as C2, C3, & K \
gives non-commutative hoops such as D3C2, which ",
  StyleBox["pseudo-",
    FontWeight->"Bold"],
  StyleBox["powers",
    FontWeight->"Bold"],
  " and introduce uncertainty because the angles do not add on \
multiplication. The \"law of large numbers\" may arise from a ",
  StyleBox["reciprocal relationship",
    FontWeight->"Bold"],
  " between sizes of three sets of squared radii, that of the universe and \
that of the \"point-like\" particles (electrons), with other particles at \
their geometric mean near the Planck size."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tHoops unify and generalize many standard algebras and their conservation \
properties make them relevant to physics. I claim that primal numbers & hoop \
algebras provide new foundations for mathematical physics, transcending (but \
not discrediting) the approach based on complex numbers. They could not have \
been discovered without computer-aided maths. Their conserved properties \
provide the mathematics for half-spin, renormalization, supersymmetry, \
polarized and chiral waves, mass, hidden variables, the \"law of large \
numbers\" etc, and the limited number of fundamental particles. \
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3 Note on Nomenclature.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThe GAP Atlas [6] instruction ",
  StyleBox["SmallGroup(mm,nn)",
    FontSlant->"Italic"],
  " has been adapted to provide an unambiguous identifier ",
  StyleBox["g",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["mmnn",
    FontSlant->"Italic"],
  " for any loop in the database, by inserting non-groups of size ",
  StyleBox["mm",
    FontSlant->"Italic"],
  " after the groups of the same size. (The GAP numbering is not followed for \
",
  StyleBox["mm",
    FontSlant->"Italic"],
  ">73). E.g. ",
  StyleBox["g0201",
    FontSlant->"Italic"],
  " is the C2 group and ",
  StyleBox["g0202",
    FontSlant->"Italic"],
  " is the complex algebra multiplication table with elements ",
  StyleBox["r",
    FontSlant->"Italic"],
  " & \[ImaginaryI] and with \[ImaginaryI]\[CenterDot]\[ImaginaryI] = -",
  StyleBox["r",
    FontSlant->"Italic"],
  ". \"Protoloops\" (preferred isomorphic Cayley tables) are defined for most \
database entries. Where possible, these are defined in terms of \"relators\", \
usually ordered by decreasing complexity. Thus the 12-element groups have \
relators ",
  Cell[BoxData[
      \(TraditionalForm\`a\^3\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`c\^2\)]],
  "=1 or ",
  Cell[BoxData[
      \(TraditionalForm\`a\^3\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`b\^4\)]],
  "=1. Wherever a \"loop structure\" has been identified the loop has been \
given a specific mnemonic such as Q8 & Q12 for the 8- & 12-element \
quaternionic group tables. (Q12 is called T in Mathworld, ",
  Cell[BoxData[
      \(TraditionalForm\`Dic\_3\)]],
  " in Wikipedia). Some loops have been predefined as Cayley Tables \
(identified by their mnemonic) because they lack an incantation or are needed \
as building blocks for larger tables. The majority of protoloops can be \
created by ",
  StyleBox["makeProtoloop[mm,nn,o]",
    FontSlant->"Italic"],
  " (with abbreviation ",
  StyleBox["mp[mm,nn,o]",
    FontSlant->"Italic"],
  ") where the option ",
  StyleBox["o",
    FontSlant->"Italic"],
  " selects between different creation procedures if more than one has been \
defined. The procedure ",
  StyleBox["idc[L]",
    FontSlant->"Italic"],
  " will identify any conservative isomorphic loop table ",
  StyleBox["L",
    FontSlant->"Italic"],
  " for most of the entries in the database (the faster & more general ",
  StyleBox["id[L]",
    FontSlant->"Italic"],
  " does not test for conservation). ",
  StyleBox["loop[[mm]]",
    FontSlant->"Italic"],
  " lists the data entries for all the tables with ",
  StyleBox["mm",
    FontSlant->"Italic"],
  " elements; ",
  StyleBox["gd[mnemonic] ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["gd[mm,nn]",
    FontSlant->"Italic"],
  " (or ",
  StyleBox["gd[] ",
    FontSlant->"Italic"],
  "after ",
  StyleBox["id",
    FontSlant->"Italic"],
  " or ",
  StyleBox["idc ",
    FontSlant->"Italic"],
  "has been used) will provide ",
  StyleBox["mm,nn",
    FontSlant->"Italic"],
  " followed by the specific loop entry.\n\tCyclic groups are called C",
  StyleBox["n ",
    FontSlant->"Italic"],
  "rather than \[DoubleStruckCapitalZ]",
  StyleBox["n",
    FontSlant->"Italic"],
  " because \[DoubleStruckCapitalZ]",
  StyleBox["n",
    FontSlant->"Italic"],
  " implies a ring with subtraction. ",
  StyleBox["\n\t",
    FontSlant->"Italic"],
  "\tMnemonics: C",
  StyleBox["n",
    FontSlant->"Italic"],
  ", D",
  StyleBox["n/2",
    FontSlant->"Italic"],
  ", and Q",
  StyleBox["n",
    FontSlant->"Italic"],
  " are cyclic, generalised Dihedral, and Quaternion groups with ",
  StyleBox["n",
    FontSlant->"Italic"],
  " elements. A",
  StyleBox["n",
    FontSlant->"Italic"],
  " & S",
  StyleBox["n",
    FontSlant->"Italic"],
  " have ",
  StyleBox["n",
    FontSlant->"Italic"],
  " generators. Alt12n, Oct, D3M2 & D3M1n, etc., are \"alternative\" or \
\"square-associative, aa.b=a.ab\" loops. The M indicates that the loop is a \
\"Moufang double\" of D3 (etc.). Compound names XY, XiY, XpY are the direct \
or indirect compositions of X & Y. Xa, Xb, are second & third isomorphs of X. \
 Xr, XJ & Xc are conservative signed tables obtained from X that also provide \
conservative tables on expanding with C2 (r), C3 (J), or both C2 & C4 (c). \
Names ending with \"n\" (Q4n, C5n, C6n, C8n, Q8n, Alt12n,  etc.) are \
non-conservative loops."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Loops, Groups, & Hoops. ", "Section",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
  TextJustification->0.25,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Summary. ",
  StyleBox["Algebraic Loops are multiplication tables. Groups are associative \
loops; Moufang loops are loops with division and (in all commutative and some \
noncommutative cases) symmetry conservation. Introducing another operation \
via \"generalized signs\" ",
    FontSlant->"Italic"],
  StyleBox["fold",
    FontSlant->"Italic"],
  StyleBox["s conservative loops to \"Hoop algebras\" over generalized \
fields. Unlike the use of groups in mathematical physics (as matrices to \
transform a single vector) hoops multiply or divide two vectors to give a \
product and two, possibly null, remainder vectors.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe examples in this notebook are intended to be comprehensible by \
non-",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users can install the ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " package and activate it with the following instruction, so they can test \
the examples with other data, or carry out other investigations. "
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(TraditionalForm\`Quit[]\)], "Input"],

Cell[BoxData[
    \(<< GroupLoopHoop`\)], "Input",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " package is concerned with \"Finite Algebraic Loops\", with their subsets \
\"Moufang Loops\" and \"Groups\", and with the related symmetry-conserving \
partial-fraction division algebras or \"Hoops\". ",
  StyleBox["GroupLoopDemo.nb",
    FontSlant->"Italic"],
  " & ",
  StyleBox["HoopDemo.nb",
    FontSlant->"Italic"],
  " explain and demonstrate the concepts. They handle algebraic loops as \
normalized quasi-group Cayley index-tables with left and right units, i.e. as \
square tables with every index occurring once in each row and column, and \
with the first row and column defining the unit or neutral element. These \
tables define closed binary operations on unsigned elements, a.b=c.  The test \
routines abelianQ",
  StyleBox[", ",
    FontSlant->"Italic"],
  "associativeQ",
  StyleBox[",",
    FontSlant->"Italic"],
  " abelGrassmanQ, alternativeQ, amQ, cQ, conservativeQ,  entropicQ, flexQ, \
flexibleQ, hamiltonianQ, indexTableQ, jordanQ, jacobiQ, MoufangQ, negatableQ, \
quasigroupQ, reductiveQ, riffQ, & signedTableQ are provided, and test whether \
tables possess specific properties. Appendix A demonstrates these tests. The \
\"conservativeQ\" test uses the table to multiply two vectors A & B. It then \
tests whether Det[A].Det[B] = \[PlusMinus] Det[AB], where Det is the \
determinant of the loop inverse table mapped with the vector elements. A & B \
are random, but must not have zero determinants."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tTables with the associative property, (xy)z = x(yz) are \"groups\". \
Tables with the slightly less restrictive Moufang property zx.yz=(z.xy)z are \
Moufang loops. This covers all tables with a division property. I conjectured \
that all Moufang loops have another key property, conservation of the \
symbolic inverse determinant, but the D3Mn table disproves this conjecture. \
Frobenius established that all groups are conservative. This ",
  StyleBox["Frobenius conservation",
    FontWeight->"Bold"],
  " property is significant because Noether's law links coonservation to \
particles and forces.",
  " Extensive searching suggests that a few \"Moufang-doubled\" loops \
(Octonions, split-octonions, D4M2, and a few others, together with their \
direct compositions with Abelian groups) are the only non-associative \
conservative tables. Moufang loops are \"square-associative\", a(ab) = (a(ab) \
(also called alternative). Other square-associative tables lack both the \
conservation and the division properties. References to groups in much of \
mathematical physics should perhaps be to hoops; the key properties are \
division and conservation; associativity is not relevant."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tMoufang loops are defined in terms of multiplication. Division is \
multiplication by a multiplicative inverse, whose existence is guaranteed by \
the Moufang properties. Negation and subtraction are not involved in their \
definition, so elements of Moufang loops are unsigned. Describing Abelian \
Moufang loops in terms of an invertible addition operation is abuse of \
nomenclature.\n\tA second operation is needed to convert a loop into an \
algebra with addition and (generalized) subtraction. This is provided by \
equivalence relationships that \"fold\" an ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " loop that multiplies sets of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " unsigned elements to an (",
  StyleBox["m/r)\[Times](m/r)",
    FontSlant->"Italic"],
  " algebraic multiplication table that multiplies vecs of ",
  StyleBox["m/r",
    FontSlant->"Italic"],
  " signed elements. ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 2 or 4 gives real and complex vectors and algebras over the \
corresponding fields. Other ",
  StyleBox["r",
    FontSlant->"Italic"],
  " values provide generalized signs and define new \"rigs\" (rings without \
negation). The second operation often introduces signed products that are not \
included in the set of defining elements, so these tables are not loops. \
Hoops are algebras that pass the conservativeQ test; they are only introduced \
briefly here; ",
  StyleBox["HoopDemo.nb ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["Hoops.nb",
    FontSlant->"Italic"],
  " deal with them in greater detail. "
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Loop Properties, Loop & Signed Table creation.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". GroupLoopHoop.m provides a database of groups, loops & hoops, together \
with procedures to create, identify & manipulate them. This section \
demonstrates the creation & identification of loops & signed tables. Index \
Tables represent loops, m\[Times]m Cayley multiplication tables. Introducing \
r-fold negation converts loops into hoop algebras with tables of size m/r\
\[Times]m/r. These are often \"signed tables\" with some signed products. Ten \
table-creating procedures are described and demonstrated."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["3.1. Index & Cayley Tables, Loops, Table Identification. ", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThe ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " package includes a database of index tables. These are normalized \
quasi-group arrays with indices as elements. They describe a loop operation \
(usually called vector multiplication) for indexed sets of coefficients, \
A={",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  ",..}, which can be written ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\_1\) d\_1\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`d\_2\)]],
  "+... where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(d\_i\)\)\)]],
  " is a (loop) direction or (hoop) dimension. Multiplication AB gives C={",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  ",...} where ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k = \[Sum]\(a\_i\) b\_j\)]],
  ", with ",
  StyleBox["k=i.j",
    FontSlant->"Italic"],
  " in the loop. In Moufang Loops this operation has a (left & right) \
\"unit\" or \"1\" and multiplication of sets of coefficients is invertible, \
making division identical to multiplication. All groups are associative \
Moufang loops; all non-associative Moufang loops are square-associative (or \
alternative). Negation is not defined for loops, so they do not represent \
algebras until they have been \"folded\" via a second operation, introducing \
negation and additive elimination (generalized subtraction). This may give a \
\"signed table\" (Section 3.7) in which some products are signed indices. \
E.g. the 2-element complex algebra has elements {1, \[ImaginaryI]} with the \
signed product \[ImaginaryI].\[ImaginaryI] = -1; it is folded from the \
4-element C4 group; the 4-element Quaternion algebra {1, i, j, k} has i.j = k \
but j.i = -k, and is folded from the 8-element quaternion group. \
\"Symmetry-conserving\" tables (I call them \"Hoops\") are discussed in \
Section 4.3. They define partial-fraction-division algebras; tables folded \
from loops with this property are also conservative.\n\tCayley tables include \
index tables, but may also have symbols or coefficients mapped onto the \
indices, to give symbolic or general Cayley tables. The ",
  StyleBox["caylindex",
    FontSlant->"Italic"],
  " procedure converts a table to an index table, whilst ",
  StyleBox["gmap",
    FontSlant->"Italic"],
  " reverses the process, mapping a ",
  StyleBox["vec",
    FontSlant->"Italic"],
  " (an indexed list of symbols and/or coefficients, which is sometimes a \
vector) onto an index table, respecting signs.\n\tThe identification ",
  StyleBox["g",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["mmnn",
    FontSlant->"Italic"],
  " (based on ",
  StyleBox["SmallGroup( mm, nn)",
    FontSlant->"Italic"],
  " in the GAP Atlas, and extended to include all the non-groups in the \
database) can be found for most conservative (Group, Moufang Loop, & Hoop) \
table isomorphs with up to 73 elements and for some non-associative and \
larger tables. ",
  StyleBox["nn",
    FontSlant->"Italic"],
  " is the position in the sub-list of loops with ",
  StyleBox["mm",
    FontSlant->"Italic"],
  " elements",
  StyleBox[".",
    FontSlant->"Italic"],
  " The ",
  StyleBox["id",
    FontSlant->"Italic"],
  " procedure uses a diagnostic property ",
  StyleBox["dico ",
    FontSlant->"Italic"],
  "(diagonal count), together with specific tests where this is not unique. \
Some database tables can only be provisionally identified because there may \
be non-isomorphic non-conservative tables with the same ",
  StyleBox["dico",
    FontSlant->"Italic"],
  ". \n\t",
  StyleBox["loop[[mm,nn]]",
    FontSlant->"Italic"],
  ",",
  StyleBox[" gd[\"mnemonic\"], gd[mm,nn] ",
    FontSlant->"Italic"],
  "or ",
  StyleBox["gd[]",
    FontSlant->"Italic"],
  " all supply the database entry. The first two entries in ",
  StyleBox["gd[]",
    FontSlant->"Italic"],
  " are ",
  StyleBox["mm,nn",
    FontSlant->"Italic"],
  " for the \"target loop\", i.e. the one currently in use",
  StyleBox[".",
    FontSlant->"Italic"],
  " The database also includes information about the ",
  StyleBox["shape",
    FontSlant->"Italic"],
  ", ",
  StyleBox["polar form",
    FontSlant->"Italic"],
  " and ",
  StyleBox["plex",
    FontSlant->"Italic"],
  " (Sections 4.3, 6.2, 7.) of many small groups.\n\tExample 1 demonstrates \
tables and mappings, and shows that the ",
  StyleBox["id",
    FontSlant->"Italic"],
  " procedure identifies a table whatever its form, provided that it is in \
the database. (As the input may be incomprehensible to non-",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users, input is hidden in \"closed cells\"; it can be revealed by \
un-checking the ",
  StyleBox["Cell<Cell Properties<Cell open",
    FontSlant->"Italic"],
  " box. The frequent",
  StyleBox[" \\n",
    FontSlant->"Italic"],
  " entries in the input are new-line symbols, used to organise the output.)"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 1. Groups C3 & C4", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{\"The group {{a,b,c},{b,c,a},{c,a,b}} is \", \
id[caylindex[{{a,b,c},{b,c,a},{c,a,b}}]],
\"\\nwith {mm,nn} = \",{mm,nn},
\"\\nand index Table \",C3//tf,
\"\\n{3.,2.+\[ImaginaryI], -4.} mapped onto C3 gives\", gmap[C3,{3.,2.+\
\[ImaginaryI], -4.}]//tf,
\"\\nListForm C4 is \",C4,\"\\nTraditional form C4 is\",C4//tf,\"\\nMapping \
{a,b,c,d} onto C4 gives a symbolic table\",gmap[C4,{a,b,c,d}]//tf}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"The group {{a,b,c},{b,c,a},{c,a,b}} is \"\>", 
        ",", "\<\"C3\"\>", ",", "\<\"\\nwith {mm,nn} = \"\>", ",", \({3, 1}\),
         ",", "\<\"\\nand index Table \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "3", "1"},
                  {"3", "1", "2"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\n{3.,2.+\[ImaginaryI], -4.} mapped onto C3 gives\"\>", 
        ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {
                    "3.`", \(\(\(2.`\)\(\[InvisibleSpace]\)\) + \[ImaginaryI]\
\), \(-4.`\)},
                  {\(\(\(2.`\)\(\[InvisibleSpace]\)\) + \[ImaginaryI]\), \
\(-4.`\), "3.`"},
                  {\(-4.`\), 
                    "3.`", \(\(\(2.`\)\(\[InvisibleSpace]\)\) + \[ImaginaryI]\
\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nListForm C4 is \"\>", 
        ",", \({{1, 2, 3, 4}, {2, 3, 4, 1}, {3, 4, 1, 2}, {4, 1, 2, 3}}\), 
        ",", "\<\"\\nTraditional form C4 is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "3", "4", "1"},
                  {"3", "4", "1", "2"},
                  {"4", "1", "2", "3"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nMapping {a,b,c,d} onto C4 gives a symbolic table\"\>", 
        ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b", "c", "d"},
                  {"b", "c", "d", "a"},
                  {"c", "d", "a", "b"},
                  {"d", "a", "b", "c"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tMost  ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " procedures accept ",
  StyleBox["TraditionalForm",
    FontSlant->"Italic"],
  " array as well as ",
  StyleBox["ListForm",
    FontSlant->"Italic"],
  " as input. Example 2 shows this for the Klein 4-group \"K\"",
  StyleBox[".",
    FontSlant->"Italic"],
  " The different ways of accessing the data about a loop are demonstrated:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 2. TraditionalForm input, Loop Data Access.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{\"TraditionalForm input such \
as\",tst={{1,2,3,4},{2,1,4,3},{3,4,1,2},{4,3,2,1}}//tf,\" is accepted.\\nThis \
group is\",
  id[tst],\"\\nLoop data can be accessed in different ways:-\\nloop[[4,1]] \
gives\",loop[[4,1]],\"\\ngd[4,1] gives\",gd[4,1],\"\\ngd[\\\"K\\\"] \
gives\",gd[\"K\"],\"\\ngd[]    gives\",gd[]}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"TraditionalForm input such as\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "1", "4", "3"},
                  {"3", "4", "1", "2"},
                  {"4", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\" is accepted.\\nThis group is\"\>", 
        ",", "\<\"K\"\>", 
        ",", "\<\"Loop data can be accessed in different ways:-\\nloop[[4,1]] \
gives\"\>", 
        ",", \({"K", {4.`}, 0, 
          "co[C2,C2]", {2, 2}, {}, {1, 2}, {1, 2}, {1, 2}}\), 
        ",", "\<\"\\ngd[4,1] gives\"\>", 
        ",", \({4, 
          1, {"K", {4.`}, 0, 
            "co[C2,C2]", {2, 2}, {}, {1, 2}, {1, 2}, {1, 2}}}\), 
        ",", "\<\"\\ngd[\\\"K\\\"] gives\"\>", 
        ",", \({4, 
          1, {"K", {4.`}, 0, 
            "co[C2,C2]", {2, 2}, {}, {1, 2}, {1, 2}, {1, 2}}}\), 
        ",", "\<\"\\ngd[]    gives\"\>", 
        ",", \({4, 
          1, {"K", {4.`}, 0, 
            "co[C2,C2]", {2, 2}, {}, {1, 2}, {1, 2}, {1, 2}}}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tInformation about the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " procedures (",
  StyleBox["Usage",
    FontSlant->"Italic"],
  ") can always be found by the \"?\" help system, and the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " implementation by \"??\". \"Usage\" for the ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " package can be seen in Section 2.7 of that package; Example 3 gives it \
for ",
  StyleBox["id & dico",
    FontSlant->"Italic"],
  ", which should be read carefully as the information is not repeated in \
this notebook (Warning! ",
  StyleBox["??id",
    FontSlant->"Italic"],
  " generates several pages of irrelevant output!):-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 3a. Help system, ?id.", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["?id", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("id[G_,L_:{}] uses a range of tests to identify 'G', which may be a \
name, or {mm,nn}, or an indexTable; if an index-list 'L' is specified, the \
corresponding subgroup of 'G' is identified. Associativity is not tested (for \
speed of execution) so unknown groupoids may be wrongly identified. Names: \
Cn, Dn/2, & Qn are cyclic or generalised Dihedral and Quaternion groups with \
n elements. An & Sn have n generators. Alt12n, Oct, D4Mn etc  are 'Square \
associative' or 'alternative aa.b=a.ab' groupoids. XY, XiY,XpY are the direct \
or indirect compositions of X & Y. Xa is a second isomorph of X. Xr & Xc are \
conservative signed tables obtained from X that also provide conservative \
algebras on expanding with C2 or (C2 & C4). Loops with names ending in n are \
not conservative. Loops with M in the name are non-associative Moufang loops. \
gnnmm is GAP SmallGroups(mm,nn). If the name contains ? identification is \
provisional because all groups of that size have not been distinguished. The \
global variables glo, gmn,mm,& nn are set by id. gmn is returned and gd[] \
will provide more details."\)], "Print",
  CellTags->"Info3368012412-9805623"]
}, Open  ]],

Cell[TextData[{
  "\tIdentification employs a variety of \"table invariants\" to distinguish \
between different conservative tables. These are functions that are \
unaffected by re-ordering a table. The most important is ",
  StyleBox["dico",
    FontSlant->"Italic"],
  ", the \"diagonal count\", which is a generalized signature for a hoop \
table:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 3b. Help system,  ?dico, ?abbr.", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[TextData[{
  "\n{\"",
  StyleBox["dico[g3207] =\",",
    FontSlant->"Italic"],
  "dico[makeProtoloop[\"g3207\"]]}\n?dico\n?abbr"
}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"dico[g3207] =", {12, 4\_5, 15}}\)], "Output"],

Cell[BoxData[
    \("dico[g_:glo] is the 'diagonal count' i.e. the count of elements of 'g' \
in the table diagonal, compressed via 'abbr' (q.v.). The first entry is the \
number of square roots of unity, and is signed if 'g' is signed, and is real \
if 'g' is abelian.  An extra diagnostic integer is added for tables with m = \
32, 48, 54, 64 or 72"\)], "Print",
  CellTags->"Info3368012496-7335081"],

Cell[BoxData[
    \("abbr[t_,o_:1] is used by 'dico' & 'trico' to create an abbreviation \
such as {12,\!\(4\_5\),15} in which subscripts indicate numbers of \
appearances of elements in a table diagonal, with the first element real for \
abelian and negated for signed tables. 'dico' has another discriminant \
appended in cases with many tables of the same size. In the example, \
dico[makeProtoloop['g3207']], there are 12 occurences of the unit; 5 other \
elements occur 4 times (total=32), and there are 15 subgroups of 4 elements."\
\)], "Print",
  CellTags->"Info3368012496-1829508"]
}, Open  ]],

Cell[TextData[{
  "\tNote that ",
  StyleBox["dico",
    FontSlant->"Italic"],
  " is the second element of ",
  " ",
  StyleBox["loop[[mm,nn]]",
    FontSlant->"Italic"],
  ", following the table mnemonic."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tMost of the procedures require that the argument is a quasigroup, so \
they apply ",
  StyleBox["gpd",
    FontSlant->"Italic"],
  " to ensure that arrays have the required properties. Example 4 tests a \
variation on the C3 example. The quasigroup property is so fundamental to the \
package that operations are aborted if it is absent."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example 4. Alter one element of C3 and the result is rejected as it is not a \
quasigroup.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],

Cell[CellGroupData[{

Cell["\<\
gpd[{{a,b,c},{b,d,a},{d,a,b}}]
?gpd\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[\({{a, b, c}, {b, d, a}, {d, a, b}}\),
          Short], "\[InvisibleSpace]", "\<\" is not a groupoid\"\>"}],
      SequenceForm[ 
        Short[ {{a, b, c}, {b, d, a}, {d, a, b}}], " is not a groupoid"],
      Editable->False]], "Print"],

Cell[BoxData[
    \($Aborted\)], "Output"],

Cell[BoxData[
    \("gpd[gg_] is used on function arguments that should be groupoids (i.e. \
magmas, loops, quasigroups). It removes any TraditionalForm wrapper and \
rejects non-groupoids by 'Abort[]'. The first row must contain the elements, \
which may be matrices; signed elements are permitted in the body of the \
table."\)], "Print",
  CellTags->"Info3368012554-3458326"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2. Creating Cayley Tables.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tProcedures are supplied to construct loops as indexTables from formulae, \
compositions, relators, cycles, permutations, \"unitary monomial matrices\", \
and \"univectors\". Each construction is demonstrated in the following \
subsections. Some skeleton routines are shown, to allow programmers to see \
what is going on. They are non-executable because they omit all checks and \
special cases.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[{
  "3.2.1. Creating Cayley Tables with ",
  StyleBox["ca",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tExample 5 uses the procedure ",
  StyleBox["ca",
    FontSlant->"Italic"],
  " to create the 6-element tables for the groups C6 (\[TildeEqual] C3C2) and \
D3. ",
  StyleBox["ca",
    FontSlant->"Italic"],
  " employs a fast formula:-  i*j \[RightArrow]Mod[i+j,m] for even i,  i*j \
\[RightArrow] Mod[i+j*k,m] for odd ",
  StyleBox["i",
    FontSlant->"Italic"],
  ". It uses an optional parameter ",
  StyleBox["k",
    FontSlant->"Italic"],
  " to create non-abelian groups; ",
  StyleBox["m",
    FontSlant->"Italic"],
  " is the number of elements. A skeleton implementation is given below. (The \
programmed formula is complicated by the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " indices being {1,..,m} rather than {0,...,m-1})."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ca[m_, k_:  0]\), ":=", 
        RowBox[{"(*", 
          StyleBox[\(skeleton . \ non - executable\),
            FontColor->RGBColor[1, 0, 0]], "*)"}], 
        "\[IndentingNewLine]", \(Table[
          Mod[i + If[EvenQ[i], j\ k - k + 1, j] - 1, m, 
            1], \[IndentingNewLine]{i, m}, {j, m}]\)}], ";"}]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  "Example 5. Create and identify two 6-element Tables using ",
  StyleBox["ca",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\"\<ca[6] \!\(\*
StyleBox[\"creates\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(c6 = ca[6]; 
        id\ [c6]\), ",", \(c6 // tf\), ",", "\"\<ca[6,5] \!\(\*
StyleBox[\"creates\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(d3 = ca[6, 5]; 
        id\ [d3]\), ",", \(d3 // tf\)}], "}"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"ca[6] \\!\\(\\* \
StyleBox[\\\"creates\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", "\<\"C3C2\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "4", "5", "6", "1"},
                  {"3", "4", "5", "6", "1", "2"},
                  {"4", "5", "6", "1", "2", "3"},
                  {"5", "6", "1", "2", "3", "4"},
                  {"6", "1", "2", "3", "4", "5"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"ca[6,5] \\!\\(\\* StyleBox[\\\"creates\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", ",", "\<\"D3\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "1", "6", "5", "4", "3"},
                  {"3", "4", "5", "6", "1", "2"},
                  {"4", "3", "2", "1", "6", "5"},
                  {"5", "6", "1", "2", "3", "4"},
                  {"6", "5", "4", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tNote that Dihedral groups such as D3 are given by ",
  StyleBox["ca[2n,2n-1]",
    FontSlant->"Italic"],
  " and generalized quaternion groups by ",
  StyleBox["ca[2n,n-1].",
    FontSlant->"Italic"],
  " In general",
  StyleBox[" ca[i,j]",
    FontSlant->"Italic"],
  " often generates groupoids that are not Moufang loops."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3.2.2. Composing Cayley Tables with ",
  StyleBox["co",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tA skeleton implementation of the composition procedure, ",
  StyleBox["co[g,h,o]",
    FontSlant->"Italic"],
  ", is given below. It puts the elements of the second array, ",
  StyleBox["h",
    FontSlant->"Italic"],
  ", suitably offset, in the place of each element of the first array ",
  StyleBox["g",
    FontSlant->"Italic"],
  ". The composition is \"indirect\" if the parameter ",
  StyleBox["a",
    FontSlant->"Italic"],
  "=2. The full procedure handles some other values of ",
  StyleBox["a",
    FontSlant->"Italic"],
  ". (The expression mod[t,m,1] gives indices in the range 1 to m.)"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{
      RowBox[{\(co[g_, h_, a_:  0]\), ":=", 
        RowBox[{"(*", 
          StyleBox[\(Skeleton . \ Shortened, \ non - executable\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["*)",
            FontColor->RGBColor[1, 0, 0]]}], 
        "\[IndentingNewLine]", \(Module[{g1 = \(Dimensions[
                  g]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
            h1 = \(Dimensions[h]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
            im, lm, result = {}, t, m}, 
          m = g1\ h1; \[IndentingNewLine]Do[
            lm = l - 1; \[IndentingNewLine]Do[
              t = {}; \[IndentingNewLine]Do[\[IndentingNewLine]Do[\
\[IndentingNewLine]If[a \[Equal] 2, 
                    If[EvenQ[l] && i > 1, 
                      AppendTo[
                        t, \((h\[LeftDoubleBracket]k, 
                                  l\[RightDoubleBracket] - 1)\) g1 + 
                          g\[LeftDoubleBracket]g1 + 2 - i, 
                            j\[RightDoubleBracket]], 
                      AppendTo[
                        t, \((h\[LeftDoubleBracket]k, 
                                  l\[RightDoubleBracket] - 1)\) g1 + 
                          g\[LeftDoubleBracket]i, 
                            j\[RightDoubleBracket]]], \
\[IndentingNewLine]AppendTo[
                      t, \((h\[LeftDoubleBracket]k, l\[RightDoubleBracket] - 
                              1)\) g1 + 
                        g\[LeftDoubleBracket]i, 
                          j\[RightDoubleBracket]]], \[IndentingNewLine]{i, 
                    g1}], \[IndentingNewLine]{k, 
                  h1}]; \[IndentingNewLine]AppendTo[result, 
                Mod[t, m, 1]], \[IndentingNewLine]{j, 
                g1}], \[IndentingNewLine]{l, 
              h1}]; \[IndentingNewLine]result]\)}], ";"}]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  "\tExample 6a uses ",
  StyleBox["co ",
    FontSlant->"Italic"],
  "to compose the ",
  StyleBox["C3 ",
    FontSlant->"Italic"],
  "table with ",
  StyleBox["C4",
    FontSlant->"Italic"],
  ", both directly and indirectly. The results are groups ",
  StyleBox["C3C4",
    FontSlant->"Italic"],
  " & ",
  StyleBox["Q12",
    FontSlant->"Italic"],
  ".  Their tables are shown. Direct composition of abelian loops gives an \
abelian loop; indirect compositions gives non-abelian loops."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 6a. Direct & Indirect Composition of C3 & C4 using ",
  StyleBox["co",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"Composing\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"with\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C4\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)co[C3,C4], \!\(\*
StyleBox[\"gives\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"abelian\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"table\",\nFontSlant->\"Italic\"]\)\>\"", 
        ",", \(idc[tst = co[C3, C4]]\), ",", \(gd[]\), ",", "\"\<\\n\>\"", 
        ",", \(tst // tf\), ",", "\"\<\!\(\*
StyleBox[\"Indirect\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"composition\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"with\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C4\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)co[C3,C4,2],\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"non\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"abelian\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"table\",\nFontSlant->\"Italic\"]\)\>\"", 
        ",", \(idc[tst1 = co[C3, C4, 2]]\), ",", "\"\<\\n\>\"", ",", \(gd[]\),
         ",", "\"\<\\n \>\"", ",", "\[IndentingNewLine]", \(tst1 // tf\)}], 
      "}"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"\\!\\(\\* \
StyleBox[\\\"Composing\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"C3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"C4\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)co[C3,C4], \\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"the\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"abelian\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"table\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", "\<\"C3C4\"\>", 
        ",", \({12, 
          2, {"C3C4", {2.`, 2\_5}, 0, 
            "co[C3,C4]", {3, 4}, {}, {10, 12}, {8, 15}, {26}}}\), 
        ",", "\<\"\\n\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", 
                    "12"},
                  {"2", "3", "1", "5", "6", "4", "8", "9", "7", "11", "12", 
                    "10"},
                  {"3", "1", "2", "6", "4", "5", "9", "7", "8", "12", "10", 
                    "11"},
                  {"4", "5", "6", "7", "8", "9", "10", "11", "12", "1", "2", 
                    "3"},
                  {"5", "6", "4", "8", "9", "7", "11", "12", "10", "2", "3", 
                    "1"},
                  {"6", "4", "5", "9", "7", "8", "12", "10", "11", "3", "1", 
                    "2"},
                  {"7", "8", "9", "10", "11", "12", "1", "2", "3", "4", "5", 
                    "6"},
                  {"8", "9", "7", "11", "12", "10", "2", "3", "1", "5", "6", 
                    "4"},
                  {"9", "7", "8", "12", "10", "11", "3", "1", "2", "6", "4", 
                    "5"},
                  {"10", "11", "12", "1", "2", "3", "4", "5", "6", "7", "8", 
                    "9"},
                  {"11", "12", "10", "2", "3", "1", "5", "6", "4", "8", "9", 
                    "7"},
                  {"12", "10", "11", "3", "1", "2", "6", "4", "5", "9", "7", 
                    "8"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\!\\(\\* \
StyleBox[\\\"Indirect\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"composition\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"C3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"C4\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)co[C3,C4,2],\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"the\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"non\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"-\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"abelian\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"table\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", "\<\"Q12\"\>", ",", "\<\"\\n\"\>", 
        ",", \({12, 
          1, {"Q12", {2, 2\_2, 6}, 0, 
            "co[C3,C4,2]", {3, 4}, {"ba" \[Rule] "a2b"}, {10, 13}, {8, 
              36}, {8, 16}}}\), ",", "\<\"\\n \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", 
                    "12"},
                  {"2", "3", "1", "5", "6", "4", "8", "9", "7", "11", "12", 
                    "10"},
                  {"3", "1", "2", "6", "4", "5", "9", "7", "8", "12", "10", 
                    "11"},
                  {"4", "6", "5", "7", "9", "8", "10", "12", "11", "1", "3", 
                    "2"},
                  {"5", "4", "6", "8", "7", "9", "11", "10", "12", "2", "1", 
                    "3"},
                  {"6", "5", "4", "9", "8", "7", "12", "11", "10", "3", "2", 
                    "1"},
                  {"7", "8", "9", "10", "11", "12", "1", "2", "3", "4", "5", 
                    "6"},
                  {"8", "9", "7", "11", "12", "10", "2", "3", "1", "5", "6", 
                    "4"},
                  {"9", "7", "8", "12", "10", "11", "3", "1", "2", "6", "4", 
                    "5"},
                  {"10", "12", "11", "1", "3", "2", "4", "6", "5", "7", "9", 
                    "8"},
                  {"11", "10", "12", "2", "1", "3", "5", "4", "6", "8", "7", 
                    "9"},
                  {"12", "11", "10", "3", "2", "1", "6", "5", "4", "9", "8", 
                    "7"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Example 6b shows that three different 48-element groups can be created by \
direct or indirect composition of D3 & Q8.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 6b. Direct & Indirect Composition of D3 & Q8 using ",
  StyleBox["co",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"Composing\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"D3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"with\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Q8\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)co[D3,Q8], \!\(\*
StyleBox[\"gives\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"non\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"abelian\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"table\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(tst = co[D3, Q8]; 
        idc[tst]\), ",", \(gd[]\), ",", "\"\<\\n\>\"", ",", "\"\<\!\(\*
StyleBox[\"Indirect\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"composition\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"D3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"with\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Q8\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)co[Q8,D3,2] &\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)co[Q8,D3,4],\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"two\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"non\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"abelian\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"tables\",\nFontSlant->\"Italic\"]\)\>\"", 
        ",", \(tst1 = co[Q8, D3, 2]; "\<\n\>"\), ",", \(idc[tst1]\), 
        ",", \(gd[]\), ",", \(tst1 = co[Q8, D3, 4]; "\<\nand\>"\), 
        ",", \(idc[tst1]\), ",", "\"\<\\n\>\"", ",", \(gd[]\)}], 
      "}"}], "\[IndentingNewLine]", \(tst1 =. ;\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"\\!\\(\\* \
StyleBox[\\\"Composing\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"D3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Q8\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)co[D3,Q8], \\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"the\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"non\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"-\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"abelian\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"table\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", "\<\"Q8D3\"\>", 
        ",", \({48, 
          40, {"Q8D3", {8, 2\_2, 6\_2, 24}, 0, 
            "co[Q8,D3]", {2, 2, 2, 3, 2}, {"aa" \[Rule] "c", 
              "bb" \[Rule] "c", "ba" \[Rule] "abc", "abab" \[Rule] "c", 
              "ed" \[Rule] "dde"}, {}, {}, {14, 27, 30}}}\), 
        ",", "\<\"\\n\"\>", 
        ",", "\<\"\\!\\(\\* \
StyleBox[\\\"Indirect\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"composition\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"D3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Q8\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)co[Q8,D3,2] &\\!\\(\\* StyleBox[\\\" \\\",\
\\nFontSlant->\\\"Italic\\\"]\\)co[Q8,D3,4],\\!\\(\\* StyleBox[\\\"gives\\\",\
\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"two\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"non\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"-\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"abelian\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"tables\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", "\<\"\\n\"\>", ",", "\<\"Q8iD3\"\>", 
        ",", \({48, 
          17, {"Q8iD3", {14, 2\_2, 6\_5}, 0, 
            "co[Q8,ca[6,5],2]", {2, 2, 2, 2, 3}, {"bb" \[Rule] "d", 
              "cc" \[Rule] "d", "ba" \[Rule] "abc", "ca" \[Rule] "adc", 
              "ea" \[Rule] "aee", "cb" \[Rule] "bcd"}, {}, {}, {}}}\), 
        ",", "\<\"\\nand\"\>", ",", "\<\"Q8pD3\"\>", ",", "\<\"\\n\"\>", 
        ",", \({48, 
          41, {"Q8pD3", {20, 2\_2, 6\_2, 12}, 0, 
            "co[Q8,D3,4]", {2, 2, 2, 2, 3}, {"bb" \[Rule] "d", 
              "cc" \[Rule] "d", "ca" \[Rule] "acd", "ea" \[Rule] "aee", 
              "cb" \[Rule] "bcd"}, {}, {}, {}}}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tDirect and indirect compositions create larger tables, with more \
symmetries. The reverse procedure, \"folding\" from larger to smaller tables, \
creates \"supersymmetry\" (",
  StyleBox["sic",
    FontSlant->"Italic"],
  " because of the way that physicists have defined supersymmetry); some \
symmetries are lost. The indirect compositions are all non-commutative, and \
so this may be a paradigm for boson-fermion supersymmetry, where the bosons \
commute and the fermions anti-commute. The ",
  StyleBox["ts",
    FontSlant->"Italic"],
  " procedure reverses direct composition. I have not looked for a \
corresponding indirect composition reversal. "
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3.2.3. Creating Matrix Cayley Tables with ",
  StyleBox["ma",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tMost groups can be represented (in many isomorphic ways) by elements \
that are square matrices, using dot-multiplication as the group operation. \
The procedure ",
  StyleBox["ma",
    FontSlant->"Italic"],
  " inverts this, finding the group generated by dot-multiplication of a \
given set of square matrices. Whenever a dot-product gives a new matrix it is \
added to the list of elements, until the group closes or the size limit is \
exceeded. A skeleton version is supplied. Defining matrices are specified in \
the database for many loops. ",
  StyleBox["st",
    FontSlant->"Italic"],
  " is conversion table that converts thematrices to indices."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{\(ma[{mm__}, maxel_:  73, o_:  0]\), ":=", 
      RowBox[{"(*", 
        StyleBox[\(Skeleton . \ Abbreviated, \ non - executable\),
          FontColor->RGBColor[1, 0, 0]], " ", "*)"}], 
      StyleBox["\[IndentingNewLine]",
        FontColor->RGBColor[1, 0, 0]], 
      RowBox[{"Module", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\(m = {mm}\), ",", "g", ",", \(j = 2\), ",", \(k = 1\), 
              ",", "lg", ",", \(mx = 2\), ",", "n", ",", 
              RowBox[{"rs", "=", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox[
                        StyleBox["\[DoubleStruckCapitalJ]",
                          FontWeight->"Plain"], "any_"], "\[Rule]", 
                      SuperscriptBox[
                        StyleBox["\[DoubleStruckCapitalJ]",
                          FontWeight->"Plain"], \(Mod[any, 3]\)]}], 
                    ",", \(\[DoubleStruckK]\^any_ \[Rule] \
\[DoubleStruckK]\^Mod[any, 2]\)}], "}"}]}], ",", "st"}], "}"}], 
          ",", \(g = Insert[m, IdentityMatrix[Length[m[\([1, 1]\)]]], 1]; 
          While[lg = Length[g]; j \[LessEqual] lg, \(k++\); 
            n = g\[LeftDoubleBracket]j\[RightDoubleBracket] . 
                  g\[LeftDoubleBracket]
                    k\[RightDoubleBracket] /. \[InvisibleSpace]rs; 
            If[\(! MemberQ[g, n]\), AppendTo[g, n]; \(mx++\); 
              If[mx > maxel, k = 9999; j = mx]]; 
            If[k \[GreaterEqual] lg, k = 1; \(j++\); 
              If[j > maxel, g = {{}}; Goto[tag]]]]; 
          g = Table[
              g\[LeftDoubleBracket]i\[RightDoubleBracket] . 
                  g\[LeftDoubleBracket]j\[RightDoubleBracket] /. rs, {i, 
                lg}, {j, lg}]; Label[tag]; 
          st = Table[
              g\[LeftDoubleBracket]j, 1\[RightDoubleBracket] -> j, {j, lg, 
                1, \(-1\)}]; \ng /. st\)}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  "\tExample 7 sets up the three Pauli-\[Sigma] matrices [3, p51] and uses ",
  StyleBox["ma",
    FontSlant->"Italic"],
  " to dot-multiply them to give a 16-element group; the 16 matrix elements \
are shown. The result is an isomorph of the ",
  StyleBox["P16",
    FontSlant->"Italic"],
  " protoloop, which is also shown. These tables have physical significance \
(discussed elsewhere) because they possess the Riemann metric."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Ex. 7. Using ",
  StyleBox["ma",
    FontSlant->"Italic"],
  " to generate a group from Pauli Matrices."
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\"\<The 3 \[Sigma] matrices are \>\"", 
        StyleBox[",",
          FontSlant->"Italic"], 
        StyleBox[" ",
          
          FontSlant->
            "Italic"], \(\[Sigma]\_1 = {{0, 1}, {1, 0}}; \[Sigma]\_1 // tf\), 
        ",", \(\[Sigma]\_2 = {{0, \(-\[ImaginaryI]\)}, {\[ImaginaryI], 
              0}}; \[Sigma]\_2 // tf\), 
        ",", \(\[Sigma]\_3 = {{1, 0}, {0, \(-1\)}}; \[Sigma]\_3 // tf\), ",", 
        "\"\<\\nma[{\!\(\[Sigma]\_1\),\!\(\[Sigma]\_2\),\!\(\[Sigma]\_3\)}] \
generates\>\"", ",", \(id[ma[{\[Sigma]\_1, \[Sigma]\_2, \[Sigma]\_3}]]\), 
        ",", "\"\<\\nThe elements are stored in matel as\>\"", 
        ",", \(Table[matel[\([i]\)] // tf, {i, 16}]\), ",", 
        "\[IndentingNewLine]", "\"\<\\nWith protoloop P16:-\\n\>\"", ",", 
        "\[IndentingNewLine]", \(P16 // tf\)}], "}"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontSize->9],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"The 3 \[Sigma] matrices are \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0", "1"},
                  {"1", "0"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0", \(-\[ImaginaryI]\)},
                  {"\[ImaginaryI]", "0"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "0"},
                  {"0", \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nma[{\\!\\(\[Sigma]\\_1\\),\\!\\(\[Sigma]\\_2\\),\\!\\(\
\[Sigma]\\_3\\)}] generates\"\>", ",", "\<\"P16\"\>", 
        ",", "\<\"\\nThe elements are stored in matel as\"\>", ",", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1", "0"},
                      {"0", "1"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "1"},
                      {"1", "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(-\[ImaginaryI]\)},
                      {"\[ImaginaryI]", "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1", "0"},
                      {"0", \(-1\)}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\[ImaginaryI]", "0"},
                      {"0", \(-\[ImaginaryI]\)}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(-1\)},
                      {"1", "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(-\[ImaginaryI]\), "0"},
                      {"0", "\[ImaginaryI]"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "\[ImaginaryI]"},
                      {"\[ImaginaryI]", "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(-1\)},
                      {\(-1\), "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(-\[ImaginaryI]\), "0"},
                      {"0", \(-\[ImaginaryI]\)}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "1"},
                      {\(-1\), "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(-\[ImaginaryI]\)},
                      {\(-\[ImaginaryI]\), "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\[ImaginaryI]", "0"},
                      {"0", "\[ImaginaryI]"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "\[ImaginaryI]"},
                      {\(-\[ImaginaryI]\), "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(-1\), "0"},
                      {"0", \(-1\)}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(-1\), "0"},
                      {"0", "1"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True]}], "}"}], 
        ",", "\<\"\\nWith protoloop P16:-\\n\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", 
                    "12", "13", "14", "15", "16"},
                  {"2", "1", "8", "15", "6", "5", "12", "3", "10", "9", "16", 
                    "7", "14", "13", "4", "11"},
                  {"3", "16", "1", "6", "7", "4", "5", "10", "11", "8", "9", 
                    "14", "15", "12", "13", "2"},
                  {"4", "7", "14", "1", "8", "11", "2", "5", "12", "15", "6", 
                    "9", "16", "3", "10", "13"},
                  {"5", "6", "7", "8", "9", "10", "11", "12", "13", "14", 
                    "15", "16", "1", "2", "3", "4"},
                  {"6", "5", "12", "3", "10", "9", "16", "7", "14", "13", "4",
                     "11", "2", "1", "8", "15"},
                  {"7", "4", "5", "10", "11", "8", "9", "14", "15", "12", 
                    "13", "2", "3", "16", "1", "6"},
                  {"8", "11", "2", "5", "12", "15", "6", "9", "16", "3", "10",
                     "13", "4", "7", "14", "1"},
                  {"9", "10", "11", "12", "13", "14", "15", "16", "1", "2", 
                    "3", "4", "5", "6", "7", "8"},
                  {"10", "9", "16", "7", "14", "13", "4", "11", "2", "1", "8",
                     "15", "6", "5", "12", "3"},
                  {"11", "8", "9", "14", "15", "12", "13", "2", "3", "16", 
                    "1", "6", "7", "4", "5", "10"},
                  {"12", "15", "6", "9", "16", "3", "10", "13", "4", "7", 
                    "14", "1", "8", "11", "2", "5"},
                  {"13", "14", "15", "16", "1", "2", "3", "4", "5", "6", "7", 
                    "8", "9", "10", "11", "12"},
                  {"14", "13", "4", "11", "2", "1", "8", "15", "6", "5", "12",
                     "3", "10", "9", "16", "7"},
                  {"15", "12", "13", "2", "3", "16", "1", "6", "7", "4", "5", 
                    "10", "11", "8", "9", "14"},
                  {"16", "3", "10", "13", "4", "7", "14", "1", "8", "11", "2",
                     "5", "12", "15", "6", "9"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tNote that non-associative hoops cannot be created by the dot-multiplication \
of matrices and are not members of GL[n].\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3.2.4. Generating Cayley Tables with ",
  StyleBox["ge",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tAnother way to create a group is to specify a list of relators ",
  StyleBox["a, b,... ",
    FontSlant->"Italic"],
  "and some relations (substitution rules such as ",
  StyleBox["ba\[RightArrow]aab) ",
    FontSlant->"Italic"],
  "between them. The relators act as the letters to be used in names of the \
group element. ",
  StyleBox["ge",
    FontSlant->"Italic"],
  " creates group elements by concatenation of relator strings. Non-abelian \
rules can be specified, leading to non-abelian groups. The relations are used \
to give lexicographic order in individual element names. Each relator acts as \
a root of unity; the ",
  StyleBox["ge",
    FontSlant->"Italic"],
  " procedure uses strings \"",
  StyleBox["a",
    FontSlant->"Italic"],
  "\", \"",
  StyleBox["b",
    FontSlant->"Italic"],
  "\", etc. as relators. Thus if ",
  Cell[BoxData[
      \(TraditionalForm\`a\^3\)]],
  "\[RightArrow]1, there will be string elements \"",
  StyleBox["a",
    FontSlant->"Italic"],
  "\" and \"",
  StyleBox["aa",
    FontSlant->"Italic"],
  "\" whilst \"",
  StyleBox["aaa",
    FontSlant->"Italic"],
  "\" becomes the unit or empty string \"\".  ",
  StyleBox["ge",
    FontSlant->"Italic"],
  " was originally written to use symbolic variables ",
  StyleBox["a, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  ",  etc. (and called ",
  StyleBox["ge",
    FontSlant->"Italic"],
  " because I originally thought that they were \"generators\"), these were \
converted to strings to reduce interference with other calculations. A final \
parameter ",
  StyleBox["o",
    FontSlant->"Italic"],
  " can be set to \[PlusMinus]1; this results in the creation of global \
variables ",
  StyleBox["genel, matel",
    FontSlant->"Italic"],
  " that record the elements and the loop, with the elements as strings. An \
experimental feature is the creation of a string replacement rule ",
  StyleBox["strep",
    FontSlant->"Italic"],
  " if ",
  StyleBox["o",
    FontSlant->"Italic"],
  "=-1, to allow investigation of noncommutative loop properties. These \
features are not demonstrated."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ge[gp_, post_: {}]\), ":=", 
        RowBox[{"(*", " ", 
          RowBox[{
            RowBox[{
              StyleBox["skeleton",
                FontColor->RGBColor[1, 0, 0]], " ", "version", " ", "of", " ",
               "ge"}], ",", " ", \(for\ groups\ only\)}], " ", 
          "*)"}], \(Module[{g = {}, cr, j, l = Plus @@ gp + 2, 
            le = Length[gp], ln = 1, lh, n = {"\<\>"}, new, p, st, rhs, si, 
            sij, t = post}, 
          cr = Take[{"\<a\>", "\<b\>", "\<c\>", "\<d\>", "\<e\>", "\<f\>", \
"\<g\>"}, le]; \[IndentingNewLine]Do[ (*i\ loop . \ 
                  Rules\ to\ reduce\ repetitions*) st = 
              cr[\([i]\)]; \[IndentingNewLine]AppendTo[t, 
              Do[st = st <> cr[\([i]\)], {gp[\([i]\)] - 1}]; 
              Rule[st, "\<\>"]], {i, le}]; \[IndentingNewLine]Do[ (*i, 
              j\ loops . \ Add\ abelian\ rules*) new = 
              Rule[lh = cr[\([j]\)] <> cr[\([i]\)], 
                cr[\([i]\)] <> 
                  cr[\([j]\)]]; \[IndentingNewLine]Do[ (*k\ loop . 
                    Omit\ redundant\ rules*) If[lh \[Equal] t[\([k, 1]\)], 
                new = "\<\>"], {k, Length[t] - 1}]; \[IndentingNewLine]If[
              Length[new] \[Equal] 2, AppendTo[t, new]], {i, 1, le - 1}, {j, 
              i + 1, le}]; \[IndentingNewLine]Do[ (*i\ loop . \ 
                  Build\ the\ element\ list*) si = cr[\([i]\)]; sij = si; 
            p = gp[\([i]\)] - 
                1; \[IndentingNewLine]Do[ (*j\ loop . Repetitions*) 
                Do[ (*k\ loop . \ New\ element = 
                    j\ repeats\ of\ k' th\ existing\ element*) AppendTo[n, 
                  If[k \[Equal] 1, sij, n[\([k]\)] <> sij]], {k, 
                  ln}]; \[IndentingNewLine]sij = sij <> si, {j, p}]; 
            ln = Length[n], {i, 
              le}];  (*element\ list\ \(\(completed\)\(.\)\)*) 
            Do[ (*i\ loop . Build\ table\ by\ \(\(concatenation\)\(.\)\)*) 
              AppendTo[
              g,  (*add\ successive\ n[\([i]\)] <> n\ rows\ to\ g*) MapThread[
                StringJoin, {Table[n[\([i]\)], {j, ln}], n}]], {i, 
              ln}]; \[IndentingNewLine]g = 
            Table[l = 0; s1 = g\[LeftDoubleBracket]i, j\[RightDoubleBracket]; 
              s1 = While[\((s2 = StringReplace[s1, t])\) \[NotEqual] s1 && 
                    l < 99, \(l++\); s1 = s2]; 
              s2, {i, ln}, {j, 
                ln}]; \[IndentingNewLine] (*Conversion\ to\ \
\(\(indices\)\(.\)\)*) st = 
            Table[g\[LeftDoubleBracket]j, 1\[RightDoubleBracket] \[Rule] 
                j, {j, ln, 1, \(-1\)}]; \[IndentingNewLine]g /. st]\)}], 
      ";"}]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  "\tExample 8 creates ",
  StyleBox["A4",
    FontSlant->"Italic"],
  " by setting up relators",
  StyleBox[" a, b, & c,",
    FontSlant->"Italic"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`a\^3 \[RightArrow] 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\^2 \[RightArrow] 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\^2 \[RightArrow] 1\)]],
  ". This is implied by the ",
  StyleBox["{3,2,2}",
    FontSlant->"Italic"],
  " entry. The elements ",
  StyleBox["{\"\", \"a\", \"aa\", \"b\", \"ab\", \"aab\", \"c\", \"ac\", \
\"aac\", \"bc\", \"abc\", \"aabc\"}",
    FontSlant->"Italic"],
  " are created. These are put into ",
  StyleBox["genel",
    FontSlant->"Italic"],
  " if the last parameter is \[PlusMinus]1, as in this example. A loop is \
then created by concatenation. The non-abelian rules ",
  StyleBox["ba\[RightArrow]abc ",
    FontSlant->"Italic"],
  "&",
  StyleBox[" ca\[RightArrow]ab",
    FontSlant->"Italic"],
  " are applied, followed by the (implicit) abelian rule ",
  StyleBox["cb\[RightArrow]bc",
    FontSlant->"Italic"],
  ", until all strings are reduced to elements. The Index table is created \
and identified.\n\tThe corresponding traditional formulation of relators is \
discussed in Section 5.2. I have not investigated the creation of \
non-associative Moufang loops from relators. "
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example 8. Group creation from relators and non-abelian rules.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "\"\<On generating \>\"", 
        ",", \(id[
          a4 = ge[{3, 2, 
                2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>"}, 
              1]]\), ",", 
        "\"\<by ge[{3,2,2},{ba\[Rule]abc,ca\[Rule]ab},1]]\\nthe string \
elements are\>\"", ",", "genel", ",", "\"\<\!\(\*
StyleBox[\"(\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"first\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"element\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"empty\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"string\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",\nFontSlant->\"Italic\"]\)\\nThe Index table is\!\(\*
StyleBox[\":\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\>\"", ",", 
        "\[IndentingNewLine]", \(a4 // tf\)}], "}"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FormatType->TraditionalForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"On generating \"\>", ",", "\<\"A4\"\>", 
        ",", "\<\"by ge[{3,2,2},{ba\[Rule]abc,ca\[Rule]ab},1]]\\nthe string \
elements are\"\>", 
        ",", \({1, "a", "aa", "b", "ab", "aab", "c", "ac", "aac", "bc", 
          "abc", "aabc"}\), 
        ",", "\<\"\\!\\(\\* \
StyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"the\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"first\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"element\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"is\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"empty\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"string\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\")\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\nThe Index table is\\!\\(\\* \
StyleBox[\\\":\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"-\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", 
                    "12"},
                  {"2", "3", "1", "5", "6", "4", "8", "9", "7", "11", "12", 
                    "10"},
                  {"3", "1", "2", "6", "4", "5", "9", "7", "8", "12", "10", 
                    "11"},
                  {"4", "11", "9", "1", "8", "12", "10", "5", "3", "7", "2", 
                    "6"},
                  {"5", "12", "7", "2", "9", "10", "11", "6", "1", "8", "3", 
                    "4"},
                  {"6", "10", "8", "3", "7", "11", "12", "4", "2", "9", "1", 
                    "5"},
                  {"7", "5", "12", "10", "2", "9", "1", "11", "6", "4", "8", 
                    "3"},
                  {"8", "6", "10", "11", "3", "7", "2", "12", "4", "5", "9", 
                    "1"},
                  {"9", "4", "11", "12", "1", "8", "3", "10", "5", "6", "7", 
                    "2"},
                  {"10", "8", "6", "7", "11", "3", "4", "2", "12", "1", "5", 
                    "9"},
                  {"11", "9", "4", "8", "12", "1", "5", "3", "10", "2", "6", 
                    "7"},
                  {"12", "7", "5", "9", "10", "2", "6", "1", "11", "3", "4", 
                    "8"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3.2.5. Generating Cayley Tables with ",
  StyleBox["pe",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tEvery group can be generated from permutations and cycles; this is of \
limited value for small groups, but suitable procedures (not shown here) are \
implemented and the database includes a few examples derived from GAP data. \
The incantations tend to be voluminous in comparison with the other \
incantations for the same group.\n\tExample 8a generates groups from \
permutations, using examples from the basic permutations that have been set \
up as arrays s3, s4, and s5. Note that 120-element S5 group needs the \
permissible size to be increased from the default value of 72. Then some \
small groups are created from 6-member permutations. In Example 8b the \
120-element ",
  Cell[BoxData[
      \(\(SL\_2\) \((5)\)\)],
    FontWeight->"Bold"],
  " group is created from the two permutations specified in a tutorial in the \
GAP manual."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 8a Generation from pre-defined permutations.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"Permutations\",\nFontSlant->\"Italic\"]\) s3 =\>\"", ",", "s3", 
        ",", "\"\<\!\(\*
StyleBox[\"generate\",\nFontSlant->\"Italic\"]\)\\n\>\"", 
        ",", \(id[pe[{s3[\([1]\)]}]]\), \( (*C2*) \), 
        ",", \(id[pe[{s3[\([2]\)]}]]\), \( (*C3*) \), 
        ",", \(id[pe[{s3[\([1]\)], s3[\([2]\)]}]]\), \( (*D3*) \), ",", 
        "\"\<\\n\!\(\*
StyleBox[\"Permutations\",\nFontSlant->\"Italic\"]\) s4 =\>\"", ",", "s4", 
        ",", "\"\<\!\(\*
StyleBox[\"generate\",\nFontSlant->\"Italic\"]\)\\n\>\"", 
        ",", \(id[pe[{s4[\([1]\)]}]]\), \( (*C2*) \), 
        ",", \(id[pe[{s4[\([3]\)]}]]\), \( (*C3*) \), 
        ",", \(id[pe[{s4[\([5]\)]}]]\), \( (*C4*) \), 
        ",", \(id[pe[{s4[\([1]\)], s4[\([2]\)]}]]\), \( (*K*) \), 
        ",", \(id[pe[{s4[\([1]\)], s4[\([4]\)]}]]\), \( (*D4*) \), 
        ",", \(id[pe[{s4[\([3]\)], s4[\([4]\)]}]]\), \( (*A4*) \), 
        ",", \(id[pe[{s4[\([1]\)], s4[\([5]\)]}]]\), \( (*S4*) \), ",", 
        "\"\<\\n\!\(\*
StyleBox[\"Permutations\",\nFontSlant->\"Italic\"]\) s5 =\>\"", ",", "s5", 
        ",", "\"\<\!\(\*
StyleBox[\"generate\",\nFontSlant->\"Italic\"]\)\\n\>\"", 
        ",", \(id[pe[{s5[\([1]\)]}]]\), \( (*C2*) \), 
        ",", \(id[pe[{s5[\([2]\)]}]]\), \( (*C3*) \), 
        ",", \(id[pe[{s5[\([3]\)]}]]\), \( (*C4*) \), 
        ",", \(id[pe[{s5[\([1]\)], s5[\([8]\)]}]]\), \( (*K*) \), 
        ",", \(id[pe[{s5[\([5]\)]}]]\), \( (*C5*) \), 
        ",", \(id[pe[{s5[\([1]\)], s5[\([2]\)]}]]\), \( (*C6*) \), 
        ",", \(id[pe[{s5[\([4]\)], s5[\([7]\)]}]]\), \( (*D3*) \), 
        ",", \(id[pe[{s5[\([1]\)], s5[\([7]\)]}]]\), \( (*D4*) \), 
        ",", \(id[
          pe[{s5[\([1]\)], s5[\([2]\)], s5[\([8]\)]}]]\), \( (*D3C2*) \), 
        ",", \(id[pe[{s5[\([2]\)], s5[\([4]\)]}]]\), \( (*A4*) \), 
        ",", \(id[pe[{s5[\([1]\)], s5[\([3]\)]}]]\), \( (*S4*) \), 
        ",", \(id[pe[{s5[\([2]\)], s5[\([5]\)]}]]\), \( (*A5*) \), 
        ",", \(id[pe[{s5[\([2]\)], s5[\([3]\)]}, 120]]\), \( (*S5*) \), ",", 
        "\"\<\\n\!\(\*
StyleBox[\"Some\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"groups\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"from\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"6\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"member\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"permutations\",\nFontSlant->\"Italic\"]\) -\>\"", 
        ",", \(id[pe[{{1, 2, 3, 4, 6, 5}}]]\), \( (*C2*) \), 
        ",", \(id[pe[{{1, 2, 3, 6, 4, 5}}]]\), \( (*C3*) \), 
        ",", \(id[pe[{{1, 2, 6, 3, 4, 5}}]]\), \( (*C4*) \), 
        ",", \(id[
          pe[{{1, 2, 3, 4, 6, 5}, {1, 2, 4, 3, 5, 6}}]]\), \( (*K*) \), 
        ",", \(id[pe[{{1, 3, 4, 6, 2, 5}}]]\), \( (*C5*) \), 
        ",", \(id[pe[{{1, 3, 2, 6, 4, 5}}]]\), \( (*C3C2\ or\ C6*) \), 
        ",", \(id[
          pe[{{1, 2, 3, 4, 6, 5}, {1, 2, 3, 5, 4, 6}}]]\), \( (*D3*) \), 
        ",", \(id[
          pe[{{1, 2, 4, 3, 6, 5}, {1, 2, 3, 6, 5, 4}}]]\), \( (*D4*) \), 
        ",", \(id[
          pe[{{1, 2, 4, 3, 6, 5}, {1, 2, 3, 6, 4, 5}}]]\), \( (*A4*) \), ",", 
        "\[IndentingNewLine]", \(id[
          pe[{{1, 3, 2, 4, 6, 5}, {1, 3, 2, 5, 6, 4}}]]\), \( (*D3C2*) \), 
        ",", "\[IndentingNewLine]", \(id[
          pe[{{1, 2, 3, 4, 6, 5}, {1, 2, 6, 3, 4, 5}}]]\), \( (*S4*) \), 
        ",", \(id[
          pe[{{1, 4, 2, 6, 3, 5}, {1, 2, 5, 6, 3, 4}}]]\), \( (*A5*) \), 
        ",", \(id[
          pe[{{1, 2, 6, 3, 5, 4}, {2, 1, 5, 3, 4, 6}}]]\)}], \( (*A4C2*) \), 
      "}"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"\\!\\(\\* \
StyleBox[\\\"Permutations\\\",\\nFontSlant->\\\"Italic\\\"]\\) s3 =\"\>", 
        ",", \({{2, 1, 3}, {3, 1, 2}}\), 
        ",", "\<\"\\!\\(\\* \
StyleBox[\\\"generate\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\n\"\>", 
        ",", "\<\"C2\"\>", ",", "\<\"C3\"\>", ",", "\<\"D3\"\>", 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"Permutations\\\",\\nFontSlant->\\\
\"Italic\\\"]\\) s4 =\"\>", 
        ",", \({{2, 1, 3, 4}, {1, 2, 4, 3}, {1, 4, 2, 3}, {3, 4, 1, 2}, {2, 
            3, 4, 1}}\), 
        ",", "\<\"\\!\\(\\* \
StyleBox[\\\"generate\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\n\"\>", 
        ",", "\<\"C2\"\>", ",", "\<\"C3\"\>", ",", "\<\"C4\"\>", 
        ",", "\<\"K\"\>", ",", "\<\"D4\"\>", ",", "\<\"A4\"\>", 
        ",", "\<\"S4\"\>", 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"Permutations\\\",\\nFontSlant->\\\
\"Italic\\\"]\\) s5 =\"\>", 
        ",", \({{2, 1, 3, 4, 5}, {1, 2, 4, 5, 3}, {2, 3, 4, 1, 5}, {1, 4, 5, 
            2, 3}, {3, 4, 5, 1, 2}, {2, 3, 4, 5, 1}, {3, 4, 1, 2, 5}, {1, 2, 
            4, 3, 5}}\), 
        ",", "\<\"\\!\\(\\* \
StyleBox[\\\"generate\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\n\"\>", 
        ",", "\<\"C2\"\>", ",", "\<\"C3\"\>", ",", "\<\"C4\"\>", 
        ",", "\<\"K\"\>", ",", "\<\"C5\"\>", ",", "\<\"C3C2\"\>", 
        ",", "\<\"D3\"\>", ",", "\<\"D4\"\>", ",", "\<\"D3C2\"\>", 
        ",", "\<\"A4\"\>", ",", "\<\"S4\"\>", ",", "\<\"A5\"\>", 
        ",", "\<\"S5\"\>", 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"Some\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"groups\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"from\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"6\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"-\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"member\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"permutations\\\
\",\\nFontSlant->\\\"Italic\\\"]\\) -\"\>", ",", "\<\"C2\"\>", 
        ",", "\<\"C3\"\>", ",", "\<\"C4\"\>", ",", "\<\"K\"\>", 
        ",", "\<\"C5\"\>", ",", "\<\"C3C2\"\>", ",", "\<\"D3\"\>", 
        ",", "\<\"D4\"\>", ",", "\<\"A4\"\>", ",", "\<\"D3C2\"\>", 
        ",", "\<\"S4\"\>", ",", "\<\"A5\"\>", ",", "\<\"A4C2\"\>"}], 
      "}"}]], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[BoxData[
    \(\(\(Example\)\(\ \)\(8\) \( b . \ 
        Generation\)\(\ \)\(of\)\(\ \)\(SL\_2\) \((5)\)\(\ \)\(from\)\(\ \
\)\(GAP\)\(\ \)\(tutorial\)\(\ \)\(Ch\)  \(.6\)  \(.2\)\(\ \)\)\)], "Text",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"Permutations\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\>\"", ",", 
        RowBox[{"perm1", "=", 
          RowBox[{"fromCycles", "[", 
            
            StyleBox[\({{1}, {\ 2, \ 3, \ 5, \ 9, 15}, {\ 4, \ 7, 12, \ 8, 
                  14}, \[IndentingNewLine]{10, 17, 23, 20, 24}, {11, 19, 22, 
                  16, 13}}\),
              FormatType->StandardForm], 
            StyleBox["]",
              FormatType->StandardForm]}]}], 
        StyleBox[",",
          FormatType->StandardForm], "\n", 
        RowBox[{"perm2", "=", 
          RowBox[{"fromCycles", "[", 
            RowBox[{"{", 
              RowBox[{
                StyleBox[\({1, 2, 4, 8, 3, 6, 11, 20, 17, 19}\),
                  FormatType->StandardForm], 
                StyleBox[",",
                  FormatType->StandardForm], 
                StyleBox["\[IndentingNewLine]",
                  FormatType->StandardForm], 
                RowBox[{
                  StyleBox["{",
                    FormatType->StandardForm], 
                  StyleBox[\(5, 10, 18, 7, 13, 22, 12, 21, 24, 15\),
                    FormatType->StandardForm], "}"}], ",", 
                RowBox[{"{", 
                  StyleBox[\(9, 16\),
                    FormatType->StandardForm], "}"}], ",", 
                RowBox[{"{", 
                  StyleBox[\(14, 23\),
                    FormatType->StandardForm], 
                  StyleBox["}",
                    FormatType->StandardForm]}]}], 
              StyleBox["}",
                FormatType->StandardForm]}], 
            StyleBox["]",
              FormatType->StandardForm]}]}], 
        StyleBox[",",
          FormatType->StandardForm], "\n", 
        RowBox[{\(SL25 = pe[{perm1, perm2}, 120]\), ";", "\"\<\!\(\*
StyleBox[\"Create\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Group\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"SL25\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Length\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontSlant->\"Italic\"]\) \>\""}], ",", \(Length[SL25]\), ",",
         "\n", "\"\<\\ndico = \>\"", ",", \(dico[SL25]\)}], "}"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"\\!\\(\\* \
StyleBox[\\\"Permutations\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({1, 3, 5, 7, 9, 6, 12, 14, 15, 17, 19, 8, 11, 4, 2, 13, 23, 
          18, 22, 24, 21, 16, 20, 10}\), 
        ",", \({2, 4, 6, 8, 10, 11, 13, 3, 16, 18, 20, 21, 22, 23, 5, 9, 19, 
          7, 1, 17, 24, 12, 14, 15}\), 
        ",", "\<\"\\!\\(\\* \
StyleBox[\\\"Create\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Group\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"SL25\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"=\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", "120", 
        ",", "\<\"\\ndico = \"\>", ",", \({2, 2\_44, 30}\)}], "}"}]], "Output",\

  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3.2.6. Creating Signed Tables with ",
  StyleBox["ms & ts.",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tThe database of over 800 loops includes many non-associative tables \
(octonions etc.) and \"signed-tables\". The signed tables have unsigned \
elements (as in \"C4c\", complex algebra, & \"Qr\", quaternion algebra, and \
in the tables in the following examples) but they include signed products \
such as \[ImaginaryI] \[ImaginaryI] = - 1  and j i = - k. They are not \
groups, because the signed products are not in the list of elements; however \
composing them with one of {C2,C3,C4} usually creates an (unsigned) Moufang \
loop. The definitions of loop properties have been extended to signed tables \
by defining tests that allow for signed elements.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tSome signed tables can be created from matrices, by using ",
  StyleBox["ms",
    FontSlant->"Italic"],
  ". This dot-multiplies the matrices (as in ",
  StyleBox["ma",
    FontSlant->"Italic"],
  ", Section 3.2.3), but does not add a new matrix to the element list if it \
only differs from an existing element by a sign. In Example 9, two matrices \
generate the Clifford(2) algebra [3,p10]; the generating matrices are the \
second and third in the ",
  StyleBox["matel",
    FontSlant->"Italic"],
  " list, after the unit matrix. The unit matrix and one new matrix have been \
added; all four negated matrices are present in the signed table."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 9. CL2 signed table from two2\[Times]2 matrices.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
tst=ms[{2,13}];{\"ms[{2,13}] uses two 2\[Times]2 \
matrices\",{u2[[2]]//tf,u2[[13]]//tf},\"\\nto create\",id[tst],tst//tf,\"\\n \
The matrices stored in matel are the \
elements\",{matel[[1]]//tf,matel[[2]]//tf,matel[[3]]//tf,matel[[4]]//tf}}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"ms[{2,13}] uses two 2\[Times]2 matrices\"\>", ",", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1", "0"},
                      {"0", \(-1\)}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "\[ImaginaryI]"},
                      {"\[ImaginaryI]", "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True]}], "}"}], ",", "\<\"\\nto create\"\>", 
        ",", "\<\"CL2\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "1", "4", "3"},
                  {"3", \(-4\), \(-1\), "2"},
                  {"4", \(-3\), \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\n The matrices stored in matel are the elements\"\>", ",",
         
        RowBox[{"{", 
          RowBox[{
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1", "0"},
                      {"0", "1"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1", "0"},
                      {"0", \(-1\)}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "\[ImaginaryI]"},
                      {"\[ImaginaryI]", "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True], ",", 
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "\[ImaginaryI]"},
                      {\(-\[ImaginaryI]\), "0"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tOther signed tables can be made by folding a table that has a suitable \
symmetric structure, using the ",
  StyleBox["ts",
    FontSlant->"Italic"],
  " (toSignedTable) procedure; this creates single signed elements as \
equivalence relations on ",
  StyleBox["r",
    FontSlant->"Italic"],
  " unsigned elements. ",
  StyleBox["P16",
    FontSlant->"Italic"],
  " (shown in Example 7) splits into four 8\[Times]8 tables or into sixteen 4\
\[Times]4 tables that repeat the structure of the top left corner with \
offsets mod 8 or 4. In Example 10, ",
  StyleBox["ts",
    FontSlant->"Italic"],
  " finds the signed tables corresponding to these structures. The 8-element \
case (",
  StyleBox["r",
    FontSlant->"Italic"],
  " =2) is not in the database; the 4-element case (",
  StyleBox["r=",
    FontSlant->"Italic"],
  "4) is the algebra that I call the Pauli-\[Sigma] algebra, P4:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 10. Collapsing P16.", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tst = 
      ts[P16]; {"\<Collapse of P16 by ts[P16,2]. \nIs the result \
conservative?\>", conservativeQ[tst], "\<\nThe table is\>", 
      tst // tf, "\<\nC4 Collapse of P16 by ts[P16,4] gives\>", 
      tst4 = ts[P16, 4]; tst4 // tf; id[tst4], tst4 // tf}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Collapse of P16 by ts[P16,2]. \\nIs the result \
conservative?\"\>", ",", "True", ",", "\<\"\\nThe table is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8"},
                  {"2", "1", \(-8\), "7", "6", "5", "4", \(-3\)},
                  {"3", "8", "1", \(-6\), "7", \(-4\), "5", "2"},
                  {"4", \(-7\), "6", "1", "8", "3", \(-2\), "5"},
                  {"5", "6", "7", "8", \(-1\), \(-2\), \(-3\), \(-4\)},
                  {"6", "5", "4", \(-3\), \(-2\), \(-1\), "8", \(-7\)},
                  {"7", \(-4\), "5", "2", \(-3\), \(-8\), \(-1\), "6"},
                  {"8", "3", \(-2\), "5", \(-4\), "7", \(-6\), \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nC4 Collapse of P16 by ts[P16,4] gives\"\>", 
        ",", "\<\"P4\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", 
                    "1", \(\(-4\)\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\)},
                  {"3", \(4\ \[ImaginaryI]\), 
                    "1", \(\(-2\)\ \[ImaginaryI]\)},
                  {"4", \(\(-3\)\ \[ImaginaryI]\), \(2\ \[ImaginaryI]\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.2.7. Generalized Cayley-Dickson and Clifford Algebras, Moufang doubling.\
\>", "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tExample 11 uses generalizations (",
  StyleBox["cd",
    FontSlant->"Italic"],
  " & ",
  StyleBox["cl",
    FontSlant->"Italic"],
  ") of the Cayley-Dickson [3, p285] and Clifford [3, p284] procedures to \
create the Octonion and Clifford(2,1) algebra signed tables. Composing them \
with C2 \"expands\" or \"unfolds\" them to ",
  StyleBox["Oct & D4C2",
    FontSlant->"Italic"],
  " respectively. Octonions cannot be created by ",
  StyleBox["ms",
    FontSlant->"Italic"],
  " as they are non-associative, unlike matrix multiplication. I call the \
generators of these tables \"univectors\" - some authors confusingly call \
them either \"vectors\" or \"scalars\"; I contend that \"scalar\" should be \
reserved for the unit element, and \"vector\" should be reserved for sets of \
elements. Bivectors and trivectors are products of two or three univectors, \
etc."
}], "Text",
  PageWidth->WindowWidth],

Cell[" Ex. 11. Signed table hoops from univectors.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<cd[{-1,-1,-1}]  creates \>", \n
      idc[tst = cd[{\(-1\), \(-1\), \(-1\)}]], 
      tst // tf, "\<\nIs this alternative?\>", 
      alternativeQ[tst], "\<\nIt expands to \>", 
      id[co[tst, C2]], "\<\n\ncl[2,1] creates\n\>", \[IndentingNewLine]idc[
        tst2 = cl[2, 1]], tst2 // tf, "\<\nIs this conservative?\>", 
      alternativeQ[tst2], "\<\nIt expands to \>", 
      id[co[tst2, C2]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"cd[{-1,-1,-1}]  creates \"\>", ",", "\<\"Octr\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8"},
                  {"2", \(-1\), "4", \(-3\), "6", \(-5\), \(-8\), "7"},
                  {"3", \(-4\), \(-1\), "2", "7", "8", \(-5\), \(-6\)},
                  {"4", "3", \(-2\), \(-1\), "8", \(-7\), "6", \(-5\)},
                  {"5", \(-6\), \(-7\), \(-8\), \(-1\), "2", "3", "4"},
                  {"6", "5", \(-8\), "7", \(-2\), \(-1\), \(-4\), "3"},
                  {"7", "8", "5", \(-6\), \(-3\), "4", \(-1\), \(-2\)},
                  {"8", \(-7\), "6", "5", \(-4\), \(-3\), "2", \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nIs this alternative?\"\>", ",", 
        "True", ",", "\<\"\\nIt expands to \"\>", ",", "\<\"Oct\"\>", 
        ",", "\<\"\\n\\ncl[2,1] creates\\n\"\>", ",", "\<\"CL21\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8"},
                  {"2", \(-1\), "4", \(-3\), "6", \(-5\), "8", \(-7\)},
                  {"3", \(-4\), "1", \(-2\), "7", \(-8\), "5", \(-6\)},
                  {"4", "3", "2", "1", "8", "7", "6", "5"},
                  {"5", \(-6\), \(-7\), "8", "1", \(-2\), \(-3\), "4"},
                  {"6", "5", \(-8\), \(-7\), "2", "1", \(-4\), \(-3\)},
                  {"7", "8", \(-5\), \(-6\), "3", "4", \(-1\), \(-2\)},
                  {"8", \(-7\), \(-6\), "5", "4", \(-3\), \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nIs this conservative?\"\>", ",", 
        "True", ",", "\<\"\\nIt expands to \"\>", ",", "\<\"D4C2\"\>"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe original Cayley-Dickson process corresponds to cd[{-1,-1...}] with \
each new \[Gamma] being -1. Schafer generalized this to \
\[Gamma]=\[PlusMinus]1. Using some \[Gamma]=+1 creates some new conservative \
signed tables. I generalized further, introducing a list as an optional final \
\[Gamma]; this composes the signed table with an abelian group to create a \
\"parent\" unsigned table. I also introduced some variations and some new \
starting tables in place of C2. Test 4 in ",
  StyleBox["GroupLoopTest",
    FontSlant->"Italic"],
  " listed 45 tables with ",
  StyleBox["cd",
    FontSlant->"Italic"],
  " incantations; only 4 of the many non-conservative cases have been \
included.",
  " The following is a (non-exhaustive) list of conservative outcomes:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[" Ex. 11a. Generalized Cayley-Dickson process.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<cd[{1,-1}]        creates \>", 
      idc[cd[{1, \(-1\)}]], "\<\ncd[{1,-1,{2}}]     creates \>", 
      idc[cd[{1, \(-1\), {2}}]], "\<\ncd[{-1,-1.}]       creates \>", 
      idc[cd[{\(-1\), \(-1. \)}]], \[IndentingNewLine]"\<\ncd[{-1,-1,-1}]     \
creates \>", 
      idc[cd[{\(-1\), \(-1\), \(-1\)}]], "\<\ncd[{-1,-1,-1,{2}}] creates \>", 
      idc[cd[{\(-1\), \(-1\), \(-1\), {2}}]], "\<\ncd[{-2,1,1}]       creates \
\>", idc[cd[{\(-2\), 1, 
            1}]], \[IndentingNewLine]"\<\ncd[{-2,1,-1.}]     creates \>", 
      idc[cd[{\(-2\), 
            1, \(-1. \)}]], \[IndentingNewLine]"\<\ncd[{3,-1.,-1.}]    \
creates \>", 
      idc[cd[{3, \(-1. \), \(-1. \)}]], \[IndentingNewLine]"\<\ncd[{3.,1,1}]  \
     creates \>", 
      idc[cd[{3. , 1, 
            1}]], \[IndentingNewLine]"\<\ncd[{1,-1,-1}]      creates \>", 
      idc[cd[{1, \(-1\), \(-1\)}]], "\<\ncd[{1,-1,-1,{2}}]  creates \>", 
      idc[cd[{1, \(-1\), \(-1\), {2}}]], "\<\ncd[{-2,1}]         creates \>", 
      idc[cd[{\(-2\), 1}]], "\<\ncd[{3.,1.}]        creates \>", 
      idc[cd[{3. , 1. }]], "\<\ncd[{4.,1.}]        creates \>", 
      idc[cd[{4. , 1. }]], "\<\ncd[{-1,1}]         creates \>", 
      idc[cd[{\(-1\), 1}]], "\<\ncd[{-1,1,1}]       creates \>", 
      idc[cd[{\(-1\), 1, 1}]], "\<\ncd[{-1,1,1,1}]     creates \>", 
      idc[cd[{\(-1\), 1, 1, 1}]], "\<\ncd[{-1,1,1,1,1}]   creates \>", 
      idc[cd[{\(-1\), 1, 1, 1, 1}]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"cd[{1,-1}]        creates ", "CL2", "\ncd[{1,-1,{2}}]     creates ", 
      "D4", "\ncd[{-1,-1.}]       creates ", "Dav", 
      "\ncd[{-1,-1,-1}]     creates ", "Octr", 
      "\ncd[{-1,-1,-1,{2}}] creates ", "Oct", 
      "\ncd[{-2,1,1}]       creates ", "O4k", 
      "\ncd[{-2,1,-1.}]     creates ", "C4C4r", 
      "\ncd[{3,-1.,-1.}]    creates ", "C3Dav", 
      "\ncd[{3.,1,1}]       creates ", "C6Kc", 
      "\ncd[{1,-1,-1}]      creates ", "Octi", 
      "\ncd[{1,-1,-1,{2}}]  creates ", "Q8M2", 
      "\ncd[{-2,1}]         creates ", "C3C4j", 
      "\ncd[{3.,1.}]        creates ", "KC3c", 
      "\ncd[{4.,1.}]        creates ", "KKr", 
      "\ncd[{-1,1}]         creates ", "O2", "\ncd[{-1,1,1}]       creates ", 
      "O4", "\ncd[{-1,1,1,1}]     creates ", "O8", 
      "\ncd[{-1,1,1,1,1}]   creates ", "O16"}\)], "Output"]
}, Open  ]],

Cell["\<\
\tThe O2, O4,...  series have 2, 4,... quadratic sizes and so describe that \
number of copies of the complex plane, with the origin as the only common \
point. Dav is an O2 isomorph.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe non-associative Moufang loops (Loops package, Gabor P. Nagy & Petr \
Vojtechovsky, in  www.GAP-system.org) are obtained by \"Chein doubling\" or \
by \"Moufang modification\" of non-abelian groups. This is partially \
implemented by the ",
  StyleBox["md",
    FontSlant->"Italic"],
  " procedure.",
  " M1201 or D3Mn is the smallest non-associative Moufang loop (doubled D3), \
but does not conserve its non-linear factors. Neither do M1601 (doubled D4), \
M1604 (modified from D4), nor M1605 (modified from Q8). The only other 16 \
element non-associative Moufang loops are M1602 (doubled Q8) & M1603 (the \
Octonion table); they conserve sums of 8 squares (with 4 negated in the M1602 \
case). Of the 71 32-element cases, only 6 (M3202 = Q8C2m; M3216 = OctC2; \
M3221 = P16M; M3235 = C8pC2M; M3254 = KiC4M & M3265 = C4iC4m) are \
conservative. Example 11b. creates all those in the database."
}], "Text",
  PageWidth->WindowWidth],

Cell[" Ex. 11b. Moufang Doubling processes.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<md[D3]                  creates \>", 
      id[md[D3]], "\<\nmd[ca[8,7]]              creates \>", 
      id[md[ca[8, 7]]], "\<\nmd[Q8]      creates conservative \>", 
      idc[md[Q8]], \[IndentingNewLine]"\<\nmd[D4,{1,2,3,8,5,6,7,4}] creates \
\>", id[md[
          D4, {1, 2, 3, 8, 5, 6, 7, 
            4}]], "\<\nmd[Q8,{1,2,3,8,5,6,7,4}] creates \>", 
      id[md[Q8, {1, 2, 3, 8, 5, 6, 7, 
            4}]], "\<\nmd[ca[10,9]              creates \>", 
      id[md[ca[10, 9]]], "\<\nmd[D3C2]                 creates \>", 
      id[md[D3C2]], \[IndentingNewLine]"\<\nmd[co[Q8,C2]] creates \
conservative\>", 
      idc[md[co[Q8, 
            C2]]], \[IndentingNewLine]"\<\n\
md[co[P4,C4],{1,10,11,12,5,14,15,16,9,2,3,4,13,6,7,8}] \n creates \
conservative \>", 
      id[md[co[P4, C4], {1, 10, 11, 12, 5, 14, 15, 16, 9, 2, 3, 4, 13, 6, 7, 
            8}]], \[IndentingNewLine]"\<\n\
md[md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\n creates \
conservative\>", 
      id[md[co[ca[8], C2, 4], {1, 6, 3, 8, 5, 2, 7, 4, 13, 14, 15, 16, 9, 10, 
            11, 12}]], \[IndentingNewLine]"\<\n\
md[md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\n creates \
conservative\>", \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ id[
        md[co[K, C4, 2], {1, 4, 3, 2, 7, 8, 5, 6, 9, 12, 11, 10, 15, 16, 13, 
            14}]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"md[D3]                  creates ", "D3Mn", 
      "\nmd[ca[8,7]]              creates ", "D4M1n", 
      "\nmd[Q8]      creates conservative ", "Q8M2", 
      "\nmd[D4,{1,2,3,8,5,6,7,4}] creates ", "D4M4n", 
      "\nmd[Q8,{1,2,3,8,5,6,7,4}] creates ", "D4M5n", 
      "\nmd[ca[10,9]              creates ", "D5Mn", 
      "\nmd[D3C2]                 creates ", "D3C2Mn", 
      "\nmd[co[Q8,C2]] creates conservative", "Q8C2M", 
      "\nmd[co[P4,C4],{1,10,11,12,5,14,15,16,9,2,3,4,13,6,7,8}] \n creates \
conservative ", "P16M", 
      "\nmd[md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\n \
creates conservative", "C8pC2M", 
      "\nmd[md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\n \
creates conservative", "KiC4M"}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3. Database rules for loop creation.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThe ",
  StyleBox["loop[[mm,nn]]",
    FontSlant->"Italic"],
  " data includes information that allows the creation of the loop ",
  StyleBox["g",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["mmnn",
    FontSlant->"Italic"],
  ", usually in several ways. The 4th entry is a prescription such as \
\"co[C3,C4,2]\" (used to create ",
  StyleBox["Q12",
    FontSlant->"Italic"],
  " in Example 6); the next two are relators and non-abelian rules such as \
{3,2,2}, {\"ba\"\[Rule] \"abc\",\"ca\"\[Rule] \"ab\"} (used to create A4 in \
Example 8). Entries 7, 8, & 9  are lists pointing to 2\[Times]2, 3\[Times]3, \
& 4\[Times]4 matrices that generate the loop via ",
  StyleBox["ma",
    FontSlant->"Italic"],
  " or the signed table via ",
  StyleBox["ms ",
    FontSlant->"Italic"],
  "(where such generating matrix sets are known to the author). Example 13 \
first gives ",
  StyleBox["gd[\"P16\"] ",
    FontSlant->"Italic"],
  "and then demonstrates the different creation processes for ",
  StyleBox["P16",
    FontSlant->"Italic"],
  ". Entry 7 is {2,3,4} because the Pauli-\[Sigma] matrices (as used in \
Example 7) are stored as ",
  StyleBox["u2[[2]], u2[[3]], u2[[4]]",
    FontSlant->"Italic"],
  ".  Entry 9 is {1,7,16} because the Dirac-\[Gamma] matrices are stored as \
",
  StyleBox["u4[[2]], u4[[7]], u4[[16]]",
    FontSlant->"Italic"],
  ". In a few cases (including ",
  StyleBox["P16 & A5",
    FontSlant->"Italic"],
  ") extra entries provide additional prescriptions. Thus ",
  StyleBox["makeProtoloop[\"P16\",o]",
    FontSlant->"Italic"],
  " creates ",
  StyleBox["P16",
    FontSlant->"Italic"],
  " in six different ways:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 13. Loop generation rules demonstrated.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[TextData[{
  "{\"P16 Data\",gd[\"P16\"],\n\"\\n\\nEffect of makeProtoloop[16,13,o] or \
mp[\\\"P16\\\",o] etc.",
  StyleBox["\\n",
    FontSlant->"Italic"],
  "o=0 uses co[P4,C4] to create       \",id[co[P4,C4]],\n\"\\no=1 uses \
ge[{2,2,2,2},{dd\[Rule]c,ba\[Rule]abc}] to create\",\nid[ge[{2,2,2,2},{dd\
\[Rule]c,ba\[Rule]abc}]],\n\"\\no=2 uses mg[{2,3,4},u2] to create  \
\",id[mg[{2,3,4},u2]],\n\"\\no=4 uses mg[{1,7,16},u4] to create \
\",id[mg[{1,7,16},u4]],\n\"\\no=5 uses co[Q8,C2,4] to create     \
\",id[co[Q8,C2,4]],\n\"\\no=6 uses co[cl[3],C2] to create    \
\",id[co[cl[3],C2]]}"
}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"P16 Data", {16, 
        13, {"P16", {8, 8}, 0, 
          "co[P4,C4]", {2, 2, 2, 2}, {"dd" \[Rule] "c", 
            "ba" \[Rule] "abc"}, {2, 3, 4}, {}, {1, 7, 16}, "co[Q8,C2,4]", 
          "co[cl[3],C2]"}}, 
      "\n\nEffect of makeProtoloop[16,13,o] or mp[\"P16\",o] etc.\no=0 uses \
co[P4,C4] to create       ", "P16", 
      "\no=1 uses ge[{2,2,2,2},{dd\[Rule]c,ba\[Rule]abc}] to create", "P16", 
      "\no=2 uses mg[{2,3,4},u2] to create  ", "P16", 
      "\no=4 uses mg[{1,7,16},u4] to create ", "P16", 
      "\no=5 uses co[Q8,C2,4] to create     ", "P16", 
      "\no=6 uses co[cl[3],C2] to create    ", "P16"}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tExample 14 tabulates abbreviated data entries for 43 of the smallest \
non-abelian groups (",
  StyleBox["mg",
    FontSlant->"Italic"],
  " & ",
  StyleBox["ms",
    FontSlant->"Italic"],
  " rules are omitted). The non-abelian rules are in compressed form, \"a4b\" \
being equivalent to \"aaaab\". The fastest prescription is usually supplied, \
",
  StyleBox["ca[mm,o]",
    FontSlant->"Italic"],
  " being preferred to \"",
  StyleBox["co[g,h,o]",
    FontSlant->"Italic"],
  "\". Note that prescriptions have not been found for \"A4\", \
\"g2003\",\"SL23\", \"P27\", and \"g2704\"; their prescription entries are ",
  StyleBox["ca[]",
    FontSlant->"Italic"],
  ". Every group appears to have generators (called \"relators\" here and in \
GAP) whose powers multiply to give the group size; John Conway assures me \
(private communication) that this is likely. The GAP system can provide a \
(not necessarily minimal) set of relators; this is demonstrated later (in \
Example 22)."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 14. Small non-abelian groups.", "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontWeight->"Bold"],

Cell[BoxData[
    FormBox[GridBox[{
          {"\"\<Name\>\"", "\"\<Length\>\"", "\"\<GAP\>\"", 
            "\"\<Prescription\>\"", "\"\<Gens\>\"", "\"\<non-Abelian\>\""},
          {"\"\<D3\>\"", "6", "1", 
            "\"\<ca[6,5]\>\"", \({3, 2}\), \({"\<ba\>" \[Rule] "\<a2b\>"}\)},
          {"\"\<D4\>\"", "8", "3", 
            "\"\<ca[8,7]\>\"", \({4, 2}\), \({"\<ba\>" \[Rule] "\<a3b\>"}\)},
          {"\"\<Q8\>\"", "8", "4", 
            "\"\<ca[8,3]\>\"", \({2, 2, 
              2}\), \({"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
\[IndentingNewLine]"\<ba\>" \[Rule] "\<abc\>"}\)},
          {"\"\<D5\>\"", "10", "1", 
            "\"\<ca[10,9]\>\"", \({5, 
              2}\), \({"\<ba\>" \[Rule] "\<a4b\>"}\)},
          {"\"\<Q12\>\"", "12", "1", 
            "\"\<co[C3,C4,2]\>\"", \({3, 
              4}\), \({"\<ba\>" \[Rule] "\<a2b\>"}\)},
          {"\"\<A4\>\"", "12", "3", 
            "\"\<ca[]\>\"", \({3, 2, 
              2}\), \({"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>"}\
\)},
          {"\"\<D3C2\>\"", "12", "4", 
            "\"\<co[C3,K,2]\>\"", \({3, 2, 
              2}\), \({"\<ba\>" \[Rule] "\<a2b\>"}\)},
          {"\"\<D7\>\"", "14", "2", 
            "\"\<ca[14,13]\>\"", \({7, 
              2}\), \({"\<ba\>" \[Rule] "\<a6b\>"}\)},
          {"\"\<KiC4\>\"", "16", "3", 
            "\"\<co[K,C4,2]\>\"", \({4, 2, 
              2}\), \({"\<ba\>" \[Rule] "\<abc\>"}\)},
          {"\"\<C4iC4\>\"", "16", "4", 
            "\"\<co[C4,C4,2]\>\"", \({4, 
              4}\), \({"\<ba\>" \[Rule] "\<a3b\>"}\)},
          {"\"\<C8pC2\>\"", "16", "6", 
            "\"\<co[ca[8],C2,4]\>\"", \({8, 
              2}\), \({"\<ba\>" \[Rule] "\<a5b\>"}\)},
          {"\"\<D8\>\"", "16", "7", 
            "\"\<ca[16,15]\>\"", \({8, 
              2}\), \({"\<ba\>" \[Rule] "\<a7b\>"}\)},
          {"\"\<Q8iC2\>\"", "16", "8", 
            "\"\<co[Q8,C2,2]\>\"", \({8, 
              2}\), \({"\<ba\>" \[Rule] "\<a3b\>"}\)},
          {"\"\<Q16\>\"", "16", "9", 
            "\"\<ca[16,7]\>\"", \({2, 2, 2, 
              2}\), \({"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
\[IndentingNewLine]"\<dd\>" \[Rule] "\<c\>", "\<ba\>" \[Rule] "\<abc\>", \
\[IndentingNewLine]"\<da\>" \[Rule] "\<abd\>", "\<db\>" \[Rule] \
"\<bcd\>"}\)},
          {"\"\<D4C2\>\"", "16", "11", 
            "\"\<co[D4,C2]\>\"", \({4, 2, 
              2}\), \({"\<ba\>" \[Rule] "\<a3b\>"}\)},
          {"\"\<Q8C2\>\"", "16", "12", 
            "\"\<co[Q8,C2]\>\"", \({2, 2, 2, 
              2}\), \({"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
\[IndentingNewLine]"\<ba\>" \[Rule] "\<abc\>"}\)},
          {"\"\<P16\>\"", "16", "13", 
            "\"\<co[P4,C4]\>\"", \({2, 2, 2, 
              2}\), \({"\<dd\>" \[Rule] "\<c\>", "\<ba\>" \[Rule] \
"\<abc\>"}\)},
          {"\"\<D9\>\"", "18", "1", 
            "\"\<ca[18,17]\>\"", \({9, 
              2}\), \({"\<ba\>" \[Rule] "\<a8b\>"}\)},
          {"\"\<D3C3\>\"", "18", "3", 
            "\"\<co[D3,C3]\>\"", \({3, 
              6}\), \({"\<ba\>" \[Rule] "\<a2b\>"}\)},
          {"\"\<E18\>\"", "18", "4", 
            "\"\<co[C3,ca[6,5],2]\>\"", \({2, 3, 
              3}\), \({"\<ba\>" \[Rule] "\<abb\>", "\<ca\>" \[Rule] \
"\<acc\>"}\)},
          {"\"\<Q20\>\"", "20", "1", 
            "\"\<ca[20,9]\>\"", \({5, 
              4}\), \({"\<ba\>" \[Rule] "\<a4b\>"}\)},
          {"\"\<g2003\>\"", "20", "3", 
            "\"\<ca[]\>\"", \({5, 4}\), \({"\<ba\>" \[Rule] "\<a2b\>"}\)},
          {"\"\<D10\>\"", "20", "4", 
            "\"\<ca[20,19]\>\"", \({10, 
              2}\), \({"\<ba\>" \[Rule] "\<a9b\>"}\)},
          {"\"\<g2101\>\"", "21", "1", 
            "\"\<co[ca[7],C3,7]\>\"", \({7, 
              3}\), \({"\<ba\>" \[Rule] "\<a2b\>"}\)},
          {"\"\<D11\>\"", "22", "1", 
            "\"\<ca[22,21]\>\"", \({11, 
              2}\), \({"\<ba\>" \[Rule] "\<a10b\>"}\)},
          {"\"\<C3iC8\>\"", "24", "1", 
            "\"\<co[C3,C8,2]\>\"", \({3, 
              8}\), \({"\<ba\>" \[Rule] "\<a2b\>"}\)},
          {"\"\<SL23\>\"", "24", "3", 
            "\"\<ca[]\>\"", \({3, 2, 2, 
              2}\), \({"\<bb\>" \[Rule] "\<d\>", "\<cc\>" \[Rule] "\<d\>", \
\[IndentingNewLine]"\<ba\>" \[Rule] "\<abcd\>", "\<ca\>" \[Rule] "\<abd\>", \
\[IndentingNewLine]"\<cb\>" \[Rule] "\<bcd\>"}\)},
          {"\"\<Q24\>\"", "24", "4", 
            "\"\<ca[24,11]\>\"", \({3, 2, 2, 
              2}\), \({"\<ba\>" \[Rule] "\<a2b\>", "\<bb\>" \[Rule] "\<c\>", \
\[IndentingNewLine]"\<dd\>" \[Rule] "\<c\>", "\<db\>" \[Rule] "\<bcd\>"}\)},
          {"\"\<D3C4\>\"", "24", "5", 
            "\"\<co[D3,C4]\>\"", \({3, 2, 
              4}\), \({"\<ba\>" \[Rule] "\<a2b\>"}\)},
          {"\"\<D12\>\"", "24", "6", 
            "\"\<ca[24,23]\>\"", \({12, 
              2}\), \({"\<ba\>" \[Rule] "\<a11b\>"}\)},
          {"\"\<Q12C2\>\"", "24", "7", 
            "\"\<co[ca[12,5],C2]\>\"", \({6, 
              4}\), \({"\<ba\>" \[Rule] "\<a5b\>"}\)},
          {"\"\<C3iC4iC2\>\"", "24", "8", 
            "\"\<co[C3,C4,C2,2,2]\>\"", \({6, 2, 
              2}\), \({"\<ba\>" \[Rule] "\<a5bc\>"}\)},
          {"\"\<D4C3\>\"", "24", "10", 
            "\"\<co[D4,C3]\>\"", \({4, 2, 
              3}\), \({"\<ba\>" \[Rule] "\<a3b\>"}\)},
          {"\"\<Q8C3\>\"", "24", "11", 
            "\"\<co[Q8,C3]\>\"", \({2, 2, 2, 
              3}\), \({"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
\[IndentingNewLine]"\<ba\>" \[Rule] "\<abc\>"}\)},
          {"\"\<S4\>\"", "24", "12", 
            "\"\<sgroup[4]\>\"", \({3, 2, 2, 
              2}\), \({"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>", \
\[IndentingNewLine]"\<da\>" \[Rule] "\<a2d\>", "\<db\>" \[Rule] "\<cd\>", \
\[IndentingNewLine]"\<dc\>" \[Rule] "\<bd\>"}\)},
          {"\"\<A4C2\>\"", "24", "13", 
            "\"\<co[A4a,C2]\>\"", \({3, 2, 2, 
              2}\), \({"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>"}\
\)},
          {"\"\<D6C2\>\"", "24", "14", 
            "\"\<co[ca[12,11],C2]\>\"", \({6, 2, 
              2}\), \({"\<ba\>" \[Rule] "\<a5b\>"}\)},
          {"\"\<D13\>\"", "26", "1", 
            "\"\<ca[26,25]\>\"", \({13, 
              2}\), \({"\<ba\>" \[Rule] "\<a12b\>"}\)},
          {"\"\<P27\>\"", "27", "3", 
            "\"\<ca[]\>\"", \({3, 3, 3}\), \({"\<ba\>" \[Rule] "\<abc\>"}\)},
          {"\"\<g2704\>\"", "27", "4", 
            "\"\<ca[]\>\"", \({9, 3}\), \({"\<ba\>" \[Rule] "\<a4b\>"}\)},
          {"\"\<Q28\>\"", "28", "1", 
            "\"\<ca[28,13]\>\"", \({7, 
              4}\), \({"\<ba\>" \[Rule] "\<a6b\>"}\)},
          {"\"\<D14\>\"", "28", "3", 
            "\"\<ca[28,27]\>\"", \({14, 
              2}\), \({"\<ba\>" \[Rule] "\<a13b\>"}\)}
          }], TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontSize->9]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Moufang Loops, Conserved \"sizes\" and \"shapes\".", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". Moufang loops have invertible multiplication, so vector division and \
multiplication are one operation; associative (and a few non-associative) \
Moufang loops \"conserve\" functions (\"sizes\") related to the determinant \
of the symbolic table. Most loops lack this Frobenius property. The division \
and conservation properties are fundamental requirements for mathematical \
physics. Sizes are generalized norms for which the triangle inequality \
becomes an equality. Non-linear sizes are symmetric polynomials; compact \
expression have been found for many, often as sums of powers or products of \
simpler polynomials that I call \"fragments\"."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["4.1. Moufang Loops, Division. ", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tMoufang loops are \"loops with units & division\", i.e. quasigroup \
multiplication tables with the indices in order in the first row and column \
(left & right units) and with ",
  StyleBox["zx.yz=(z.xy)z",
    FontSlant->"Italic"],
  " for all ",
  StyleBox["xyz",
    FontSlant->"Italic"],
  ". (There are other, related, Moufang properties. [2, p93]) They are groups \
if the multiplication is associative. Every finite group (and every Octonion) \
can be expressed as a Moufang loop index table (often in many isomorphic \
forms). A specific isomorph or \"protoloop\" (chosen because it demonstrates \
the structure of the loop and its similarities with other loops) is defined \
for every loop in my database. It is a convenient definition of the loop as \
an index table; ",
  StyleBox["shape & toPol",
    FontSlant->"Italic"],
  " (etc.) definitions employ it."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tExample 15 uses ",
  StyleBox["makeProtoloop[\"Qr\"] ",
    FontSlant->"Italic"],
  "to create a copy (called ",
  StyleBox["qr",
    FontSlant->"Italic"],
  " here) of the Quaternion algebra signed multiplication table. This is \
shown both as a signed table and in the usual form with the univectors ",
  StyleBox["i",
    FontSlant->"Italic"],
  " & ",
  StyleBox["j",
    FontSlant->"Italic"],
  " (i.e. the Cayley-Dickson generators [3, p285] that are fourth roots of \
unity). Tests then shows that the table is non-abelian but has the \
associative and extended moufangQ properties. (The strict MoufangQ test fails \
because at least one product changes sign.)"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 15. Quaternion algebra tables & properties.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qr = 
      makeProtoloop["\<Qr\>"]; {"\<Quaternion Index Table & Univector \
multiplication table\>", qr // tf, 
      gmap[qr, {1, i, j, i\[VeryThinSpace]j}] // tf, "\<\nAbelian    \>", 
      abelianQ[qr], "\<\nAssociative\>", 
      associativeQ[qr], "\<\nmoufang    \>", 
      moufangQ[qr], "\<\nMoufang    \>"\ , MoufangQ[qr]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Quaternion Index Table & Univector multiplication \
table\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", \(-1\), "4", \(-3\)},
                  {"3", \(-4\), \(-1\), "2"},
                  {"4", "3", \(-2\), \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "i", "j", \(i\ j\)},
                  {"i", \(-1\), \(i\ j\), \(-j\)},
                  {"j", \(\(-i\)\ j\), \(-1\), "i"},
                  {\(i\ j\), "j", \(-i\), \(-1\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nAbelian    \"\>", ",", "False", 
        ",", "\<\"\\nAssociative\"\>", ",", "True", 
        ",", "\<\"\\nmoufang    \"\>", ",", "True", 
        ",", "\<\"\\nMoufang    \"\>", ",", "False"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?MoufangQ", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("MoufangQ tests if zx.yz=(z.xy)z, the 3rd Moufang Identity. See PMA \
p92. As this fails for many conservative signed tables such as Qr, unsigned \
tests can be performed by moufangQ."\)], "Print",
  CellTags->"Info3368026555-3164607"]
}, Open  ]],

Cell[TextData[{
  "\tThe Moufang division property means that multiplicative inverses exist \
for vectors (and not just for table elements). The unit of a loop \
multiplication is the vec {1,0,...}, and so the inverse of a vec such as \
{a,b,...} can be found (for small loops) by solving for the vec {p,q,...} \
that gives the unit as a product, {p,q,...}{a,b,...} = {1,0,...}. This \
defines a left inverse iff the loop is conservative. (A right inverse could \
be found similarly; an abelian table gives a single inverse.)  The table \
determinant is a denominator for each element of the inverse, as Cramer's \
method has been used in its calculation. Each numerator is a derivation, so \
division and differentiation are linked.\n\tExample 16 finds left inverses \
for ",
  StyleBox["C4",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Qr, CL2, P4, Dav",
    FontSlant->"Italic"],
  " [7], & C9j & C9J (which are both \"\[DoubleStruckCapitalJ]-signed\"), \
finding the expressions for ",
  StyleBox["p,q",
    FontSlant->"Italic"],
  ", etc. The",
  StyleBox[" C4",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Dav",
    FontSlant->"Italic"],
  " inverses are shown to split into partial fractions, because their \
determinants factorise. "
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 16. Solving for Multiplicative Inverses.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
(*16a C4*)
C4inv=Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"C4\"]=={1,0,0,0},{p,q,r,s}]
Apart[{p,q,r,s}/.C4inv]\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] \(\(-\)\(\ \)\) \(\((\(\(-\)\(\ \)\) a\^3 - \(b\^2\) c + 
                  a  c\^2 + 2 \( a \( b  d\)\) - 
                  c  d\^2)\) \((a\^4 - b\^4 + 4 \( a \(\( b\^2\) c\)\) - 2 \(\
\( a\^2\) c\^2\) + c\^4 - 4 \(\( a\^2\) \(b  d\)\) - 4 \( b \(\( c\^2\) d\)\) \
+ 2 \(\( b\^2\) d\^2\) + 4 \( a \( c  d\^2\)\) - d\^4)\)\^\(-1\)\), 
        q \[Rule] \(\(-\)\(\ \)\) \(\((\(a\^2\) b + b  c\^2 - \(b\^2\) d - 
                  2 \( a \( c  d\)\) + 
                  d\^3)\) \((a\^4 - b\^4 + 4 \( a \(\( b\^2\) c\)\) - 2 \(\( \
a\^2\) c\^2\) + c\^4 - 4 \(\( a\^2\) \(b  d\)\) - 4 \( b \(\( c\^2\) d\)\) + \
2 \(\( b\^2\) d\^2\) + 4 \( a \( c  d\^2\)\) - d\^4)\)\^\(-1\)\), 
        r \[Rule] \((a  b\^2 - \(a\^2\) c + c\^3 - 2 \( b \( c  d\)\) + 
                a  d\^2)\) \((a\^4 - b\^4 + 4 \( a \(\( b\^2\) c\)\) - 2 \(\( \
a\^2\) c\^2\) + c\^4 - 4 \(\( a\^2\) \(b  d\)\) - 4 \( b \(\( c\^2\) d\)\) + \
2 \(\( b\^2\) d\^2\) + 4 \( a \( c  d\^2\)\) - d\^4)\)\^\(-1\), 
        s \[Rule] \(\(-\)\(\ \)\) \(\((b\^3 - 
                  2 \( a \( b  c\)\) + \(a\^2\) d + \(c\^2\) d - 
                  b  d\^2)\) \((a\^4 - b\^4 + 4 \( a \(\( b\^2\) c\)\) - 2 \(\
\( a\^2\) c\^2\) + c\^4 - 4 \(\( a\^2\) \(b  d\)\) - 4 \( b \(\( c\^2\) d\)\) \
+ 2 \(\( b\^2\) d\^2\) + 4 \( a \( c  d\^2\)\) - d\^4)\)\^\(-1\)\)}}\)], \
"Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{\(1\/4\) \((a - b + c - d)\)\^\(-1\) + \(1\/4\) \((a + b + c + d)\)\^\
\(-1\) + \(1\/2\) \(\((a - 
                  c)\) \((a\^2 + b\^2 - 2 \( a  c\) + c\^2 - 2 \( b  d\) + \
d\^2)\)\^\(-1\)\), \(-\(1\/4\)\) \((a - b + c - d)\)\^\(-1\) + \(1\/4\) \((a \
+ b + c + d)\)\^\(-1\) + \(1\/2\) \(\((\(\(-\)\(\ \)\) b + 
                  d)\) \((a\^2 + b\^2 - 2 \( a  c\) + c\^2 - 2 \( b  d\) + \
d\^2)\)\^\(-1\)\), \(1\/4\) \((a - b + c - d)\)\^\(-1\) + \(1\/4\) \((a + b + \
c + d)\)\^\(-1\) + \(1\/2\) \(\((\(\(-\)\(\ \)\) a + 
                  c)\) \((a\^2 + b\^2 - 2 \( a  c\) + c\^2 - 2 \( b  d\) + \
d\^2)\)\^\(-1\)\), \(-\(1\/4\)\) \((a - b + c - d)\)\^\(-1\) + \(1\/4\) \((a \
+ b + c + d)\)\^\(-1\) + \(1\/2\) \(\((b - 
                  d)\) \((a\^2 + b\^2 - 2 \( a  c\) + c\^2 - 2 \( b  d\) + \
d\^2)\)\^\(-1\)\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16b Quaternion*)
Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"Qr\"]=={1,0,0,0},{p,q,r,s}]\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] a\/\(a\^2 + b\^2 + c\^2 + d\^2\), 
        q \[Rule] \(-\(b\/\(a\^2 + b\^2 + c\^2 + d\^2\)\)\), 
        r \[Rule] \(-\(c\/\(a\^2 + b\^2 + c\^2 + d\^2\)\)\), 
        s \[Rule] \(-\(d\/\(a\^2 + b\^2 + c\^2 + d\^2\)\)\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16c Clifford(2)*)
Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"CL2\"]=={1,0,0,0},{p,q,r,s}]\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] a\/\(a\^2 - b\^2 + c\^2 - d\^2\), 
        q \[Rule] \(-\(b\/\(a\^2 - b\^2 + c\^2 - d\^2\)\)\), 
        r \[Rule] \(-\(c\/\(a\^2 - b\^2 + c\^2 - d\^2\)\)\), 
        s \[Rule] \(-\(d\/\(a\^2 - b\^2 + c\^2 - d\^2\)\)\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16d Pauli-\[Sigma]*)
Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"P4\"]=={1,0,0,0},{p,q,r,s}]\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] a\/\(a\^2 - b\^2 - c\^2 - d\^2\), 
        q \[Rule] b\/\(\(-a\^2\) + b\^2 + c\^2 + d\^2\), 
        r \[Rule] \(-\(c\/\(a\^2 - b\^2 - c\^2 - d\^2\)\)\), 
        s \[Rule] \(-\(d\/\(a\^2 - b\^2 - c\^2 - d\^2\)\)\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16e Davenport Algebra*)
Davinv=Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"Dav\"]=={1,0,0,0},{p,q,r,s}]
Apart[{p,q,r,s}/.Davinv]\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] \(-\(\((\(-a\^3\) - a\ b\^2 - a\ c\^2 - 2\ b\ c\ d + 
                  a\ d\^2)\)/\((a\^4 + 2\ a\^2\ b\^2 + b\^4 + 2\ a\^2\ c\^2 - 
                  2\ b\^2\ c\^2 + c\^4 + 8\ a\ b\ c\ d - 2\ a\^2\ d\^2 + 
                  2\ b\^2\ d\^2 + 2\ c\^2\ d\^2 + d\^4)\)\)\), 
        q \[Rule] \(-\(\((a\^2\ b + b\^3 - b\ c\^2 + 2\ a\ c\ d + 
                  b\ d\^2)\)/\((a\^4 + 2\ a\^2\ b\^2 + b\^4 + 2\ a\^2\ c\^2 - 
                  2\ b\^2\ c\^2 + c\^4 + 8\ a\ b\ c\ d - 2\ a\^2\ d\^2 + 
                  2\ b\^2\ d\^2 + 2\ c\^2\ d\^2 + d\^4)\)\)\), 
        r \[Rule] \(-\(\((a\^2\ c - b\^2\ c + c\^3 + 2\ a\ b\ d + 
                  c\ d\^2)\)/\((a\^4 + 2\ a\^2\ b\^2 + b\^4 + 2\ a\^2\ c\^2 - 
                  2\ b\^2\ c\^2 + c\^4 + 8\ a\ b\ c\ d - 2\ a\^2\ d\^2 + 
                  2\ b\^2\ d\^2 + 2\ c\^2\ d\^2 + d\^4)\)\)\), 
        s \[Rule] \(-\(\((\(-2\)\ a\ b\ c + a\^2\ d - b\^2\ d - c\^2\ d - 
                  d\^3)\)/\((a\^4 + 2\ a\^2\ b\^2 + b\^4 + 2\ a\^2\ c\^2 - 
                  2\ b\^2\ c\^2 + c\^4 + 8\ a\ b\ c\ d - 2\ a\^2\ d\^2 + 
                  2\ b\^2\ d\^2 + 2\ c\^2\ d\^2 + d\^4)\)\)\)}}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{\(a - d\)\/\(2\ \((a\^2 + b\^2 + 2\ b\ c + c\^2 - 2\ a\ d + d\^2)\)\) \
+ \(a + d\)\/\(2\ \((a\^2 + b\^2 - 2\ b\ c + c\^2 + 2\ a\ d + d\^2)\)\), \
\(\(-b\) - c\)\/\(2\ \((a\^2 + b\^2 + 2\ b\ c + c\^2 - 2\ a\ d + d\^2)\)\) + \
\(\(-b\) + c\)\/\(2\ \((a\^2 + b\^2 - 2\ b\ c + c\^2 + 2\ a\ d + d\^2)\)\), \
\(\(-b\) - c\)\/\(2\ \((a\^2 + b\^2 + 2\ b\ c + c\^2 - 2\ a\ d + d\^2)\)\) + \
\(b - c\)\/\(2\ \((a\^2 + b\^2 - 2\ b\ c + c\^2 + 2\ a\ d + d\^2)\)\), \(\(-a\
\) + d\)\/\(2\ \((a\^2 + b\^2 + 2\ b\ c + c\^2 - 2\ a\ d + d\^2)\)\) + \(a + \
d\)\/\(2\ \((a\^2 + b\^2 - 2\ b\ c + c\^2 + 2\ a\ d + d\^2)\)\)}}\)], "Output",\

  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16f C9j*)
C9jinv=Solve[(hoopTimes[{p,q,r},{a,b,c},\"C9j\"]/.\[DoubleStruckCapitalJ]^3 \
\[Rule] 1)=={1,0,0},{p,q,r}]/.\[DoubleStruckCapitalJ]^3 \[Rule] 1\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] \(-\(\(\(-a\^2\) + b\ c\)\/\(a\^3 - 3\ a\ b\ c + 
                  c\^3\ \[DoubleStruckCapitalJ] + 
                  b\^3\ \[DoubleStruckCapitalJ]\^2\)\)\), 
        q \[Rule] \(-\(\(a\ b - c\^2\ \[DoubleStruckCapitalJ]\)\/\(a\^3 - 
                  3\ a\ b\ c + c\^3\ \[DoubleStruckCapitalJ] + 
                  b\^3\ \[DoubleStruckCapitalJ]\^2\)\)\), 
        r \[Rule] \(-\(\(a\ c - b\^2\ \[DoubleStruckCapitalJ]\^2\)\/\(a\^3 - 
                  3\ a\ b\ c + c\^3\ \[DoubleStruckCapitalJ] + 
                  b\^3\ \[DoubleStruckCapitalJ]\^2\)\)\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16g C9J*)
C9Jinv=Solve[(hoopTimes[{p,q,r},{a,b,c},\"C9J\"]/.\[DoubleStruckCapitalJ]^3 \
\[Rule] 1)=={1,0,0},{p,q,r}]/.\[DoubleStruckCapitalJ]^3 \[Rule] 1\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] \(-\(\(\(-a\^2\) + 
                  b\ c\ \[DoubleStruckCapitalJ]\)\/\(a\^3 + 
                  b\^3\ \[DoubleStruckCapitalJ] - 
                  3\ a\ b\ c\ \[DoubleStruckCapitalJ] + 
                  c\^3\ \[DoubleStruckCapitalJ]\^2\)\)\), 
        q \[Rule] \(-\(\(a\ b - c\^2\ \[DoubleStruckCapitalJ]\)\/\(a\^3 + 
                  b\^3\ \[DoubleStruckCapitalJ] - 
                  3\ a\ b\ c\ \[DoubleStruckCapitalJ] + 
                  c\^3\ \[DoubleStruckCapitalJ]\^2\)\)\), 
        r \[Rule] \(-\(\(\(-b\^2\) + a\ c\)\/\(a\^3 + 
                  b\^3\ \[DoubleStruckCapitalJ] - 
                  3\ a\ b\ c\ \[DoubleStruckCapitalJ] + 
                  c\^3\ \[DoubleStruckCapitalJ]\^2\)\)\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe procedure ",
  StyleBox["hoopIn",
    FontSlant->"Italic"],
  StyleBox["verse",
    FontSlant->"Italic"],
  " calculates the inverse of a vec in a conservative algebra. It is \
discussed in detail in Section 6.3, but is demonstrated in Example 17. The ",
  StyleBox["Qr",
    FontSlant->"Italic"],
  " inverse Ai of an arbitrary vec A={4.,1.,2.,3} is calculated, and Ai\
\[CenterDot]A is shown to be {1,0,0,0}. Then A is multiplied by B={5., 2., \
1., 7.}, giving AB= {-5., 24., 13., 40.}. Finally, AB is divided by A (by \
pre-multiplying by Ai), and B is recovered."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 17. Multiplicative Inverse, Division.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{id[\"Qr\"];\"A is\",A={4.,1.,2.,3},\"\\nQuaternion Inverse of A \
is\",Ai=hoopInverse[A],\"\\nAi\[CenterDot]A is the \
unit\",Chop[hoopTimes[Ai,A]],\"\\nB is            \",B={5.,2.,1.,7.},\"\\nAB \
is           \",AB=hoopTimes[A,B],\"\\nAi\[CenterDot]AB recovers \
B\",hoopTimes[Ai,AB]}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A is", {4.`, 1.`, 2.`, 3}, 
      "\nQuaternion Inverse of A is", {0.13333333333333333`, \
\(-0.03333333333333333`\), \(-0.06666666666666667`\), \(-0.1`\)}, 
      "\nAi\[CenterDot]A is the unit", {1.`, 0, 0, 0}, 
      "\nB is            ", {5.`, 2.`, 1.`, 7.`}, 
      "\nAB is           ", {\(-5.`\), 24.`, 13.`, 40.`}, 
      "\nAi\[CenterDot]AB recovers B", {5.`, 2.`, 0.9999999999999996`, 
        7.`}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2. Size Conservation.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tIf the multiplication table is a loop, the determinant has at least two \
factors. (It is a quasigroup with each element occuring once in each row and \
column. Add all the other rows to the first row; the sum of elements is then \
seen to be a determinant factor.) This is not true for signed tables; some \
factors (including the sum of the elements) are destroyed when a Moufang loop \
is folded to a signed table.\n\tMoufang Loop inverses split into partial \
fractions with their factors as denominators (Example 16a). A few small \
signed tables have a single factor or one repeated factor (Examples 16 b-d); \
most have a number of different factors (Example 16 e). I call the symbolic \
protoloop factors \"sizes\", and the list of sizes the \"shape\" of a loop or \
hoop. Section 4.3 goes into more detail of sizes & shapes. The \
complex-conjugate factor-pairs of quadratic factors are not conserved.\n\tI \
first inverted signed tables involving \[ImaginaryI] or \
\[DoubleStruckCapitalJ] (Example 16f) in September 2003 and found that sizes \
are actually \"generalized conjugates\" of the signed determinant factors. \
This is related to Frobenius's discovery (Section 4.4) that it is the \
determinant of the ",
  StyleBox["inverted",
    FontSlant->"Italic"],
  " associative table that is conserved. As the factors are identical where \
negation is the only sign, many sizes can be found from the direct table.\n\t\
Conservative hoops conserve all their \"sizes\" on multiplication - they are \
defined by that property. They also (trivially) conserve linear sizes on \
addition and splitting. Example 18 demonstrates conservation for two \
6-element groups by adding and multiplying two symbolic vecs. The linear size \
of the sum is subtracted from the linear sizes of the summands, giving {0,0} \
to show that it is conserved on addition. Then all the sizes of the product \
are shown to match the product of the multiplicand sizes."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 18. Conservation of C3C2 & D3 Sizes", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(a4 =. \), ";", \(A = {a1, a2, a3, a4, a5, a6}\), 
      ";", \(B = {b1, b2, b3, b4, b5, b6}\), ";", 
      RowBox[{"{", 
        RowBox[{
        "\"\<Set Target Loop to\>\"", ",", \(id["\<C3C2\>"]\), 
          ",", \(C3C2 // tf\), ",", "\"\<\\nSet  A =\>\"", 
          ",", \(A = {a1, a2, a3, a4, a5, a6}\), ",", "\"\<\\nSet  B =\>\"", 
          ",", \(B = {b1, b2, b3, b4, b5, b6}\), ",", "\"\<\\nThen AB=\>\"", 
          ",", \(AB = hoopTimes[A, B]\), ",", 
          StyleBox["\"\<\\nShape of A is  \>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sa = shape[A]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox["\"\<\\nShape of B is  \>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sb = shape[B]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox["\"\<\\nShape of A+B is \>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sapb = Simplify[shape[A + B]]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox["\"\<\\n'+' conserves linear factors\>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sapb = Simplify[Take[sa + sb - sapb, 2]]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox["\"\<\\nShape of AB is \>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sab = Simplify[shape[AB]]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          
          StyleBox["\"\<\\nProduct of shapes A & B = shape of product AB\>\"",
            
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(Simplify[sa\ sb == sab]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], "\[IndentingNewLine]", 
          "\"\<\\n\\nChange Target Loop to\>\"", ",", \(id["\<D3\>"]\), 
          ",", \(D3 // tf\), ",", "\"\<\\nAB=\>\"", 
          ",", \(AB = hoopTimes[A, B]\), 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox["\"\<\\nShape of A is  \>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sa = shape[A]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox["\"\<\\nShape of B is  \>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sb = shape[B]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox["\"\<\\nShape of A+B is \>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sapb = Simplify[shape[A + B]]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox["\"\<\\n'+' conserves linear factors\>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sapb = Simplify[Take[sa + sb - sapb, 2]]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox["\"\<\\nShape of AB is \>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(sab = Simplify[shape[AB]]\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          
          StyleBox["\"\<\\nProduct of shapes A & B = shape of product AB\>\"",
            
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          StyleBox[\(Simplify[sa\ sb == sab]\),
            FontSlant->"Plain"]}], 
        StyleBox["}",
          FontSlant->"Plain"]}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Set Target Loop to\"\>", ",", "\<\"C3C2\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "5", "6", "4"},
                  {"3", "1", "2", "6", "4", "5"},
                  {"4", "5", "6", "1", "2", "3"},
                  {"5", "6", "4", "2", "3", "1"},
                  {"6", "4", "5", "3", "1", "2"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nSet  A =\"\>", 
        ",", \({a1, a2, a3, a4, a5, a6}\), ",", "\<\"\\nSet  B =\"\>", 
        ",", \({b1, b2, b3, b4, b5, b6}\), ",", "\<\"\\nThen AB=\"\>", 
        ",", \({a1  b1 + a3  b2 + a2  b3 + a4  b4 + a6  b5 + a5  b6, 
          a2  b1 + a1  b2 + a3  b3 + a5  b4 + a4  b5 + a6  b6, 
          a3  b1 + a2  b2 + a1  b3 + a6  b4 + a5  b5 + a4  b6, 
          a4  b1 + a6  b2 + a5  b3 + a1  b4 + a3  b5 + a2  b6, 
          a5  b1 + a4  b2 + a6  b3 + a2  b4 + a1  b5 + a3  b6, 
          a6  b1 + a5  b2 + a4  b3 + a3  b4 + a2  b5 + a1  b6}\), 
        ",", "\<\"\\nShape of A is  \"\>", 
        ",", \({a1 + a2 + a3 + a4 + a5 + a6, 
          a1 + a2 + a3 - a4 - a5 - 
            a6, \(1\/2\) \((\((a1 - a2 + a4 - a5)\)\^2 + \((a1 - a3 + a4 - \
a6)\)\^2 + \((a2 - a3 + a5 - a6)\)\^2)\), \(1\/2\) \((\((a1 - a2 - a4 + a5)\)\
\^2 + \((a1 - a3 - a4 + a6)\)\^2 + \((a2 - a3 - a5 + a6)\)\^2)\)}\), 
        ",", "\<\"\\nShape of B is  \"\>", 
        ",", \({b1 + b2 + b3 + b4 + b5 + b6, 
          b1 + b2 + b3 - b4 - b5 - 
            b6, \(1\/2\) \((\((b1 - b2 + b4 - b5)\)\^2 + \((b1 - b3 + b4 - \
b6)\)\^2 + \((b2 - b3 + b5 - b6)\)\^2)\), \(1\/2\) \((\((b1 - b2 - b4 + b5)\)\
\^2 + \((b1 - b3 - b4 + b6)\)\^2 + \((b2 - b3 - b5 + b6)\)\^2)\)}\), 
        ",", "\<\"\\nShape of A+B is \"\>", 
        ",", \({a1 + a2 + a3 + a4 + a5 + a6 + b1 + b2 + b3 + b4 + b5 + b6, 
          a1 + a2 + a3 - a4 - a5 - a6 + b1 + b2 + b3 - b4 - b5 - 
            b6, \(1\/2\) \((\((a1 - a2 + a4 - a5 + b1 - b2 + b4 - b5)\)\^2 + \
\((a1 - a3 + a4 - a6 + b1 - b3 + b4 - b6)\)\^2 + \((a2 - a3 + a5 - a6 + b2 - \
b3 + b5 - b6)\)\^2)\), \(1\/2\) \((\((a1 - a2 - a4 + a5 + b1 - b2 - b4 + \
b5)\)\^2 + \((a1 - a3 - a4 + a6 + b1 - b3 - b4 + b6)\)\^2 + \((a2 - a3 - a5 + \
a6 + b2 - b3 - b5 + b6)\)\^2)\)}\), 
        ",", "\<\"\\n'+' conserves linear factors\"\>", ",", \({0, 0}\), 
        ",", "\<\"\\nShape of AB is \"\>", 
        ",", \({\((a1 + a2 + a3 + a4 + a5 + a6)\) \((b1 + b2 + b3 + b4 + b5 + 
                b6)\), \((a1 + a2 + a3 - a4 - a5 - a6)\) \((b1 + b2 + b3 - 
                b4 - b5 - b6)\), \((a1\^2 + a2\^2 + a3\^2 - a3  a4 + a4\^2 - 
                a3  a5 - a4  a5 + a5\^2 + 2 \( a3  a6\) - a4  a6 - a5  a6 + 
                a6\^2 - a2 \((a3 + a4 - 2  a5 + a6)\) - 
                a1 \((a2 + a3 - 2  a4 + a5 + a6)\))\) \((b1\^2 + b2\^2 + 
                b3\^2 - b3  b4 + b4\^2 - b3  b5 - b4  b5 + b5\^2 + 
                2 \( b3  b6\) - b4  b6 - b5  b6 + b6\^2 - 
                b2 \((b3 + b4 - 2  b5 + b6)\) - 
                b1 \((b2 + b3 - 2  b4 + b5 + b6)\))\), \((a1\^2 + a2\^2 + 
                a3\^2 + a3  a4 + a4\^2 + a3  a5 - a4  a5 + a5\^2 - 
                2 \( a3  a6\) - a4  a6 - a5  a6 + a6\^2 + 
                a2 \((\(\(-\)\(\ \)\) a3 + a4 - 2  a5 + a6)\) + 
                a1 \((\(\(-\)\(\ \)\) a2 - a3 - 2  a4 + a5 + 
                      a6)\))\) \((b1\^2 + b2\^2 + b3\^2 + b3  b4 + b4\^2 + 
                b3  b5 - b4  b5 + b5\^2 - 2 \( b3  b6\) - b4  b6 - b5  b6 + 
                b6\^2 + b2 \((\(\(-\)\(\ \)\) b3 + b4 - 2  b5 + b6)\) + 
                b1 \((\(\(-\)\(\ \)\) b2 - b3 - 2  b4 + b5 + b6)\))\)}\), 
        ",", "\<\"\\nProduct of shapes A & B = shape of product AB\"\>", ",", 
        "True", ",", "\<\"\\n\\nChange Target Loop to\"\>", ",", "\<\"D3\"\>",
         ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "1", "6", "5", "4", "3"},
                  {"3", "4", "5", "6", "1", "2"},
                  {"4", "3", "2", "1", "6", "5"},
                  {"5", "6", "1", "2", "3", "4"},
                  {"6", "5", "4", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nAB=\"\>", 
        ",", \({a1  b1 + a2  b2 + a5  b3 + a4  b4 + a3  b5 + a6  b6, 
          a2  b1 + a1  b2 + a4  b3 + a5  b4 + a6  b5 + a3  b6, 
          a3  b1 + a4  b2 + a1  b3 + a6  b4 + a5  b5 + a2  b6, 
          a4  b1 + a3  b2 + a6  b3 + a1  b4 + a2  b5 + a5  b6, 
          a5  b1 + a6  b2 + a3  b3 + a2  b4 + a1  b5 + a4  b6, 
          a6  b1 + a5  b2 + a2  b3 + a3  b4 + a4  b5 + a1  b6}\), 
        ",", "\<\"\\nShape of A is  \"\>", 
        ",", \({a1 + a2 + a3 + a4 + a5 + a6, 
          a1 - a2 + a3 - a4 + a5 - 
            a6, \(1\/2\) \((\((a1 - a3)\)\^2 - \((a2 - a4)\)\^2 + \((a1 - a5)\
\)\^2 + \((a3 - a5)\)\^2 - \((a2 - a6)\)\^2 - \((a4 - a6)\)\^2)\)}\), 
        ",", "\<\"\\nShape of B is  \"\>", 
        ",", \({b1 + b2 + b3 + b4 + b5 + b6, 
          b1 - b2 + b3 - b4 + b5 - 
            b6, \(1\/2\) \((\((b1 - b3)\)\^2 - \((b2 - b4)\)\^2 + \((b1 - b5)\
\)\^2 + \((b3 - b5)\)\^2 - \((b2 - b6)\)\^2 - \((b4 - b6)\)\^2)\)}\), 
        ",", "\<\"\\nShape of A+B is \"\>", 
        ",", \({a1 + a2 + a3 + a4 + a5 + a6 + b1 + b2 + b3 + b4 + b5 + b6, 
          a1 - a2 + a3 - a4 + a5 - a6 + b1 - b2 + b3 - b4 + b5 - 
            b6, \(1\/2\) \((\((a1 - a3 + b1 - b3)\)\^2 - \((a2 - a4 + b2 - \
b4)\)\^2 + \((a1 - a5 + b1 - b5)\)\^2 + \((a3 - a5 + b3 - b5)\)\^2 - \((a2 - \
a6 + b2 - b6)\)\^2 - \((a4 - a6 + b4 - b6)\)\^2)\)}\), 
        ",", "\<\"\\n'+' conserves linear factors\"\>", ",", \({0, 0}\), 
        ",", "\<\"\\nShape of AB is \"\>", 
        ",", \({\((a1 + a2 + a3 + a4 + a5 + a6)\) \((b1 + b2 + b3 + b4 + b5 + 
                b6)\), \((a1 - a2 + a3 - a4 + a5 - a6)\) \((b1 - b2 + b3 - 
                b4 + b5 - b6)\), \((a1\^2 - a2\^2 + a3\^2 - a4\^2 - a3  a5 + 
                a5\^2 - a1 \((a3 + a5)\) + a4  a6 - a6\^2 + 
                a2 \((a4 + a6)\))\) \((b1\^2 - b2\^2 + b3\^2 - b4\^2 - 
                b3  b5 + b5\^2 - b1 \((b3 + b5)\) + b4  b6 - b6\^2 + 
                b2 \((b4 + b6)\))\)}\), 
        ",", "\<\"\\nProduct of shapes A & B = shape of product AB\"\>", ",", 
        "True"}], "}"}]], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tSizes are a generalization of metrics and norms. The triangle inequality \
becomes exact, but sizes may be negative for non-abelian hoops, and may be \
linear, quadratic, cubic (rare), quartic etc. A4 is the smallest group with a \
conserved volume (cubic size); quartic sizes are very common.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4.3. Algebras, Determinant Factors, \"",
  StyleBox["sizes",
    FontSlant->"Italic"],
  "\" & \"",
  StyleBox["shapes",
    FontSlant->"Italic"],
  "\"."
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tWhilst general algebras allow very general entries (structure constants) \
in each cell of the Cayley multiplication table, many algebras of physical \
significance have single entries in each cell. The most relevant of these are \
related to Moufang Loops, and in particular to those tables that have \"",
  StyleBox["Frobenius-conservation",
    FontSlant->"Italic"],
  "\" for functions related to the factors of the multiplication table \
determinant. (I conjectured this to be a consequence of the Moufang \
properties until finding many exceptions amongst the non-associative Moufang \
loops in [8].) This is discussed and demonstrated in the next section, after \
introducing the determinant and its factors."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe database is restricted to tables with single elements in each cell; \
the elements are indices (or signed indices), and so vecs can be mapped \
(using ",
  StyleBox["gmap",
    FontSlant->"Italic"],
  ") onto the table by putting the signed i'th component of the vec wherever \
the index \"i\" appears in the protoloop. Hoops are algebras with very simple \
structure constants."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tLoop determinants can be calculated after mapping symbolic or numeric vec \
elements onto the index table. Frobenius [4] showed that the group property, \
associativity, was a sufficient condition for the determinant of a product to \
be the product of the multiplicand determinants (up to a minus sign). \
Octonions, a few other nonassociative Moufang loops, and many signed tables \
share this property with groups. I use it as the defining property for hoop \
algebras.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tConservative loops are found to conserve (up to a sign) the real factors of \
the determinant on multiplication - complex linear factors obtained by \
splitting quadratic factors into complex-conjugate pairs are not generally \
conserved. Real linear factors are trivially conserved on addition. I call \
each determinant factor a \"size\", and the list of sizes the \"shape\" of a \
vec in a particular algebra. Each size is a group \"ideal\". It is also a \
symmetric polynomial.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\t\tFrobenius worked with the inverse of the group table, whilst I usually \
work with the table itself. This is significant for signed tables, where the \
conserved properties appear to be \"plex-conjugates\" of the determinant \
factors of the non-inverted table (Section 6.3). If the table is unsigned, or \
only involves \"-\", the group table and the inverse table have the same \
factors, and sizes have been found from the group table determinant; \
conjugation does not alter them. With signed tables involving \[ImaginaryI] \
or \[DoubleStruckCapitalJ], etc, (",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^3\)]],
  "=1, see Section 5.1) the group table factors have to be modified in a way \
that is not yet fully understood; several such signed tables have been found \
to conserve their modified shapes. Appendix D goes into more detail."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tAs computer-mathematics systems such as ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are needed in all but the smallest cases, ",
  StyleBox["GroupLoopHoop.nb ",
    FontSlant->"Italic"],
  "provides procedures to factorize table determinants, and to find compact \
expressions for these factors. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can only factorise full symbolic tables up to 11\[Times]11 on my PC, and \
a number of techniques have been developed for larger tables (Appendix D). \
The shapes of many small loops have been found and are included in the \
database; the largest are for 32-element loops."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tMany non-linear sizes can be expressed in compact forms as the sums of \
smaller polynomials (which I call \"fragments\"). These are often sums of \
squares.  Some progress (Appendix D2)",
  StyleBox[" ",
    FontSlant->"Italic"],
  "has been made with the automatic calculation of these compact forms by the \
heuristic procedure ",
  StyleBox["frag",
    FontSlant->"Italic"],
  ".\n(Technical note. Negation is undefined for loops, but \"-\" always \
occurs in determinants as the \"symmetric differences\" of numbers. Squaring \
a symmetric difference gives a positive result; conservation \"up to a sign\" \
copes with negation in linear terms.)"
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.4. Loop Determinant Factor Conservation, Hoops.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tExample 19 multiplies two symbolic 4-vecs A & B using ",
  StyleBox["Qr ",
    FontSlant->"Italic"],
  "as the multiplication rule; this sets ",
  StyleBox["glo",
    FontSlant->"Italic"],
  " (the \"target\" loop) to ",
  StyleBox["Qr ",
    FontSlant->"Italic"],
  "so that it can be omitted from later instructions. (",
  StyleBox["hoopShape[\"Qr\"] ",
    FontSlant->"Italic"],
  " could be used to set the target loop.)",
  " The shape (the list of factors of the determinant) is available in the \
database, and so the shapes of A, B, & AB can be found. It is shown that the \
product of the sizes of A & B equals the sizes of the product AB. This is \
\"size conservation on multiplication\", the defining property for a hoop \
algebra."
}], "Text",
  PageWidth->WindowWidth],

Cell[" Example 19. Conservation of sizes.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "\"\<Symbolic shape for\>\"", ",", \(a4 =. ; qr = id["\<Qr\>"]\), 
        ",", \(sh["\<Qr\>"]\), ",", "\"\<\\nThe table is stored as \!\(\*
StyleBox[\"glo\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(glo // tf\), ",", 
        "\"\<\\nA=\>\"", ",", \(A = {a1, a2, a3, a4}\), ",", "\"\<B=\>\"", 
        ",", \(B = {b1, b2, b3, b4}\), ",", "\"\<\\n\!\(\*
StyleBox[\"AB\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontSlant->\"Italic\"]\)\>\"", 
        ",", \(AB = hoopTimes[A, B, qr]\), ",", "\"\<\\n\!\(\*
StyleBox[\"Shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",\nFontSlant->\"Italic\"]\)\>\"", 
        StyleBox[",",
          FontSlant->"Italic"], \(sa = shape[A]\), 
        StyleBox[",",
          FontSlant->"Italic"], "\"\<\\n\!\(\*
StyleBox[\"Shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"B\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",\nFontSlant->\"Italic\"]\)\>\"", 
        StyleBox[",",
          FontSlant->"Italic"], \(sb = shape[B]\), 
        StyleBox[",",
          FontSlant->"Italic"], "\"\<\\n\!\(\*
StyleBox[\"Shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"AB\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",\nFontSlant->\"Italic\"]\)\>\"", 
        StyleBox[",",
          FontSlant->"Italic"], \(sab = shape[AB]\), 
        StyleBox[",",
          FontSlant->"Italic"], "\"\<\\n\!\(\*
StyleBox[\"Product\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shapes\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"&\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"B\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"equals\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"AB\",\nFontSlant->\"Italic\"]\)\>\"", 
        StyleBox[",",
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], 
        RowBox[{
          StyleBox["Simplify",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontSlant->"Plain"], \(sa\ sb\  == sab\), 
          StyleBox["]",
            FontSlant->"Italic"]}]}], 
      StyleBox["}",
        FontSlant->"Plain"]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Symbolic shape for\"\>", ",", "\<\"Qr\"\>", 
        ",", \({a\^2 + b\^2 + c\^2 + d\^2}\), 
        ",", "\<\"\\nThe table is stored as \\!\\(\\* \
StyleBox[\\\"glo\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"=\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", \(-1\), "4", \(-3\)},
                  {"3", \(-4\), \(-1\), "2"},
                  {"4", "3", \(-2\), \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA=\"\>", ",", \({a1, a2, a3, a4}\), 
        ",", "\<\"B=\"\>", ",", \({b1, b2, b3, b4}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"AB\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\* StyleBox[\\\"=\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({a1\ b1 - a2\ b2 - a3\ b3 - a4\ b4, 
          a2\ b1 + a1\ b2 - a4\ b3 + a3\ b4, 
          a3\ b1 + a4\ b2 + a1\ b3 - a2\ b4, 
          a4\ b1 - a3\ b2 + a2\ b3 + a1\ b4}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"is\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({a1\^2 + a2\^2 + a3\^2 + a4\^2}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"B\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"is\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({b1\^2 + b2\^2 + b3\^2 + b4\^2}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"AB\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"is\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({\((a4\ b1 - a3\ b2 + a2\ b3 + a1\ b4)\)\^2 + \((a3\ b1 + a4\ \
b2 + a1\ b3 - a2\ b4)\)\^2 + \((a2\ b1 + a1\ b2 - a4\ b3 + a3\ b4)\)\^2 + \
\((a1\ b1 - a2\ b2 - a3\ b3 - a4\ b4)\)\^2}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Product\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"shapes\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"&\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"B\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"equals\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"AB\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", "True"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tWhilst Frobenius showed that all groups conserve their determinants, \
this property is also possessed by the larger class that I call \"hoops\" \
(because they are shape-conserving loops or rings). Octonions [3, pp97,303] \
and a few other non-associative Moufang Loops are included; they (and their \
direct compositions with abelian groups) appear to be the only \
\"alternative\" (square-associative, xx.y=x.xy but xy.z\[NotEqual]x.yz) \
tables that are conservative. The database contains many conservative tables. \
Most loops (even if they have a unit) are non-conservative but only a few \
such (identified by mnemonics ending in ",
  StyleBox["n",
    FontSlant->"Italic"],
  ") are included in the database. The table ",
  StyleBox["C6n ",
    FontSlant->"Italic"],
  "is tested in Example 20; it also has a shape, with two linear and two \
quadratic sizes, in the databank. Simplifying the product of the shapes minus \
the shape of the product gives {0,0, two long expressions}, showing that the \
last two sizes are NOT conserved. ",
  StyleBox["C6n",
    FontSlant->"Italic"],
  " is not a division algebra; the result of Ai= ",
  "hoopIn",
  "verse[ A,\"C6n\"] is NOT an inverse; neither is the solution to Ai\
\[CenterDot]A={1,0,0,0,0,0}."
}], "Text",
  PageWidth->WindowWidth],

Cell[" Example 20. Non-conservation of sizes with C6n.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[TextData[{
  "{\"",
  StyleBox["Target Loop is",
    FontSlant->"Italic"],
  "\",tst=C6n;id[tst],tst//tf,\"\\nMoufang \
Property\",MoufangQ[tst],A={a1,a2,a3,a4,a5,a6};B={b1,b2,b3,b4,b5,b6};\"\\nAB=\
\",AB=",
  "hoopTi",
  "mes[A,B],sa=shape[A];sb=shape[B];\"\\nShape[AB]-Shape[A]*Shape[B]\",sab=\
Simplify[shape[AB]-sa sb]}"
}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Target Loop is\"\>", ",", "\<\"C6n\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "6", "4", "5"},
                  {"3", "1", "2", "5", "6", "4"},
                  {"4", "5", "6", "2", "1", "3"},
                  {"5", "6", "4", "1", "3", "2"},
                  {"6", "4", "5", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nMoufang Property\"\>", ",", "False", 
        ",", "\<\"\\nAB=\"\>", 
        ",", \({a1\ b1 + a3\ b2 + a2\ b3 + a5\ b4 + a4\ b5 + a6\ b6, 
          a2\ b1 + a1\ b2 + a3\ b3 + a4\ b4 + a6\ b5 + a5\ b6, 
          a3\ b1 + a2\ b2 + a1\ b3 + a6\ b4 + a5\ b5 + a4\ b6, 
          a4\ b1 + a6\ b2 + a5\ b3 + a1\ b4 + a2\ b5 + a3\ b6, 
          a5\ b1 + a4\ b2 + a6\ b3 + a3\ b4 + a1\ b5 + a2\ b6, 
          a6\ b1 + a5\ b2 + a4\ b3 + a2\ b4 + a3\ b5 + a1\ b6}\), 
        ",", "\<\"\\nShape[AB]-Shape[A]*Shape[B]\"\>", 
        ",", \({0, 
          0, \(-3\)\ \((a2\ \((\(-a4\)\ b1 + a6\ b1 + a5\ b2 - a6\ b2 + 
                      a4\ b3 - a5\ b3)\) + 
                a1\ \((\(-a5\)\ b1 + a4\ \((b1 - b2)\) + a6\ b2 + a5\ b3 - 
                      a6\ b3)\) + 
                a3\ \((a5\ b1 - a6\ b1 + a4\ b2 - a5\ b2 - a4\ b3 + 
                      a6\ b3)\))\)\ \((b4 - 
                b5)\), \((a3\ \((a5\ \((b1 + b2 - 2\ b3)\) + 
                      a6\ \((b1 - 2\ b2 + b3)\) + 
                      a4\ \((\(-2\)\ b1 + b2 + b3)\))\) + 
                a2\ \((a6\ \((b1 + b2 - 2\ b3)\) + 
                      a4\ \((b1 - 2\ b2 + b3)\) + 
                      a5\ \((\(-2\)\ b1 + b2 + b3)\))\) + 
                a1\ \((a4\ \((b1 + b2 - 2\ b3)\) + 
                      a5\ \((b1 - 2\ b2 + b3)\) + 
                      a6\ \((\(-2\)\ b1 + b2 + b3)\))\))\)\ \((b4 + b5 - 
                2\ b6)\)}\)}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThe database contains the direct compositions of Oct with C2, C3, C4, K, \
C5, & Oct (all conservative), the same indirect compositions and the \
composition with C5n (none conservative). Several alternative tables are also \
included apart from these; apart from Q8M2, Q8pC2M, P16M, C8pC2M and C4iC4M \
they lack the Frobenius property.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tNoether's laws show that the particles and forces of physics are related to \
symmetries and conserved properties; and Stephen Adler argues that division \
algebras are needed to describe physics. Consequently these algebras should \
be relevant to particle physics. \
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Generalized Signs.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Summary. ",
  StyleBox["Roots of unity are generalized signs, which I write as ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^j\)]],
  StyleBox[" : ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["\[DoubleStruckS]",
            FontSlant->"Italic"], "r"], TraditionalForm]]],
  StyleBox["=1; I propose a set of double struck characters for specific \
generalized signs. \"-\" is one of the square roots, and \"\[ImaginaryI]\" is \
one of the fourth roots, of unity. Many algebras employ several different \
square roots, cube roots, etc. Algebraic expressions involving \"-\" & \"\
\[ImaginaryI]\" are special cases of more general expressions involving \
generalized signs; e.g ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{
            StyleBox["\[DoubleStruckS]",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "\[Theta]"}]], TraditionalForm]]],
  StyleBox[" defines multi-phase sinusoids with r phases (",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  StyleBox[" defines a 4-phase sinusoid that folds to Cos[\[Theta]]+\
\[ImaginaryI] Sin[\[Theta]]); ordinary negation is an equivalence relation on \
indexed pairs of numbers and generalizes to rotations of indexed sets.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["5.1. Roots of Unity provide Generalized Signs.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThe \"ordinary signs\" are \"+\" & \"-\"; the latter is a square root of \
+1 (or \"unity\"). The imaginary numbers \"\[ImaginaryI]\" & \"-\[ImaginaryI]\
\" also behave as signs; they are fourth roots of +1. As many algebras have \
more than one entity that squares to unity, \"-\" is ambiguous, and so it is \
misleading to call \[ImaginaryI] \"the\" square root of -1. \n\tGeneralized \
signs are distinct primitive roots of unity. There are \"terplex\" algebras \
using \[DoubleStruckCapitalJ], with ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^3\)]],
  "=1; \"Study numbers\" have two entities that square to unity; Quaternions \
have three entities (i, j, ij in Example 15) that are fourth roots of unity.\n\
\tExample 21 shows my proposed standard nomenclature for generalised signs, \
with ",
  Cell[BoxData[
      \(\[DoubleStruckS]\^j\)]],
  " : ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox["\[DoubleStruckS]", 
          StyleBox["\[DoubleStruckR]",
            FontSlant->"Italic"]], "\[Rule]", "1"}]]],
  " as a general case, the  \[DoubleStruckR]'th roots of unity. Example 21 \
also shows the substitution rules that make ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " handle \[DoubleStruckD], \[DoubleStruckG], \[DoubleStruckH], \
\[DoubleStruckCapitalI], \[DoubleStruckCapitalJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM], \[DoubleStruckN], \[DoubleStruckO], \
\[DoubleStruckS], \[DoubleStruckP] & \[DoubleStruckCapitalY] as generalized \
signs akin to \[ImaginaryI]. Various properties have to be specified; these \
are shown for \[DoubleStruckCapitalJ].\n\tWhilst roots of unity are commonly \
called \"cyclotomic roots of unity\", because they can be projected onto the \
unit circle in the complex plane, as generalized signs they are independent \
orthogonal mathematical entities. Expressing them as complex numbers puts \
them on a Procrustean bed and conceals their orthogonality. Generalised \
primitive roots of unitysigns (and their powers, until reaching unity) act as \
orthogonal directions, and several distinct \[DoubleStruckR]'th roots occur \
in many algebras - impossible for \"cyclotomic roots of unity\". In general, \
these signs are not converted to complex cyclotomic numbers; the properties \
shown in Example 21 are sufficient to define them. Section 5.5 is an \
exception; it is convenient to use the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " procedures for the standard Cos, Sin, etc functions there."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 21. Generalized Signs.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\"\<Proposed nomenclature for \!\(\*
StyleBox[\"Generalized\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Signs\",\nFontSlant->\"Italic\"]\) \>\"", ",", "unitSigns", ",", 
        "\"\<\\nVarious properties are imposed to ensure correct behaviour \
e.g.:-\\nNumber \[DoubleStruckCapitalJ] =\>\"", 
        ",", \(NumberQ[\[DoubleStruckCapitalJ]]\), ",", 
        "\"\<\\nSign[\[DoubleStruckCapitalJ]] =\>\"", 
        ",", \(Sign[\[DoubleStruckCapitalJ]]\), ",", 
        "\"\<\\nAbs[\[DoubleStruckCapitalJ]] =\>\"", 
        ",", \(Abs[\[DoubleStruckCapitalJ]]\), ",", 
        "\"\<\\nAbs[-\[DoubleStruckCapitalJ]] =\>\"", 
        ",", \(Abs[\(-\[DoubleStruckCapitalJ]\)]\), ",", 
        "\"\<\\nPositive \[DoubleStruckCapitalJ] =\>\"", 
        ",", \(Positive[\[DoubleStruckCapitalJ]]\), ",", 
        "\"\<\\nPositive -\[DoubleStruckCapitalJ] =\>\"", 
        ",", \(Positive[\(-\[DoubleStruckCapitalJ]\)]\), " ", ",", 
        "\"\<\\nRe[\[DoubleStruckCapitalJ]] =\>\"", 
        ",", \(Re[\[DoubleStruckCapitalJ]]\), ",", 
        "\"\<\\nRe[a_\[DoubleStruckCapitalJ]] =\>\"", 
        ",", \(Re[a_\ \[DoubleStruckCapitalJ]]\), ",", 
        "\"\<\\nImaginary[\[DoubleStruckCapitalJ]] =\>\"", 
        ",", \(Im[\[DoubleStruckCapitalJ]]\), ",", 
        "\"\<\\nImaginary[a_\[DoubleStruckCapitalJ]] =\>\"", 
        ",", \(Im[a_\ \[DoubleStruckCapitalJ]]\)}], "}"}]], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Proposed nomenclature for \\!\\(\\* \
StyleBox[\\\"Generalized\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Signs\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({\[DoubleStruckD]\^12 \[ShortRightArrow] 
            1, \[DoubleStruckD]\^any_ \[Rule] \[DoubleStruckD]\^Mod[any, 12], \
\[DoubleStruckG]\^7 \[Rule] 
            1, \[DoubleStruckG]\^any_ \[Rule] \[DoubleStruckG]\^Mod[any, 7], \
\[DoubleStruckH]\^6 \[Rule] 
            1, \[DoubleStruckH]\^any_ \[Rule] \[DoubleStruckH]\^Mod[any, 6], \
\[DoubleStruckCapitalI]\^4 \[Rule] 
            1, \[DoubleStruckCapitalI]\^any_ \[Rule] \
\[DoubleStruckCapitalI]\^Mod[any, 4], \[DoubleStruckCapitalJ]\^3 \[Rule] 
            1, \[DoubleStruckCapitalJ]\^any_ \[Rule] \
\[DoubleStruckCapitalJ]\^Mod[any, 3], \[DoubleStruckK]\^any_?OddQ \[Rule] \
\[DoubleStruckK], \[DoubleStruckK]\^any_?EvenQ \[Rule] 
            1, \[DoubleStruckL]\^any_?OddQ \[Rule] \[DoubleStruckL], \
\[DoubleStruckL]\^any_?EvenQ \[Rule] 
            1, \[DoubleStruckM]\^any_?OddQ \[Rule] \[DoubleStruckM], \
\[DoubleStruckM]\^any_?EvenQ \[Rule] 1, \[DoubleStruckN]\^9 \[Rule] 
            1, \[DoubleStruckN]\^any_ \[Rule] \[DoubleStruckN]\^Mod[any, 9], \
\[DoubleStruckO]\^8 \[Rule] 
            1, \[DoubleStruckO]\^any_ \[Rule] \[DoubleStruckO]\^Mod[any, 8], \
\[DoubleStruckP]\^5 \[Rule] 
            1, \[DoubleStruckP]\^any_ \[Rule] \[DoubleStruckP]\^Mod[any, 5], \
\[DoubleStruckS]\^GroupLoopHoop`Private`\[DoubleStruckR] \[Rule] 
            1, \[DoubleStruckS]\^any_ \[Rule] \[DoubleStruckS]\^Mod[any, \
GroupLoopHoop`Private`\[DoubleStruckR]], \[DoubleStruckCapitalY]\^3 \[Rule] 
            1, \[DoubleStruckCapitalY]\^any_ \[Rule] \
\[DoubleStruckCapitalY]\^Mod[any, 3]}\), 
        ",", "\<\"\\nVarious properties are imposed to ensure correct \
behaviour e.g.:-\\nNumber \[DoubleStruckCapitalJ] =\"\>", ",", "True", 
        ",", "\<\"\\nSign[\[DoubleStruckCapitalJ]] =\"\>", ",", 
        "\[DoubleStruckCapitalJ]", 
        ",", "\<\"\\nAbs[\[DoubleStruckCapitalJ]] =\"\>", ",", "1", 
        ",", "\<\"\\nAbs[-\[DoubleStruckCapitalJ]] =\"\>", ",", "1", 
        ",", "\<\"\\nPositive \[DoubleStruckCapitalJ] =\"\>", ",", "False", 
        ",", "\<\"\\nPositive -\[DoubleStruckCapitalJ] =\"\>", ",", "False", 
        ",", "\<\"\\nRe[\[DoubleStruckCapitalJ]] =\"\>", ",", "0", 
        ",", "\<\"\\nRe[a_\[DoubleStruckCapitalJ]] =\"\>", ",", "0", 
        ",", "\<\"\\nImaginary[\[DoubleStruckCapitalJ]] =\"\>", ",", "0", 
        ",", "\<\"\\nImaginary[a_\[DoubleStruckCapitalJ]] =\"\>", ",", "0"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe following sections show how generalized signs are used as (1) group \
relators, (2) in 2\[Times]2 (\[Sigma]), 3\[Times]3 (\[Tau]) and 4\[Times]4 (\
\[Gamma]) unitary monomial matrices, to generate groups with second negation \
(",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckK]\^2\)]],
  "=+1), ternary (",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^3\)]],
  "=+1), and other symmetries, (3) as signs in tables such as ",
  StyleBox["C9J",
    FontSlant->"Italic"],
  ", and (4) to define generalized \"polyhelix\" sinusoids."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2. Generalized Signs as group relators.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tExample 8 (Section 3.2.5) demonstrated the use of generalized signs to \
create the group A4 via the ",
  StyleBox["ge",
    FontSlant->"Italic"],
  " procedure. This required one cube root and two distinct square roots of \
unity (called \"",
  StyleBox["a",
    FontSlant->"Italic"],
  "\", \"",
  StyleBox["b",
    FontSlant->"Italic"],
  "\" & \"",
  StyleBox["c",
    FontSlant->"Italic"],
  "\" rather than \[DoubleStruckCapitalJ], \[DoubleStruckK] & \
\[DoubleStruckL] because ",
  StyleBox["ge",
    FontSlant->"Italic"],
  " needs lex ordering of relators). Prime groups have a single (prime root) \
relator. Every group probably has relators whose powers multiply to the group \
length; e.g. ",
  StyleBox["g3251",
    FontSlant->"Italic"],
  " needs 5 relators that are different square roots of unity, ",
  Cell[BoxData[
      \(TraditionalForm\`2\^5\)]],
  "=32. The database includes a few groups for which I have not found such \
relators."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tMost ",
  "rela",
  "tor rules were discovered empirically, retaining the shortest wherever \
more than one gave a particular group. I later learned that most could have \
been found by using the GAP instruction ",
  StyleBox["gap> RelatorsOfFpGroup( Image( IsomorphismFpGroup( SmallGroup( \
mm,nn))))",
    FontSlant->"Italic"],
  ". See Section 13.2. "
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3. Generalized Signs in Unitary Monomial Matrices.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
 \tExample 22  shows two \"unitary monomial matrices\" employing the \
generalized signs \[DoubleStruckCapitalJ]  & \[DoubleStruckG]. The \
determinants of these matrices are 1 (unitary) and they have exactly one \
non-zero element in each row and column (monomial); together they generate \
the group C21.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["Example 22. Generalized Signs in Unitary Monomial Matrices.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"Two\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"\[Times]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"unitary\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"matrices\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"using\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"generalized\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"signs\",\nFontSlant->\"Italic\"]\) \>\"", 
        ",", \(u2[\([10]\)] // tf\), ",", \(u2[\([21]\)] // tf\), ",", 
        "\"\<\\n\!\(\*
StyleBox[\"They\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"generate\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"isomorph\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) \>\"", ",", \(mm =. ; 
        id[test = mg[{21, 10}, u2]]\), ",", "\"\<\!\(\*
StyleBox[\"which\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"has\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"matrix\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"elements\",\nFontSlant->\"Italic\"]\) \>\"", ",", "matel", ",", 
        "\"\<\\n\!\(\*
StyleBox[\"and\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"dimensions\",\nFontSlant->\"Italic\"]\) \>\"", 
        ",", \(Dimensions[test]\)}], "}"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"\\!\\(\\* \
StyleBox[\\\"Two\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"2\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"\
\[Times]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"2\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"unitary\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"matrices\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"using\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"generalized\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"signs\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"\[DoubleStruckCapitalJ]", "0"},
                  {"0", \(\[DoubleStruckCapitalJ]\^2\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"\[DoubleStruckG]", "0"},
                  {"0", \(\[DoubleStruckG]\^6\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"They\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"generate\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"isomorph\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", "\<\"C21\"\>", 
        ",", "\<\"\\!\\(\\* StyleBox[\\\"which\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\* StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"matrix\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"elements\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({{{1, 0}, {0, 1}}, {{\[DoubleStruckG], 
              0}, {0, \[DoubleStruckG]\^6}}, {{\[DoubleStruckCapitalJ], 
              0}, {0, \[DoubleStruckCapitalJ]\^2}}, {{\[DoubleStruckG]\^2, 
              0}, {0, \[DoubleStruckG]\^5}}, {{\[DoubleStruckG]\ \
\[DoubleStruckCapitalJ], 
              0}, {0, \[DoubleStruckG]\^6\ \[DoubleStruckCapitalJ]\^2}}, {{\
\[DoubleStruckG]\^3, 
              0}, {0, \[DoubleStruckG]\^4}}, {{\[DoubleStruckG]\^2\ \
\[DoubleStruckCapitalJ], 
              0}, {0, \[DoubleStruckG]\^5\ \[DoubleStruckCapitalJ]\^2}}, {{\
\[DoubleStruckG]\^4, 
              0}, {0, \[DoubleStruckG]\^3}}, {{\[DoubleStruckG]\^3\ \
\[DoubleStruckCapitalJ], 
              0}, {0, \[DoubleStruckG]\^4\ \[DoubleStruckCapitalJ]\^2}}, {{\
\[DoubleStruckG]\^5, 
              0}, {0, \[DoubleStruckG]\^2}}, {{\[DoubleStruckG]\^4\ \
\[DoubleStruckCapitalJ], 
              0}, {0, \[DoubleStruckG]\^3\ \[DoubleStruckCapitalJ]\^2}}, {{\
\[DoubleStruckG]\^6, 
              0}, {0, \[DoubleStruckG]}}, {{\[DoubleStruckG]\^5\ \
\[DoubleStruckCapitalJ], 
              0}, {0, \[DoubleStruckG]\^2\ \[DoubleStruckCapitalJ]\^2}}, {{\
\[DoubleStruckG]\^6\ \[DoubleStruckCapitalJ], 
              0}, {0, \[DoubleStruckG]\ \[DoubleStruckCapitalJ]\^2}}, {{\
\[DoubleStruckCapitalJ]\^2, 
              0}, {0, \[DoubleStruckCapitalJ]}}, {{\[DoubleStruckG]\ \
\[DoubleStruckCapitalJ]\^2, 
              0}, {0, \[DoubleStruckG]\^6\ \[DoubleStruckCapitalJ]}}, {{\
\[DoubleStruckG]\^2\ \[DoubleStruckCapitalJ]\^2, 
              0}, {0, \[DoubleStruckG]\^5\ \[DoubleStruckCapitalJ]}}, {{\
\[DoubleStruckG]\^3\ \[DoubleStruckCapitalJ]\^2, 
              0}, {0, \[DoubleStruckG]\^4\ \[DoubleStruckCapitalJ]}}, {{\
\[DoubleStruckG]\^4\ \[DoubleStruckCapitalJ]\^2, 
              0}, {0, \[DoubleStruckG]\^3\ \[DoubleStruckCapitalJ]}}, {{\
\[DoubleStruckG]\^5\ \[DoubleStruckCapitalJ]\^2, 
              0}, {0, \[DoubleStruckG]\^2\ \[DoubleStruckCapitalJ]}}, {{\
\[DoubleStruckG]\^6\ \[DoubleStruckCapitalJ]\^2, 
              0}, {0, \[DoubleStruckG]\ \[DoubleStruckCapitalJ]}}}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"and\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"dimensions\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({21, 21}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4. Generalized Signs in Signed Tables.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tAll groups are hoops, because they can be considered to be folded from \
the composition of the group with C2 or C4, and this allows them to be \
algebras over the real and complex fields, as well as being loop \
multiplication tables for sets of primal coefficients. If they have the \
appropriate structure, as in Example 10, they can be folded to versions with \
some negated indices or, as in ",
  StyleBox["P4,",
    FontSlant->"Italic"],
  " some complex indices. Others fold to \[DoubleStruckCapitalJ]-signed \
algebras, such as those in Example 23. This uses the ",
  StyleBox["ts",
    FontSlant->"Italic"],
  " procedure (",
  StyleBox["tosignedTable",
    FontSlant->"Italic"],
  ") which ",
  "is sufficiently general to handle signs \[ImaginaryI] & \
\[DoubleStruckCapitalJ] and to fold suitable loops to signed tables."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
Example 23. Generalized Sign \[DoubleStruckCapitalJ] in Signed Tables.\
\>", "Subsubsection",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<The C9 group isomorph\>", 
      tstJ = {{1, 2, 3, 4, 5, 6, 7, 8, 9}, {2, 9, 1, 5, 3, 4, 8, 6, 7}, {3, 
            1, 5, 6, 4, 8, 9, 7, 2}, {4, 5, 6, 7, 8, 9, 1, 2, 3}, {5, 3, 4, 
            8, 6, 7, 2, 9, 1}, {6, 4, 8, 9, 7, 2, 3, 1, 5}, {7, 8, 9, 1, 2, 
            3, 4, 5, 6}, {8, 6, 7, 2, 9, 1, 5, 3, 4}, {9, 7, 2, 3, 1, 5, 6, 
            4, 8}}; \[IndentingNewLine]tstJ // 
        tf, "\<\[DoubleStruckCapitalJ]-folds to\>", id[tstj = ts[tstJ, 3]], 
      tstj // tf, "\<The C3C3 group isomorph\>", 
      tstJJ = {{1, 2, 3, 4, 5, 6, 7, 8, 9}, {2, 9, 4, 5, 3, 7, 8, 6, 1}, {3, 
            4, 8, 6, 7, 2, 9, 1, 5}, {4, 5, 6, 7, 8, 9, 1, 2, 3}, {5, 3, 7, 
            8, 6, 1, 2, 9, 4}, {6, 7, 2, 9, 1, 5, 3, 4, 8}, {7, 8, 9, 1, 2, 
            3, 4, 5, 6}, {8, 6, 1, 2, 9, 4, 5, 3, 7}, {9, 1, 5, 3, 4, 8, 6, 
            7, 2}}; \[IndentingNewLine]tstJJ // 
        tf, "\<\[DoubleStruckCapitalJ]-folds to\>", id[tstjj = ts[tstJJ, 3]], 
      tstjj // tf}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"The C9 group isomorph\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8", "9"},
                  {"2", "9", "1", "5", "3", "4", "8", "6", "7"},
                  {"3", "1", "5", "6", "4", "8", "9", "7", "2"},
                  {"4", "5", "6", "7", "8", "9", "1", "2", "3"},
                  {"5", "3", "4", "8", "6", "7", "2", "9", "1"},
                  {"6", "4", "8", "9", "7", "2", "3", "1", "5"},
                  {"7", "8", "9", "1", "2", "3", "4", "5", "6"},
                  {"8", "6", "7", "2", "9", "1", "5", "3", "4"},
                  {"9", "7", "2", "3", "1", "5", "6", "4", "8"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\[DoubleStruckCapitalJ]-folds to\"\>", 
        ",", "\<\"C9j\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", \(3\ \[DoubleStruckCapitalJ]\^2\), "1"},
                  {"3", "1", \(2\ \[DoubleStruckCapitalJ]\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"The C3C3 group isomorph\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8", "9"},
                  {"2", "9", "4", "5", "3", "7", "8", "6", "1"},
                  {"3", "4", "8", "6", "7", "2", "9", "1", "5"},
                  {"4", "5", "6", "7", "8", "9", "1", "2", "3"},
                  {"5", "3", "7", "8", "6", "1", "2", "9", "4"},
                  {"6", "7", "2", "9", "1", "5", "3", "4", "8"},
                  {"7", "8", "9", "1", "2", "3", "4", "5", "6"},
                  {"8", "6", "1", "2", "9", "4", "5", "3", "7"},
                  {"9", "1", "5", "3", "4", "8", "6", "7", "2"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\[DoubleStruckCapitalJ]-folds to\"\>", 
        ",", "\<\"C3C3j\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", \(3\ \[DoubleStruckCapitalJ]\^2\), 
                    "\[DoubleStruckCapitalJ]"},
                  {"3", 
                    "\[DoubleStruckCapitalJ]", \(2\ \
\[DoubleStruckCapitalJ]\^2\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.5. Exponent of Generalised Signs, PolyHelix Identity.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tExtended signs, \[DoubleStruckS] : ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^r\)]],
  "=1, generalize the sinusoids Cos[x] = Re[",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ x\)\)]],
  "], Sin[x] = Im[",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ x\)\)]],
  "] to multi-phase sinusoids ",
  StyleBox["genCos[x,m] ",
    FontSlant->"Italic"],
  "= Re[",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_m\%\(\[DoubleStruckS]\ x\)\)]],
  "] where ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_m\)]],
  " is a (normalizing) modification of \[ExponentialE] that depends on ",
  StyleBox["m",
    FontSlant->"Italic"],
  ", the number of phases. The normalising element is easily shown to be \
Re[",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_m\%\(Im[\[DoubleStruckS]]\)\)]],
  "] = Re[",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^Im[\((\(-1\))\)\^\(2/m\)]\)]],
  "], where the second expression is the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " implementation of the first. (This gives ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_3\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_6\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\@3/2\)\)]],
  "\[TildeEqual]2.3774, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_12\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\@\[ExponentialE]\)]],
  "\[TildeEqual]1.6487). The generation of these sinusoids as solutions to \
banded differential equations is described in Appendix E.\n\tMulti-phase \
sinusoids have an exponential series formulation that simplifies, when ",
  StyleBox["m",
    FontSlant->"Italic"],
  " = 4, to half the standard Cos and Sin series, with half the terms \
becoming zero. This is traditionally folded and mis-interpreted as two \
asymmetrical phases, {Cos[x], Sin[x]} instead of four symmetrical phases ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ x\)\)]],
  " = {Cos[x], Sin[x], -Cos[x], -Sin[x]}/2. \n\tIt is convenient to include a \
phase parameter \"j\" in the generalised sinusoid procedures ",
  StyleBox["genCos[x,m,j]",
    FontSlant->"Italic"],
  " & ",
  StyleBox["genSin[x,m,j],",
    FontSlant->"Italic"],
  " and to normalize the amplitude to 1.  I also include phases between \
+Cosh[x] and -Cosh[x] if ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=0, and between Cosh[x] and Sinh[x] if ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=2."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell["Example  24.  genCos, genSin.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?genCos\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("genCos[x_,m_:4,j_:0] creates the j'th phase of the generalized \
antisymmetric sinusoid or helix with m phases; generalised Cosh and Sinh \
functions are generated if m=0 or 2."\)], "Print",
  PageWidth->WindowWidth,
  CellTags->"Info3362457282-3716175"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?genSin\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("genSin[x_,m_:4,j_:0] creates the j'th phase of the generalized \
symmetric sinusoid or helix with m phases; generalised Cosh and Sinh \
functions are generated if m=0 or 2."\)], "Print",
  PageWidth->WindowWidth,
  CellTags->"Info3362457286-9933190"]
}, Open  ]],

Cell[TextData[{
  "\tExamples 25 & 26 demonstrate ",
  StyleBox["genCos",
    FontSlant->"Italic"],
  " & ",
  StyleBox["genSin ",
    FontSlant->"Italic"],
  "by plotting three phases of the 3-phase & 12-phase sinusoids over their \
periods 2\[Pi]/Sin[2\[Pi]/3] = ",
  Cell[BoxData[
      \(\@3\)]],
  "\[Pi] = 7.2552 & 4\[Pi]=12.5664. "
}], "Text",
  PageWidth->WindowWidth],

Cell["Example  25.  3-phase Sinusoids.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{genCos[x, 3], genCos[x, 3, 1], genCos[x, 3, 2]}, {x, 0, 
          2  \[Pi]/Sin[2  \[Pi]/3]}, 
        PlotLabel -> "\<Fig.4. genCos. Phases 0,1,2 for m = 3\>"];\)\)], \
"Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.131269 0.309017 0.294302 [
[.15508 .29652 -3 -9 ]
[.15508 .29652 3 0 ]
[.28635 .29652 -3 -9 ]
[.28635 .29652 3 0 ]
[.41762 .29652 -3 -9 ]
[.41762 .29652 3 0 ]
[.54888 .29652 -3 -9 ]
[.54888 .29652 3 0 ]
[.68015 .29652 -3 -9 ]
[.68015 .29652 3 0 ]
[.81142 .29652 -3 -9 ]
[.81142 .29652 3 0 ]
[.94269 .29652 -3 -9 ]
[.94269 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -113 0 ]
[.5 .63053 113 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15508 .30902 m
.15508 .31527 L
s
[(1)] .15508 .29652 0 1 Mshowa
.28635 .30902 m
.28635 .31527 L
s
[(2)] .28635 .29652 0 1 Mshowa
.41762 .30902 m
.41762 .31527 L
s
[(3)] .41762 .29652 0 1 Mshowa
.54888 .30902 m
.54888 .31527 L
s
[(4)] .54888 .29652 0 1 Mshowa
.68015 .30902 m
.68015 .31527 L
s
[(5)] .68015 .29652 0 1 Mshowa
.81142 .30902 m
.81142 .31527 L
s
[(6)] .81142 .29652 0 1 Mshowa
.94269 .30902 m
.94269 .31527 L
s
[(7)] .94269 .29652 0 1 Mshowa
.125 Mabswid
.05006 .30902 m
.05006 .31277 L
s
.07632 .30902 m
.07632 .31277 L
s
.10257 .30902 m
.10257 .31277 L
s
.12882 .30902 m
.12882 .31277 L
s
.18133 .30902 m
.18133 .31277 L
s
.20759 .30902 m
.20759 .31277 L
s
.23384 .30902 m
.23384 .31277 L
s
.26009 .30902 m
.26009 .31277 L
s
.3126 .30902 m
.3126 .31277 L
s
.33885 .30902 m
.33885 .31277 L
s
.36511 .30902 m
.36511 .31277 L
s
.39136 .30902 m
.39136 .31277 L
s
.44387 .30902 m
.44387 .31277 L
s
.47012 .30902 m
.47012 .31277 L
s
.49638 .30902 m
.49638 .31277 L
s
.52263 .30902 m
.52263 .31277 L
s
.57514 .30902 m
.57514 .31277 L
s
.60139 .30902 m
.60139 .31277 L
s
.62765 .30902 m
.62765 .31277 L
s
.6539 .30902 m
.6539 .31277 L
s
.70641 .30902 m
.70641 .31277 L
s
.73266 .30902 m
.73266 .31277 L
s
.75891 .30902 m
.75891 .31277 L
s
.78517 .30902 m
.78517 .31277 L
s
.83768 .30902 m
.83768 .31277 L
s
.86393 .30902 m
.86393 .31277 L
s
.89018 .30902 m
.89018 .31277 L
s
.91644 .30902 m
.91644 .31277 L
s
.96894 .30902 m
.96894 .31277 L
s
.9952 .30902 m
.9952 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -174 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.4) show
93.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(genCos) show
141.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
153.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phases) show
195.000 12.750 moveto
(0) show
201.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
207.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
213.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
219.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
231.000 12.750 moveto
(for) show
255.000 12.750 moveto
(m) show
267.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
279.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
285.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01924 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01565 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38344 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .16187 m
.06244 .23088 L
.10458 .31175 L
.14415 .38761 L
.18221 .45561 L
.22272 .5178 L
.26171 .5637 L
.28302 .58185 L
.29279 .58839 L
.30316 .59406 L
.31266 .59809 L
.31807 .59988 L
.32313 .60121 L
.32777 .60215 L
.33201 .60277 L
.33436 .60301 L
.33568 .60312 L
.33691 .6032 L
.33809 .60325 L
.33917 .60329 L
.3404 .60331 L
.34157 .60332 L
.34273 .60331 L
.34398 .60327 L
.34515 .60322 L
.34622 .60316 L
.34885 .60295 L
.35133 .60267 L
.35627 .60188 L
.36165 .60066 L
.37124 .59758 L
.38012 .5937 L
.39878 .58239 L
.41939 .56509 L
.45959 .51812 L
.49828 .45906 L
.53942 .38569 L
.57904 .30965 L
.61715 .23641 L
.65771 .16358 L
.69676 .1032 L
.71667 .07742 L
.73825 .05399 L
.75906 .03629 L
.76896 .02965 L
.77824 .02451 L
.78728 .02053 L
.79193 .01888 L
.797 .01739 L
.79987 .01669 L
Mistroke
.80253 .01614 L
.80529 .01566 L
.80778 .01531 L
.81024 .01505 L
.81256 .01487 L
.81383 .0148 L
.815 .01475 L
.81628 .01472 L
.81693 .01472 L
.81764 .01472 L
.81895 .01473 L
.82016 .01476 L
.82079 .01479 L
.82149 .01482 L
.8229 .0149 L
.82546 .01512 L
.82787 .01541 L
.83236 .01613 L
.83719 .0172 L
.84251 .01873 L
.84811 .02071 L
.85811 .02524 L
.8779 .0378 L
.89628 .05361 L
.93537 .09936 L
.97619 .16187 L
Mfstroke
.02381 .16187 m
.06244 .10236 L
.08255 .07646 L
.10458 .05279 L
.12507 .03562 L
.13422 .02954 L
.14415 .0241 L
.14961 .02163 L
.15465 .01968 L
.15937 .01815 L
.16457 .01678 L
.16922 .01585 L
.17146 .0155 L
.17359 .01523 L
.17474 .0151 L
.17599 .01499 L
.17714 .0149 L
.17819 .01484 L
.17943 .01478 L
.18012 .01475 L
.18076 .01474 L
.18191 .01472 L
.18314 .01472 L
.18439 .01474 L
.18552 .01477 L
.18682 .01483 L
.18806 .01491 L
.19026 .0151 L
.19265 .01537 L
.19528 .01575 L
.19807 .01626 L
.20308 .01741 L
.2131 .02067 L
.22415 .02573 L
.2435 .03819 L
.26435 .05655 L
.30549 .10634 L
.34512 .16838 L
.38322 .23711 L
.42378 .31513 L
.46283 .38989 L
.50433 .46338 L
.54431 .52337 L
.58278 .56714 L
.60265 .58341 L
.61267 .58984 L
.62369 .59549 L
.62891 .59764 L
.63386 .59937 L
.63835 .60066 L
Mistroke
.64314 .60176 L
.64586 .60226 L
.64833 .60263 L
.65081 .60292 L
.65314 .60312 L
.65447 .6032 L
.65519 .60324 L
.65587 .60327 L
.65706 .6033 L
.65838 .60332 L
.65911 .60332 L
.65981 .60331 L
.66111 .60328 L
.66184 .60326 L
.66251 .60323 L
.66403 .60314 L
.66522 .60305 L
.66646 .60294 L
.66868 .60268 L
.67369 .60189 L
.67801 .60094 L
.68274 .59964 L
.69342 .59564 L
.70335 .59066 L
.72385 .57657 L
.74245 .55956 L
.78248 .51056 L
.821 .45017 L
.86197 .37609 L
.90143 .30008 L
.93937 .22749 L
.97619 .16187 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00;@3oool00`000000oooo0?ooo`3o0?oooh40oooo000]0?ooo`030000003oool0oooo0?l0
ooooP@3oool00200oooo1`0000060?ooo`030000003oool0oooo0?l0ooooP@3oool002<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooh40oooo000S0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3ooon10?ooo`008`3oool00`000000oooo0?ooo`070?oo
o`<00000>03oool6000007L0oooo1@00001g0?ooo`D00000BP3oool001L0oooo1P0000060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0=03oool5000000D0oooo1P00001/0?ooo`D0
00001@3oool4000006d0oooo1P0000050?ooo`D00000A@3oool002<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0`0?ooo`@00000403oool2000006H0oooo1000000>0?ooo`<00000
J03oool200000100oooo0`0000120?ooo`008`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo02h0oooo0P00000F0?ooo`800000HP3oool2000001D0oooo1000001Q0?ooo`<000005@3o
ool3000003l0oooo000Q0?ooo`<000002@3oool00`000000oooo0?ooo`0/0?ooo`8000006P3oool2
000005h0oooo0P00000K0?ooo`<00000F`3oool3000001/0oooo0`00000l0?ooo`008`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02X0oooo0P00000N0?ooo`800000FP3oool20000
0200oooo00<000000?ooo`3oool0EP3oool200000240oooo0P00000j0?ooo`00;@3oool00`000000
oooo0?ooo`0X0?ooo`8000008P3oool2000005H0oooo0P00000S0?ooo`800000E@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo000]0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1A0?ooo`8000009`3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=P3oool002d0oooo00<0
00000?ooo`3oool09@3oool2000002P0oooo0P00001@0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0CP3oool2000002T0oooo0P00000f0?ooo`00;@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02X0oooo0P00001=0?ooo`030000003oool0oooo02X0oooo0P00001=
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0<`3oool002d0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0<P3oool002d0oooo00<000000?ooo`3oool08@3oool200000340oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0a0?ooo`00;@3oool200000240oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`140?ooo`800000<`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0<03oool002d0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0=03o
ool2000004<0oooo0P00000e0?ooo`030000003oool0oooo02l0oooo000]0?ooo`030000003oool0
oooo01d0oooo0P00000h0?ooo`800000@@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0^0?ooo`00;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0]0?ooo`00;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0[0?ooo`00;@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Z0?ooo`00;@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0Y
0?ooo`00;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`00;@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0W0?ooo`00
;@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0V0?ooo`00;@3oool2000001H0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02D0oooo000]0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo02@0oooo000]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo02@0oooo000]0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02<0
oooo000]0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0280oooo000]0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0240oooo000]
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo0200oooo000]0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01l0oooo000]0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo01h0oooo000]0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01d0oooo000]0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo01`0oooo000]0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01/0oooo000]0?ooo`8000003@3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool06`3oool002d0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool06P3oool002d0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool06@3oool002d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1Q
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0603oool002d0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool0603oool002d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool05`3oool002d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
5P3oool002d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool05P3oool002d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool05@3oool0
02d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0503oool002d0oooo0P0000060?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0D0?ooo`00;@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0C0?ooo`00;@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`0B0?ooo`00;@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0B
0?ooo`00;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`0A0?ooo`00;@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0@0?ooo`00
;@3oool01@000000oooo0?ooo`3oool0000007<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0LP3oool00`000000
oooo0?ooo`0@0?ooo`00;@3oool010000000oooo0?ooo`00001e0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool03`3oool000l0oooo100000060?ooo`8000001P3oool4000000P0oooo
00@000000?ooo`3oool00000M@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0
oooo00D000000?ooo`3oool0oooo0000001f0?ooo`030000003oool0oooo00l0oooo000>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000007L0oooo00D000000?ooo`3o
ool0oooo0000001h0?ooo`030000003oool0000007P0oooo00<000000?ooo`3oool03P3oool000h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0
oooo0P00001h0?ooo`040000003oool0oooo000007T0oooo0P00001j0?ooo`030000003oool0oooo
00d0oooo000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`050?ooo`800000N@3oool2000007/0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0=0?ooo`001@3oool6000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00D0oooo0`00001i0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`000000NP3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo100000080?ooo`800000N@3oool2000007T0oooo00@0
00000?ooo`3oool00000N@3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool2000007T0oooo00<0
00000?ooo`000000N03oool01@000000oooo0?ooo`3oool0000007P0oooo00<000000?ooo`3oool0
3@3oool000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`000000M`3oool01@000000oooo0?ooo`3oool0000007H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00h0oooo
000?0?ooo`@000003P3oool5000000L0oooo00<000000?ooo`000000M`3oool01@000000oooo0?oo
o`3oool0000007H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo00h0oooo000]0?ooo`040000003oool0oooo000007D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`0?0?ooo`00;@3oool010000000oooo0?ooo`00001d0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool0403oool002d0oooo00D000000?ooo`3oool0oooo
0000001c0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0403oool002d0oooo00D0
00000?ooo`3oool0oooo0000001b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0
4@3oool002d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool04@3oool002d0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool04P3oool0
02d0oooo0P0000040?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`0C0?ooo`00;@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0C0?ooo`00;@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`0D0?ooo`00;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0J@3oool00`000000oooo0?ooo`0D0?ooo`00;@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0E
0?ooo`00;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`0F0?ooo`00;@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0F0?ooo`00
;@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0G0?ooo`00;@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0G0?ooo`00;@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`0H0?ooo`00;@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`0I0?ooo`00;@3oool2000000/0oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01X0oooo000]
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo01/0oooo000]0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01`0oooo000]0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo01`0oooo000]0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01d0oooo000]0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01d0oooo000]0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01h0oooo000]0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01h0oooo000]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo01l0oooo000]0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01l0oooo
000]0?ooo`8000004@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0803oool002d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0803oool002d0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool08@3oool002d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool08@3oool002d0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
8P3oool002d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool08P3oool002d0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0G0?ooo`L00000;03oool6000002T0oooo00<000000?ooo`3oool00P3oool4
00000300oooo1000000C0?ooo`030000003oool0oooo01T0oooo1000000<0?ooo`030000003oool0
oooo0240oooo1000000W0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool0
02d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0W0?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;P3oool2000002d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool06P3oool002d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo02h0oooo0P00000]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0:`3oool600000140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01l0oooo0P0000030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0000000]0?ooo`030000
003oool0oooo0080oooo0P00000_0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`00
00000P00000U0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool002d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo
00D000000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0;03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01`0oooo1000000>0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01T0oooo000]0?ooo`8000005`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0000000A0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0H0?ooo`00
;@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo0`00000^0?ooo`800000
103oool00`000000oooo0?ooo`0Z0?ooo`800000103oool00`000000oooo0?ooo`0]0?ooo`030000
003oool000000100oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0603oool002d0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`0000000`00
000^0?ooo`D00000<@3oool200000100oooo00<000000?ooo`3oool07@3oool5000000l0oooo00<0
00000?ooo`3oool07`3oool300000280oooo00<000000?ooo`3oool01`3oool6000001X0oooo000]
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo02L0oooo000]0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02P0oooo000]0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo02P0oooo000]0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo02T0oooo000]0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo02T0oooo000]0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02X0oooo000]0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
02/0oooo000]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo02/0oooo000T0?ooool00000R00000050?ooo`00;@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool2000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`800000203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool2000000P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`800000203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo0P0000080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool2000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool000000300oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool0
02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0;P3oool002d0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0;P3oool002d0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0;`3oool002d0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0;`3oool002d0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0<03oool002d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0<03oool002d0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0<@3oool002d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0<@3oool002d0oooo0P00000S0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0b0?ooo`00;@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0b0?ooo`00;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0c0?ooo`00;@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0c0?ooo`00;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0d0?ooo`00;@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0d0?ooo`00;@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0e0?ooo`00;@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0e0?oo
o`00;@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0f0?ooo`00;@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0f0?ooo`00;@3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0g0?ooo`00;@3oool2000002T0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo000]0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
03P0oooo000]0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo03P0oooo000]0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03T0oooo
000]0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo03X0oooo000]0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03X0oooo000]0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo03/0oooo000]0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03/0oooo000]0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo03`0oooo000]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03`0oooo000]0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo03d0oooo000]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo03d0oooo000]0?ooo`800000;`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?P3oool002d0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0?`3oool002d0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?`3oool002d0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0@03oool002d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0@03oool002d0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0@@3oool002d0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool002d0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@P3o
ool002d0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0@P3oool002d0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0@`3oool002d0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0@`3oool002d0oooo0P00000f0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`140?ooo`00;@3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`150?ooo`00;@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0K@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`150?ooo`00;@3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`160?oo
o`00;@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`160?ooo`00;@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`170?ooo`00;@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`170?ooo`00;@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`180?ooo`003`3oool40000
00H0oooo0P0000060?ooo`@00000203oool00`000000oooo0?ooo`0i0?ooo`050000003oool0oooo
0?ooo`000000MP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo00D00000
0?ooo`3oool0oooo0000001:0?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0j0?ooo`040000003oool0oooo000007L0oooo00@000000?ooo`3oool00000
N03oool010000000oooo0?ooo`00001;0?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0000007P0oooo00@000000?ooo`3oool00000N@3oool2000004`0oooo000>0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo03/0oooo0P00001i0?ooo`800000NP3oool2000004`0oooo000>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`<00000>`3o
ool2000007T0oooo0P00001j0?ooo`800000C03oool000h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`@00000203oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
000007T0oooo0P00001i0?ooo`040000003oool0oooo000004/0oooo000>0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03X0oooo00@000000?ooo`3oool00000M`3oool00`000000oooo0000001i0?ooo`040000003o
ool0oooo000004/0oooo000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1d0?ooo`040000003oool0oooo000007L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`180?ooo`003`3oool4000000h0oooo1@0000070?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04L0oooo000]0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo04L0oooo000]0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
04H0oooo000]0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo04D0oooo000]0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04D0oooo
000]0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo04@0oooo000]0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0K03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04<0oooo000]0?oo
o`800000=@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0@`3oool002d0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0@P3oool002d0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
@P3oool002d0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0@@3oool002d0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@03oool0
02d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0@03oool002d0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?`3oool002d0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0?P3oool002d0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?P3oool002d0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0?@3oool002d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0?03oool002d0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0?03oool002d0oooo0P00000]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0k0?ooo`00;@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0j0?ooo`00;@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0i0?ooo`00;@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0i0?ooo`00;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0h0?ooo`00;@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0g0?ooo`00;@3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0f0?ooo`00;@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0e0?ooo`00;@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0e0?oo
o`00;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0d0?ooo`00;@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0c0?ooo`00;@3o
ool2000002<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0380oooo000]0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0340oooo000]0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0300oooo000]0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo02l0oooo000]0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02l0oooo
000]0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo02h0oooo000]0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02d0oooo000]0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02/0oooo000]0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo02X0oooo000]0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo02T0oooo000]0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0480oooo0P00000e0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0:03oool0
02d0oooo0P00000H0?ooo`030000003oool0oooo04@0oooo0P00000b0?ooo`800000A`3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo04@0oooo0P00000X0?ooo`00;@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0U0?ooo`00;@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1:0?ooo`800000;@3oool2000004/0oooo
00<000000?ooo`3oool0903oool002d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool08`3oool002d0oooo00<00000
0?ooo`3oool04P3oool2000004l0oooo0P00000X0?ooo`800000D@3oool00`000000oooo0?ooo`0V
0?ooo`800000D03oool2000002<0oooo000]0?ooo`030000003oool0oooo0100oooo0P00001C0?oo
o`800000903oool2000005@0oooo0P00000T0?ooo`800000E03oool200000240oooo000]0?ooo`03
0000003oool0oooo00h0oooo0P00001G0?ooo`030000003oool0oooo01l0oooo0P00001H0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0EP3oool2000001l0oooo000]0?ooo`030000
003oool0oooo00`0oooo0P00001J0?ooo`8000007P3oool00`000000oooo0?ooo`1I0?ooo`800000
7P3oool2000005/0oooo0P00000M0?ooo`00803oool7000000H0oooo00<000000?ooo`3oool02P3o
ool2000005h0oooo0P00000J0?ooo`800000GP3oool2000001X0oooo0P00001O0?ooo`8000006`3o
ool002<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`800000HP3oool3
000001D0oooo0P00001R0?ooo`8000005P3oool2000006<0oooo0P00000I0?ooo`008`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo1000001W0?ooo`@000003P3oool30000
06H0oooo1000000>0?ooo`@00000I`3oool3000001H0oooo000S0?ooo`030000003oool0oooo00L0
oooo1`00001_0?ooo`h00000K@3oool>000006h0oooo2000000>0?ooo`008`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0ooooP@3oool002<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?oooh40oooo000S0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooon10?ooo`008@3oool3000000T0oooo00<000000?ooo`3oool0o`3ooon10?oo
o`008`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooP@3oool002d0oooo
00<000000?ooo`3oool0o`3ooon10?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00E03oool40000
02T0oooo1000003o0?ooob`0oooo001H0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08X0oooo001H0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0R@3oool200000100oooo0P00002;0?ooo`00@@3o
ool4000000D0oooo1`0000030?ooo`<0000000<0oooo0000003oool0103oool2000000L0oooo1000
00050?ooo`8000003`3oool3000000030?ooo`000000oooo00@0oooo100000030?ooo`<000000P3o
ool3000000<0oooo100000050?ooo`@00000103oool5000000D0oooo0P00000>0?ooo`D00000103o
ool300000080oooo0`0000030?ooo`D000000`3oool5000000D0oooo100000040?ooo`D000003@3o
ool4000000H0oooo00<000000?ooo`3oool0103oool7000000@0oooo00<000000?ooo`3oool0103o
ool6000000h0oooo1@0000040?ooo`@00000103oool5000000/0oooo0`000000103oool000000000
003oool2000001d0oooo1000000V0?ooo`00@P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`8000002@3oool00`000000oooo
0?ooo`040?ooo`8000003P3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool2000000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool2000000P0oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`H000002`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02<0oooo00120?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08`3oool00480
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool6000001D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`H000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`@000005P3oool5
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`@000001@3oool4
000000@0oooo1P0000040?ooo`@00000303oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo02<0oooo00120?ooo`@000001`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo0?ooo`8000003@3oool010000000oooo0?ooo`00000F0?ooo`040000003oool0oooo0?ooo`80
0000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`3oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000000h0oooo0P0000001@3oool000000000003oool0000000`0oooo1P00000>0?ooo`8000009P3o
ool00480oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`<000001P3oool3000000030?oo
o`000000000000`0oooo00@000000?ooo`3oool000005`3oool3000000030?ooo`000000000000@0
oooo100000030?ooo`80000000@0oooo00000000000000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo100000050?ooo`D000005@3oool00`000000oooo0?ooo`020?oo
o`060000003oool0oooo0?ooo`000000oooo0`0000050?ooo`<000001P3oool5000000@0oooo1000
00050?ooo`D000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`H00000103oool4000000@0oooo0P00
0000103oool0000000000000000:0?ooo`80000000D0oooo0000003oool0oooo0000000S0?ooo`03
0000003oool0oooo02<0oooo00120?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0000000b0?ooo`040000003oool0oooo0?ooo`8000009`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000=03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0S0?oo
o`00@@3oool7000001l0oooo00<000000?ooo`000000<`3oool3000000030?ooo`000000oooo02D0
oooo1P0000040?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`<000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0
oooo001=0?ooo`030000003oool0oooo01P0oooo0P00001W0?ooo`800000=@3oool400000100oooo
00<000000?ooo`3oool03@3oool400000140oooo0`0000120?ooo`@000009P3oool004d0oooo00<0
00000?ooo`3oool0o`3ooomQ0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.88648, -1.05879, \
0.0292751, 0.0130577}}]
}, Open  ]],

Cell["Example  26. 12-phase Half-Spin Sinusoids.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{genSin[x, 12], genSin[x, 12, 1], genSin[x, 12, 2]}, {x, 0, 
          2  \[Pi]/Sin[2  \[Pi]/12]}, 
        PlotLabel -> "\<Fig.5. genSin. Phases 0,1,2 for m = 12\>"];\)\)], \
"Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0757881 0.309017 0.294302 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.93327 .29652 -6 -9 ]
[.93327 .29652 6 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -116 0 ]
[.5 .63053 116 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(2)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(4)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(6)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(8)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(10)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(12)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.0617 .30902 m
.0617 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.13749 .30902 m
.13749 .31277 L
s
.21328 .30902 m
.21328 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.28907 .30902 m
.28907 .31277 L
s
.36486 .30902 m
.36486 .31277 L
s
.40275 .30902 m
.40275 .31277 L
s
.44064 .30902 m
.44064 .31277 L
s
.51643 .30902 m
.51643 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.59222 .30902 m
.59222 .31277 L
s
.66801 .30902 m
.66801 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.7438 .30902 m
.7438 .31277 L
s
.81958 .30902 m
.81958 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.89537 .30902 m
.89537 .31277 L
s
.97116 .30902 m
.97116 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -177 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.5) show
93.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(genSin) show
141.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
153.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phases) show
195.000 12.750 moveto
(0) show
201.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
207.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
213.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
219.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
231.000 12.750 moveto
(for) show
255.000 12.750 moveto
(m) show
267.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
279.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
291.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02474 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .015 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
.02381 .16187 m
.06244 .23088 L
.10458 .31175 L
.14415 .38761 L
.18221 .45561 L
.22272 .5178 L
.26171 .5637 L
.28302 .58185 L
.29279 .58839 L
.30316 .59406 L
.31266 .59809 L
.31807 .59988 L
.32313 .60121 L
.32777 .60215 L
.33201 .60277 L
.33436 .60301 L
.33568 .60312 L
.33691 .6032 L
.33809 .60325 L
.33917 .60329 L
.3404 .60331 L
.34157 .60332 L
.34273 .60331 L
.34398 .60327 L
.34515 .60322 L
.34622 .60316 L
.34885 .60295 L
.35133 .60267 L
.35627 .60188 L
.36165 .60066 L
.37124 .59758 L
.38012 .5937 L
.39878 .58239 L
.41939 .56509 L
.45959 .51812 L
.49828 .45906 L
.53942 .38569 L
.57904 .30965 L
.61715 .23641 L
.65771 .16358 L
.69676 .1032 L
.71667 .07742 L
.73825 .05399 L
.75906 .03629 L
.76896 .02965 L
.77824 .02451 L
.78728 .02053 L
.79193 .01888 L
.797 .01739 L
.79987 .01669 L
Mistroke
.80253 .01614 L
.80529 .01566 L
.80778 .01531 L
.81024 .01505 L
.81256 .01487 L
.81383 .0148 L
.815 .01475 L
.81628 .01472 L
.81693 .01472 L
.81764 .01472 L
.81895 .01473 L
.82016 .01476 L
.82079 .01479 L
.82149 .01482 L
.8229 .0149 L
.82546 .01512 L
.82787 .01541 L
.83236 .01613 L
.83719 .0172 L
.84251 .01873 L
.84811 .02071 L
.85811 .02524 L
.8779 .0378 L
.89628 .05361 L
.93537 .09936 L
.97619 .16187 L
Mfstroke
.02381 .05414 m
.06244 .09948 L
.10458 .16424 L
.14415 .23528 L
.18221 .30837 L
.22272 .38611 L
.26171 .45584 L
.30316 .51926 L
.32392 .54541 L
.34309 .56563 L
.36173 .58138 L
.37125 .58784 L
.3815 .59356 L
.3917 .59797 L
.40103 .60086 L
.40552 .60186 L
.40789 .60228 L
.41042 .60265 L
.41284 .60293 L
.41504 .60312 L
.4161 .60319 L
.41725 .60325 L
.41834 .60329 L
.41933 .60331 L
.4206 .60332 L
.42179 .60331 L
.42287 .60329 L
.42403 .60324 L
.4253 .60318 L
.42665 .60309 L
.42907 .60286 L
.4313 .60259 L
.43339 .60228 L
.43816 .60135 L
.44335 .60002 L
.4481 .5985 L
.45882 .59403 L
.46862 .58869 L
.47775 .58268 L
.49845 .56539 L
.53749 .52011 L
.57899 .4568 L
.61897 .38533 L
.65744 .31153 L
.69836 .23295 L
.73776 .16243 L
.77565 .10386 L
.79673 .07659 L
.81599 .05559 L
.8359 .03817 L
Mistroke
.85481 .02595 L
.86442 .02141 L
.86969 .01942 L
.87466 .01786 L
.8793 .01668 L
.88174 .01617 L
.88431 .01572 L
.88649 .0154 L
.88887 .01512 L
.88991 .01502 L
.89103 .01493 L
.89208 .01486 L
.89306 .01481 L
.89428 .01476 L
.89493 .01474 L
.89563 .01472 L
.89632 .01472 L
.89705 .01472 L
.89836 .01473 L
.89957 .01476 L
.9007 .01481 L
.90193 .01488 L
.90325 .01498 L
.90625 .01528 L
.90906 .01567 L
.91434 .01668 L
.91937 .01796 L
.924 .01943 L
.93447 .02374 L
.94419 .02897 L
.95327 .03489 L
.97392 .05197 L
.97619 .05414 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003oo`3ooooo
0?oood80oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3oool30?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0oooo0`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`<0oooo
000/0?ooo`L000002@3oool00`000000oooo0?ooo`3o0?ooool0oooo0`3oool002l0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo0`3oool002l0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo0`3oool002l0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo0`3oool002l0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`3o0?ooool0oooo0`3oool001l0oooo200000080?ooo`030000003o
ool0oooo00X0oooo1000003o0?ooofP0oooo4`00000G0?oooa800000603oool@000003D0oooo000_
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`8000004`3oool2
00000180oooo0`00000B0?ooo`<00000403oool500000100oooo1P00000_0?ooo`00;`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooHP3oool5000001L0oooo1@00000:0?oo
o`<00000603oool3000000/0oooo0P00000K0?ooo`800000;@3oool002l0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?ooof00oooo0P00000Q0?ooo`8000001P3oool2000001h0
oooo0P0000060?ooo`<000007`3oool2000002/0oooo000_0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0o`3ooomN0?ooo`8000009@3oool200000080oooo0P00000R0?ooo`<00000
00<0oooo000000000000903oool2000002T0oooo000_0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0o`3ooomM0?ooo`030000003oool0oooo02H0oooo0`00000V0?ooo`<000009`3o
ool2000002L0oooo000[0?ooo`<0000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`3o
0?oooe/0oooo0P00000W0?ooo`8000000P3oool2000002<0oooo0P0000030?ooo`8000009`3oool2
000002D0oooo000^0?ooo`800000303oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?oo
o`3oool09@3oool2000000H0oooo0P00000P0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`00?03oool00`000000oooo0?ooo`3o0?oooeP0
oooo0P00000W0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool2000000T0
oooo0P00000W0?ooo`8000008P3oool003`0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000
003oool0oooo02D0oooo0P00000<0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0V0?ooo`800000803oool003`0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`8000009`3oool00`000000oooo0?ooo`0=0?ooo`800000603oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3oool003`0oooo00<00000
0?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0C0?ooo`8000004@3oool2000002P0oooo00<000000?ooo`3oool0703oool0
03`0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool09P3oool2000001`0oooo000l0?ooo`030000003oool0oooo0?l0ooooD@3oool2000002L0
oooo0P00000F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01T0oooo000l0?ooo`030000003oool0oooo0?l0oooo
D03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01L0oooo0P00000>0?ooo`030000
003oool0oooo01L0oooo0P00000X0?ooo`030000003oool0oooo01P0oooo000l0?ooo`<00000o`3o
oom?0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo0P00000N0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool05P3oool003`0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool2000001H0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooB`3oool2000002L0oooo0P00000R0?ooo`800000103oool00`000000
oooo0?ooo`0Q0?ooo`800000:03oool00`000000oooo0?ooo`0C0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooodX0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0T0?ooo`040000
003oool0oooo000002H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0B0?ooo`00
?03oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0V0?ooo`800000:03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo
000l0?ooo`800000o`3ooom90?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3o
ool2000002T0oooo00<000000?ooo`3oool0>@3oool003`0oooo00<000000?ooo`000000o`3ooom7
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
000Y0?ooo`030000003oool0oooo03P0oooo000l0?ooo`040000003oool0oooo00000?l0ooooA@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03L0oooo000l0?ooo`040000003oool0
oooo00000?l0ooooA03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03L0oooo000l
0?ooo`050000003oool0oooo0?ooo`000000o`3ooom20?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0=P3oool003`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?ooocl0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0e0?ooo`00?03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo03@0oooo000l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3ooolk0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0<`3oool003`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0b0?ooo`00?03oool3000000D0oooo00<000000?ooo`3oool0o`3o
oolh0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0<P3oool003`0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0a0?ooo`00?03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0?l0oooo=03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0300oooo000l0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0;`3oool003`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`3o0?oooc00oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0^0?ooo`00?03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo;`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo02d0oooo000l0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0;@3oool0
03`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooob`0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0/0?ooo`00?03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0?l0oooo:P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02/0
oooo000l0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0:P3oool003`0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0Y0?ooo`00?03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo9@3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo000l0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0:03oool003`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooob<0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`00?03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo8@3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02H0oooo000l0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3o
oolO0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09@3oool003`0oooo0`00000B
0?ooo`030000003oool0oooo0?l0oooo7P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02D0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooolM0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0903oool003`0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0S0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo
6P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02<0oooo000l0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool08P3oool003`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o
0?oooaL0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Q0?ooo`00?03oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo5P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0240oooo000l0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0o`3ooolE0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0803oool003`0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0O0?ooo`00?03oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo000l
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool07P3oool003`0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?oo
o`00?03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo01d0oooo000l0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0o`3oool=0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
703oool003`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0K0?ooo`00?03oool3000001`0oooo00<00000
0?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool06`3oool0
03`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0J0?ooo`00?03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01X0
oooo000l0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool06@3oool003`0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0H0?ooo`00?03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo103oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo000l0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0o`3oool30?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooo`40
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0F0?ooo`00?03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo01H0oooo000l0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0oP3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo000E0?ooo`@00000203oool3
000000T0oooo1000000;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0oooo000D0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool3000000P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o03oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0oooo000C0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool3000000L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0nP3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo01<0oooo000C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0180oooo
000C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0n03oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0180oooo00070?ooo`P00000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool4000002D0oooo00<00000
0?ooo`3oool0mP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo000C0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool2000000<0oooo00<000000?oo
o`3oool0203oool2000002L0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0i0?oo
o`004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`00
00000P00000;0?ooo`800000:03oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03T0
oooo000C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool0lP3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0h0?ooo`004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0000000X0?ooo`030000003oool0oooo0?80oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0>03oool001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?oo
o`3`0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo03L0oooo000D0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000002P0oooo00<0
00000?ooo`3oool0l03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0g0?ooo`005@3oool4000001<0oooo1P00000:
0?ooo`050000003oool0oooo0?ooo`000000:03oool00`000000oooo0?ooo`3^0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo03H0oooo000l0?ooo`050000003oool0oooo0?ooo`000000:03oool00`000000oooo0?oo
o`3]0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo03H0oooo000l0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03D0oooo000l0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3Z0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo03D0oooo000l0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo03@0oooo000l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`3X0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo03<0oooo000l0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo0380oooo000l0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`3U0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo0380oooo000l0?ooo`<000001P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0<@3oool003`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0>80oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0<@3oool003`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0<03oool003`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0>00oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0<03oool003`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0>00oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0;`3oool003`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=h0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0;`3oool003`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0=h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0;P3oool003`0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0;P3o
ool003`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0=/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0;@3oool003`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0;03oool003`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0=P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool0;03oool003`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0:`3oool003`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool0:`3oool003`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0:P3oool003`0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=@0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool0:P3oool003`0oooo0`00000>0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0d`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`0Y0?ooo`00?03oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0Y0?ooo`00?03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0d03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0X0?ooo`00?03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0X0?ooo`00?03oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0W0?ooo`00?03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0W0?ooo`00?03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0c03oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`0V0?ooo`00?03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0b`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`0U0?ooo`00?03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0U
0?ooo`00?03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0b03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`0T0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0T0?ooo`00
?03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
aP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`0S0?ooo`00?03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0S0?ooo`00?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0a03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`0R0?ooo`00?03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0R0?ooo`00?03oool3000001H0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0240
oooo000l0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`320?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo0240oooo000l0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0200oooo000l
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`30
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo0200oooo000l0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01l0oooo000l0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo01h0oooo000l0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo01h0oooo000l0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2l0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo01d0oooo000l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09`3oool0
10000000oooo0?ooo`3oool8000004X0oooo1000001;0?ooo`@00000503oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00X0oooo0`00000I0?ooo`030000003oool0oooo02T0oooo1`00
00060?ooo`@00000?P3oool7000000@0oooo2@00000O0?ooo`00?03oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`090?ooo`050000003o
ool0oooo0?ooo`000000603oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0000000N0?ooo`00?03oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo02L0oooo00D000000?ooo`3oool0oooo0000001B0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0703oool003`0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0BP3o
ool7000004P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool06`3oool003`0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool0
03`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0B@3oool01@000000oooo0?ooo`3oool0000004T0oooo0P000006
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<
0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`00?03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`180?ooo`050000003oool0oooo0?ooo`000000B@3oool00`000000oooo0000
00040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0=0?ooo`@000005@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`00?03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`18
0?ooo`040000003oool0oooo000004T0oooo00<000000?ooo`3oool01000000@0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000001D0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool06@3oool003`0oooo0`00000O0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`170?ooo`040000003oool0oooo000004T0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo
000l0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`000000BP3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool003`0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0U0?ooo`8000001@3oool00`000000oooo0?ooo`19
0?ooo`800000B`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1:0?oo
o`800000C03oool200000100oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0?0?oo
o`050000003oool0oooo0?ooo`0000004`3oool00`000000oooo0?ooo`0]0?ooo`<0000000<0oooo
0000003oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo0`000000
0`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
02H0oooo1000001>0?ooo`030000003oool0oooo04`0oooo1000000<0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0403oool3000001<0oooo00<000000?ooo`3oool0<@3oool20000
00T0oooo100000100?ooo`8000002@3oool4000000T0oooo00<000000?ooo`3oool05P3oool003`0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo09P0
oooo00<000000?ooo`3oool05P3oool003`0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool05@3oool003`0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool05@3oool003`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0503oool003`0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool0503oool003`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool04`3oool003`0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0
4`3oool003`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0:00oooo00<000000?ooo`3oool04P3oool003`0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool04P3oool0
03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0:80oooo00<000000?ooo`3oool04@3oool00300ooooo`00003o000000`000001P3oool003`0oooo
0P00000B0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool00000403oool00`000000
oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool003`0oooo0P00000B0?ooo`03
0000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo
0140oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`00?03oool00`000000oooo0000000X0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool09`3oool003`0oooo00<000000?ooo`00
0000:@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0;T0oooo000l0?ooo`040000
003oool0oooo000002P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2M0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2i0?ooo`00
?03oool010000000oooo0?ooo`00000Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0W@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0^P3oool003`0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0^P3oool003`0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0^`3oool003`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool003`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0_03oool003`0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0_03oool0
03`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0_@3oool003`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0_@3oool003`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0_P3oool003`0oooo0`0000050?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`2n0?ooo`00?03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2o
0?ooo`00?03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`2o0?ooo`00?03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`300?ooo`00
?03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`300?ooo`00?03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`310?ooo`00?03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`310?ooo`00?03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`320?ooo`00?03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`320?ooo`00?03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`330?ooo`00?03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`330?ooo`00?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`340?ooo`00?03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`340?oo
o`00?03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`350?ooo`00?03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`240?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`350?ooo`00?03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`360?ooo`00?03oool3000000d0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0<H0oooo000l0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0840oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0<L0oooo000l0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0<L0oooo000l0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0<P0oooo
000l0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0<P0oooo000l0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0<T0oooo000l0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0<T0oooo000l0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0<X0oooo000l0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0<X0oooo000l0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0</0oooo000l0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0<`0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0<`0oooo000l0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0<d0
oooo000l0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0<d0oooo000l0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0<h0oooo000l
0?ooo`<000005@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0LP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0cP3oool003`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0c`3oool003`0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0d03oool003`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0d03oool003`0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0d@3o
ool003`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0d@3oool003`0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0dP3oool003`0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0dP3oool003`0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0d`3oool003`0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0e03oool003`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0e03oool003`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0e@3oool003`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0e@3oool003`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
eP3oool003`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0eP3oool003`0oooo0`00000M0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3G0?ooo`00?03oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`3G0?ooo`00?03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3H0?ooo`00?03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`3I0?ooo`00?03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`3I0?ooo`00?03oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3J
0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`3J0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3K0?ooo`00
?03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`3K0?ooo`00?03oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3L0?ooo`00?03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`3M0?ooo`005@3oool4000000P0oooo0`0000090?ooo`@000002`3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`3M0?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo0`0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`3N0?ooo`004`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
0`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`3N0?ooo`004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`3O0?ooo`004`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3O
0?ooo`004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01`3oool4000002D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0>00oooo000C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03`3oool2000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3Q0?ooo`00
4`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`000000
0P00000;0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0>40oooo000C0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0>80oooo000C
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0><0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0><0oooo000D0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0>@0oooo000E0?ooo`@000004`3oool6000000X0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
i03oool003`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0i@3oool003`0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0iP3oool0
03`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0iP3oool003`0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0i`3oool003`0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0j03oool003`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0j03oool003`0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0j@3oool003`0oooo0`00000`0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`3Z0?ooo`00?03oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3Z0?ooo`00
?03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`3[0?ooo`00?03oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3[0?ooo`00?03oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`3/0?ooo`00?03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3]0?ooo`00?03oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`3]0?ooo`00?03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3^0?ooo`00?03oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`3_0?ooo`00?03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`3_0?ooo`00?03oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3`0?oo
o`00?03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`3a0?ooo`00?03oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3a0?ooo`00?03o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`3b0?ooo`00?03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3b0?ooo`00?03oool30000
03/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0?<0oooo000l0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0?@0oooo000l0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?@0oooo
000l0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0?D0oooo000l0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?H0oooo000l0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0?L0oooo000l0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?P0oooo000l0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo0?P0oooo000l0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?T0oooo000l0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0?X0oooo000l0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0?/0oooo000l0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?`0
oooo000l0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0?d0oooo000l0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?h0oooo000l
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0?l0oooo000l0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo000l0?ooo`<0
0000A`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0o`3oool10?ooo`00?03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooo`80oooo000l0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0?l0oooo0`3oool003`0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3oool40?ooo`00?03oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo000l0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo1P3oool003`0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0o`3oool70?ooo`00?03oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo000l
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V
0?ooo`050000003oool0oooo0?ooo`000000:03oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0?l0oooo203oool003`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`000000:03oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0?l0oooo2@3oool003`0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo2P3oool003`0oooo00<000000?ooo`3o
ool0D03oool2000002P0oooo00<000000?ooo`3oool0903oool00`000000oooo0000000V0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3oool;0?ooo`00?03oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo02H0oooo0P00000R0?ooo`8000000`3oool00`000000oooo
0?ooo`0Q0?ooo`800000:@3oool00`000000oooo0?ooo`3o0?ooo``0oooo000l0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00@0oooo0P00000P0?ooo`030000003oool0oooo02L0oooo0P00003o0?ooo`l0oooo000l
0?ooo`030000003oool0oooo05@0oooo0P00000X0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`00?03oool3000005H0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo403oool003`0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01L0oooo0P00000=0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oooa40
oooo000l0?ooo`030000003oool0oooo05P0oooo0P00000W0?ooo`8000005P3oool00`000000oooo
0?ooo`0>0?ooo`8000005P3oool2000002T0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`00?03o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool09`3o
ool200000?l0oooo5@3oool003`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00l0oooo0P00000E0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oooaD0oooo000l0?ooo`030000003oool0oooo
05`0oooo0P00000W0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool20000
00h0oooo0P00000Y0?ooo`030000003oool0oooo0?l0oooo5P3oool003`0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0U0?ooo`8000002`3oool2000001/0oooo0P00000;0?ooo`03
0000003oool0oooo02L0oooo0P00003o0?oooaT0oooo000l0?ooo`030000003oool0oooo05l0oooo
0P00000W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`060?ooo`800000:@3oool00`000000oooo0?ooo`3o0?oooaT0oooo000l0?ooo`030000003o
ool0oooo0640oooo0P00000V0?ooo`8000001P3oool00`000000oooo0?ooo`0O0?ooo`8000001@3o
ool00`000000oooo0?ooo`0W0?ooo`800000o`3ooolL0?ooo`00?03oool00`000000oooo0?ooo`1S
0?ooo`8000009P3oool200000080oooo0P00000T0?ooo`80000000<0oooo000000000000:03oool2
00000?l0oooo7P3oool002`0oooo1`0000090?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool09@3oool2000002L0oooo0`00000V0?ooo`<00000o`3ooolP0?ooo`00;`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo06H0oooo0P00000S0?ooo`8000000P3oool2000002<0
oooo0P0000030?ooo`8000008P3oool200000?l0oooo8`3oool002l0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1X0?ooo`8000007P3oool3000000H0oooo0P00000N0?ooo`<00000
1`3oool2000001h0oooo0P00003o0?ooobD0oooo000_0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0JP3oool5000001L0oooo0P00000;0?ooo`8000006P3oool2000000`0oooo0`00
000I0?ooo`800000o`3ooolW0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo06l0oooo0P00000@0?ooo`D000003`3oool600000140oooo0`00000A0?ooo`<000004@3oool5
00000?l0oooo:@3oool002l0oooo00<000000?ooo`3oool02P3oool400000700oooo4000000J0?oo
oa4000005`3ooolA00000?l0oooo;P3oool002l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?ooool0oooo0`3oool002l0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`3o0?ooool0oooo0`3oool002l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`3o0?ooool0oooo0`3oool002l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o
0?ooool0oooo0`3oool002l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
ool0oooo0`3oool002/0oooo0`0000000`3oool000000?ooo`0;0?ooo`030000003oool0oooo0?l0
ooooo`3oool30?ooo`00;P3oool2000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`<0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3oool30?ooo`00o`3ooooo0?oood80oooo003o0?oo
ool0oooo@P3oool00?l0ooooo`3ooom20?ooo`00o`3ooooo0?oood80oooo003o0?ooool0oooo@P3o
ool00?l0ooooo`3ooom20?ooo`00o`3ooooo0?oood80oooo003o0?ooool0oooo@P3oool00?l0oooo
o`3ooom20?ooo`00o`3ooooo0?oood80oooo001[0?ooo`@00000>03oool400000?l0ooooUP3oool0
06l0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0_P3oool00700oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`2h0?ooo`8000005P3oool200000;l0oooo001`0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0^03oool2000001H0oooo0P00002o0?ooo`00D@3oool6000000H0oooo2@00
00060?ooo`<0000000<0oooo0000003oool01P3oool3000000T0oooo100000080?ooo`<000005@3o
ool3000000030?ooo`000000oooo00H0oooo1@0000050?ooo`<000000`3oool3000000<0oooo00<0
00000?ooo`0000000`0000050?ooo`T00000103oool3000000<0oooo0`0000050?ooo`<000004P3o
ool6000000L0oooo0`0000030?ooo`<00000103oool5000000030?ooo`000000000000<0oooo00<0
00000?ooo`0000000`0000080?ooo`D000001@3oool00`000000oooo00000003000001@0oooo1000
00080?ooo`8000002@3oool7000000H0oooo0P0000080?ooo`P00000403oool7000000L0oooo1@00
00060?ooo`H00000403oool300000080oooo0P0000020?ooo`8000009`3oool7000000@0oooo2000
000Z0?ooo`00D`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`3oool0oooo0P0000070?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo0`00000D0?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`<00000503oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000303oool00`000000oooo
0?ooo`070?ooo`800000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0:03oool005<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool3000000L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`<000004`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`<00000
503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool3000000/0oooo00<000000?ooo`3oool01`3oool3000000P0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0=0?ooo`P00000503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo001C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0;@3oool005<0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`P000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool6000000X0oooo00<000000?ooo`3oool00`3oool8000000X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0/0?ooo`00D`3oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`D000001`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool50000
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`D000004P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0[
0?ooo`00D`3oool5000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0100oooo0P0000030?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo100000090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`800000503oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool03@3oool8
000001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`00D`3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`3o
ool200000180oooo00<000000?ooo`0000000P00000O0?ooo`040000003oool0oooo0?ooo`800000
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000
003oool0oooo00<0oooo0P00000=0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`800000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool200000100oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo000000030?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`800000
0P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
:@3oool005<0oooo00D000000?ooo`3oool0oooo000000060?ooo`@000002P3oool3000000030?oo
o`00000000000140oooo00<000000?ooo`3oool08P3oool3000000030?ooo`000000000000H0oooo
100000060?ooo`80000000@0oooo00000000000000001P3oool00`000000oooo0?ooo`090?ooo`@0
0000203oool2000000040?ooo`0000000000000001l0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000800000203oool5000000H0oooo1@0000000`3o
ool000000?ooo`050?ooo`@000001`3oool5000000030?ooo`000000oooo00l0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool03P3oool7000000L0oooo1@0000060?ooo`8000000P3oool3000000l0oooo0P0000000`3o
ool00000000000020?ooo`800000;03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
02P0oooo001C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0X0?ooo`00D`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`020?ooo`800000=@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00540oooo2P00
00060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0AP3oool4000000030?ooo`00
0000oooo00H0oooo00<000000?ooo`3oool0:@3oool7000000L0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo0`0000000`3oool000000?oo
o`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1K0?ooo`<0000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02T0oooo001Q0?ooo`030000003oool0oooo01l0oooo1P00001@0?ooo`030000003oool0
oooo03H0oooo0P0000180?ooo`@000005@3oool2000001D0oooo1000000E0?ooo`H00000FP3oool2
000000T0oooo1000000/0?ooo`00o`3ooooo0?oood80oooo003o0?ooool0oooo@P3oool00?l0oooo
o`3ooom20?ooo`00o`3ooooo0?oood80oooo0000\
\>"],
  ImageRangeCache->{{{0, 431.25}, {266.125, 0}} -> {-1.53043, -1.05872, \
0.0506467, 0.0130424}}]
}, Open  ]],

Cell[TextData[{
  "\tNote that neither the phasality ",
  StyleBox["m",
    FontSlant->"Italic"],
  " nor the phase ",
  StyleBox["j",
    FontSlant->"Italic"],
  " need be an integer. Also ",
  StyleBox["genCos[x,m,m/4]\[Congruent]genSin[x,m]",
    FontSlant->"Italic"],
  ", so one of the series is redundant. Both are included for compatibility \
with normal mathematics, with ",
  StyleBox["genSin",
    FontSlant->"Italic"],
  " as the antisymmetric sinusoid. ",
  StyleBox["genSin",
    FontSlant->"Italic"],
  " is preferable to ",
  StyleBox["genCos",
    FontSlant->"Italic"],
  " in some situations such as Direction Sines, as ",
  StyleBox["genSin[x,m,0]~x",
    FontSlant->"Italic"],
  " for small ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and the value tends to zero with ",
  StyleBox["x",
    FontSlant->"Italic"],
  ". When x = 0, terms involving ",
  StyleBox["genSin[x,m,0]",
    FontSlant->"Italic"],
  " drop out of expressions, making them compatible with renormalization."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.6. Generalized Signs & Generalized negation.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tOrdinary negation \"-\" is a first member of the \"generalized negations\
\". It corresponds to a binary equivalence relation, with ",
  Cell[BoxData[
      \(TraditionalForm\`r\_i\)]],
  "~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  "}, -",
  Cell[BoxData[
      \(TraditionalForm\`r\_i\)]],
  "~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "}, 0~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "} in a group with ",
  StyleBox["m",
    FontSlant->"Italic"],
  " elements. This is the rotation of the elements by ",
  StyleBox["m/2",
    FontSlant->"Italic"],
  ", either to the left or the right. It fails for odd ",
  StyleBox["m",
    FontSlant->"Italic"],
  " groups and for some even-",
  StyleBox["m",
    FontSlant->"Italic"],
  " groups such as ",
  StyleBox["D3",
    FontSlant->"Italic"],
  " that lack a C2 symmetry,",
  StyleBox[" ",
    FontSlant->"Italic"],
  "but it can be extended to rotation by factors of ",
  StyleBox["m",
    FontSlant->"Italic"],
  ". Extra negations are introduced in this way. Thus C3 has two (left and \
right) negations ",
  Cell[BoxData[
      \(TraditionalForm\`A\&\[LeftArrow]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`A\&\[RightArrow]\)]],
  ". The real (C2) axiom that ",
  StyleBox["A",
    FontSlant->"Italic"],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`A\&\[LeftRightArrow]\)]],
  "~0 is {a,b}+{b,a} = {a+b,a+b} \[Tilde] 0. In the C3 case this becomes ",
  StyleBox["A",
    FontSlant->"Italic"],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`A\&\[LeftArrow]\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\&\[RightArrow]\)\(\ \)\)\)]],
  "~ 0, {a,b,c} + {b,c,a} + {c,a,b} = {a+b+c, a+b+c, a+b+c} \[Tilde] 0. As \
{a+b+...+",
  StyleBox["m",
    FontSlant->"Italic"],
  "} is always a factor of a quasigroup determinant, ",
  StyleBox["r-",
    FontSlant->"Italic"],
  "fold negation corresponds to equivalencing that factor to zero. \
Renormalization makes it (and usually some other factors) explicitly zero. \
Subtraction is \"additive elimination\", adding one or more terms to give a \
result that equivalences to zero."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  " \tThe standard development of numbers from sets [8, p46] is defective, \
prematurely introducing ordinary negation as an equivalence relation (ER) on \
a two-element indexed set; {",
  Cell[BoxData[
      \(TraditionalForm\`a\_1, a\_2\)]],
  "} is arbitrarily given the \"+\" sign and {",
  Cell[BoxData[
      \(TraditionalForm\`a\_2, a\_1\)]],
  "} the \"-\" sign. Negation is not needed in the development of unsigned \
rational and continuous numbers from set theory and a continuum axiom. The \
unsigned Rationals, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DoubleStruckCapitalQ]\^+\)\)]],
  ", are an ER on a two-element ",
  StyleBox["ordered",
    FontSlant->"Italic"],
  " set of natural numbers; a continuity axiom extends them to the unsigned \
continuous numbers (the half-line) that I call \"Primal\" numbers. The \
development and multiplication of indexed sets of primal coefficients then \
leads to loops, and to generalized negation as ER's on rotated multi-element \
indexed sets. Ordinary negation then arises in many, but not all, algebras.\n\
\tSome physical entities appear to be primal - they can be expressed using \
non-negative coefficients. There is no evidence for negative time, so it is \
always positive, i.e. Time is a Direction. Other entities, such as \
derivatives, are Real, being ER's on pairs of primal coefficients. \
Accelerations are ambiguous; are they ER's on three coefficients (terplex \
numbers), or on two derivatives (Study numbers)? Complex numbers are ER's on \
quads of primal numbers, Quaternions are ER's on sets of eight primal \
numbers."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Hoop Algebras.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Summary.",
  StyleBox[" Conservative m\[Times]m loops become m/r\[Times]m/r \"Hoop \
Algebras\" after imposing r-fold negation to provide generalized signs, \
addition & generalized subtraction. Polar & Hyperbolic dual forms exist for \
some hoops, and provide generalized powers, roots, and rotations. When sizes \
approach zero, multiplication & division \"renormalize\" by working in a \
constrained sub-algebra and splitting-off  \"remainders\" of appropriate \
shape. Multiplication or division by a vec with some zero sizes \"projects\" \
the result into a constrained sub-algebra and \"ejects\" one or two \
remainder(s).",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[{
  "6.1. \"",
  StyleBox["Hoops",
    FontSlant->"Italic"],
  "\" - Generalized Division Algebras."
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tI coined the name \"Hoops\" for all algebras obtained by folding \
conservative loops because they are rings or loops that conserve their shape, \
and fit between groups and loops. Many of the algebras relevant to \
mathematical physics are hoops or specializations of particular hoops. This \
is discussed in Section 7, but complex algebra is treated  here.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tExample 27 shows the relationship of C4 to \[DoubleStruckCapitalC], by \
mapping {\"+1\", \"\[ImaginaryI]\", \"-1\", \"-\[ImaginaryI]\"} onto the C4 \
index table and then isolating the quarter-table, which can be seen to be the \
complex algebra multiplication table; this is a C2 fold. The 4-vecs \
{a,b,-a,-b} & {d,e,-d,-e} (which fold to {2a,2b} & {2d,2e}) are then \
multiplied; the product matches the complex product of \
(2a+2\[ImaginaryI]b)*(2d+2\[ImaginaryI]e).\
\>", "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example 27. The C4 group \"equivalences\" to \[DoubleStruckCapitalC].\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"\"\<\!\(\*
StyleBox[\"Full\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C4\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Table\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontSlant->\"Italic\"]\) \>\"", 
            ",", \(c4 = 
              gmap[C4, {"\<+1\>", "\<\[ImaginaryI]\>", "\<-1\>", "\<-\
\[ImaginaryI]\>"}]\), ",", "\"\< \!\(\*
StyleBox[\"Signed\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"quarter\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"table\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\[DoubleStruckCapitalC]\>\"", 
            ",", \(c4c = Take[Transpose[Take[c4, 2]], 2]\)}], "}"}], "//", 
        "TraditionalForm"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"\<\"\\!\\(\\* StyleBox[\\\"Full\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"C4\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Table\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"=\\\
\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\<\"+1\"\>", "\<\"\[ImaginaryI]\"\>", "\<\"-1\"\>", "\<\"-\
\[ImaginaryI]\"\>"},
                {"\<\"\[ImaginaryI]\"\>", "\<\"-1\"\>", "\<\"-\[ImaginaryI]\"\
\>", "\<\"+1\"\>"},
                {"\<\"-1\"\>", "\<\"-\[ImaginaryI]\"\>", "\<\"+1\"\>", "\<\"\
\[ImaginaryI]\"\>"},
                {"\<\"-\[ImaginaryI]\"\>", "\<\"+1\"\>", "\<\"\[ImaginaryI]\"\
\>", "\<\"-1\"\>"}
                }], "\[NoBreak]", ")"}], 
          ",", "\<\" \\!\\(\\* \
StyleBox[\\\"Signed\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"quarter\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"table\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"is\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\[DoubleStruckCapitalC]\"\>", ",", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\<\"+1\"\>", "\<\"\[ImaginaryI]\"\>"},
                {"\<\"\[ImaginaryI]\"\>", "\<\"-1\"\>"}
                }], "\[NoBreak]", ")"}]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\"\<C4 \!\(\*
StyleBox[\"product\",\nFontSlant->\"Italic\"]\) {a,b,-a,-b}*{d,e,-d,-e}= \
\>\"", ",", \(abef = 
          hoopTimes[{a, b, \(-a\), \(-b\)}, {e, f, \(-e\), \(-f\)}, C4]\), 
        ",", "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"This\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"equivalences\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"to\",\nFontSlant->\"Italic\"]\) \>\"", 
        ",", \(abef[\([1]\)] - abef[\([3]\)]\), 
        ",", \(abef[\([2]\)] - abef[\([4]\)]\), ",", "\n", 
        "\"\<\\n &  to (a+\[ImaginaryI] b)*(e+\[ImaginaryI] f) =\>\"", 
        ",", \(ComplexExpand[\((2  a + 2  \[ImaginaryI]\ b)\) \((2  e + 
                2  \[ImaginaryI]\ f)\)]\), ",", "\"\<\\nC4 \!\(\*
StyleBox[\"determinant\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", 
        ",", \(frag[
          Factor[Det[{{a, b, c, d}, {b, c, d, a}, {c, d, a, b}, {d, a, b, 
                  c}}]]]\), ",", "\"\<\\nC4c \!\(\*
StyleBox[\"determinant\",\nFontSlant->\"Italic\"]\)       \>\"", 
        ",", \(Factor[Det[{{a, b}, {b, \(-a\)}}]]\)}], "}"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FormatType->TraditionalForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"C4 \\!\\(\\* \
StyleBox[\\\"product\\\",\\nFontSlant->\\\"Italic\\\"]\\) \
{a,b,-a,-b}*{d,e,-d,-e}= \"\>", 
        ",", \({2 \( a  e\) - 2 \( b  f\), 
          2 \( b  e\) + 2 \( a  f\), \(-2\) \(a  e\) + 
            2 \( b  f\), \(-2\) \(b  e\) - 2 \( a  f\)}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"This\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"equivalences\\\",\
\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"to\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \(4 \( a  e\) - 4 \( b  f\)\), 
        ",", \(4 \( b  e\) + 4 \( a  f\)\), 
        ",", "\<\"\\n &  to (a+\[ImaginaryI] b)*(e+\[ImaginaryI] f) =\"\>", 
        ",", \(4 \( a  e\) - 
          4 \( b  f\) + \((\[ImaginaryI])\) \((4 \( b  e\) + 4 \( a  f\))\)\),
         ",", "\<\"\\nC4 \\!\\(\\* \
StyleBox[\\\"determinant\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({\(-1\), a - b + c - d, 
          a + b + c + d, \((a - c)\)\^2 + \((b - d)\)\^2}\), 
        ",", "\<\"\\nC4c \\!\\(\\* \
StyleBox[\\\"determinant\\\",\\nFontSlant->\\\"Italic\\\"]\\)       \"\>", 
        ",", \(\(\(-\)\(\ \)\) a\^2 - b\^2\)}], "}"}]], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6.2. Polar and Hyperbolic \"",
  StyleBox["Duals",
    FontSlant->"Italic"],
  "\", Powers & Roots."
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThe polyhelix identity (Appendix E) ensures that some hoop algebras have \
polar \"duals\" with conserved radii and offsets, together with angles that \
are added (in abelian algebras) when the ",
  StyleBox["vecs",
    FontSlant->"Italic"],
  " are multiplied. The shapes of these hoops include conserved signed sums \
of squares. If a size can be expressed as ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y\^2\)\(\ \)\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  ", x, y and r can be interpreted as sides of a right angled triangle with \
\[Theta]=Arctan[x,y]; if  ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`z\^2\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  "; \[Theta]=ArcTan[2x-y-z,",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "(z-y)]. Polar duals are generalizations of the Cartesian {x,y} \
\[LeftRightArrow] Polar {r,\[Theta]} duality of the complex plane. ",
  StyleBox["hoopP",
    FontSlant->"Italic"],
  "o",
  StyleBox["wer",
    FontSlant->"Italic"],
  " uses the additivity of angles in duals to calculate ",
  StyleBox["vec",
    FontSlant->"Italic"],
  " powers and roots. Hoops are not restricted to infinitesimal rotations.\n \
\tExample 28 demonstrates the sinusoidal dual for the Terplex hoop (which \
uses the C3 group as the multiplication table and conserves (",
  Cell[BoxData[
      \(TraditionalForm\`\((a - b)\)\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`\((b - c)\)\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`\((c - a)\)\^2\)]],
  ")/2 ). The 3-vec ",
  StyleBox["A",
    FontSlant->"Italic"],
  " has been chosen to have a simple polar form, so that the relation between \
the polar form of the cube root ",
  StyleBox["r3A",
    FontSlant->"Italic"],
  " and that of ",
  StyleBox["A",
    FontSlant->"Italic"],
  " can be seen",
  StyleBox[".",
    FontSlant->"Italic"],
  " The original value is recovered on cubing ",
  StyleBox["r3A",
    FontSlant->"Italic"],
  ". Note that roots of powers will recover a \"rotated\" version of the \
original vec if the angle of the power exceeds 2\[Pi]. The result will have \
the same sizes as the original vec, but the angle may be different. Raising a \
root to the corresponding power does not have this problem as 2\[Pi] is not \
exceeded."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["6.2.1 Terplex Powers and Roots.", "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
Example 28. \"Terplex\" vecs have polar duals that provide powers and \
roots.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \({id[C3]; "\<Terplex A = \>", A = {1. , 5, 5}, "\<\nPolar form   \>", 
      toPolar[A, "\<C3\>"], "\<\nCube Root r3A\>", 
      r3A = hoopPower[A, 1/3], "\<\nPolar form   \>", 
      toPolar[r3A], \*"\"\<\\n\!\(\@11\%3\),\!\(\@16\%3\),\[Pi]/3\>\"", \
{\@11. \%3, \@16. \%3, \[Pi]/3. }, \*"\"\<\\n\!\(r3A\^3\)=A       \>\"", 
      hoopPower[r3A, 3]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Terplex A = ", {1.`, 5, 5}, "\nPolar form   ", {11.`, 16.`, \[Pi]}, 
      "\nCube Root r3A", {1.2704603808458383`, \(-0.316940671122361`\), 
        1.2704603808458383`}, 
      "\nPolar form   ", {2.2239800905693157`, 2.519842099789746`, 
        1.0471975511965976`}, 
      "\n\!\(\@11\%3\),\!\(\@16\%3\),\[Pi]/3", {2.2239800905693157`, 
        2.519842099789746`, 1.0471975511965976`}, 
      "\n\!\(r3A\^3\)=A       ", {1.000000000000001`, 4.999999999999999`, 
        5.`}}\)], "Output"]
}, Open  ]],

Cell["\<\
\tWhilst A has components from the real field in the above examples, hoop \
algebras are valid over the complex field (because any G can be considered to \
be folded from GC4). This is demonstrated in the next example; hyperbolic \
functions are inherently complex, even for real arguments.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2.2 Hypolar Powers and Roots.", "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tWhen a size involves the difference of two squares, or (as in C4 & K) \
two linear sizes can combine to conserve a difference of two squares, a \
hyperbolic dual polar (\"hypolar\") form exists. This is based on ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Cosh\^2\),
          FontSlant->"Italic"], TraditionalForm]]],
  " - ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Sinh\^2\),
          FontSlant->"Italic"], TraditionalForm]]],
  " = 1, and I write ",
  Cell[BoxData[
      \(TraditionalForm\`u\^2\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  "; here ",
  StyleBox["x & y",
    FontSlant->"Italic"],
  " are coordinates on the \"hyperbolic plane\" rather than the complex plane \
and ",
  StyleBox["u",
    FontSlant->"Italic"],
  " is (by analogy with the bones of the forearm) an \"ulna\"",
  ". These are \"Study numbers\", the hyperbolic analogue of complex numbers. \
The ",
  StyleBox["arcTanh[adj,opp]",
    FontSlant->"Italic"],
  " function (defined in section 2.8.2 and discussed in Appendix C) is an \
extension of ArcTanh that gives results for complex or real arguments by \
taking the quadrant of the real ",
  StyleBox["adj,opp",
    FontSlant->"Italic"],
  " components into account. The \"hyperangle\" is a complex number that \
becomes infinite whenever ",
  StyleBox["adj ",
    FontSlant->"Italic"],
  "= \[PlusMinus] ",
  StyleBox["opp",
    FontSlant->"Italic"],
  ", i.e. on the 45\[Degree] lines in the \"hypercomplex plane\". ",
  StyleBox[" tohyVec",
    FontSlant->"Italic"],
  " recovers the signed adjacent-opposite components, unlike ",
  StyleBox["Tanh",
    FontSlant->"Italic"],
  ", which only provides their ratio. The database contains nine hypolar \
examples. The hypolar form may have both hypolar and polar components as in \
C4. Example 29 shows the same vecs A={3.-2\[ImaginaryI], 5., -2, 2.+\
\[ImaginaryI]} & B={5.+\[ImaginaryI], 3.-2\[ImaginaryI], -2. -3\[ImaginaryI], \
4.} being multiplied by both C4 & the Klein group K, which has two hypolar \
angles (the first matching that of C4). The hypolar coordinates are \
\"synthetic\" in both examples, as they are obtained from pairs of linear \
sizes. "
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example 29. Hypolar sizes multiply & angles add on multiplication.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\({"\<Target group is\>", 
      id[C4], "\<with hypolar form\>", \[IndentingNewLine]tohyPolar[{a, b, c, 
          d}]}\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \({A = {3.  - 2  \[ImaginaryI], 5. , \(-2\), 2.  + \[ImaginaryI]}, 
        hA = tohyPolar[A, "\<C4\>"], Chop[tohyVector[hA] - A], 
        B = {5.  + \[ImaginaryI], 
            3.  - 2  \[ImaginaryI], \(-2. \) - 3  \[ImaginaryI], 4. }, 
        hB = tohyPolar[B], AB = hoopTimes[A, B], hAB = tohyPolar[AB], 
        Chop[hA*hB - hAB], Chop[hA + hB - hAB]} // TraditionalForm\), "\n", 
    \({"\<Change Target group to\>", id[K]}\), "\n", 
    \({A, hA = tohyPolar[A, "\<K\>"], Chop[tohyVector[hA] - A], B, 
        hB = tohyPolar[B], AB = hoopTimes[A, B], hAB = tohyPolar[AB], 
        Chop[hA*hB - hAB], Chop[hA + hB - hAB]} // 
      TraditionalForm\)}], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False,
  CellOpen->False],

Cell[BoxData[
    \({"Target group is", "C4", 
      "with hypolar form", {\((a + c)\)\^2 - \((b + d)\)\^2, 
        If[\((a + c)\)\^2 - 1.`\ \((b + d)\)\^2 \[Equal] 0, \[Infinity], 
          Log[\(\((a + c)\) + \((b + d)\)\)\/\@\(\((a + c)\)\^2 - 1.`\ \((b + \
d)\)\^2\)]], \((a - c)\)\^2 + \((b - d)\)\^2, 
        ArcTan[a - c, b - d]}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "Function", \(a\ or\ u\^2\), \(\(\(.\)\(b\)\)\ or\ \
hyperangle\), \(c\ or\ v\^2\), \(\(\(.\)\(d\)\)\ or\ hyperangle\)},
            {"vectorA", \(3\[InvisibleSpace] - 2\ \[ImaginaryI]\), 
              "5", \(-2\), \(2. \[InvisibleSpace] + \[ImaginaryI]\)},
            {\(hA = hypolarC4[A]\), \(\(-51\) - 
                18\ \[ImaginaryI]\), \(0.0919\[InvisibleSpace] + 
                1.2768  \[ImaginaryI]\), \(29\[InvisibleSpace] - 
                26\ \[ImaginaryI]\), \(0.5306\[InvisibleSpace] + 
                0.0257\ \[ImaginaryI]\)},
            {\(A - hyvectorC4[hA]\), "0", "0", "0", "0"},
            {\(vector\ B\), \(5\[InvisibleSpace] + \[ImaginaryI]\), \(3.  - 
                2\ \[ImaginaryI]\), \(\(-2\) - 3\ \[ImaginaryI]\), "4."},
            {\(hB = hypolarC4[B]\), \(\(-40\) + 
                16\ \[ImaginaryI]\), \(0.4952\[InvisibleSpace] - 
                1.7610\ \[ImaginaryI]\), \(30\[InvisibleSpace] + 
                60\ \[ImaginaryI]\), \(\(-0.2318\) - 
                0.1469\ \[ImaginaryI]\)},
            {\(vector\ AB\), \(49\[InvisibleSpace] - 
                2\ \[ImaginaryI]\), \(21\[InvisibleSpace] . \(-15\)\ \
\[ImaginaryI]\), \(1\[InvisibleSpace] - 
                13\ \[ImaginaryI]\), \(5. \[InvisibleSpace] - 
                12. \ \[ImaginaryI]\)},
            {\(hypolarC4[AB]\), \(2328\[InvisibleSpace] - 
                96\ \[ImaginaryI]\), \(0.5872\[InvisibleSpace] - 
                0.4842\ \[ImaginaryI]\), \(2430 + 
                960\ \[ImaginaryI]\), \(0.2988\[InvisibleSpace] - 
                0.1213\ \[ImaginaryI]\)},
            {\(Both\ sizes\ multiply\), 
              "0", \(1.7068\[InvisibleSpace] + 0.9547\ \[ImaginaryI]\), 
              "0", \(\(-0.4180\) + 0.0374\ \[ImaginaryI]\)},
            {\(Both\ angles\ add\), \(\(-2419\) + 94\ \[ImaginaryI]\), 
              "0", \(\(-2371\) - 926\ \[ImaginaryI]\), "0"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontSize->9,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
    \({"Change Target group to", "K"}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "Function", \(a\ or\ u\^2\), \(\(\(.\)\(b\)\)\ or\ \
hyperangle\), \(c\ or\ v\^2\), \(\(\(.\)\(d\)\)\ or\ hyperangle\)},
            {"vectorA", \(3 - 2  \[ImaginaryI]\), 
              "5", \(-2\), \(2.  + \[ImaginaryI]\)},
            {\(hA = hypolarC4[A]\), \(\(-51\) - 
                18  \[ImaginaryI]\), \( .09193 + 
                1.2768  \[ImaginaryI]\), \(13 - 
                14  \[ImaginaryI]\), \( .67026 +  .0524  \[ImaginaryI]\)},
            {\(A - hyvectorC4[hA]\), "0", "0", "0", "0"},
            {\(vector\ B\), \(5\[InvisibleSpace] + \[ImaginaryI]\), \(3.  - 
                2\ \[ImaginaryI]\), \(\(-2\) - 3\ \[ImaginaryI]\), "4"},
            {\(hB = hypolarC4[B]\), \(\(-40\) + 
                16\ \[ImaginaryI]\), \(0.49525\[InvisibleSpace] - 
                1.7610\ \[ImaginaryI]\), \(36 + 
                52\ \[ImaginaryI]\), \(\(-0.22291\) - 
                0.1609\ \[ImaginaryI]\)},
            {\(vector\ AB\), \(44\[InvisibleSpace] - 
                7\ \[ImaginaryI]\), \(21. \[InvisibleSpace] - 
                15\ \[ImaginaryI]\), \(6 - 8\ \[ImaginaryI]\), \(5.  - 
                12\ \[ImaginaryI]\)},
            {\(hypolarC4[AB]\), \(2328 - 
                96\ \[ImaginaryI]\), \(0.58718\[InvisibleSpace] - 
                0.48425\ \[ImaginaryI]\), \(1196 + 
                172\ \[ImaginaryI]\), \(0.4412 - 0.1084\ \[ImaginaryI]\)},
            {\(Both\ sizes\ multiply\), 
              "0", \(1.7069 +  .9547\ \[ImaginaryI]\), 
              "0", \(\(- .5863\) +  .0114  \[ImaginaryI]\)},
            {\(Both\ angles\ add\), \(\(-2419\) + 94\ \[ImaginaryI]\), 
              "0", \(\(-1147\) - 134\ \[ImaginaryI]\), "0"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontSize->9,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2.3 Non-abelian Pseudo-powers and Roots induce rotations.", \
"Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tUntil November 2005, I had found no non-abelian polar forms. Non-abelian \
hoops conserve repeated quadratic factors that are sums of more than three \
squares; each duplicated quadratic releases three degrees of freedom and an \
angle can only take up one. I then realized that both the quadratic size and \
two {r,\[Theta]} components were needed. Applying this to D3, \[Eta]\[Eta]=",
  Cell[BoxData[
      \(\((\((a - c)\)\^2 + \((c - e)\)\^2 + \((e - a)\)\^2)\)/2\ and\)],
    FontFamily->"Times New Roman"],
  "\n\[Kappa]\[Kappa]=",
  Cell[BoxData[
      \(\((\((a - c)\)\^2 + \((c - e)\)\^2 + \((e - a)\)\^2 - \((b - d)\)\^2 \
- \((d - f)\)\^2 - \((f - b)\)\^2)\)/2\)],
    FontFamily->"Times New Roman"],
  " are supplied by ",
  StyleBox["toPolar",
    FontSlant->"Italic"],
  ". The two radii are then calculated by ",
  StyleBox["toVector",
    FontSlant->"Italic"],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Kappa]\[Kappa]\)],
    FontFamily->"Times New Roman"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\[Kappa]\[Kappa] - \[Eta]\[Eta]\)\)],
    FontFamily->"Times New Roman"],
  " i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\((\((b - d)\)\^2 - \((d - f)\)\^2 - \((f - b)\)\
\^2)\)/2\)\)]],
  ". The corresponding angles are multiplied by exponents in ",
  StyleBox["hoopP",
    FontSlant->"Italic"],
  "o",
  StyleBox["wer",
    FontSlant->"Italic"],
  ", and give results with correct sizes, so ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(A\^\(1/p\)\),
              "TraditionalForm"], ")"}], "p"], TraditionalForm]]],
  "=A, but the radii are not conserved. Consequently these \"powers\" differ \
from repeated products, though they have the same sizes. I call them \
\"pseudo-powers\". The following examples show this for ",
  Cell[BoxData[
      \(TraditionalForm\`\@A\%3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`A\^2\)]],
  " in the D3 algebra. The same calculations in the C3C2 algebra show that \
abelian powers match repeated products - provided that angles do not exceed 2\
\[Pi]."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 29A. D3 pseudo-powers induce rotations.", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(id["\<D3\>"]; {"\<A         \>", 
      A = {1. , 3. , 0. , \(-1. \), \(-2. \), 1. }, "\<\nshape  A  =\>", 
      shape[A], \*"\"\<\\nr3A=\!\(A\^\(1/3\)\)    \>\"", 
      r3A = hoopPower[A, 1/3], "\<\nshape r3A =\>", 
      shape[r3A], \*"\"\<\\n\!\(r3A\^3\)=A     \>\"", \n
      r3A3 = hoopPower[r3A, 3. ], \*"\"\<\\nshape \!\(r3A\^3\)=\>\"", 
      shape[r3A3], "\<\nr3A.r3A.r3A\>", 
      A3AA = hoopTimes[r3A, 
          hoopTimes[r3A, r3A]], \*"\"\<\\nshape \!\(r3A\^3\)=\>\"", 
      shape[A3AA], \*"\"\<\\n\!\(A\^2\)=        \>\"", \n
      hoopPower[A, 2. ], "\<\nAA =       \>", hoopTimes[A, A]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A         ", {1.`, 3.`, 0.`, \(-1.`\), \(-2.`\), 1.`}, 
      "\nshape  A  =", {2.`, \(-4.`\), \(-5.`\)}, 
      "\nr3A=\!\(A\^\(1/3\)\)    ", {0.8415068369191917`, 
        1.724204854952156`, \(-0.3144346503134702`\), \
\(-0.3410981904303987`\), \(-0.6908121876423842`\), 0.04055438640977941`}, 
      "\nshape r3A =", {1.2599210498948743`, \(-1.5874010519681994`\), \
\(-1.7099759466766957`\)}, 
      "\n\!\(r3A\^3\)=A     ", {1.`, 2.9999999999999982`, 
        0, \(-0.9999999999999971`\), \(-1.999999999999997`\), 
        1.0000000000000018`}, 
      "\nshape \!\(r3A\^3\)=", {2.0000000000000058`, \(-4.`\), \
\(-4.999999999999988`\)}, 
      "\nr3A.r3A.r3A", {10.739318173995784`, 
        12.16778327290708`, \(-4.1878686553211875`\), \
\(-6.289252845067996`\), \(-7.551449518674596`\), \(-2.878530427839082`\)}, 
      "\nshape \!\(r3A\^3\)=", {2.0000000000000018`, \(-4.000000000000001`\), \
\(-5.000000000000067`\)}, 
      "\n\!\(A\^2\)=        ", {\(-1.333333333333333`\), 6.2007750890142095`, 
        1.6666666666666672`, \(-2.4015501780284176`\), \
\(-6.333333333333333`\), 6.2007750890142095`}, 
      "\nAA =       ", {12.`, 6.`, 
        3.`, \(-10.`\), \(-5.`\), \(-2.`\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
Example 29B. C3C2 powers are not rotated unless angles exceed 2\[Pi].\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(id["\<C3C2\>"]; 
    Chop[{"\<A         \>", 
        A = {1. , 3. , 0. , \(-1. \), \(-2. \), 1. }, "\<\nshape  A  =\>", 
        shape[A], \*"\"\<\\nr3A=\!\(A\^\(1/3\)\)    \>\"", 
        r3A = hoopPower[A, 1/3], "\<\nshape r3A =\>", 
        shape[r3A], \*"\"\<\\n\!\(r3A\^3\)=A     \>\"", \n
        r3A3 = hoopPower[r3A, 3. ], \*"\"\<\\nshape \!\(r3A\^3\)=\>\"", 
        shape[r3A3], "\<\nr3A.r3A.r3A\>", 
        A3AA = hoopTimes[r3A, 
            hoopTimes[r3A, r3A]], \*"\"\<\\nshape \!\(r3A\^3\)=\>\"", 
        shape[A3AA], \*"\"\<\\n\!\(A\^2\)=        \>\"", \n
        hoopPower[A, 2. ], "\<\nAA =       \>", hoopTimes[A, A]}]\)], "Input",\

  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A         ", {1.`, 3.`, 0, \(-1.`\), \(-2.`\), 1.`}, 
      "\nshape  A  =", {2.`, 6.`, 1.`, 27.`}, 
      "\nr3A=\!\(A\^\(1/3\)\)    ", {1.179506940454502`, 
        0.17950694045450213`, 
        0.17950694045450213`, \(-0.42619992382287764`\), \
\(-0.42619992382287775`\), 0.5738000761771221`}, 
      "\nshape r3A =", {1.2599210498948734`, 1.8171205928321394`, 
        0.9999999999999999`, 2.999999999999999`}, 
      "\n\!\(r3A\^3\)=A     ", {0.9999999999999997`, 2.9999999999999987`, 
        0, \(-0.9999999999999991`\), \(-1.9999999999999991`\), 
        0.9999999999999992`}, 
      "\nshape \!\(r3A\^3\)=", {1.9999999999999991`, 5.999999999999997`, 
        0.9999999999999978`, 26.999999999999975`}, 
      "\nr3A.r3A.r3A", {0.9999999999999996`, 2.9999999999999982`, 
        0, \(-0.9999999999999997`\), \(-1.9999999999999991`\), 
        0.9999999999999989`}, 
      "\nshape \!\(r3A\^3\)=", {1.9999999999999984`, 5.999999999999998`, 
        0.9999999999999986`, 26.999999999999957`}, 
      "\n\!\(A\^2\)=        ", {\(-2.`\), 11.`, 10.999999999999995`, 
        4.`, \(-9.999999999999998`\), \(-9.999999999999993`\)}, 
      "\nAA =       ", {\(-2.`\), 11.`, 11.`, 
        4.`, \(-10.`\), \(-10.`\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tQuaternion pseudo-powers can be formulated in different ways; \
quaternions conserve the sum of four squares which can be paired off \
arbitrarily. The implementation uses ArcTan[a,b] and ArcTan[c,d]; ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(Q\^r\),
              "TraditionalForm"], ")"}], \(1/r\)], TraditionalForm]]],
  " reverts correctly (if no wrap-round occurs). The standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package <<Quaternion`  implements procedures for ",
  StyleBox["Quaternion[{a,b,c,d}] ",
    FontSlant->"Italic"],
  "objects, but rejects biquaternions (i.e.with complex coefficients). My ",
  StyleBox["QPower[{a,b,c,d},r]",
    FontSlant->"Italic"],
  " calculates powers and roots for both quaternions and biquaternions, \
matching ",
  StyleBox["Quaternion[{a,b,c,d}]^r ",
    FontSlant->"Italic"],
  "in the first case. "
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 29c. Quaternion powers and pseudo-powers.", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<A           =\>", {1 +  .2\ \[ImaginaryI],  .5 -  .1  \
\[ImaginaryI],  .3, \(- .4\)}, "\<\nCube Root r3A=\>", 
      r3A = QPower[
          A = {1 +  .2\ \[ImaginaryI],  .5 -  .1  \[ImaginaryI],  .3, \(- \
.4\)}, 1/3], "\<\ncubes correctly\>", \[IndentingNewLine]r3A3 = 
        Chop[QPower[r3A, 
            3]], \[IndentingNewLine]id["\<Qr\>"]; "\<\nPseudo-Cube Root \
q3A=\>", g3A = 
        hoopPower[A, 1/3], "\<\ncubes correctly\>", \[IndentingNewLine]g3A3 = 
        Chop[hoopPower[g3A, 
            3]], "\<\nA^2           =\>", \[IndentingNewLine]A2 = 
        Chop[QPower[A, 2]], "\<\nA A is the same\>", \n
      AA = Chop[hoopTimes[A, A]], "\<\ncorrect QPower roots  \>", \n
      rA2 = Chop[
          QPower[A2, 1/2]], "\<\nhoopPower A^2\>", \[IndentingNewLine]gA2 = 
        Chop[hoopPower[A, 
            2]], "\<\ncorrect hoopPower roots\>", \[IndentingNewLine]Chop[
        hoopPower[gA2, 1/2]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A           =", {1 + 
          0.2`  \[ImaginaryI], \(\(0.5`\)\(\[InvisibleSpace]\)\) - 
          0.1`  \[ImaginaryI], 0.3`, \(-0.4`\)}, 
      "\nCube Root r3A=", {\(\(1.0466264504350709`\)\(\[InvisibleSpace]\)\) + 
          0.0455707038014122`  \[ImaginaryI], \(\(0.15026919914397022`\)\(\
\[InvisibleSpace]\)\) - 
          0.04502081217784149`  \[ImaginaryI], \(\(0.09188847783434914`\)\(\
\[InvisibleSpace]\)\) - 
          0.008634791739835045`  \[ImaginaryI], \(-0.12251797044579889`\) + 
          0.011513055653113393`  \[ImaginaryI]}, 
      "\ncubes correctly", {\(\(1.0000000000000004`\)\(\[InvisibleSpace]\)\) \
+ 0.20000000000000023`  \[ImaginaryI], \(\(0.5000000000000001`\)\(\
\[InvisibleSpace]\)\) - 0.10000000000000035`  \[ImaginaryI], 
        0.3000000000000001`, \(-0.40000000000000036`\)}, 
      "\nPseudo-Cube Root q3A=", \
{\(\(0.7069860045263642`\)\(\[InvisibleSpace]\)\) + 
          0.05929016780217531`  \[ImaginaryI], \(\(0.10836924093942352`\)\(\
\[InvisibleSpace]\)\) - 0.02944608934610602`  \[ImaginaryI], 
        0.7560856467169442`, \(-0.24144361614268647`\)}, 
      "\ncubes correctly", {\(\(1.0000000000000002`\)\(\[InvisibleSpace]\)\) \
+ 0.19999999999999962`  \[ImaginaryI], \(\(0.49999999999999994`\)\(\
\[InvisibleSpace]\)\) - 0.09999999999999927`  \[ImaginaryI], 
        0.30000000000000016`, \(-0.40000000000000013`\)}, 
      "\nA^2           =", {\(\(0.4700000000000002`\)\(\[InvisibleSpace]\)\) \
+ 0.5000000000000002`  \[ImaginaryI], 
        1.04`, \(\(0.6`\)\(\[InvisibleSpace]\)\) + 
          0.12000000000000002`  \[ImaginaryI], \(-0.8000000000000002`\) - 
          0.16000000000000006`  \[ImaginaryI]}, 
      "\nA A is the same", {\(\(0.47`\)\(\[InvisibleSpace]\)\) + 
          0.5`  \[ImaginaryI], 
        1.04`, \(\(0.6000000000000001`\)\(\[InvisibleSpace]\)\) + 
          0.12`  \[ImaginaryI], \(-0.8`\) - 
          0.16000000000000003`  \[ImaginaryI]}, 
      "\ncorrect QPower roots  ", {\(\(1.`\)\(\[InvisibleSpace]\)\) + 
          0.19999999999999998`  \[ImaginaryI], \
\(\(0.5`\)\(\[InvisibleSpace]\)\) - 0.09999999999999987`  \[ImaginaryI], 
        0.29999999999999993`, \(-0.4`\)}, 
      "\nhoopPower A^2", {\(\(0.8708116248988154`\)\(\[InvisibleSpace]\)\) + 
          0.5604192616283038`  \[ImaginaryI], \(\(1.2278523695613623`\)\(\
\[InvisibleSpace]\)\) - 
          0.04318076762117436`  \[ImaginaryI], \(-0.07000000000000003`\), \
\(-0.24`\)}, 
      "\ncorrect hoopPower roots", {\(\(1.0000000000000002`\)\(\
\[InvisibleSpace]\)\) + 
          0.20000000000000004`  \[ImaginaryI], \
\(\(0.5`\)\(\[InvisibleSpace]\)\) - 0.09999999999999999`  \[ImaginaryI], 
        0.3`, \(-0.4`\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
6.2.4 Powers and Repeated Products may differ for Signed Sizes.\
\>", "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tA distinction must be drawn between powers and repeated products \
wherever sizes are signed or angles are large. Powers are continuous \
functions of the exponent, and so are their shapes. Powers revert correctly \
unless angles exceed 2\[Pi].\nRepeated products must have sizes that respect \
the signs of the original sizes. If A has a negative size, AAA and AAAAA will \
have the same sign negative, but AA and AAAA will have it positive. ",
  Cell[BoxData[
      \(TraditionalForm\`\@AA\)]],
  " will not equal A. If A has a complex size, powers will only have the same \
sign when the exponent is divisible by 4, etc. The power ",
  Cell[BoxData[
      \(TraditionalForm\`A\^p\)]],
  " is a continuous function of ",
  StyleBox["p",
    FontSlant->"Italic"],
  ".\n\tThis is demonstrated in the next example, where a C4 vector is chosen \
to have the second size negative. A={3.,4.,2.,4.5}, but ",
  Cell[BoxData[
      \(TraditionalForm\`\@AA\)]],
  "={4.75,2.25,3.75,2.75}. The angle is small, so powers up the 6th reverts \
correctly; the 7th power gives a rotated 7th root (not shown)."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example 29a. C4 powers & multiplication with a negative size.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(id["\<C4\>"]; {"\<If A = \>", 
      A = {3. , 4. , 2. , 4.5}, "\<\nShape[A] =   \>", 
      shape[A], "\<\n& toPolar[A]=\>", toPolar[A]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"If A = ", {3.`, 4.`, 2.`, 4.5`}, 
      "\nShape[A] =   ", {13.5`, \(-3.5`\), 1.25`}, 
      "\n& toPolar[A]=", {13.5`, \(-3.5`\), 
        1.25`, \(-0.4636476090008061`\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{\(A19 = 
            Flatten[{\*"\"\<\!\(A\^1.99\)\>\"", hoopPower[A, 1.99]}]\), 
          ",", \(Flatten[{\*"\"\<\!\(A\^2\)\>\"", A20 = hoopPower[A, 2]}]\), 
          ",", \(Flatten[{\*"\"\<\!\(A\^2.01\)\>\"", 
              A21 = hoopPower[A, 2.01]}]\), 
          ",", \(Flatten[rA20 = {\*"\"\<\!\(\@A\^2\)\>\"", hoopPower[A20]}]\),
           ",", 
          RowBox[{"Flatten", "[", 
            RowBox[{"{", 
              RowBox[{"\"\<\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\>\"", 
                ",", \(AA = hoopTimes[A, A]\)}], "}"}], "]"}], 
          ",", \(Flatten[{\*"\"\<\!\(\@\(A . A\)\)\>\"", 
              rAA = hoopPower[AA]}]\), 
          ",", \(Flatten[{\*"\"\<\!\(\@\(A\^6\)\%6\)\>\"", 
              r6A6 = hoopPower[hoopPower[A, 6], 1/6]}]\)}], "}"}], "//", 
      "tf"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"\\!\\(A\\^1.99\\)\"\>", "41.744468507773185`", 
              "46.91862160036751`", "40.99068159240931`", 
              "47.914022301304904`"},
            {"\<\"\\!\\(A\\^2\\)\"\>", "42.875`", "48.125`", "42.125`", 
              "49.125`"},
            {"\<\"\\!\\(A\\^2.01\\)\"\>", "44.035903835721854`", 
              "49.36273103621788`", "43.28971628609257`", 
              "50.36731784269318`"},
            {"\<\"\\!\\(\\@A\\^2\\)\"\>", "3.`", "4.`", "2.`", "4.5`"},
            {"\<\"\\!\\(\\* \
StyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\".\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "49.`", "42.`", 
              "48.25`", "43.`"},
            {"\<\"\\!\\(\\@\\(A . A\\)\\)\"\>", "4.75`", "2.25`", "3.75`", 
              "2.75`"},
            {"\<\"\\!\\(\\@\\(A\\^6\\)\\%6\\)\"\>", "3.`", "4.`", "2.`", 
              "4.5`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3. Generalized Multiplicative Inverse, Division .", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tCramer's rule provides a generalized multiplicative inverse Ainv, such \
that Ainv\[CenterDot]A = {1,0,...} (the unit). Wherever the multiplication is \
conservative, Ainv\[CenterDot]AB = B, allowing division C/A = \
Ainv\[CenterDot]C. This is implemented as ",
  StyleBox["hoopInverse",
    FontSlant->"Italic"],
  ". Ainv is the left inverse in non-abelian hoops. For small algebras, Ainv \
can be found by solving the equations {p,q,r,..} \[Times] {a,b,c,..} == \
{1,0,0,..} for the elements of the inverse, {p,q,r,..}. This was demonstrated \
in Example 16. It is shown for several more algebras in Examples 30 - 32. \
Each element of the inverse is a fraction, with a divisor (denominator) that \
is related to the table determinant. The denominators factorise in many \
cases, permitting the inverse elements to be expressed as partial fractions. \
This provides generalised \"partial-fraction division\", which is developed \
in Sections 6.4. & 6.5. The partial fraction numerators are derivations of \
the denominators, wrt. each variable. Division is closely related to \
differentiation and the orbits are solutions to the banded sets of \
differential equations described by the hoops.\n\tExample 30 gives the \
general \"Terplex\" or ",
  StyleBox["C3",
    FontSlant->"Italic"],
  " inverse of ",
  StyleBox["{a,b,c}",
    FontSlant->"Italic"],
  ", and then shows that ",
  StyleBox["Ainv",
    FontSlant->"Italic"],
  "*",
  StyleBox["AB=B",
    FontSlant->"Italic"],
  ". Terplex \"fits between\" Real and Complex algebra (which are folded from \
the ",
  StyleBox["C2",
    FontSlant->"Italic"],
  " and ",
  StyleBox["C4",
    FontSlant->"Italic"],
  " groups and are \"algebras without real divisors of zero\"). It differs \
from them in having partial-fraction divisors of zero."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example 30. \"Terplex\" vecs have a multiplicative inverse & Partial-fraction \
Division.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{id[C3];\"Terplex solution to {p,q,r}\[Times]{a,b,c}=={1,0,0} \
is\",Solve[hoopTimes[{p,q,r},{a,b,c},C3]=={1,0,0},{p,q,r}],
\"\\nThe denominator is the determinant. It factorises into\" \
,fa[C3],\"\\nallowing the elements to split into partial fractions so that \
the Terplex inverse of {a,b,c} =\",Apart[hoopInverse[{a,b,c}]],\"\\nNumeric \
Example:-\",{\"\\nA    =\",
A={1.,5,5},\"\\nB    =\",B={4.,3,1},\"\\nAB   =\",AB=hoopTimes[A,B],\"\\nAi = \
 \",Ainv=hoopInverse[A],
    \"\\nAi\[Times]AB \",hoopTimes[Ainv,AB]}//tf}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Terplex solution to {p,q,r}\[Times]{a,b,c}=={1,0,0} \
is\"\>", ",", \({{p \[Rule] \(-\(\(\(-a\^2\) + b\ c\)\/\(a\^3 + b\^3 - 
                      3\ a\ b\ c + c\^3\)\)\), 
            q \[Rule] \(-\(\(a\ b - c\^2\)\/\(a\^3 + b\^3 - 3\ a\ b\ c + 
                      c\^3\)\)\), 
            r \[Rule] \(-\(\(\(-b\^2\) + a\ c\)\/\(a\^3 + b\^3 - 3\ a\ b\ c + 
                      c\^3\)\)\)}}\), 
        ",", "\<\"\\nThe denominator is the determinant. It factorises into\"\
\>", ",", \(\((a + b + c)\)\ \((a\^2 - a\ b + b\^2 - a\ c - b\ c + c\^2)\)\), 
        ",", "\<\"\\nallowing the elements to split into partial fractions so \
that the Terplex inverse of {a,b,c} =\"\>", 
        ",", \({1\/\(3\ \((a + b + c)\)\) + \(2\ a - b - c\)\/\(3\ \((a\^2 - \
a\ b + b\^2 - a\ c - b\ c + c\^2)\)\), 
          1\/\(3\ \((a + b + c)\)\) + \(\(-a\) - b + 2\ c\)\/\(3\ \((a\^2 - a\
\ b + b\^2 - a\ c - b\ c + c\^2)\)\), 
          1\/\(3\ \((a + b + c)\)\) + \(\(-a\) + 2\ b - c\)\/\(3\ \((a\^2 - a\
\ b + b\^2 - a\ c - b\ c + c\^2)\)\)}\), ",", "\<\"\\nNumeric Example:-\"\>", 
        ",", 
        TagBox[
          
          FormBox[\({"\nA    =", {1.`, 5, 5}, "\nB    =", {4.`, 3, 1}, 
              "\nAB   =", {24.`, 28.`, 36.`}, 
              "\nAi =  ", {\(-0.13636363636363635`\), 0.11363636363636365`, 
                0.11363636363636365`}, 
              "\nAi\[Times]AB ", {4.000000000000002`, 3.0000000000000013`, 
                1.0000000000000013`}}\),
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThe database contains nine 3\[Times]3 signed tables that define \
conservative division algebras. The multiplicative inverses for four of these \
are found in Example 31. The shapes are conjugates of the determinants; in \
the first example conjugation has no effect as everything is real.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["Example 31. Inverses for some other 3-element algebras.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{\"C3C2c =\",tst=cd[{3}];tst//tf,id[tst];\"C3C2c solution to \
{p,q,r}\[Times]{a,b,c}]=={1,0,0} \
is\",Solve[hoopTimes[{p,q,r},{a,b,c}]=={1,0,0},{p,q,r}],
\"\\nThe denominator is the determinant and factorises into\\n \
(a-b+c)*(((a+b)^2+(b+c)^2+(c-a)^2)/2)\",

\"\\n\\nC4C3c =\",tst=C4C3c;tst//tf,id[tst];
\"\\nC4C3c solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0} is\",
Solve[hoopTimes[{p,q,r},{a,b,c}]=={1,0,0},{p,q,r}],
\"\\nThe denominator is NOT the determinant, which is\",
Expand[fa[tst]],\"the denominator factorises into ((a-\[ImaginaryI] b-\
\[ImaginaryI] c)((a + \[ImaginaryI] b)^2-(b-c)^2+(\[ImaginaryI] c+a)^2)/2\",

tst=C3i;id[tst];\"\\n\\nC3i =\",tst//tf,\"\\nC3i solution to \
{p,q,r}\[Times]{a,b,c}]=={1,0,0} 
is\",Solve[hoopTimes[{p,q,r},{a,b,c}]\[Equal]{1,0,0},{p,q,r}],    \"\\nThe \
denominator is NOT the determinant, which is\",
Expand[fa[tst]],\"the denominator factorises into (a-\[ImaginaryI] b-c)((a+\
\[ImaginaryI] b)^2+(\[ImaginaryI] b-c)^2+(c+a)^2)/2\",

tst=C9J;\"\\n\\nC9J =\",tst//tf,id[C9J];\"\\nC9J solution to \
{p,q,r}\[Times]{a,b,c}]=={1,0,0} is\",
Solve[hoopTimes[{p,q,r},{a,b,c}]=={1,0,0},{p,q,r}]/.\[DoubleStruckCapitalJ]^3 \
-> 1,
\"\\nThe denominator does not factorize. It is NOT the determinant, which \
is\" ,-fa[tst]/.\[DoubleStruckCapitalJ]^3 -> 1}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"C3C2c =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "3", "1"},
                  {"3", "1", "2"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"C3C2c solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0} is\"\>", 
        ",", \({{p \[Rule] \(-\(\(\(-a\^2\) + b\ c\)\/\(a\^3 + b\^3 - 
                      3\ a\ b\ c + c\^3\)\)\), 
            q \[Rule] \(-\(\(a\ b - c\^2\)\/\(a\^3 + b\^3 - 3\ a\ b\ c + 
                      c\^3\)\)\), 
            r \[Rule] \(-\(\(\(-b\^2\) + a\ c\)\/\(a\^3 + b\^3 - 3\ a\ b\ c + 
                      c\^3\)\)\)}}\), 
        ",", "\<\"\\nThe denominator is the determinant and factorises \
into\\n (a-b+c)*(((a+b)^2+(b+c)^2+(c-a)^2)/2)\"\>", 
        ",", "\<\"\\n\\nC4C3c =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", \(3\ \[ImaginaryI]\), \(-1\)},
                  {"3", \(-1\), \(2\ \[ImaginaryI]\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nC4C3c solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0} \
is\"\>", ",", \({{p \[Rule] \(-\(\(\(-a\^2\) - 
                      b\ c\)\/\(a\^3 - \[ImaginaryI]\ b\^3 + 
                      3\ a\ b\ c - \[ImaginaryI]\ c\^3\)\)\), 
            q \[Rule] \(-\(\(\[ImaginaryI]\ a\ b + 
                      c\^2\)\/\(\[ImaginaryI]\ a\^3 + b\^3 + 
                      3\ \[ImaginaryI]\ a\ b\ c + c\^3\)\)\), 
            r \[Rule] \(-\(\(\(-\[ImaginaryI]\)\ b\^2 + 
                      a\ c\)\/\(a\^3 - \[ImaginaryI]\ b\^3 + 
                      3\ a\ b\ c - \[ImaginaryI]\ c\^3\)\)\)}}\), 
        ",", "\<\"\\nThe denominator is NOT the determinant, which is\"\>", 
        ",", \(a\^3 + \[ImaginaryI]\ b\^3 + 
          3\ a\ b\ c + \[ImaginaryI]\ c\^3\), 
        ",", "\<\"the denominator factorises into ((a-\[ImaginaryI] b-\
\[ImaginaryI] c)((a + \[ImaginaryI] b)^2-(b-c)^2+(\[ImaginaryI] \
c+a)^2)/2\"\>", ",", "\<\"\\n\\nC3i =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "3", "\[ImaginaryI]"},
                  {"3", "\[ImaginaryI]", \(2\ \[ImaginaryI]\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nC3i solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0}  \
is\"\>", ",", \({{p \[Rule] \(-\(\(\(-a\^2\) + \[ImaginaryI]\ b\ c\)\/\(a\^3 \
+ \[ImaginaryI]\ b\^3 - 3\ \[ImaginaryI]\ a\ b\ c - c\^3\)\)\), 
            q \[Rule] \(\[ImaginaryI]\ \((a\ b - \[ImaginaryI]\ c\^2)\)\)\/\(\
\(-\[ImaginaryI]\)\ a\^3 + b\^3 - 3\ a\ b\ c + \[ImaginaryI]\ c\^3\), 
            r \[Rule] \(-\(\(\(-b\^2\) + 
                      a\ c\)\/\(a\^3 + \[ImaginaryI]\ b\^3 - 
                      3\ \[ImaginaryI]\ a\ b\ c - c\^3\)\)\)}}\), 
        ",", "\<\"\\nThe denominator is NOT the determinant, which is\"\>", 
        ",", \(a\^3 - \[ImaginaryI]\ b\^3 + 3\ \[ImaginaryI]\ a\ b\ c - 
          c\^3\), ",", "\<\"the denominator factorises into (a-\[ImaginaryI] \
b-c)((a+\[ImaginaryI] b)^2+(\[ImaginaryI] b-c)^2+(c+a)^2)/2\"\>", 
        ",", "\<\"\\n\\nC9J =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "3", "\[DoubleStruckCapitalJ]"},
                  {"3", 
                    "\[DoubleStruckCapitalJ]", \(2\ \
\[DoubleStruckCapitalJ]\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nC9J solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0} is\"\>",
         ",", \({{p \[Rule] \(-\(\(\(-a\^2\) + 
                      b\ c\ \[DoubleStruckCapitalJ]\)\/\(a\^3 + 
                      b\^3\ \[DoubleStruckCapitalJ] - 
                      3\ a\ b\ c\ \[DoubleStruckCapitalJ] + 
                      c\^3\ \[DoubleStruckCapitalJ]\^2\)\)\), 
            q \[Rule] \(-\(\(a\ b - c\^2\ \[DoubleStruckCapitalJ]\)\/\(a\^3 + 
                      b\^3\ \[DoubleStruckCapitalJ] - 
                      3\ a\ b\ c\ \[DoubleStruckCapitalJ] + 
                      c\^3\ \[DoubleStruckCapitalJ]\^2\)\)\), 
            r \[Rule] \(-\(\(\(-b\^2\) + a\ c\)\/\(a\^3 + 
                      b\^3\ \[DoubleStruckCapitalJ] - 
                      3\ a\ b\ c\ \[DoubleStruckCapitalJ] + 
                      c\^3\ \[DoubleStruckCapitalJ]\^2\)\)\)}}\), 
        ",", "\<\"\\nThe denominator does not factorize. It is NOT the \
determinant, which is\"\>", 
        ",", \(c\^3 + b\^3\ \[DoubleStruckCapitalJ] - 
          3\ a\ b\ c\ \[DoubleStruckCapitalJ] + 
          a\^3\ \[DoubleStruckCapitalJ]\^2\)}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The database also contains eleven 4\[Times]4 signed tables. Example 32 \
calculates the inverses for four of them:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell["Example 32. Some 4-element algebra inverses.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{\"Qr =\",tst=cd[{-1,-1}];tst//tf,id[tst];\"Qr solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} \
is\",Solve[hoopTimes[{p,q,r,s},{a,b,c,d}]=={1,0,0,0},{p,q,r,s}],\"\\nThe \
determinant is the denominator squared 
(a^2+b^2+c^2+d^2)^2\",

\"\\n\\nDav =\",tst=cd[{-1,-1.}];tst//tf,id[tst];\"\\nDavenport Algebra \
solution to {p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} \
is\",ss=Solve[hoopTimes[{p,q,r,s},{a,b,c,d}]=={1,0,0,0},{p,q,r,s}];d0=Factor[\
ss[[1,1,2,3,1]]][[1]];d1=frag[d0];e0=  \
Factor[ss[[1,1,2,3,1]]][[2]];e1=frag[e0];{p->Apart[ss[[1,1,2]]],\"\\n\",q->\
Apart[ss[[1,2,2]]],\"\\n\",r->Apart[ss[[1,3,2]]],\"\\n\",s->Apart[ss[[1,4,2]]]\
}/.{d0\[Rule]d1,e0\[Rule]e1},\"\\nThe denominator is the determinant, with \
factors\", {d1,e1},

\"\\n\\nP4 =\",tst=P4;tst//tf,id[tst];\"\\nP4 solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} \
is\",Solve[hoopTimes[{p,q,r,s},{a,b,c,d}]=={1,0,0,0},{p,q,r,s}],
\"\\nThe determinant is the denominator squared \
\",Factor[Det[gmap[tst,alph]]],

\"\\n\\nCL2 =\",
tst=cd[{1,-1}];tst//tf,id[tst];\"\\nClifford(2) solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} \
is\",Solve[hoopTimes[{p,q,r,s},{a,b,c,d}]=={1,0,0,0},{p,q,r,s}],
\"\\nThe negated determinant is the denominator squared \
\",-Factor[Det[gmap[tst,alph]]]}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Qr =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", \(-1\), "4", \(-3\)},
                  {"3", \(-4\), \(-1\), "2"},
                  {"4", "3", \(-2\), \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"Qr solution to {p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} \
is\"\>", ",", \({{p \[Rule] a\/\(a\^2 + b\^2 + c\^2 + d\^2\), 
            q \[Rule] \(-\(b\/\(a\^2 + b\^2 + c\^2 + d\^2\)\)\), 
            r \[Rule] \(-\(c\/\(a\^2 + b\^2 + c\^2 + d\^2\)\)\), 
            s \[Rule] \(-\(d\/\(a\^2 + b\^2 + c\^2 + d\^2\)\)\)}}\), 
        ",", "\<\"\\nThe determinant is the denominator squared  \
(a^2+b^2+c^2+d^2)^2\"\>", ",", "\<\"\\n\\nDav =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", \(-1\), "4", \(-3\)},
                  {"3", "4", \(-1\), \(-2\)},
                  {"4", \(-3\), \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nDavenport Algebra solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} is\"\>", 
        ",", \({p \[Rule] {}, "\n", q \[Rule] {}, "\n", r \[Rule] {}, "\n", 
          s \[Rule] {}}\), 
        ",", "\<\"\\nThe denominator is the determinant, with factors\"\>", 
        ",", \({{}, {}}\), ",", "\<\"\\n\\nP4 =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", 
                    "1", \(\(-4\)\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\)},
                  {"3", \(4\ \[ImaginaryI]\), 
                    "1", \(\(-2\)\ \[ImaginaryI]\)},
                  {"4", \(\(-3\)\ \[ImaginaryI]\), \(2\ \[ImaginaryI]\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nP4 solution to {p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} is\
\"\>", ",", \({{p \[Rule] a\/\(a\^2 - b\^2 - c\^2 - d\^2\), 
            q \[Rule] b\/\(\(-a\^2\) + b\^2 + c\^2 + d\^2\), 
            r \[Rule] \(-\(c\/\(a\^2 - b\^2 - c\^2 - d\^2\)\)\), 
            s \[Rule] \(-\(d\/\(a\^2 - b\^2 - c\^2 - d\^2\)\)\)}}\), 
        ",", "\<\"\\nThe determinant is the denominator squared \"\>", 
        ",", \(\((a\^2 - b\^2 - c\^2 - d\^2)\)\^2\), 
        ",", "\<\"\\n\\nCL2 =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "1", "4", "3"},
                  {"3", \(-4\), \(-1\), "2"},
                  {"4", \(-3\), \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nClifford(2) solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} is\"\>", 
        ",", \({{p \[Rule] a\/\(a\^2 - b\^2 + c\^2 - d\^2\), 
            q \[Rule] \(-\(b\/\(a\^2 - b\^2 + c\^2 - d\^2\)\)\), 
            r \[Rule] \(-\(c\/\(a\^2 - b\^2 + c\^2 - d\^2\)\)\), 
            s \[Rule] \(-\(d\/\(a\^2 - b\^2 + c\^2 - d\^2\)\)\)}}\), 
        ",", "\<\"\\nThe negated determinant is the denominator squared \"\>",
         ",", \(\((a\^2 - b\^2 + c\^2 - d\^2)\)\^2\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe denominators are the \"plex-conjugates\" (Section 7) of the \
determinants; in many cases the only signs in an expression are \"+\" and \"-\
\" and the conjugate is identical to the determinant. Many inverses were \
found empirically. They led me to believe (until September 2003) that the \
determinant (or its repeated factor) was the denominator. The more general \
conjugate relationship was discovered after finding the inverses for ",
  StyleBox["C9J & C3C3J",
    FontSlant->"Italic"],
  " by the above technique."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe ",
  StyleBox["hoopInverse",
    FontSlant->"Italic"],
  " procedure calculates the inverse for vecs in any conservatve algebra, \
provided that the sizes are known or can be calculated. The individual \
partial-fractions are \"derivates\" (polynomials identical to the derivative \
but defined without recourse to infinitesimals) of the denominators, derived \
with respect to the variables taken in an order corresponding to the position \
of the (possibly signed) unit in the multiplication table. This is a \
consequence of Cramer's method. As another consequence, repeated factors \
appear as multiples of the single-factor term, rather than in the general \
partial-fraction with several terms appearing with different powers in the \
denominators. The database contains the ",
  StyleBox["shape",
    FontSlant->"Italic"],
  " of many protoloop tables, as symbolic denominators or their factors; the \
lists ",
  StyleBox["gi & gp",
    FontSlant->"Italic"],
  " are also included. ",
  StyleBox["gp",
    FontSlant->"Italic"],
  " is related to polar duals and is described in Section 9.1; ",
  StyleBox["gi",
    FontSlant->"Italic"],
  " is the above-mentioned location of the variables, multiplied by any sign \
needed by the corresponding partial fraction; ",
  StyleBox["gi",
    FontSlant->"Italic"],
  " also includes the multiplicity of each size, needed by ",
  StyleBox["hoopInverse",
    FontSlant->"Italic"],
  ". Where known, ",
  StyleBox["plex",
    FontSlant->"Italic"],
  " is also set by ",
  StyleBox["sh",
    FontSlant->"Italic"],
  ". Multiplying a vector by its plex gives a quadratic size; each plex is an \
involution.\n\tThe relationship between division and derivates implies a \
relationship with differentiation. This needs to be explored.",
  StyleBox["\n\thoopInverse",
    FontSlant->"Italic"],
  " builds up the inverse for the symbolic protoloop (i.e. with elements \
{a,b,..}), and finally replaces the standard symbols by the coefficients of \
the argument. (The next section discusses the inverse when a size becomes \
zero.) Example 33 uses ",
  StyleBox["hoopInverse",
    FontSlant->"Italic"],
  " to calculate symbolic inverses for several tables, and confirms their \
correctness by showing that Ai\[CenterDot]A={1,0...}. (This has already been \
checked in Test 8 , Section 1.4. of ",
  StyleBox["GroupLoopTest.nb",
    FontSlant->"Italic"],
  ")"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 33. ",
  StyleBox["hoopIn",
    FontSlant->"Italic"],
  StyleBox["verse",
    FontSlant->"Italic"],
  " for some small hoops. "
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\({glo = C3; id[glo], "\< Inverse =\>", 
      tst = hoopInverse[{a, b, c}], "\<\nconfirmation\>", 
      Simplify[hoopTimes[
          tst, {a, b, c}]], \[IndentingNewLine]\[IndentingNewLine]"\<\n\n\>", 
      glo = cd[{3}]; id[glo], "\< Inverse =\>", 
      tst = hoopInverse[{a, b, c}], "\<\nconfirmation Ainv.A =\>", 
      Simplify[hoopTimes[
          tst, {a, b, c}]], \[IndentingNewLine]\[IndentingNewLine]"\<\n\n\>", 
      glo = C4C3c; id[glo], "\< Inverse =\>", 
      tst = hoopInverse[{a, b, c}], "\<\nconfirmation Ainv.A =\>", 
      Simplify[hoopTimes[
          tst, {a, b, c}]], \[IndentingNewLine]\[IndentingNewLine]"\<\n\n\>", 
      glo = C9J; id[glo], "\< Inverse =\>", 
      tst = hoopInverse[{a, b, c}], "\<\nconfirmation Ainv.A =\>", 
      Simplify[hoopTimes[
            tst, {a, b, c}]] /. \[DoubleStruckCapitalJ]\^3 \[Rule] 
          1, \[IndentingNewLine]\[IndentingNewLine]"\<\n\n\>", glo = C4; 
      id[glo], "\< Inverse =\>", 
      tst = hoopInverse[{a, b, c, d}], "\<\nconfirmation Ainv.A =\>", 
      Simplify[hoopTimes[
          tst, {a, b, c, 
            d}]], \[IndentingNewLine]\[IndentingNewLine]"\<\n\n\>", 
      glo = cd[{1, \(-1\)}]; id[glo], "\< Inverse =\>", 
      tst = hoopInverse[{a, b, c, d}], "\<\nconfirmation Ainv.A =\>", 
      Simplify[hoopTimes[tst, {a, b, c, d}]]}\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"C3", 
      " Inverse =", {\(a\^2 - b\ c\)\/\(a\^3 + b\^3 - 3\ a\ b\ c + c\^3\), \(\
\(-a\)\ b + c\^2\)\/\(a\^3 + b\^3 - 3\ a\ b\ c + c\^3\), \(b\^2 - a\ c\)\/\(a\
\^3 + b\^3 - 3\ a\ b\ c + c\^3\)}, "\nconfirmation", {1, 0, 0}, "\n\n", "C3", 
      " Inverse =", {\(a\^2 - b\ c\)\/\(a\^3 + b\^3 - 3\ a\ b\ c + c\^3\), \(\
\(-a\)\ b + c\^2\)\/\(a\^3 + b\^3 - 3\ a\ b\ c + c\^3\), \(b\^2 - a\ c\)\/\(a\
\^3 + b\^3 - 3\ a\ b\ c + c\^3\)}, "\nconfirmation Ainv.A =", {1, 0, 0}, 
      "\n\n", "C4C3c", 
      " Inverse =", {\(a\^2 + b\ c\)\/\(a\^3 + 3\ a\ b\ c - \[ImaginaryI]\ \
\((b\^3 + c\^3)\)\), \(\(-a\)\ b + \[ImaginaryI]\ c\^2\)\/\(a\^3 + 3\ a\ b\ c \
- \[ImaginaryI]\ \((b\^3 + c\^3)\)\), \(\[ImaginaryI]\ b\^2 - a\ c\)\/\(a\^3 \
+ 3\ a\ b\ c - \[ImaginaryI]\ \((b\^3 + c\^3)\)\)}, 
      "\nconfirmation Ainv.A =", {1, 0, 0}, "\n\n", "C9J", 
      " Inverse =", {\(a\^2 - b\ c\ \[DoubleStruckCapitalJ]\)\/\(a\^3 - 3\ a\ \
b\ c\ \[DoubleStruckCapitalJ] + \[DoubleStruckCapitalJ]\ \((b\^3 + c\^3\ \
\[DoubleStruckCapitalJ])\)\), \(\[DoubleStruckCapitalJ]\^3\ \((\(-a\)\ b + \
c\^2\ \[DoubleStruckCapitalJ])\)\)\/\(a\^3 - 3\ a\ b\ c\ \
\[DoubleStruckCapitalJ] + \[DoubleStruckCapitalJ]\ \((b\^3 + c\^3\ \
\[DoubleStruckCapitalJ])\)\), \(\((b\^2 - a\ c)\)\ \[DoubleStruckCapitalJ]\^3\
\)\/\(a\^3 - 3\ a\ b\ c\ \[DoubleStruckCapitalJ] + \[DoubleStruckCapitalJ]\ \
\((b\^3 + c\^3\ \[DoubleStruckCapitalJ])\)\)}, 
      "\nconfirmation Ainv.A =", {\(a\^3 - 3\ a\ b\ c\ \
\[DoubleStruckCapitalJ] + \[DoubleStruckCapitalJ]\^4\ \((b\^3 + c\^3\ \
\[DoubleStruckCapitalJ])\)\)\/\(a\^3 - 3\ a\ b\ c\ \[DoubleStruckCapitalJ] + \
\[DoubleStruckCapitalJ]\ \((b\^3 + c\^3\ \[DoubleStruckCapitalJ])\)\), 0, 0}, 
      "\n\n", "C4", 
      " Inverse =", {1\/4\ \((\(2\ \((a - c)\)\)\/\(\((a - c)\)\^2 + \((b - \
d)\)\^2\) + 1\/\(a - b + c - d\) + 1\/\(a + b + c + d\))\), 
        1\/4\ \((\(-\(\(2\ \((b - 
                          d)\)\)\/\(\((a - c)\)\^2 + \((b - d)\)\^2\)\)\) + 
              1\/\(\(-a\) + b - c + d\) + 1\/\(a + b + c + d\))\), 
        1\/4\ \((\(-\(\(2\ \((a - 
                          c)\)\)\/\(\((a - c)\)\^2 + \((b - d)\)\^2\)\)\) + 
              1\/\(a - b + c - d\) + 1\/\(a + b + c + d\))\), 
        1\/4\ \((\(2\ \((b - d)\)\)\/\(\((a - c)\)\^2 + \((b - d)\)\^2\) + 
              1\/\(\(-a\) + b - c + d\) + 1\/\(a + b + c + d\))\)}, 
      "\nconfirmation Ainv.A =", {1, 0, 0, 0}, "\n\n", "CL2", 
      " Inverse =", {a\/\(a\^2 - b\^2 + c\^2 - d\^2\), 
        b\/\(\(-a\^2\) + b\^2 - c\^2 + d\^2\), 
        c\/\(\(-a\^2\) + b\^2 - c\^2 + d\^2\), 
        d\/\(\(-a\^2\) + b\^2 - c\^2 + d\^2\)}, 
      "\nconfirmation Ainv.A =", {1, 0, 0, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6.4. Zero sizes, \"",
  StyleBox["Renormalizing",
    FontSlant->"Italic"],
  "\" Partial-Fraction Division, \"",
  StyleBox["remainders\"",
    FontSlant->"Italic"],
  " ."
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tIf a vec has one or more size that is zero, size conservation means that \
the same size(s) of any product will also be zero. The result is \
\"projected\" onto a sub-algebra in which this size is constrained to be \
zero. This can create \"annihilators\" (vecs with all shapes zero). Example \
34 sets up three vecs, each having one of the D3 sizes equal to zero. Their \
product is an annihilator - a vector with all sizes zero - in the D3 algebra.\
\
\>", "Text",
  PageWidth->WindowWidth],

Cell["Example 34. D3 vecs with Zero Sizes, Annihilators.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(id[D3]; {"\<z0      =\>", 
      z0 = {1, 0, \(-2\), \(-4\), \(-2\), 1}, "\<\n z1      =\>", 
      z1 = {1, 3, 2, \(-4\), \(-2\), 0}, "\<\n z2      =\>", 
      z2 = {0, \(-5\), \(-1\), \(-4\), \(-2\), \(-6\)}, "\<\nz0 z1    =\>", 
      z01 = hoopTimes[z0, z1], "\<\nz0 z1 z2 =\>", 
      zz = hoopTimes[z2, z01], "\<\nz0 shape      =\>", 
      shape[z0], "\<\nz1 shape      =\>", shape[z1], "\<\nz0z1 shape    =\>", 
      shape[z01], "\<\nz2 shape      =\>", 
      shape[z2], "\<\nz0 z1 z2 shape=\>", shape[zz]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"z0      =", {1, 0, \(-2\), \(-4\), \(-2\), 1}, 
      "\n z1      =", {1, 3, 2, \(-4\), \(-2\), 0}, 
      "\n z2      =", {0, \(-5\), \(-1\), \(-4\), \(-2\), \(-6\)}, 
      "\nz0 z1    =", {17, 1, \(-12\), \(-12\), \(-5\), 11}, 
      "\nz0 z1 z2 =", {6, 6, 6, 6, \(-12\), \(-12\)}, 
      "\nz0 shape      =", {\(-6\), 0, \(-12\)}, 
      "\nz1 shape      =", {0, 2, \(-24\)}, "\nz0z1 shape    =", {0, 0, 288}, 
      "\nz2 shape      =", {\(-18\), 12, 0}, 
      "\nz0 z1 z2 shape=", {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tAny vec ",
  StyleBox["A0",
    FontSlant->"Italic"],
  " with one or more zero size is a member of a constrained sub-algebra (of \
reduced symmetry) in which these sizes are constrained to be zero. The result \
of multiplying a general vec by such a vec must be in this sub-algebra, for \
the zero sizes are conserved. Multiplication \"projects\" vecs into the \
sub-algebra. To make the algebra conservative, the sizes that would be lost \
are \"ejected\" into \"remainders\". This is analogous to integer division of \
I by J, where I/J gives a quotient Q and a remainder (smaller than J) of R, \
so that I = Q*J + R. By analogy, hoop division A/B gives a quotient Q and (if \
necessary) two remainders Rl & Rr (whose sizes are the zeroes of the left and \
right arguments respectively), with A=Q*B+Rl, B=Q*A+Rr. As division is \
multiplication by an inverse (e.g. B=1/C), multiplication gives a product P \
but also generates left & right remainders; A*B = P+Rl+Rr, with P/A+Rl = B, \
P/B+Rr = A. This is implemented in ",
  StyleBox["hoopT",
    FontSlant->"Italic"],
  "i",
  StyleBox["mes",
    FontSlant->"Italic"],
  " wherever the multiplicands have different sizes that are zero to within \
an arbitrarily small number ",
  StyleBox["hmin",
    FontSlant->"Italic"],
  ". This requires that the inverse calculated by ",
  StyleBox["hoopInverse[B]",
    FontSlant->"Italic"],
  " is given a zero size wherever B has near-zero size. Note the analogy with \
\"q-deformed\" algebras.",
  StyleBox[" ",
    FontSlant->"Italic"],
  "In effect, the multiplicands are reduced to vecs with compatible sizes \
before multiplication, by ejecting the remainders. Of course, in many cases \
the shapes are compatible and both the remainders are zero vectors. \n\t\
Example 35 sets up two vecs that have different zero-sizes in the C4 algebra, \
multiplies them, shows that the remainders have the correct sizes, and shows \
that dividing AB by B0 does not give A until the remainder has been added."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(id[C4]\), ";", 
      RowBox[{"Chop", "[", 
        RowBox[{"{", 
          RowBox[{
          "\"\<Example 35. C4 multiplication with remainders\>\"", ",", 
            "\"\<\\n         A0 = \>\"", ",", \(A0 = {2, 1, 2, 1}\), ",", 
            "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)A0 = \>\"", 
            ",", \(sA0 = shape[A0, "\<C4\>"]\), ",", "\[IndentingNewLine]", 
            "\"\<\\n         B0 = \>\"", ",", \(B0 = {3, \(-1\), 2, \(-4\)}\),
             ",", "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) B0 = \>\"", ",", \(shape[B0]\), 
            ",", "\[IndentingNewLine]", "\"\<\\n         AB = \>\"", 
            ",", \(AB = hoopTimes[A0, B0]\), ",", "\[IndentingNewLine]", 
            "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) AB = \>\"", ",", \(shape[AB]\), 
            ",", "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Note\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"that\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"two\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"sizes\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"have\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"become\",\nFontSlant->\"Italic\"]\) 0\>\"", ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Remainder\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Rl\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(RA = Rl\), ",", 
            "\"\<\\n\!\(\*
StyleBox[\"has\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\) \>\"", ",", \(shape[Rl]\), ",", 
            "\"\<\\n\!\(\*
StyleBox[\"remainder\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Rr\",\nFontSlant->\"Italic\"]\)\>\"", ",", "Rr", ",", 
            "\"\<\\n\!\(\*
StyleBox[\"has\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\>\"", ",", \(shape[Rr]\), ",", 
            "\"\<\\nAB/B0      =\>\"", 
            ",", \(AoB = hoopTimes[AB, hoopInverse[B0]]\), ",", 
            "\"\<\\nAdding Rl gives A0\>\"", ",", \(AoB + RA\)}], 
          StyleBox["}",
            FontSlant->"Italic"]}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier New",
  FontSize->10],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 35. C4 multiplication with remainders\"\>", 
        ",", "\<\"\\n         A0 = \"\>", ",", \({2, 1, 2, 1}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)A0 = \"\>", ",", \({6, 2, 0}\), 
        ",", "\<\"\\n         B0 = \"\>", ",", \({3, \(-1\), 2, \(-4\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) B0 = \"\>", 
        ",", \({0, 10, 10}\), ",", "\<\"\\n         AB = \"\>", 
        ",", \({5, \(-5\), 5, \(-5\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) AB = \"\>", 
        ",", \({0, 20, 0}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"Note\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"that\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"two\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"sizes\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"have\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"become\\\",\\nFontSlant->\\\"Italic\\\"]\\) 0\"\>", 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Remainder\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Rl\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({3\/2, 3\/2, 3\/2, 3\/2}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({6, 0, 0}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"remainder\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Rr\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({1\/2, 3\/2, \(-\(1\/2\)\), \(-\(3\/2\)\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", \({0, 0, 10}\),
         ",", "\<\"\\nAB/B0      =\"\>", 
        ",", \({1\/2, \(-\(1\/2\)\), 1\/2, \(-\(1\/2\)\)}\), 
        ",", "\<\"\\nAdding Rl gives A0\"\>", ",", \({2, 1, 2, 1}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tDivision is multiplication by the multiplicative inverse, found by ",
  StyleBox["hoopInverse",
    FontSlant->"Italic"],
  ". This is therefore formulated so that the inverse ",
  StyleBox["A0inv",
    FontSlant->"Italic"],
  " has the same zeroes as ",
  StyleBox["A0",
    FontSlant->"Italic"],
  ", rather than these sizes being infinite. If any of the numerator sizes \
approach zero (to within an arbitrary ",
  StyleBox["hmin",
    FontSlant->"Italic"],
  "), the calculation proceeds in the sub-algebra in which these factors are \
constrained to be zero. The result is projected",
  StyleBox[" ",
    FontSlant->"Italic"],
  "into the sub-algebra, and the infinite terms have been \"factored out\" or \
\"renormalized\". Conic sections provide an analogy - constraining a distance \
from some plane reduces the 3D symmetry of the bicone to one of several 2d \
symmetries. ",
  StyleBox["hoopInverse",
    FontSlant->"Italic"],
  " is a unary operation and the remainders do not exist until division \
(multiplication by the inverse) occurs. Thus remainders are the result of the \
binary operation of hoop multiplication. (Discovered 19th Dec. 2004.)"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tVecs can be projected onto a sub-space by pre-multiplying by a vec such \
as ",
  StyleBox["A0",
    FontSlant->"Italic"],
  " and then post-multiplying by its inverse. This is demonstrated in Example \
36, using the C4 algebra (complex coefficients are used to show that the \
algebra is effective over the complex field); ",
  StyleBox["A0",
    FontSlant->"Italic"],
  " is chosen to have the second size zero. The size of the remainder is the \
second size of the original vec:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 36. ",
  StyleBox["C4 Division with Zero Sizes; Projection, Remainders.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(id[C4]\), ";", 
      RowBox[{"Chop", "[", 
        RowBox[{"{", 
          RowBox[{
          "\"\<        A0=  \>\"", 
            ",", \(A0 = {1, 4, 5.  + \[ImaginaryI], 2 + \[ImaginaryI]}\), 
            ",", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)A0 = \>\"", 
            ",", \(sA0 = shape[A0, "\<C4\>"]\), ",", "\"\<\\nA0i\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Inverse\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) A0, =\>\"", 
            ",", \(A0i = hoopInverse[A0]\), ",", "\[IndentingNewLine]", 
            "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) A0i =\>\"", ",", \(shape[A0i]\), 
            ",", "\[IndentingNewLine]", "\"\<\\n         B=   \>\"", 
            ",", \(B = {1.  + 4  \[ImaginaryI], \(-2\), \(-4\), \(-4\) - 
                  3  \[ImaginaryI]}\), ",", "\[IndentingNewLine]", 
            "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) B   =\>\"", ",", \(shape[B]\), ",",
             "\[IndentingNewLine]", "\"\<\\n      BA0i=   \>\"", 
            ",", \(BA0i = hoopTimes[A0i, B, "\<C4\>"]\), ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) BA0i \>\"", ",", \(shape[BA0i]\), 
            ",", "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Note\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"that\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"nd\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"size\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"has\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"become\",\nFontSlant->\"Italic\"]\) 0   \[UpArrow]\>\"", ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Multiplying\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"by\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A0\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"projection\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)B\>\"", 
            ",", \(A0BA0i = hoopTimes\ [A0, BA0i, "\<C4\>"]\), ",", 
            "\"\<\\n\!\(\*
StyleBox[\"with\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\) \>\"", ",", \(shape[A0BA0i]\), ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"with\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"1\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"st\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"&\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"rd\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"sizes\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"matching\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)B,\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"&\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"nd\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"size\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"zero\",\nFontSlant->\"Italic\"]\).\>\"", ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Premultiplying\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)B \!\(\*
StyleBox[\"by\",\nFontSlant->\"Italic\"]\) A0\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)A0B\>\"", 
            ",", \(A0B = hoopTimes[A0, B, "\<C4\>"]\), ",", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) A0B =\>\"", 
            ",", \(shape[A0B = hoopTimes[A0, B, "\<C4\>"]]\), ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Multiply\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"by\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A0i\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"same\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"projection\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) B\>\"", 
            ",", \(B0 = hoopTimes[A0i, A0B, "\<C4\>"]\), ",", "\"\<\\n\!\(\*
StyleBox[\"The\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"difference\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"between\",\nFontSlant->\"Italic\"]\) B & A0BA0i \!\(\*
StyleBox[\"is\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"remainder\",\nFontSlant->\"Italic\"]\) Rr\>\"", 
            ",", \(Rr = B - A0BA0i\), ",", "\"\<\\n\!\(\*
StyleBox[\"with\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"sizes\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(shape[Rr]\), ",", 
            "\"\< \!\(\*
StyleBox[\"i\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"e\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",\nFontSlant->\"Italic\"]\) \!\(\*
StyleBox[\"the\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"second\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"size\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)  B.\>\""}], 
          StyleBox["}",
            FontSlant->"Italic"]}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier New",
  FontSize->10],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"        A0=  \"\>", 
        ",", \({1, 4, \(\(5.`\)\(\[InvisibleSpace]\)\) + \[ImaginaryI], 
          2 + \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)A0 = \"\>", 
        ",", \({\(\(12.`\)\(\[InvisibleSpace]\)\) + 2\ \[ImaginaryI], 
          0, \(\(18.`\)\(\[InvisibleSpace]\)\) + 4.`\ \[ImaginaryI]}\), 
        ",", "\<\"\\nA0i\\!\\(\\* StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Inverse\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) A0, =\"\>", 
        ",", \({\(-0.09149443561208266`\) - 
            0.006319554848966614`\ \[ImaginaryI], \(-0.026788553259141493`\) \
+ 0.03485691573926868`\ \[ImaginaryI], \(\(0.13203497615262322`\)\(\
\[InvisibleSpace]\)\) - 
            0.0004372019077901433`\ \[ImaginaryI], \(\(0.06732909379968204`\)\
\(\[InvisibleSpace]\)\) - 0.04161367249602544`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) A0i =\"\>", 
        ",", \({\(\(0.0810810810810811`\)\(\[InvisibleSpace]\)\) - 
            0.013513513513513514`\ \[ImaginaryI], 
          0, \(\(0.05294117647058823`\)\(\[InvisibleSpace]\)\) - 
            0.011764705882352941`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n         B=   \"\>", 
        ",", \({\(\(1.`\)\(\[InvisibleSpace]\)\) + 
            4\ \[ImaginaryI], \(-2\), \(-4\), \(-4\) - 3\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) B   =\"\>", 
        ",", \({\(-9.`\) + \[ImaginaryI], \(\(3.`\)\(\[InvisibleSpace]\)\) + 
            7\ \[ImaginaryI], \(\(4.`\)\(\[InvisibleSpace]\)\) + 
            52.`\ \[ImaginaryI]}\), ",", "\<\"\\n      BA0i=   \"\>", 
        ",", \({\(-0.5172893481717011`\) - 
            0.3463831478537361`\ \[ImaginaryI], \(-0.7819952305246423`\) - 
            0.2875596184419713`\ \[ImaginaryI], \(\(0.15918124006359302`\)\(\
\[InvisibleSpace]\)\) + 
            0.44773449920508746`\ \[ImaginaryI], \(\(0.42388712241653415`\)\(\
\[InvisibleSpace]\)\) + 0.38891096979332274`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) BA0i \"\>", 
        ",", \({\(-0.7162162162162162`\) + 
            0.20270270270270285`\ \[ImaginaryI], 
          0, \(\(0.8235294117647058`\)\(\[InvisibleSpace]\)\) + 
            2.7058823529411766`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"Note\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"that\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"2\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"nd\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"size\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"become\\\",\\nFontSlant->\\\"Italic\\\"]\\) 0   \[UpArrow]\"\>", 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Multiplying\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"by\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A0\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"a\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"projection\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)B\"\>", 
        ",", \({\(\(0.25`\)\(\[InvisibleSpace]\)\) + 
            2.25`\ \[ImaginaryI], \(-1.25`\) + 
            1.7500000000000002`\ \[ImaginaryI], \(-4.749999999999999`\) - 
            1.7499999999999996`\ \[ImaginaryI], \(-3.25`\) - 
            1.2499999999999996`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({\(-9.`\) + 1.0000000000000009`\ \[ImaginaryI], 
          0, \(\(3.9999999999999947`\)\(\[InvisibleSpace]\)\) + 
            51.999999999999986`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"1\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"st\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"&\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"rd\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"sizes\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"matching\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)B,\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"&\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"2\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"nd\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"size\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"zero\\\",\\nFontSlant->\\\"Italic\\\"]\\).\"\>", 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"Premultiplying\\\",\\nFontSlant->\
\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)B \\!\\(\\* \
StyleBox[\\\"by\\\",\\nFontSlant->\\\"Italic\\\"]\\) A0\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)A0B\"\>", 
        ",", \({\(-39.`\) - 14\ \[ImaginaryI], \(-23.`\) - 
            7.`\ \[ImaginaryI], \(-16.`\) + 11.`\ \[ImaginaryI], \(-32.`\) + 
            4.`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) A0B =\"\>", 
        ",", \({\(-110.`\) - 6.`\ \[ImaginaryI], 
          0, \(-136.`\) + 952.`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Multiply\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"by\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A0i\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"the\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"same\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"projection\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) B\"\>", 
        ",", \({\(\(0.2499999999999991`\)\(\[InvisibleSpace]\)\) + 
            2.25`\ \[ImaginaryI], \(-1.2500000000000009`\) + 
            1.75`\ \[ImaginaryI], \(-4.750000000000001`\) - 
            1.75`\ \[ImaginaryI], \(-3.2500000000000004`\) - 
            1.25`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"The\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"difference\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"between\\\",\\nFontSlant->\\\"Italic\\\"]\\) B & A0BA0i \
\\!\\(\\* StyleBox[\\\"is\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"the\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"remainder\\\",\\nFontSlant->\\\"Italic\\\"]\\) Rr\"\>", 
        ",", \({\(\(0.75`\)\(\[InvisibleSpace]\)\) + 
            1.75`\ \[ImaginaryI], \(-0.75`\) - 
            1.7500000000000002`\ \[ImaginaryI], \(\(0.7499999999999991`\)\(\
\[InvisibleSpace]\)\) + 1.7499999999999996`\ \[ImaginaryI], \(-0.75`\) - 
            1.7500000000000004`\ \[ImaginaryI]}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"sizes\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({0, \(\(2.999999999999999`\)\(\[InvisibleSpace]\)\) + 
            7.`\ \[ImaginaryI], 0}\), 
        ",", "\<\" \\!\\(\\* StyleBox[\\\"i\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\* StyleBox[\\\".\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"e\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\".\\\
\",\\nFontSlant->\\\"Italic\\\"]\\) \\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"second\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"size\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)  B.\"\>"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThus renormalizing multiplication/division is conservative if it is \
interpreted as projecting the result into the constrained sub-algebra whilst \
splitting off (ejecting) remainders that contains the lost sizes. Conjecture \
- this may be related to fundamental particle interactions and decay, where \
particles with different symmetries occur, but the symmetries may be \
conserved by the creation of more than one particle.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.5. Degenerate monosized algebras.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tCollapsing loops to hoops makes many sizes zero; some signed table hoops \
have only one (often repeated) size and so cannot exhibit renormalisation. In \
this respect, they are degenerate hoops. Those in the database are shown in \
Example 37. They include C4c=\[DoubleStruckCapitalC]; Qr=quaternion algebra, \
\[DoubleStruckCapitalH]; the octonion algebra Octi, Octc=Octonions \
\[DoubleStruckCapitalO]; Octi=split-Octonions, P4=Pauli-\[Sigma]; \
Cliffords(2), (3), (0,4), (1,3), (2,2), (3,1), (4) (but not C8r, \
Clifford(2,1), Clifford(0,3), shown in Example 37a). In the example, some \
factors are found by ",
  StyleBox["fa[mp[mnemonic]]",
    FontSlant->"Italic"],
  ", which factorizes the determinant after mapping members of the alphabet \
onto the index table. Others are given by the same mapping onto the known \
shape, whilst the 16-membered Cliffords are mapped with {a,3,7,1,2,.. ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  "...",
  Cell[BoxData[
      \(TraditionalForm\`2\^12\)]],
  "} (truncated as appropriate) to provide compact output. Three other hoops, \
with two distinct factors, are shown in Example 37a."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 37. ",
  StyleBox["Some degenerate hoops. ",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{\( (*Ex . \ 37\ Single - Factor\ Hoops*) \), 
        "\[IndentingNewLine]", 
        RowBox[{\(a8 = Take[alpha, 8]\), ";", 
          RowBox[{"{", 
            RowBox[{"\"\<\[DoubleStruckCapitalC]   \!\(\*
StyleBox[\"Factor\",\nFontSlant->\"Italic\"]\) \>\"", 
              ",", \(-fa[mp["\<C4c\>"]]\), ",", "\"\<\\nC9J  \!\(\*
StyleBox[\"Factor\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\>\"", 
              ",", \(\(sh["\<C9J\>"]\)[\([1]\)]\), ",", "\"\<\\nQr   \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", 
              ",", \(fa[mp["\<Qr\>"]]\), ",", "\"\<\\nOctr \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", 
              ",", \(fa[mp["\<Octr\>"]]\), ",", "\"\<\\nOcti \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", 
              ",", \(fa[cd[{1, \(-1\), \(-1\)}]]\), ",", "\"\<\\nP4   \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", 
              ",", \(fa[mp["\<P4\>"]]\), ",", "\"\<\\nCL2  \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(fa[cl[2]]\), 
              ",", "\"\<\\nCL3  \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", 
              ",", \(\((shape[a8, "\<CL3\>"])\)^2\), ",", "\"\<\\nCL04 \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(fp[cl[0, 4]]\), 
              ",", "\"\<\\nCL13 \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(fp[cl[1, 3]]\), 
              ",", "\"\<\\nCL22 \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(fp[cl[2, 2]]\), 
              ",", "\"\<\\nCL31 \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(fp[cl[3, 1]]\), 
              ",", "\"\<\\nCL4  \!\(\*
StyleBox[\"Factors\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(fp[cl[4]]\)}], 
            "}"}]}]}], TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier New"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"\[DoubleStruckCapitalC]   \\!\\(\\* \
StyleBox[\\\"Factor\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \(a\^2 + b\^2\), 
        ",", "\<\"\\nC9J  \\!\\(\\* \
StyleBox[\\\"Factor\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \(a\^3 + b\^3\ \[DoubleStruckCapitalJ] - 
          3\ a\ b\ c\ \[DoubleStruckCapitalJ] + 
          c\^3\ \[DoubleStruckCapitalJ]\^2\), 
        ",", "\<\"\\nQr   \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", ",", \(\((a\^2 + b\^2 + c\^2 + d\^2)\)\^2\), 
        ",", "\<\"\\nOctr \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", 
        ",", \(\((a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + 
                h\^2)\)\^4\), 
        ",", "\<\"\\nOcti \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", 
        ",", \(\((a\^2 - b\^2 + c\^2 - d\^2 + e\^2 - f\^2 + g\^2 - 
                h\^2)\)\^4\), 
        ",", "\<\"\\nP4   \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", ",", \(\((a\^2 - b\^2 - c\^2 - d\^2)\)\^2\), 
        ",", "\<\"\\nCL2  \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", ",", \(\((a\^2 - b\^2 - c\^2 + d\^2)\)\^2\), 
        ",", "\<\"\\nCL3  \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", 
        ",", \({\((4\ \((\(-"d"\)\ "e" + "c"\ "f" - "b"\ "g" + "a"\ "h")\)\^2 \
+ \(("a"\^2 - "b"\^2 - "c"\^2 + "d"\^2 - "e"\^2 + "f"\^2 + "g"\^2 - "h"\^2)\)\
\^2)\)\^2}\), 
        ",", "\<\"\\nCL04 \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", 
        ",", \(\((128102388808777273 + 1413496832\ a - 697668950\ a\^2 + 
                a\^4)\)\^4\), 
        ",", "\<\"\\nCL13 \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", 
        ",", \(\((128094571362680377 - 1413464064\ a + 697658026\ a\^2 + 
                a\^4)\)\^4\), 
        ",", "\<\"\\nCL22 \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", 
        ",", \(\((126108638031095097 + 1405075456\ a - 694839894\ a\^2 + 
                a\^4)\)\^4\), 
        ",", "\<\"\\nCL31 \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", 
        ",", \(\((98181466481244393 - 1270857728\ a + 644179290\ a\^2 + 
                a\^4)\)\^4\), 
        ",", "\<\"\\nCL4  \\!\\(\\* StyleBox[\\\"Factors\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\"\>", 
        ",", \(\((35345327484971257 + 733986816\ a - 357979754\ a\^2 + 
                a\^4)\)\^4\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Example 37a.",
    FontWeight->"Bold"],
  " Related Hoops with two factors."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"\"\<C8r \!\(\*
StyleBox[\"splits\",\nFontSlant->\"Italic\"]\)\>\"", 
          ",", \(shape[a8, "\<C8r\>"]\), ",", "\"\<\\nCL21 \!\(\*
StyleBox[\"splits\",\nFontSlant->\"Italic\"]\) \>\"", 
          ",", \(\((shape[a8, "\<CL21\>"])\)^2\), ",", "\"\<\\nCL03 \!\(\*
StyleBox[\"splits\",\nFontSlant->\"Italic\"]\) \>\"", 
          ",", \(\((shape[a8, "\<CL03\>"])\)^2\)}], "}"}], 
      TraditionalForm]], "Input",
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"C8r \\!\\(\\* \
StyleBox[\\\"splits\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({"a"\^2 + "b"\^2 + "c"\^2 + 
            "d"\^2 + \@2\ \(("a"\ "b" - "b"\ "c" + "a"\ "d" + "c"\ "d")\), 
          "a"\^2 + "b"\^2 + "c"\^2 + 
            "d"\^2 - \@2\ \(("a"\ "b" - "b"\ "c" + "a"\ "d" + "c"\ "d")\)}\), 
        ",", "\<\"\\nCL21 \\!\\(\\* \
StyleBox[\\\"splits\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({\((\(-\(("d" - "e")\)\^2\) - \(("c" + "f")\)\^2 + \(("b" + \
"g")\)\^2 + \(("a" - "h")\)\^2)\)\^2, \((\(-\(("d" + "e")\)\^2\) - \(("c" - \
"f")\)\^2 + \(("b" - "g")\)\^2 + \(("a" + "h")\)\^2)\)\^2}\), 
        ",", "\<\"\\nCL03 \\!\\(\\* \
StyleBox[\\\"splits\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({\((\(("d" + "e")\)\^2 + \(("c" - "f")\)\^2 + \(("b" + \
"g")\)\^2 + \(("a" - "h")\)\^2)\)\^2, \((\(("d" - "e")\)\^2 + \(("c" + "f")\)\
\^2 + \(("b" - "g")\)\^2 + \(("a" + "h")\)\^2)\)\^2}\)}], "}"}]], "Output",
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "\tThe sizes of \[DoubleStruckCapitalC], \[DoubleStruckCapitalH], and \
\[DoubleStruckCapitalO] are sums of squared coefficients, and so can only be \
zero (for real coefficients) in the trivial case where all the coefficients \
are zero. This makes them (together with \[DoubleStruckCapitalR]) the only \
\"division algebras without real divisors of zero\". All other hoops have \
real divisors of zero; all hoops (including \[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], and \
\[DoubleStruckCapitalO]) have divisors of zero in the complex field. (The \
sizes of ",
  StyleBox["Sed",
    FontSlant->"Italic"],
  " and higher Cayley-Dickson algebras are also sums of squares, but they are \
not conserved.) \n\tDivision of a vector A by an annihilitor (i.e. a vector \
whose sizes are all zero) is interpreted as giving a result {0,0...} and a \
remainder that is all of A."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. Many algebras are Hoops.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". Most of the algebras of Mathematical Physics are Hoop algebras or \
constrained Hoop algebras."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["7.1. Real, Complex, Quaternion, Octonion Algebras.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tThe importance of hoops is that most \"physical\" algebras are hoops or \
restrictions on hoops, and so have conserved properties. C2 is the \
multiplication table for real numbers, expressed as {+,-}, with +*+ and -*- \
both giving +. C4c (folded from C4) is Complex, {r,i}, with i*i = - r \
(Example 27). Non-abelian Quaternions, non-associative Octonions, \
non-alternative & non-conservative (but power-associative) sedenions are all \
Cayley-Dickson algebras:- Qr, Octc, Sed. Qr, Oct & Octi compose with C2 to \
form (associative) Q8 & (alternative) Oct and M(16,2) Moufang loops; they \
describe rotations in 3 & 7 dimensions (Section 6.6) and also multiply \
univectors to give scalar products and cross products. Composing Sed and \
higher Cayley-Dickson algebras does not give Moufang loops; they are not \
conservative division algebras.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["\<\
\t(Technical note. It is well-known that the 16 vectors {\[PlusMinus]1/2,\
\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/2} are \"rational units\" for \
Quaternions; it may be a new observation that there are many others. \
Permutations of {\[PlusMinus]2/3,\[PlusMinus]2/3,\[PlusMinus]1/3,0}, {\
\[PlusMinus]4/5,\[PlusMinus]2/5,\[PlusMinus]2/5,\[PlusMinus]1/5}, {\
\[PlusMinus]5/6,\[PlusMinus]3/6,\[PlusMinus]1/6,\[PlusMinus]1/6}, {\
\[PlusMinus]4/6,\[PlusMinus]4/6,\[PlusMinus]1/6,\[PlusMinus]1/6}, {\
\[PlusMinus]5/7,\[PlusMinus]4/7,\[PlusMinus]2/7,\[PlusMinus]2/7}, and {\
\[PlusMinus]6/7,\[PlusMinus]3/7,\[PlusMinus]2/7,0} are examples - in each \
case the sum of the squared elements (the size) is 1. Similarly, permutations \
of {\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/2,0,0,0,0}, \
{\[PlusMinus]2/3,\[PlusMinus]1/3,\[PlusMinus]1/3,\[PlusMinus]1/3,\[PlusMinus]\
1/3,\[PlusMinus]1/3,0,0}, {\[PlusMinus]3/4,\[PlusMinus]1/4,\[PlusMinus]1/4,\
\[PlusMinus]1/4,\[PlusMinus]1/4,\[PlusMinus]1/4,\[PlusMinus]1/4,\[PlusMinus]1/\
4},  {\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/4,\
\[PlusMinus]1/4,\[PlusMinus]1/4,\[PlusMinus]1/4,0} are all octonion rational \
units.)\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2. Vector Dot & Cross products.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tExample 38 shows that dot & cross products are hoop multiplications where \
only the univectors are multiplied (i.e. the scalar and multivector elements \
of the multiplicands are kept at zero). The symbols are chosen to match those \
in [3, p11] for quaternions and CL2, and to match [3, p37] for octonions and \
CL3.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 38. ",
  StyleBox["Dot & Cross products with Qr & Octr.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopTimes[{0, e\_1, e\_2, 0}, {0, u\_1, u\_2, 
        0}, "\<Qr\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({\(-e\_1\)\ u\_1 - e\_2\ u\_2, 0, 
      0, \(-e\_2\)\ u\_1 + e\_1\ u\_2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopTimes[{0, a\_1, a\_2, 0, a\_3, 0, 0, 0}, {0, b\_1, 
        b\_2, 0, b\_3, 0, 0, 0}, "\<Octr\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({\(-a\_1\)\ b\_1 - a\_2\ b\_2 - a\_3\ b\_3, 0, 
      0, \(-a\_2\)\ b\_1 + a\_1\ b\_2, 
      0, \(-a\_3\)\ b\_1 + a\_1\ b\_3, \(-a\_3\)\ b\_2 + a\_2\ b\_3, 
      0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tIn both cases the first term is the scalar product (up to a sign), \
whilst the univectors (and octonion trivector) in the product are zero. The \
Qr trivector result ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_2\) u\_1 - \(e\_1\) u\_2\)]],
  " is the 2D cross product, and Octc gives the (negated) 3D scalar product \
",
  Cell[BoxData[
      StyleBox[\(a\_1\ b\_1 + a\_2\ b\_2 + a\_3\ b\_3\),
        FontSlant->"Italic"]]],
  " together with the vector cross product  ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-a\_2\)\ b\_1 + a\_1\ b\_2)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) e\_2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((\(-a\_3\)\ b\_1 + a\_1\ b\_3)\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) e\_3\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-a\_3\)\ b\_2 + a\_2\ b\_3)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(e\_2\) e\_3\)]],
  ". (Remember that the bivector ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) e\_2\)]],
  " is the 4th element basis direction, etc., with coefficient 0 in the \
multiplicands). "
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
7.3. Cayley-Dickson, Clifford, Exterior, Wedge & Lie Algebras.\
\>", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tSection 3.2.7 demonstrated some generalisations of the Cayley-Dickson \
process, creating many hoops.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tClifford algebras are hoops, created by ",
  StyleBox["cl",
    FontSlant->"Italic"],
  " or by folding a specific group isomorph. Wedge (exterior) algebras are \
the bivector part of the Clifford product ([3] p.10). They multiply \
univectors using Clifford algebra rules; the scalars and multivectors are \
kept at zero in the multiplicands so various products are zero (i.e. these \
are Grassmann algebras). Multiplying univectors ",
  Cell[BoxData[
      \(TraditionalForm\`u\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u\_2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  " in CL2 gives a scalar ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) u\_1 - \(e\_2\) u\_2\)]],
  " and a bivector ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) u\_2 - \(e\_2\) u\_1\)]],
  "; the univectors in the product are zero. CL3 gives the wedge product of \
three univectors when the scalar and multivector terms are zero in the \
multiplicands:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 39a. ",
  StyleBox["Wedge Products, Exterior Algebras. Qr, Octr.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(TraditionalForm\`hoopTimes[{0, u\_1, u\_2, 0}, {0, v\_1, v\_2, 
        0}, "\<Qr\>"]\), "\[IndentingNewLine]", 
    \(TraditionalForm\`hoopTimes[{0, u\_1, u\_2, 0, u\_3, 0, 0, 0}, {0, v\_1, 
        v\_2, 0, v\_3, 0, 0, 0}, "\<Octr\>"]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({\(-u\_1\)\ v\_1 - u\_2\ v\_2, 0, 
      0, \(-u\_2\)\ v\_1 + u\_1\ v\_2}\)], "Output"],

Cell[BoxData[
    \({\(-u\_1\)\ v\_1 - u\_2\ v\_2 - u\_3\ v\_3, 0, 
      0, \(-u\_2\)\ v\_1 + u\_1\ v\_2, 
      0, \(-u\_3\)\ v\_1 + u\_1\ v\_3, \(-u\_3\)\ v\_2 + u\_2\ v\_3, 
      0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Example 39b. ",
  StyleBox["Wedge Products, Exterior Algebras. CL2, CL3",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(TraditionalForm\`hoopTimes[{0, u\_1, u\_2, 0}, {0, v\_1, v\_2, 
        0}, "\<CL2\>"]\), "\[IndentingNewLine]", 
    \(TraditionalForm\`hoopTimes[{0, u\_1, u\_2, 0, u\_3, 0, 0, 0}, {0, v\_1, 
        v\_2, 0, v\_3, 0, 0, 0}, "\<CL3\>"]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({u\_1\ v\_1 - u\_2\ v\_2, 0, 
      0, \(-u\_2\)\ v\_1 + u\_1\ v\_2}\)], "Output"],

Cell[BoxData[
    \({u\_1\ v\_1 + u\_2\ v\_2 + u\_3\ v\_3, 0, 
      0, \(-u\_2\)\ v\_1 + u\_1\ v\_2, 
      0, \(-u\_3\)\ v\_1 + u\_1\ v\_3, \(-u\_3\)\ v\_2 + u\_2\ v\_3, 
      0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThese only differ from the quaternion and octonion univector products in \
the sign of the first term.\n\tLounesto [3, footnote 11, p11; p38] points out \
the distinction between the oriented plane-area bivector wedge product and \
the vector-valued cross product. The cross products involve a metric; wedge \
products do not.\n\tDifferent 16-element Clifford algebras multiply 4 \
univectors to give scalars and three bivectors with assorted signs. (Trailing \
zeroes are omitted in the input; ",
  StyleBox["hoopTi",
    FontSlant->"Italic"],
  StyleBox["mes",
    FontSlant->"Italic"],
  " pads out short vecs with zeroes.):- "
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 40. ",
  StyleBox["Wedge Products, Exterior Algebras. CL4 etc",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    FormBox[
      FormBox[\(hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, 
            u\_2, 0, u\_3, 0, 0, u\_4}, "\<CL4\>"]\),
        "TraditionalForm"], TraditionalForm], "\n", 
    FormBox[
      FormBox[\(hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, 
            u\_2, 0, u\_3, 0, 0, u\_4}, "\<CL04\>"]\),
        "TraditionalForm"], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      FormBox[\(hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, 
            u\_2, 0, u\_3, 0, 0, u\_4}, "\<CL31\>"]\),
        "TraditionalForm"], TraditionalForm]}], "Input",
  PageWidth->WindowWidth,
  FontFamily->"Courier New"],

Cell[BoxData[
    \({e\_1\ u\_1 + e\_2\ u\_2 + e\_3\ u\_3 - e\_4\ u\_4, 0, 
      0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 + e\_4\ u\_3 + e\_3\ u\_4, 
      0, \(-e\_3\)\ u\_1 - e\_4\ u\_2 + e\_1\ u\_3 - e\_2\ u\_4, 
      e\_4\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 + e\_1\ u\_4, 0, 0, 0, 0, 0, 0, 0, 
      0, 0}\)], "Output"],

Cell[BoxData[
    \({\(-e\_1\)\ u\_1 - e\_2\ u\_2 - e\_3\ u\_3 + e\_4\ u\_4, 0, 
      0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 - e\_4\ u\_3 - e\_3\ u\_4, 
      0, \(-e\_3\)\ u\_1 + e\_4\ u\_2 + e\_1\ u\_3 + 
        e\_2\ u\_4, \(-e\_4\)\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 - e\_1\ u\_4, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output"],

Cell[BoxData[
    \({\(-e\_1\)\ u\_1 + e\_2\ u\_2 + e\_3\ u\_3 + e\_4\ u\_4, 0, 
      0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 + e\_4\ u\_3 + e\_3\ u\_4, 
      0, \(-e\_3\)\ u\_1 - e\_4\ u\_2 + e\_1\ u\_3 - 
        e\_2\ u\_4, \(-e\_4\)\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 - e\_1\ u\_4, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
\tFinite Lie algebras appear to be Clifford hoops for which the real (scalar) \
elements have been zeroed. This has yet to be explored. Clifford(5) has the \
same number of distinct off-diagonal elements as the string theory group with \
496 (=32/31/2) elements, suggesting that these elements are related to \
multivectors.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.4. Penrose Twistors.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\t[Wikipedia,Twistor theory] \"Twistors map the geometric objects of the four \
dimensional (Minkowski) space-time .. into the geometric objects in the \
4-dimensional complex space with the metric signature (2,2).\" \
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\t CL2 conserves ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2 - b\^2 + c\^2 - d\^2\)]],
  ". C2D4r & CL21 conserve two (repeated) functions, both composed of four \
squares, with two negated. Thus they have sub-algebras with the signature \
(2,2). D4, KiC4c & KiC4r have (2,2) repeated sizes, but also have other \
sizes. I have not explored the relationships with twistors."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Shape C2D4r =\>", id[mp["\<C2D4r\>"]]; 
      shape[a8 = Take[alph, 8]], "\<\nShape  CL21 =\>", id[mp["\<CL21\>"]]; 
      shape[a8], "\<\nShape    D4 =\>", id[mp["\<D4\>"]]; 
      shape[a8], "\<\nShape KiC4c =\>", id[mp["\<KiC4c\>"]]; 
      shape[a8], "\<\nShape KiC4r =\>", id[mp["\<KiC4r\>"]]; 
      shape[a8]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Shape C2D4r =", {\((a + b)\)\^2 - \((c + d)\)\^2 + \((e + f)\)\^2 - \
\((g + h)\)\^2, \((a - b)\)\^2 - \((c - d)\)\^2 + \((e - f)\)\^2 - \((g - \
h)\)\^2}, 
      "\nShape  CL21 =", {\(-\((d - e)\)\^2\) - \((c + f)\)\^2 + \((b + \
g)\)\^2 + \((a - h)\)\^2, \(-\((d + e)\)\^2\) - \((c - f)\)\^2 + \((b - \
g)\)\^2 + \((a + h)\)\^2}, 
      "\nShape    D4 =", {a + b - c - d + e + f - g - h, 
        a - b + c - d + e - f + g - h, a - b - c + d + e - f - g + h, 
        a + b + c + d + e + f + g + 
          h, \((a - e)\)\^2 - \((b - f)\)\^2 + \((c - g)\)\^2 - \((d - \
h)\)\^2}, 
      "\nShape KiC4c =", {\((a - b + c - d)\)\^2 + \((e - f + g - h)\)\^2, \
\((a + b + c + d)\)\^2 + \((e + f + g + h)\)\^2, \((a - c)\)\^2 - \((b - d)\)\
\^2 + \((e - g)\)\^2 - \((f - h)\)\^2}, 
      "\nShape KiC4r =", {\((a - e)\)\^2 - \((b - f)\)\^2 + \((c - g)\)\^2 - \
\((d - h)\)\^2, \((a + b + e + f)\)\^2 + \((c - d + g - h)\)\^2, \((a - b + e \
- f)\)\^2 + \((c + d + g + h)\)\^2}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["8. (Visualization Deleted).", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["9. Orbits.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". Polar duals become continuous \"Orbits\" when the non-zero offsets and \
squared radii (or their product) are constrained to be one, defining \"unital\
\" sub-algebras. Many orbits appear to be unstable and have zero size. The \
implications of the few cases with finite sizes are discussed Section 10."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["9.1. C3, K & C4 Orbits have fixed amplitudes.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tFinite groups have finite \"orbits\", sets of points. These become \
continuous orbits (continuous multi-phase sinusoids) in algebras with polar \
duals - the duals form an equivalence class if offsets and squared radii (or \
ulnae) are constrained to values of 0 or 1 whilst angles are allowed to vary. \
They constitute continuous closed unitary sub-algebras; hoop multiplication \
of two orbits gives another orbit.\n\tOrbit vector values are given by ",
  StyleBox["toVector",
    FontSlant->"Italic"],
  " using arbitrary angles, all other parameters being 0 or 1. (",
  StyleBox["toVector",
    FontSlant->"Italic"],
  " uses the table ",
  StyleBox["gp",
    FontSlant->"Italic"],
  " which is set up by ",
  StyleBox["sh[\"mnemonic\"] ",
    FontSlant->"Italic"],
  "to distinguish between sizes and angles.) The three C3 and four C4 orbits \
are set up in Example 41; the names correspond to the sizes. Note that ",
  StyleBox["shape[\"C3\"]",
    FontSlant->"Italic"],
  " has one L1(linear) and one L2 (quadratic) size whilst a C3 vector has 3 \
degrees of freedom. Similarly, ",
  StyleBox["shape[\"C4\"]",
    FontSlant->"Italic"],
  " has three size parameters to describe a 4-element vector. Each squared \
radius provides a degree of freedom that is utilized by the angle parameter, \
which is a \"hidden variable\" for the cartesian form. Each polar form is the \
shape together with an angle for each quadratic size. Example 41 also sets up \
and multiplies the C3 orbits, showing the product to be an orbit with the \
angles added. Then four C4 orbit pairs are set up and multiplied; the \
products are orbits with the correct sizes:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 41. ",
  StyleBox["C3 & C4 Orbit Multiplication.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \(TraditionalForm\`a\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<C3 Orbits\>", "\<\nOC301 is {0,1,\[Sigma]} with vector form\>", 
      gmn = "\<C3\>"; mm = 3; 
      OC301 = toVector[{0, 
            1, \[Sigma]}], "\<\nOC311 is {1,1,\[Sigma]} with vector form\>", 
      OC311 = toVector[{1, 
            1, \[Sigma]}], "\<\nProducts are orbits with added angles; the \
polar form of the product is\>", 
      Simplify[toPolar[
          hoopTimes[OC301, OC311, 
            C3]]], "\<\n\nC4 Orbits\>", \[IndentingNewLine]gmn = "\<C4\>"; 
      mm = 4; "\<\nOC4001 is {0,0,1,a} with vector form\>", 
      OC4001 = toVector[{0, 0, 1, 
            a}], "\<\nOC4011 is {0,1,1,b} with vector form\>", 
      OC4011 = toVector[{0, 1, 1, 
            b}], "\<\nOC4101 = {1,0,1,c} with vector form\>", 
      OC4101 = toVector[{1, 0, 1, 
            c}], "\<\nOC4111 is {1,1,1,d} with vector form\>", 
      OC4111 = toVector[{1, 1, 1, 
            d}], "\<\n\n\>", \
\[IndentingNewLine]Simplify[{"\<OC4001\[Times]OC4001 has the 001 shape\>", 
          shape[hoopTimes[OC4001, OC4001, 
              C4]], "\<\nOC4101\[Times]OC4011 also has the 001 shape\nas the \
two offsets disappear   \>", 
          shape[hoopTimes[OC4101, 
              OC4011]], "\<\nOC4101\[Times]OC4111 has the 101 shape\>", 
          shape[hoopTimes[OC4101, 
              OC4111]], "\<\nOC4111\[Times]OC4111 has the 111 shape\>", 
          shape[hoopTimes[OC4111, OC4111]]}]}\)], "Input",
  PageWidth->WindowWidth,
  FontSize->10],

Cell[BoxData[
    \({"C3 Orbits", 
      "\nOC301 is {0,1,a} with vector form", {\(2\ Cos[a]\)\/3, 
        2\/3\ Cos[a + \(2\ \[Pi]\)\/3], 2\/3\ Cos[a - \(2\ \[Pi]\)\/3]}, 
      "\nOC311 is {1,1,b} with vector form", {1\/3\ \((1 + 2\ Cos[b])\), 
        1\/3\ \((1 + 2\ Cos[b + \(2\ \[Pi]\)\/3])\), 
        1\/3\ \((1 + 2\ Cos[b - \(2\ \[Pi]\)\/3])\)}, 
      "\nProducts are orbits with added angles; the polar form of the product \
is", {0, 1, ArcTan[Cos[a + b], Sin[a + b]]}, "\n\nC4 Orbits", 
      "\nOC4001 is {0,0,1,a} with vector form", {Cos[a]\/2, 
        Sin[a]\/2, \(-\(Cos[a]\/2\)\), \(-\(Sin[a]\/2\)\)}, 
      "\nOC4011 is {0,1,1,b} with vector form", {1\/4\ \((1 + 2\ Cos[b])\), 
        1\/4\ \((\(-1\) + 2\ Sin[b])\), 1\/4\ \((1 - 2\ Cos[b])\), 
        1\/4\ \((\(-1\) - 2\ Sin[b])\)}, 
      "\nOC4101 = {1,0,1,c} with vector form", {1\/4\ \((1 + 2\ Cos[c])\), 
        1\/4\ \((1 + 2\ Sin[c])\), 1\/4\ \((1 - 2\ Cos[c])\), 
        1\/4\ \((1 - 2\ Sin[c])\)}, 
      "\nOC4111 is {1,1,1,d} with vector form", {1\/4\ \((2 + 2\ Cos[d])\), 
        Sin[d]\/2, 1\/4\ \((2 - 2\ Cos[d])\), \(-\(Sin[d]\/2\)\)}, 
      "\n\n", {"OC4001\[Times]OC4001 has the 001 shape", {0, 0, 1}, 
        "\nOC4101\[Times]OC4011 also has the 001 shape\nas the two offsets \
disappear   ", {0, 0, 1}, 
        "\nOC4101\[Times]OC4111 has the 101 shape", {1, 0, 1}, 
        "\nOC4111\[Times]OC4111 has the 111 shape", {1, 1, 1}}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "Example 42. ",
  StyleBox["C3 & C4 Chiral Orbits.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[TextData[{
  "\tThese orbits possess chirality, as the order of the orbit components is \
reversed if the angle is negated. I appending a ",
  StyleBox["c",
    FontSlant->"Italic"],
  " to the orbit name to indicate negation of the angle"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<OC301c is {0,1,-a} with vector form\>", gmn = "\<C3\>"; mm = 3; 
      OC301 = toVector[{0, 1, \(-a\)}], gmn = "\<C4\>"; 
      mm = 4; "\<\nOC4001c is {0,0,1,-a} with vector form\>", 
      OC4001 = toVector[{0, 0, 1, \(-a\)}]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"OC301c is {0,1,-a} with vector form", {\(2\ Cos[a]\)\/3, 
        2\/3\ Cos[a - \(2\ \[Pi]\)\/3], 2\/3\ Cos[a + \(2\ \[Pi]\)\/3]}, 
      "\nOC4001c is {0,0,1,-a} with vector form", {Cos[a]\/2, \(-\(Sin[
                a]\/2\)\), \(-\(Cos[a]\/2\)\), Sin[a]\/2}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tThe group K (C2C2) cannot have a polar orbit as it has no L2 size, but \
the four L1 sizes can be combined to give six paired difference-of-squares \
formulations. Hyperbolic orbits can be defined using any of these as \
adjacent",
  Cell[BoxData[
      \(TraditionalForm\`\^2\)]],
  ", opposite",
  Cell[BoxData[
      \(TraditionalForm\`\^2\)]],
  " pairs. Two orbits are set up in Example 43 and multiplied. The product is \
shown to be an orbit with unit sizes; its \"angles\" appear in complex form \
but numeric substitutions show that they are the sums of those in the \
multiplicands."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 43. Klein Group Hyperbolic Orbit Multiplication.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \({gmn = "\<K\>"; "\<OKh11a is {1,\[Alpha],1,a} with vector form\n\>", 
      OKh11a = tohyVector[{1, \[Alpha], 1, 
            a}], "\<\nOKh11b is {1,\[Beta],1,b} with vector form\>", 
      OKh11b = tohyVector[{1, \[Beta], 1, 
            b}], "\<\nTheir product Polar form is\n\>", 
      Simplify[tohyPolar[
          hoopTimes[OKh11a, OKh11b, 
            K]]], "\<\nSubstituting \[Alpha]\[Rule].1, \[Beta]\[Rule].3, a\
\[Rule].22, b\[Rule].28 shows that the angles have added to give \>", \
{Log[\((Cosh[\[Alpha] + \[Beta]] + Sinh[\[Alpha] + \[Beta]])\)], 
          Log[\((Cosh[a + b] + Sinh[a + b])\)]} /. {\[Alpha] \[Rule]  .1, 
          a \[Rule]  .22, \[Beta] \[Rule]  .3, b \[Rule]  .28}}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontSize->10],

Cell[BoxData[
    \({"OKh11a is {1,\[Alpha],1,a} with vector form\n", {Cosh[a]\/2 + 
          Cosh[\[Alpha]]\/2, 
        Sinh[a]\/2 + Sinh[\[Alpha]]\/2, \(-\(Cosh[a]\/2\)\) + 
          Cosh[\[Alpha]]\/2, \(-\(Sinh[a]\/2\)\) + Sinh[\[Alpha]]\/2}, 
      "\nOKh11b is {1,\[Beta],1,b} with vector form", {Cosh[b]\/2 + 
          Cosh[\[Beta]]\/2, 
        Sinh[b]\/2 + Sinh[\[Beta]]\/2, \(-\(Cosh[b]\/2\)\) + 
          Cosh[\[Beta]]\/2, \(-\(Sinh[b]\/2\)\) + Sinh[\[Beta]]\/2}, 
      "\nTheir product Polar form is\n", {1, 
        If[Cosh[\[Alpha] + \[Beta]] == Sinh[\[Alpha] + \[Beta]] || 
            Cosh[\[Alpha] + \[Beta]] + Sinh[\[Alpha] + \[Beta]] == 0, 
          If[x$1117 \[NotEqual] 
              0, \(\[Infinity]\ Sign[y$1117]\)\/Sign[x$1117], 0, 0], 
          b$1117 = Log[N[\(x$1117 + y$1117\)\/\@\(x$1117\^2 - y$1117\^2\)]]; 
          Chop[Re[b$1117] + \[ImaginaryI]\ Chop[Im[b$1117]]]], 1, 
        If[Cosh[a + b] == Sinh[a + b] || Cosh[a + b] + Sinh[a + b] == 0, 
          If[x$1118 \[NotEqual] 
              0, \(\[Infinity]\ Sign[y$1118]\)\/Sign[x$1118], 0, 0], 
          b$1118 = Log[N[\(x$1118 + y$1118\)\/\@\(x$1118\^2 - y$1118\^2\)]]; 
          Chop[Re[b$1118] + \[ImaginaryI]\ Chop[Im[b$1118]]]]}, 
      "\nSubstituting \[Alpha]\[Rule].1, \[Beta]\[Rule].3, a\[Rule].22, b\
\[Rule].28 shows that the angles have added to give ", {0.4`, 
        0.5`}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["9.2. C5, C7 & C8 Orbits have unstable amplitudes.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThe orbits of C3 are of fixed squared radius 2/3 and offsets 0 or 1/3.  \
Those of C4 are of fixed squared radii or ulnae of magnitude 1/2, and offsets \
0 or \[PlusMinus]1/4. For C2 there is only one, hyperbolic, orbit with a unit \
ulna. Orbits of Cp (p prime>3) can be developed, with p sinusoidal phases, \
but their radii are unconstrained, though their offsets are 0 or 1/p. Example \
44 shows that OC51r, a five-phase orbit with radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", has an L4 size of zero and so is unconstrained. The angle and L1 and L4 \
parameters only use 3 of the 5 degrees of freedom. Example 45 shows that a \
seven-phase orbit with radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  " has a zero size in C7 (I have not found a polar expression for this \
group). These orbits also appear to be unstable - numerical integration of \
the relevant differential-equation sets is unstable. Example 46 shows that an \
eight-phase orbit with radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  " has a zero size in C8. "
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 44.  ",
  StyleBox["Zero-sized C5 orbit.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{gmn = \"C5\";\"OC51r is\",OC51r = 
    toVector[{d, r, \[Sigma]}], 
  \"\\nThe radius disappears from the shape\", 
  Simplify[shape[OC51r]]}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier",
  FontSize->10],

Cell[BoxData[
    \({"OC51r is", {1\/5\ \((d + r\ Sin[\[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(2\ \[Pi]\)\/5 + \[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(4\ \[Pi]\)\/5 + \[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(6\ \[Pi]\)\/5 + \[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(8\ \[Pi]\)\/5 + \[Sigma]])\)}, 
      "\nThe radius disappears from the shape", {d, 0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Example 45. ",
  StyleBox[" Zero-sized C7 orbit.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{tst = {d + r*Sin[\[Sigma]], 
     d + r*Sin[(2*Pi)/7 + \[Sigma]], 
     d + r*Sin[(4*Pi)/7 + \[Sigma]], 
     d + r*Sin[(6*Pi)/7 + \[Sigma]], 
     d + r*Sin[(8*Pi)/7 + \[Sigma]], 
     d + r*Sin[(10*Pi)/7 + 
         \[Sigma]], d + 
      r*Sin[(12*Pi)/7 + \[Sigma]]}/
    7;\"OC7dr is\",tst,\"The determinant simplifies (slowly!) to\", Simplify[
    fp[ca[7], tst]]}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"OC7dr is", {1\/7\ \((d + r\ Sin[\[Sigma]])\), 
        1\/7\ \((d + r\ Sin[\(2\ \[Pi]\)\/7 + \[Sigma]])\), 
        1\/7\ \((d + r\ Sin[\(4\ \[Pi]\)\/7 + \[Sigma]])\), 
        1\/7\ \((d + r\ Sin[\(6\ \[Pi]\)\/7 + \[Sigma]])\), 
        1\/7\ \((d + r\ Sin[\(8\ \[Pi]\)\/7 + \[Sigma]])\), 
        1\/7\ \((d + r\ Sin[\(10\ \[Pi]\)\/7 + \[Sigma]])\), 
        1\/7\ \((d + r\ Sin[\(12\ \[Pi]\)\/7 + \[Sigma]])\)}, 
      "The determinant simplifies (slowly!) to", 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Example 46. ",
  StyleBox[" Zero-sized C8 orbit.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{tst = {d + r*Sin[\[Sigma]], 
     d + r*Sin[(2*Pi)/8 + \[Sigma]], 
     d + r*Sin[(4*Pi)/8 + \[Sigma]], 
     d + r*Sin[(6*Pi)/8 + \[Sigma]], 
     d + r*Sin[(8*Pi)/8 + \[Sigma]], 
     d + r*Sin[(10*Pi)/8 + 
         \[Sigma]], d + 
      r*Sin[(12*Pi)/8 + \[Sigma]], d + 
      r*Sin[(14*Pi)/8 + \[Sigma]]}/
    8;\"OC8dr is\",tst,\"The determinant simplifies to\", Simplify[
    fp[ca[8], tst]]}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"OC8dr is", {1\/8\ \((d + r\ Sin[\[Sigma]])\), 
        1\/8\ \((d + r\ Sin[\[Pi]\/4 + \[Sigma]])\), 
        1\/8\ \((d + r\ Cos[\[Sigma]])\), 
        1\/8\ \((d + r\ Sin[\(3\ \[Pi]\)\/4 + \[Sigma]])\), 
        1\/8\ \((d - r\ Sin[\[Sigma]])\), 
        1\/8\ \((d + r\ Sin[\(5\ \[Pi]\)\/4 + \[Sigma]])\), 
        1\/8\ \((d - r\ Cos[\[Sigma]])\), 
        1\/8\ \((d + r\ Sin[\(7\ \[Pi]\)\/4 + \[Sigma]])\)}, 
      "The determinant simplifies to", 0}\)], "Output"]
}, Open  ]],

Cell["\<\
\t Stable, finite amplitude, orbits with 3, 4, 6, 9, and 12 phases have been \
found, some of which have polarization and chirality. They may be related to \
deBroglie waves. This leads to the surmise that quarks are wave packets with \
ternary symmetry, and leptons are wave packets with 4-fold symmetry. Some of \
the elements of hoops act as half-spin and unit-spin quantum operators (see \
Section 10). The orbit magnitudes may be related to the Planck size of \
\"extended\" particles; the number of types of particles may be related to \
the number of stable orbits. This is discussed in Section 10.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["9.3. Non-Abelian Orbits. (Under development.)", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tNon-Abelian groups have repeated factors that release extra degrees of \
freedom that cannot be taken up by the (radius,angle} formulation. On \
25/11/05 I discovered a polar form for repeated (i.e. non-abelian) quadratic \
shapes such as D3 and Qr, breaking the quadratic into two parts that are not \
conserved separately. These give \"pseudo-powers\" that revert to a vector of \
the correct size, even though the angles do not add.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 47.  ",
  StyleBox["D3 orbit.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toPol[{a, b, c, d, e, f}, "\<D3\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c + d + e + f, a - b + c - d + e - f, 
      1\/2\ \((\((a - c)\)\^2 + \((c - e)\)\^2 + \((\(-a\) + e)\)\^2)\) + 
        1\/2\ \((\(-\((b - d)\)\^2\) - \((d - f)\)\^2 - \((\(-b\) + \
f)\)\^2)\), ArcTan[2\ a - c - e, \@3\ \((\(-c\) + e)\)], 
      1\/2\ \((\((a - c)\)\^2 + \((c - e)\)\^2 + \((\(-a\) + e)\)\^2)\), 
      ArcTan[2\ b - d - f, \@3\ \((\(-d\) + f)\)]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(toVec[{\[Gamma], \[Delta], \[Eta]\[Eta], \[Chi], \[Kappa]\[Kappa], \
\[Psi]}, "\<D3\>"] /. {4 \@ \[Eta]\[Eta] \[Rule] \[Eta], 
        4 \@ \[Kappa]\[Kappa] \[Rule] \[Kappa], 
        4\ \@\(\(-\[Eta]\[Eta]\) + \[Kappa]\[Kappa]\) \[Rule] \[Nu]}\)], \
"Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({1\/6\ \((\[Gamma] + \[Delta] + \[Kappa]\ Cos[\[Chi]])\), 
      1\/6\ \((\[Gamma] - \[Delta] + \[Nu]\ Cos[\[Psi]])\), 
      1\/6\ \((\[Gamma] + \[Delta] + \[Kappa]\ Cos[\(2\ \[Pi]\)\/3 + \[Chi]])\
\), 1\/6\ \((\[Gamma] - \[Delta] + \[Nu]\ Cos[\(2\ \[Pi]\)\/3 + \[Psi]])\), 
      1\/6\ \((\[Gamma] + \[Delta] + \[Kappa]\ Cos[\(2\ \[Pi]\)\/3 - \[Chi]])\
\), 1\/6\ \((\[Gamma] - \[Delta] + \[Nu]\ Cos[\(2\ \[Pi]\)\/3 - \
\[Psi]])\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(id[D3]; {"\<If A=\>", 
      A, \*"\"\<\\n\!\(\@\(\(A\)\(\\\ \)\)\)=\>\"", 
      rA = hoopPower[A], \[IndentingNewLine]"\<\n with Polar form\>", 
      toPolar[A], \[IndentingNewLine]\*"\"\<\\n(\!\(\@A\)\!\(\()\^2\)\) is \
correct\>\"", 
      rA2 = hoopPower[rA, 
          2], \[IndentingNewLine]\*"\"\<\\nbut \!\(\@A\).\!\(\@\(\(A\)\(\\\ \
\)\)\)=\>\"", rArA = hoopTimes[rA, rA]}\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Prepend", "[", 
            RowBox[{\(shape[A]\), ",", "\"\<Shape[\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)]\>\""}], "]"}], 
          ",", \(Prepend[shape[rA], \*"\"\<Shape[\!\(\@A\)]\>\""]\), 
          ",", \(Prepend[shape[rA2], \*"\"\<Shape[\!\(\((\@A)\)\^2\)]\>\""]\),
           ",", \(Prepend[
            shape[rArA], \*"\"\<Shape[\!\(\@A\).\!\(\@A\)]\>\""]\)}], "}"}], "//",
       "tf"}]}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"If A=", {2.`, \(-1.`\), 4.`, 1.`, 3.`, 5.`}, 
      "\n\!\(\@\(\(A\)\(\\ \)\)\)=", {1.184026244006728`, 
        0.8945386347732366`, 1.5773461371970567`, \(-1.4154813976717826`\), 
        0.1094563121831859`, 1.391771456285517`}, 
      "\n with Polar form", {14.`, 4.`, \(-25.`\), \(-2.6179938779914944`\), 
        3.`, 2.4278682746450277`}, 
      "\n(\!\(\@A\)\!\(\()\^2\)\) is correct", {1.9999999999999998`, \
\(-1.0000000000000007`\), 4.`, 1.0000000000000024`, 3.`, 5.000000000000001`}, 
      "\nbut \!\(\@A\).\!\(\@\(\(A\)\(\\ \)\)\)=", {6.4880338717125845`, 
        2.078320452493908`, 1.7559830641437073`, 0.5046192161472423`, 
        0.7559830641437076`, 2.417060331358851`}}\)], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Shape[\\!\\(\\* StyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)]\"\>", "14.`", "4.`", \(-25.`\)},
            {"\<\"Shape[\\!\\(\\@A\\)]\"\>", "3.7416573867739418`", 
              "1.9999999999999993`", \(-5.`\)},
            {"\<\"Shape[\\!\\(\\((\\@A)\\)\\^2\\)]\"\>", 
              "14.000000000000004`", 
              "3.9999999999999956`", \(-25.00000000000001`\)},
            {"\<\"Shape[\\!\\(\\@A\\).\\!\\(\\@A\\)]\"\>", 
              "14.000000000000002`", "3.9999999999999982`", 
              "24.999999999999993`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(id[D3]; {Flatten[{"\<If B=\>", 
            B = {3. , \(-1. \), 2. , 2. , 5. , 3. }}], 
        Flatten[{"\<AB = \>", 
            AB = hoopTimes[A, 
                B]}], \[IndentingNewLine]Flatten[{"\<Polar A= \>", 
            sa = toPolar[A]}], \[IndentingNewLine]Flatten[{"\<Polar B= \>", 
            sb = toPolar[B]}], 
        Flatten[{"\<Polar AB=\>", 
            sab = toPolar[
                AB]}], \[IndentingNewLine]Flatten[{"\<Only 3 sizes \
multiply\>", sa\ sb - sab}]} // tf\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If B=\"\>", "3.`", \(-1.`\), "2.`", "2.`", "5.`", "3.`"},
            {"\<\"AB = \"\>", "50.`", "40.`", "37.`", "17.`", "23.`", 
              "29.`"},
            {"\<\"Polar A= \"\>", "14.`", 
              "4.`", \(-25.`\), \(-2.6179938779914944`\), "3.`", 
              "2.4278682746450277`"},
            {"\<\"Polar B= \"\>", "14.`", "6.`", \(-6.`\), 
              "1.7609219301413634`", "7.`", "2.899028779494308`"},
            {"\<\"Polar AB=\"\>", "196.`", "24.`", 
              "150.`", \(-0.5449788606363033`\), "547.`", 
              "0.5486956907469642`"},
            {"\<\"Only 3 sizes multiply\"\>", "0.`", "0.`", 
              "0.`", \(-4.065103972094753`\), \(-526.`\), 
              "6.4897643102701625`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
\tAs with high-angle abelian multiplication, non-abelian powers rotate \
vectors.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["9.4. Harmonics. (Under development.)", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tThis study started with the observation that banded sets of differential \
equations had multi-phase sinusoidal solutions, and was followed by the study \
of groups. Multi-phase sinusoidal orbits imply a relationship - the groups \
are acting like the differential equations, with each group element being the \
rate of change of two other elements. Orbits may be first harmonics \
corresponding to stable particles, and higher harmonics should be resonances \
corresponding to unstable particles. \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["10. \"ROGER\" Algebras, Quantum Operators, Subsymmetry.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Summary. ",
  StyleBox["A few hoop algebras have stable orbits that define a fundamental \
area, and provide operators with half-integral or integral spin. It is \
surmized that these Renormalizing Orbit-Generating Equivalence-Relation \
(ROGER) algebras may provide an explanation of  fundamental particle \
stability. Their use as Quantum Operators is discussed. C3K provides \
half-spin operators; folding it to C3C2 gives integer-spin sub-symmetrical \
operators. \"Dozal\" (the unitary algebra of 12-element directors) conserves \
many functions that may be related to particle properties.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["10.1. Quantum operators.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tOrbits have only been found for a few hoops in the database, but some hoops \
have stable orbits with 3, 4, 6, 12 & 16 phases that may define a fundamental \
size. Some other hoops have unstable orbits that do not define a fundamental \
size (Section 9.2). It is conjectured that stable orbit sizes are related to \
the Planck area, and that their orbits are related to deBroglie waves. These \
Renormalizing Orbit-Generating Equivalence-Relation \"ROGER\" algebras may \
provide quantum operators for fundamental particles. In particular, elements \
of the C3K (g1205) algebra appear to be half-spin operators.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tJ.J.Hamilton published [9] a \"hypercomplex arithmetic\" with half-spin \
hypercomplex quantum operators as well as integer-spin quantum operators. He \
generalised complex conjugation (in which the conjugate of a conjugate is the \
original, ",
  StyleBox["i:(i*)*=+i",
    FontSlant->"Italic"],
  ") to include elements ",
  StyleBox["{a,b,a*,b*}",
    FontSlant->"Italic"],
  " demonstrating \"biconjugation\" (my term) in which the conjugate of a \
conjugate is the negated original, ",
  StyleBox["a:a** =-a, (a*)** =-a*,  b:b** =-b, (b*)** =-b*.",
    FontSlant->"Italic"],
  "  He demonstrated that ",
  StyleBox["{a,b,a*,b*}",
    FontSlant->"Italic"],
  "  act like fundamental half-integral spin quantum operators with \
properties that cannot be expressed as complex numbers. (This is because they \
exist in the hyperbolic plane of Example 41 rather than the complex plane. \
They are different square roots of unity whilst his full-spin operators ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "& ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "are different fourth roots.) Matrix representations (which are are not \
fundamental) can be obtained for them. He stated that ",
  Cell[BoxData[
      \(TraditionalForm\`2\^r\)]],
  " elements are required, thereby unnecessarily restricting himself to \
hypercomplex, rather than general, number systems. His multiplication table \
(Table II, reproduced below) uses the eight elements ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_\(\(n\)\(\ \)\)\)\(=\)\)\)]],
  " {",
  StyleBox["1, i, h, k, a, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(b\^*\)\)]],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(a\^*\)\)]],
  StyleBox[", b",
    FontSlant->"Italic"],
  "}. However, he has several distinct \"-1\" elements (",
  Cell[BoxData[
      \(TraditionalForm\`h\^2, \ a\^2\ and\ a\^\(\(*\)\(2\)\)\)]],
  " are all +1); he also introduces several other elements and many aliases. \
Example 48 converts his Table II to an index table and identifies it as an O4 \
isomorph. O4 is obtained on folding C4K, C3KC2, & C8K."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 48. ",
  StyleBox["J.J.Hamiltons's Hypercomplex Multiplication Table.  (His Table \
II.)",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    RowBox[{"     ", 
      FormBox[GridBox[{
            {
              " ", \(E\_0\), \(E\_1\), \(E\_2\), \(E\_3\), \(E\_4\), \
\(E\_5\), \(E\_6\), \(E\_7\)},
            {\(E\_0\), "1", "i", "h", "k", "a", \(b\^*\), \(a\^*\), "b"},
            {\(E\_1\), "i", \(-1\), "k", \(-h\), \(b\^*\), \(-a\), 
              "b", \(-\(a\^*\)\)},
            {\(E\_2\), "h", "k", "1", "i", \(a\^*\), "b", "a", \(b\^*\)},
            {\(E\_3\), "k", \(-h\), "i", \(-1\), 
              "b", \(-\(a\^*\)\), \(b\^*\), \(-a\)},
            {\(E\_4\), "a", \(b\^*\), \(a\^*\), "b", "1", "i", "h", "k"},
            {\(E\_5\), \(b\^*\), \(-a\), "b", \(-\(a\^*\)\), "i", \(-1\), 
              "k", \(-h\)},
            {\(E\_6\), \(a\^*\), "b", "a", \(b\^*\), "h", "k", "1", "i"},
            {\(E\_7\), "b", \(-\(a\^*\)\), \(b\^*\), \(-a\), "k", \(-h\), 
              "i", \(-1\)}
            }],
        "TraditionalForm"]}]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\"\<This is \>\"", ",", 
        RowBox[{"id", "[", 
          RowBox[{"tst", "=", 
            RowBox[{"caylindex", "[", "   ", 
              FormBox[GridBox[{
                    {"1", "i", "h", "k", "a", \(b\^*\), \(a\^*\), "b"},
                    {"i", \(-1\), "k", \(-h\), \(b\^*\), \(-a\), 
                      "b", \(-\(a\^*\)\)},
                    {"h", "k", "1", "i", \(a\^*\), "b", "a", \(b\^*\)},
                    {"k", \(-h\), "i", \(-1\), 
                      "b", \(-\(a\^*\)\), \(b\^*\), \(-a\)},
                    {"a", \(b\^*\), \(a\^*\), "b", "1", "i", "h", "k"},
                    {\(b\^*\), \(-a\), "b", \(-\(a\^*\)\), "i", \(-1\), 
                      "k", \(-h\)},
                    {\(a\^*\), "b", "a", \(b\^*\), "h", "k", "1", "i"},
                    {"b", \(-\(a\^*\)\), \(b\^*\), \(-a\), "k", \(-h\), 
                      "i", \(-1\)}
                    }],
                "TraditionalForm"], "]"}]}], "]"}], ",", \(tst // tf\)}], 
      "}"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"This is \"\>", ",", "\<\"O4\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8"},
                  {"2", \(-1\), "4", \(-3\), "6", \(-5\), "8", \(-7\)},
                  {"3", "4", "1", "2", "7", "8", "5", "6"},
                  {"4", \(-3\), "2", \(-1\), "8", \(-7\), "6", \(-5\)},
                  {"5", "6", "7", "8", "1", "2", "3", "4"},
                  {"6", \(-5\), "8", \(-7\), "2", \(-1\), "4", \(-3\)},
                  {"7", "8", "5", "6", "3", "4", "1", "2"},
                  {"8", \(-7\), "6", \(-5\), "4", \(-3\), "2", \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tBecause O4 (g0813) is an equivalence relation on C3KC2 (g2415), Table II \
is embedded in C3KC2, and also in C3K, which is folded from C3KC2. Completing \
an \"extended table\" using Hamilton's definitions for -",
  StyleBox["1,-h,-a",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["-a*",
    FontSlant->"Italic"],
  ", and for their products, gives a 12\[Times]12 C3K isomorph. Choosing \
generators  ",
  Cell[BoxData[
      \(TraditionalForm\`i\^3\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`h\^2\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "=1 (to match Hamilton's nomenclature) gives the elements that are shown \
above the table in Example 48. If the supplementary and ill-defined \"-1\" \
term is converted to an arbitrary variable ",
  StyleBox["ii",
    FontSlant->"Italic"],
  " (it is ",
  Cell[BoxData[
      \(TraditionalForm\`i\^2\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`E\_1\%2\)]],
  " in Table II), the table becomes C3K. Deleting the rows and columns \
starting with negated elements (and shown in plain face) reduces this table \
to his Table II, which is therefore embedded in C3K:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 49. ",
  StyleBox["J.J.Hamiltons's Table II is embedded in C3K.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \( (*\ \ \ \ \
1\ \ \ \ i\ \ \ i\^2\ \ \ h\ \ \ hi\ \ \ hi\^2\ \ a\ \ ai\ \ \ ai\^2\ \
ah\ \ ahi\ ahi\^2\ *) \)], "Input",
  PageWidth->WindowWidth,
  FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"jjh3", "=", 
        RowBox[{GridBox[{
              {
                StyleBox["1"], 
                StyleBox["i"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["h"], 
                StyleBox["k"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["a"], 
                StyleBox[\(b\^*\)], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\)], 
                StyleBox["b"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"]},
              {
                StyleBox["i"], 
                StyleBox[\(-1\)], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["k"], 
                StyleBox[\(-h\)], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\)], 
                StyleBox[\(-a\)], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox["b"], 
                StyleBox[\(-\(a\^*\)\)], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"]},
              {
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["i",
                  FontWeight->"Plain"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Plain"], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\),
                  FontWeight->"Plain"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox["b",
                  FontWeight->"Plain"]},
              {
                StyleBox["h"], 
                StyleBox["k"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["1"], 
                StyleBox["i"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\)], 
                StyleBox["b"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox["a"], 
                StyleBox[\(b\^*\)], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"]},
              {
                StyleBox["k"], 
                StyleBox[\(-h\)], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["i"], 
                StyleBox[\(-1\)], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["b"], 
                StyleBox[\(-\(a\^*\)\)], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\)], 
                StyleBox[\(-a\)], 
                StyleBox["a",
                  FontWeight->"Plain"]},
              {
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Plain"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["i",
                  FontWeight->"Plain"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox["b",
                  FontWeight->"Plain"], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\),
                  FontWeight->"Plain"]},
              {
                StyleBox["a"], 
                StyleBox[\(b\^*\)], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\)], 
                StyleBox["b"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox["1"], 
                StyleBox["i"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["h"], 
                StyleBox["k"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"]},
              {
                StyleBox[\(b\^*\)], 
                StyleBox[\(-a\)], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox["b"], 
                StyleBox[\(-\(a\^*\)\)], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox["i"], 
                StyleBox[\(-1\)], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["k"], 
                StyleBox[\(-h\)], 
                StyleBox["h",
                  FontWeight->"Plain"]},
              {
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\),
                  FontWeight->"Plain"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox["b",
                  FontWeight->"Plain"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["i",
                  FontWeight->"Plain"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Plain"]},
              {
                StyleBox[\(a\^*\)], 
                StyleBox["b"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox["a"], 
                StyleBox[\(b\^*\)], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox["h"], 
                StyleBox["k"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["1"], 
                StyleBox["i"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"]},
              {
                StyleBox["b"], 
                StyleBox[\(-\(a\^*\)\)], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\)], 
                StyleBox[\(-a\)], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox["k"], 
                StyleBox[\(-h\)], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["i"], 
                StyleBox[\(-1\)], 
                StyleBox["1",
                  FontWeight->"Plain"]},
              {
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox["b",
                  FontWeight->"Plain"], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\),
                  FontWeight->"Plain"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Plain"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["i",
                  FontWeight->"Plain"]}
              }], "/.", \(\(-1\) \[Rule] ii\)}]}], 
      ";", \({"\<This is \>", id[caylindex[jjh3]]}\)}]], "Input",
  Editable->False,
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \({"This is ", "C3K"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tHence Hamilton's hypercomplex algebra can be interpreted as the C3K \
algebra if his ",
  StyleBox["i",
    FontSlant->"Italic"],
  " is a cube root of 1, with ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["h",
    FontSlant->"Italic"],
  " being different square roots of 1. His half-spin operators {",
  StyleBox["a, a*, -a\[Congruent]a**,b, b*, -b\[Congruent]b**\[Congruent]-a*",
    
    FontSlant->"Italic"],
  "} are then {",
  StyleBox["a, a h, a i i, a h i, a i , a h i i",
    FontSlant->"Italic"],
  "}; conjugation is multiplication by ",
  StyleBox["h",
    FontSlant->"Italic"],
  " (with ",
  StyleBox["h h",
    FontSlant->"Italic"],
  " =1), but biconjugation becomes multiplication by ",
  StyleBox["i",
    FontSlant->"Italic"],
  " or ",
  StyleBox["i i",
    FontSlant->"Italic"],
  ". This introduces ternary symmetry, and defies the prejudice that there \
must be ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " elements in an algebra - which is only true for real algebras without \
divisors of zero."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tC3K has a polar-vector duality, interconverting the vector form {e,i,ii, \
h,hi,hii, a,ai,aii, ah,ahi,ahii} (where e is the neutral element or 1) and \
the polar form with four scalar offsets {\[Alpha], \[Beta], \[Gamma], \
\[Delta]}, and four {squared radius, angle} pairs {\[Zeta]\[Zeta], \[Tau], \
\[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \[Chi], ",
  StyleBox["\[CurlyKappa]\[CurlyKappa]",
    FontWeight->"Bold"],
  ", \[Psi]} in a three-phase system. The squared radii are sums of squares, \
and so are positive for real vec coefficients. (The interconversions are \
still valid for complex coefficients, but these can give complex and negative \
radii.) \nThe following expressions are edited to emphasise the \
inter-relationships between the vector and polar forms. In particular, \
quadratic polar elements such as \[Zeta]\[Zeta] become radii such as \[Zeta], \
and 2\[Pi]/3 is written as \[Omega]:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 50. ",
  StyleBox["C3K Polar Dual.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \(toPolar[{a, b, c, d, e, f, g, h, i, j, k, l}, "\<C3K\>"]\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \({ (*\[Alpha]*) a + b + c + d + e + f + g + h + i + j + k + l, \[Beta] = 
        a + b + c - d - e - f + g + h + i - j - k - 
          l, \[IndentingNewLine] (*\[Gamma]*) a + b + c + d + e + f - g - h - 
        i - j - k - l, \[Delta] = 
        a + b + c - d - e - f - g - h - i + j + k + 
          l, \[IndentingNewLine] (*\[Zeta]\[Zeta]*) \((\((a - b + d - e + g - \
h + j - k)\)\^2 + \((b - c + e - f + h - i + k - l)\)\^2 + \((\(-a\) + c - d \
+ f - g + i - j + l)\)\^2)\)/2, \[IndentingNewLine] (*\[Tau]*) ArcTan[
        2\ a - b - c + 2\ d - e - f + 2\ g - h - i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c + e - f + h - i + k - 
              l)\)], \[IndentingNewLine] (*\[Lambda]\[Lambda]*) \((\((a - b - \
d + e + g - h - j + k)\)\^2 + \((\(-a\) + c + d - f - g + i + j - l)\)\^2 + \
\((b - c - e + f + h - i - k + l)\)\^2)\)/2, \[IndentingNewLine] (*\[Phi]*) 
        ArcTan[2\ a - b - c - 2\ d + e + f + 2\ g - h - i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c - e + f + h - i - k + 
              l)\)], \[IndentingNewLine] (*\[Eta]\[Eta]*) \((\((a - b + d - e \
- g + h - j + k)\)\^2 + \((\(-a\) + c - d + f + g - i + j - l)\)\^2 + \((b - \
c + e - f - h + i - k + l)\)\^2)\)/2, \[IndentingNewLine] (*\[Chi]*) ArcTan[
        2\ a - b - c + 2\ d - e - f - 2\ g + h + i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c + e - f - h + i - k + 
              l)\)], \[IndentingNewLine] (*\[CurlyKappa]\[CurlyKappa]*) \
\((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - c - e + f - h + i + k - l)\
\)\^2 + \((\(-a\) + c + d - f + g - i - j + l)\)\^2)\)/
        2, \[IndentingNewLine] (*\[Psi]*) ArcTan[
        2\ a - b - c - 2\ d + e + f - 2\ g + h + i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c - e + f - h + i + k - l)\)]}\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[TextData[{
  "Example 51. ",
  StyleBox["C3K Polar-Dual reversion to Cartesian form.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \(C3Kv = 
      toVector[{\[Alpha], \[Beta], \[Gamma], \[Delta], \[Zeta]\[Zeta], \
\[Tau], \[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \[Chi], \[CurlyKappa]\
\[CurlyKappa], \[Psi]}, "\<C3K\>"] /. {2  \[Pi]/3 \[Rule] \[Omega], \ 
          4  \[Pi]/3 \[Rule] 
            2  \[Omega], \@\[Zeta]\[Zeta] \[Rule] \[Zeta], \@\[Lambda]\
\[Lambda] \[Rule] \[Lambda], \@\[Eta]\[Eta] \[Rule] \[Eta], \@\[CurlyKappa]\
\[CurlyKappa] \[Rule] \[CurlyKappa]}\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \({\ \  (*a*) \((\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + 
            2\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \ \  + 
            2\ \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  + 
            2\ \[CurlyKappa]\ Cos[\[Psi]])\), \  (*b*) \((\[Alpha] + \[Beta] \
+ \[Gamma] + \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] + \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + 
            2\ \[Eta]\ Cos[\[Chi] + \[Omega]] + 
            2\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \  (*c*) \((\[Alpha] \
+ \[Beta] + \[Gamma] + \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] - \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]] + 
            2\ \[Eta]\ Cos[\[Chi] - \[Omega]] + 
            2\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\), \  (*d*) \((\[Alpha] \
- \[Beta] + \[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + 
            2\ \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - 
            2\ \[CurlyKappa]\ Cos[\[Psi]])\), \  (*e*) \((\[Alpha] - \[Beta] \
+ \[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] + \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + 
            2\ \[Eta]\ Cos[\[Chi] + \[Omega]] - 
            2\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \  (*f*) \((\[Alpha] \
- \[Beta] + \[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] - \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]] + 
            2\ \[Eta]\ Cos[\[Chi] - \[Omega]] - 
            2\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\), \  (*g*) \((\[Alpha] \
+ \[Beta] - \[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - 
            2\ \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - 
            2\ \[CurlyKappa]\ Cos[\[Psi]])\), \  (*h*) \((\[Alpha] + \[Beta] \
- \[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] + \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - 
            2\ \[Eta]\ Cos[\[Chi] + \[Omega]] - 
            2\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \  (*i*) \((\[Alpha] \
+ \[Beta] - \[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] - \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]] - 
            2\ \[Eta]\ Cos[\[Chi] - \[Omega]] - 
            
            2\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\), \  (*j*) \((\[Alpha] \
- \[Beta] - \[Gamma] + \[Delta] + 2\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - 
            2\ \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  + 
            2\ \[CurlyKappa]\ Cos[\[Psi]])\), \  (*k*) \((\[Alpha] - \[Beta] \
- \[Gamma] + \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] + \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - 
            2\ \[Eta]\ Cos[\[Chi] + \[Omega]] + 
            2\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \  (*l*) \((\[Alpha] \
- \[Beta] - \[Gamma] + \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] - \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]] - 
            2\ \[Eta]\ Cos[\[Chi] - \[Omega]] + 
            2\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\)}/12\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[TextData[{
  "\tThese polar-duals define orbits in the unital cases (i.e. when the \
product of non-zero sizes is constrained to be 1). ",
  StyleBox["Giving angles such as ",
    FontWeight->"Plain"],
  "\[Tau]",
  StyleBox[" ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["the form -(",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_p\ t\)\(-\)\)\)],
    FontWeight->"Plain"],
  StyleBox["P.x)/\[HBar]  gives the orbit the properties of a multi-phase \
deBroglie wave.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10.2. ",
  StyleBox["Dozal", "Text"],
  ". (under development.)"
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\t\"Dozal\" is my name for the algebra of 12 real elements. There are five \
12-element groups, with mnemonics ",
  StyleBox["C3C4, Q12, C3K, D3C2 & A4",
    FontSlant->"Italic"],
  ". I have not found a polar form for ",
  StyleBox["A4",
    FontSlant->"Italic"],
  ", but the others have closely related polar forms with intrinsic \
Planck-area-like finite amplitudes. The cubic A4 size ",
  StyleBox["l3",
    FontSlant->"Italic"],
  " discriminates between different types of orbit - a topic still to be \
investigated. The interconversions are shown in the same format as that used \
in Examples 50 & 51. \nIn Sci.Math, Jan 2006. Robert Israel provided a lemma \
to split a quartic C3C4 factor \"L4\" into two sums of squares, giving the \
l22a & l22b sizes. Prior to that, my version of the C3C4 shape did not \
conserve angles and so did not calculate powers correctly. The conversion of \
the vector form to the polar form is only expressed compactly if local \
variables {e1,e2, etc, with \[Psi]6=\[Psi]+\[Pi]/6}are used:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"Example", " ", "52.", " ", 
      StyleBox["General",
        FontWeight->"Plain"], 
      StyleBox[" ",
        FontWeight->"Plain"], 
      StyleBox["C3C4",
        FontWeight->"Plain"], 
      StyleBox[" ",
        FontWeight->"Plain"], 
      StyleBox[\(\(orbit\)\(.\)\),
        FontWeight->"Plain"]}]], "Input",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[BoxData[{
    \(C3C4abcdefghijkl . \[IndentingNewLine]Local\ symbols\ {\[Epsilon], 
        r = \(-Sqrt[3]\), e1 = a + b + c - g - h - i, 
        e2 = d + e + f - j - k - l, \[IndentingNewLine]a1 = 
          a - b + d - e + g - h + j - k, 
        a2 = a - b - d + e + g - h - j + k, \[IndentingNewLine]b1 = 
          b - c + e - f + h - i + k - l, 
        b2 = b - c - e + f + h - i - k + l, \[IndentingNewLine]c1 = 
          c - a + f - d + i - g + l - j, c2 = c - a - f + d + i - g - l + j, 
        f1 = a - b - g + 
            h + \((d + e - 2\ f - j - k + 2  l)\) 
              r3, \[IndentingNewLine]f2 = \((a + b - 2  c - g - h + 2  i)\) 
              r3 - d + e + j - k, \[IndentingNewLine]f3 = 
          a - b - g + 
            h - \((d + e - 2\ f - j - k + 2  l)\) 
              r3, \[IndentingNewLine]f4 = \((a + b - 2  c - g - h + 2  i)\) 
              r3 + d - e - j + k}\), "\[IndentingNewLine]", 
    \(\({a + b + c + d + e + f + g + h + i + j + k + l, 
        a + b + c - d - e - f + g + h + i - j - k - 
          l, \[IndentingNewLine]\[Epsilon] = e1\^2 + e2\^2, 
        If[\[Epsilon] == 0 && e2 \[Equal] 0, 0, ArcTan[e1, e2], 
          ArcTan[e1, e2]], \[IndentingNewLine]\((a1\^2 + b1\^2 + c1\^2)\)/2, 
        If[b1 \[Equal] 0, 0, 
          ArcTan[a1 - c1, 
            r\ b1]], \[IndentingNewLine]\((a2\^2 + b2\^2 + c2\^2)\)/2, 
        If[b2 \[Equal] 0, 0, 
          ArcTan[a2 - c2, r\ b2]], \[IndentingNewLine]\((f1\^2 + f2\^2)\) 
          3/4, If[f2 \[Equal] 0, \(-\[Pi]\)/6, 
          ArcTan[f1, f2] - \[Pi]/6], \[IndentingNewLine]\((f3\^2 + f4\^2)\) 
          3/4, If[f4 \[Equal] 0, \(-\[Pi]\)/6, 
          ArcTan[f3, f4] - \[Pi]/6]};\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  FontSize->9],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \ \ \ \ \ \)\(C3C4\[Alpha]\[Beta]\[Epsilon]\[Sigma]\
\[Zeta]\[Tau]\[Lambda]\[Phi]\[Eta]\[Chi]\[Kappa]\[Psi]\  . \
\[IndentingNewLine]{\[Alpha] + \[Beta] + \[Epsilon]\ Cos[\[Sigma]] + \[Zeta]\ \
Cos[\[Tau]]\ \ \ \ \ \  + 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + \@3\ \[Eta]\ Cos[\[Chi]6] \
+ \[Eta]\ Sin[\[Chi]6] + \@3\ \[Kappa]\ Cos[\[Psi]6] + \[Kappa]\ \
Sin[\[Psi]6], \[Alpha] + \[Beta] + \[Epsilon]\ Cos[\[Sigma]] + \[Zeta]\ Cos[\
\[Tau] + \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - \@3\ \[Eta]\ Cos[\[Chi]6] \
+ \[Eta]\ Sin[\[Chi]6] - \@3\ \[Kappa]\ Cos[\[Psi]6] + \[Kappa]\ \
Sin[\[Psi]6], \[Alpha] + \[Beta] + \[Epsilon]\ Cos[\[Sigma]] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \  - 
            2\ \[Eta]\ Sin[\[Chi]6]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \  - 
            2\ \[Kappa]\ Sin[\[Psi]6], \[Alpha] - \[Beta] + \[Epsilon]\ Sin[\
\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - \@3\ \[Eta]\ Sin[\[Chi]6] \
+ \[Eta]\ Cos[\[Chi]6] - \[Kappa]\ Cos[\[Psi]6] + \@3\ \[Kappa]\ \
Sin[\[Psi]6], \[Alpha] - \[Beta] + \[Epsilon]\ Sin[\[Sigma]] + \[Zeta]\ Cos[\
\[Tau] + \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + \@3\ \[Eta]\ Sin[\[Chi]6] \
+ \[Eta]\ Cos[\[Chi]6] - \[Kappa]\ Cos[\[Psi]6] - \@3\ \[Kappa]\ \
Sin[\[Psi]6], \[Alpha] - \[Beta] + \[Epsilon]\ Sin[\[Sigma]] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \  - 2\ \[Eta]\ Cos[\[Chi]6] + 
            2\ \[Kappa]\ Cos[\[Psi]6], \[Alpha] + \[Beta] - \[Epsilon]\ Cos[\
\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - \@3\ \[Eta]\ Cos[\[Chi]6] \
- \[Eta]\ Sin[\[Chi]6] - \@3\ \[Kappa]\ Cos[\[Psi]6] - \[Kappa]\ \
Sin[\[Psi]6], \[Alpha] + \[Beta] - \[Epsilon]\ Cos[\[Sigma]] + \[Zeta]\ Cos[\
\[Tau] + \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + \@3\ \[Eta]\ Cos[\[Chi]6] \
- \[Eta]\ Sin[\[Chi]6] + \@3\ \[Kappa]\ Cos[\[Psi]6] - \[Kappa]\ \
Sin[\[Psi]6], \[Alpha] + \[Beta] - \[Epsilon]\ Cos[\[Sigma]] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \  + 
            2\ \[Eta]\ Sin[\[Chi]6]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \  + 
            2\ \[Kappa]\ Sin[\[Psi]6], \[Alpha] - \[Beta] - \[Epsilon]\ Sin[\
\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + \@3\ \[Eta]\ Sin[\[Chi]6] \
- \[Eta]\ Cos[\[Chi]6] + \[Kappa]\ Cos[\[Psi]6] - \@3\ \[Kappa]\ \
Sin[\[Psi]6], \[Alpha] - \[Beta] - \[Epsilon]\ Sin[\[Sigma]] + \[Zeta]\ Cos[\
\[Tau] + \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - \@3\ \[Eta]\ Sin[\[Chi]6] \
- \[Eta]\ Cos[\[Chi]6] + \[Kappa]\ Cos[\[Psi]6] + \@3\ \[Kappa]\ \
Sin[\[Psi]6], \[Alpha] - \[Beta] - \[Epsilon]\ Sin[\[Sigma]] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] - \
\[Omega]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 2\ \[Eta]\ \
Cos[\[Chi]6]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  - 
            2\ \[Kappa]\ Cos[\[Psi]6]}/12\)\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell["\<\
\tAs Q12 and D3C2 are noncommutative, the dual forms do not create angles \
that add on multiplication and cannot create true powers or roots.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 53. ",
  StyleBox["Q12 Cartesian & Polar-Dual interconversions.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \(id[Q12]; 
    Q12p = toPolar[{a, b, c, d, e, f, g, h, i, j, k, l}]\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \({a + b + c + d + e + f + g + h + i + j + k + l, \[IndentingNewLine]a + 
        b + c - d - e - f + g + h + i - j - k - 
        l, \[IndentingNewLine]\((a + b + c - g - h - i)\)\^2 + \((d + e + f - \
j - k - l)\)\^2, \[IndentingNewLine]ArcTan[a + b + c - g - h - i, 
        d + e + f - j - k - 
          l], \[IndentingNewLine]\((\((a - b + g - h)\)\^2 + \((b - c + h - \
i)\)\^2 + \((\(-a\) + c - g + i)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
        2\ a - b - c + 2\ g - h - 
          i, \(-\@3\)\ \((b - c + h - 
              i)\)], \[IndentingNewLine]\((\((d - e + j - k)\)\^2 + \((e - f \
+ k - l)\)\^2 + \((\(-d\) + f - j + l)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
        2\ d - e - f + 2\ j - k - 
          l, \(-\@3\)\ \((e - f + k - 
              l)\)], \[IndentingNewLine]\((\((a - b - g + h)\)\^2 + \((\(-a\) \
+ c + g - i)\)\^2 + \((b - c - h + i)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
        2\ a - b - c - 2\ g + h + 
          i, \(-\@3\)\ \((b - c - h + 
              i)\)], \[IndentingNewLine]\((\((d - e - j + k)\)\^2 + \((\(-d\) \
+ f + j - l)\)\^2 + \((e - f - k + l)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
        2\ d - e - f - 2\ j + k + 
          l, \(-\@3\)\ \((e - f - k + l)\)]}\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \)\(Q12\[Alpha]\[Beta]\[Epsilon]\[Sigma]\[Zeta]\[Tau]\
\[Lambda]\[Phi]\[Eta]\[Chi]\[CurlyKappa]\[Psi]\[IndentingNewLine]
    {\ \ \((\[Alpha] + \[Beta] + 2\ \[Epsilon]\ Cos[\[Sigma]] + 
            4\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  + 
            4\ \[Eta]\ Cos[\[Chi]])\), \[IndentingNewLine]\((\[Alpha] + \
\[Beta] + 2\ \[Epsilon]\ Cos[\[Sigma]] + 4\ \[Zeta]\ Cos[\[Tau] + \[Omega]] + 
            4\ \[Eta]\ Cos[\[Chi] + \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] + \[Beta] + 2\ \[Epsilon]\ Cos[\[Sigma]] + 
            4\ \[Zeta]\ Cos[\[Tau] - \[Omega]] + 
            4\ \[Eta]\ Cos[\[Chi] - \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] - \[Beta] + 2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \  + 
            4\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  + 
            4\ \[CurlyKappa]\ Cos[\[Psi]])\), \[IndentingNewLine]\((\[Alpha] \
- \[Beta] + 2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \  + 
            4\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + 
            4\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + 
            2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \  + 
            4\ \[Lambda]\ Cos[\[Phi] - \[Omega]] + 
            4\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] - 2\ \[Epsilon]\ Cos[\[Sigma]] + 
            4\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \ \ \ \  - 
            4\ \[Eta]\ Cos[\[Chi]])\), \[IndentingNewLine]\((\[Alpha] + \
\[Beta] - 2\ \[Epsilon]\ Cos[\[Sigma]] + 4\ \[Zeta]\ Cos[\[Tau] + \[Omega]] - 
            4\ \[Eta]\ Cos[\[Chi] + \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] + \[Beta] - 2\ \[Epsilon]\ Cos[\[Sigma]] + 
            4\ \[Zeta]\ Cos[\[Tau] - \[Omega]] - 
            4\ \[Eta]\ Cos[\[Chi] - \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] - \[Beta] - 2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \  + 
            4\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  - 
            4\ \[CurlyKappa]\ Cos[\[Psi]])\), \[IndentingNewLine]\((\[Alpha] \
- \[Beta] - 2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \  + 
            4\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - 
            4\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] - 
            2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \  + 
            4\ \[Lambda]\ Cos[\[Phi] - \[Omega]] - 
            4\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\)}/12\)\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[TextData[{
  "Example 54. ",
  StyleBox["General D3C2 orbit.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \(id[D3C2]; \ 
    D3C2p = toPolar[{a, b, c, d, e, f, g, h, i, j, k, l}]\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \({a + b + c + d + e + f + g + h + i + j + k + l, 
      a + b + c - d - e - f + g + h + i - j - k - l, \[IndentingNewLine]a + 
        b + c + d + e + f - g - h - i - j - k - l, 
      a + b + c - d - e - f - g - h - i + j + k + 
        l, \ \((\((a - b + g - h)\)\^2 + \((b - c + h - i)\)\^2 + \((\(-a\) + \
c - g + i)\)\^2)\)/2, \ \ ArcTan[
        2\ a - b - c + 2\ g - h - 
          i, \(-\@3\)\ \((b - c + h - 
              i)\)], \ \((\((\(-d\) + e - j + k)\)\^2 + \((d - f + j - \
l)\)\^2 + \((\(-e\) + f - k + l)\)\^2)\)/2, 
      ArcTan[\(-2\)\ d + e + f - 2\ j + k + 
          l, \(-\@3\)\ \((\(-e\) + f - k + 
              l)\)], \((\((a - b - g + h)\)\^2 + \((\(-a\) + c + g - i)\)\^2 \
+ \((b - c - h + i)\)\^2)\)/2, \ \ ArcTan[
        2\ a - b - c - 2\ g + h + 
          i, \(-\@3\)\ \((b - c - h + 
              i)\)], \ \((\((\(-d\) + e + j - k)\)\^2 + \((\(-e\) + f + k - \
l)\)\^2 + \((d - f - j + l)\)\^2)\)/2, 
      ArcTan[\(-2\)\ d + e + f + 2\ j - k - 
          l, \(-\@3\)\ \((\(-e\) + f + k - l)\)]}\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \)\(D3C2\[Alpha]\[Beta]\[Gamma]\[Delta]\[Zeta]\[Tau]\
\[Lambda]\[Phi]\[Eta]\[Chi]\[CurlyKappa]\[Psi]\[IndentingNewLine]
    {\ \ \((\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + 
            4\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  + 
            4\ \[Eta]\ Cos[\[Chi]])\), \[IndentingNewLine]\((\[Alpha] + \
\[Beta] + \[Gamma] + \[Delta] + 4\ \[Zeta]\ Cos[\[Tau] + \[Omega]] + 
            4\ \[Eta]\ Cos[\[Chi] + \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + 
            4\ \[Zeta]\ Cos[\[Tau] - \[Omega]] + 
            4\ \[Eta]\ Cos[\[Chi] - \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - 
            4\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - 
            4\ \[CurlyKappa]\ Cos[\[Psi]])\), \[IndentingNewLine]\((\[Alpha] \
- \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - 
            4\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - 
            4\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - 
            4\ \[Lambda]\ Cos[\[Phi] - \[Omega]] - 
            4\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + 
            4\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - 
            4\ \[Eta]\ Cos[\[Chi]])\), \[IndentingNewLine]\((\[Alpha] + \
\[Beta] - \[Gamma] - \[Delta] + 4\ \[Zeta]\ Cos[\[Tau] + \[Omega]] - 
            4\ \[Eta]\ Cos[\[Chi] + \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + 
            4\ \[Zeta]\ Cos[\[Tau] - \[Omega]] - 
            4\ \[Eta]\ Cos[\[Chi] - \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] - \[Beta] - \[Gamma] + \[Delta]\ \ \ \ \ \  - 
            4\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + 
            4\ \[CurlyKappa]\ Cos[\[Psi]])\), \[IndentingNewLine]\((\[Alpha] \
- \[Beta] - \[Gamma] + \[Delta]\ \ \ \ \ \  - 
            4\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + 
            4\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Gamma] + \[Delta]\ \ \ \ \ \  - 
            4\ \[Lambda]\ Cos[\[Phi] - \[Omega]] + 
            4\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\)}/12\)\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[TextData[{
  "\tDozal algebra has been investigated because of its potential as a \
particle paradigm, having just enough variety to describe fundamental \
particles. 39 functions have been found to be conserved by one or more of the \
five Dozal group multiplications. The following table shows (for the first \
23) those functions that are sizes (irreducible determinant factors) as \
\"i\",  conserved combinations of sizes by \"c\", those that are conserved on \
orbit multiplication by \"o\", and those that are only conserved when some \
\"radii\" are zero or negative by \"n\". (Negative radii can occur in ",
  StyleBox["Q12 & D3C2",
    FontSlant->"Italic"],
  " because they have sizes with 3 positive and 3 negative squared terms.) \
Preliminary speculations about the relation between functions and particle \
properties are also included. The names indicate the type of function:- o",
  StyleBox["n",
    FontSlant->"Italic"],
  " are linear functions, offsets in orbits. p",
  StyleBox["ab",
    FontSlant->"Italic"],
  "-s",
  StyleBox["ab",
    FontSlant->"Italic"],
  " have b terms each of order a. l3 is the cubic A4 size. l4",
  StyleBox["p",
    FontSlant->"Italic"],
  "-l4",
  StyleBox["s",
    FontSlant->"Italic"],
  " are quartic sizes."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
No. Name C3C4 Q12 C3K D3C2 A4 Property?
1   o1   i    i   i   i    i   
2   o2   i    i   i   i       Charge
3   o3            i   i       Hypercharge
4   o4            i   i       
5  l22a  i
6  l22b  i
7   p22  o    o   o   o       
8   q22  i    i   o   o       Leptons
9   r22  c    c   c   c       
10  s22           c   c    i   
11  p23  i    n   i   n       u Quarks
12  q23  i    n   i   n       d Quarks    
13  r23  o    n   i   n       
14  s23  o    n   i   n       
15  q24  o    o   o   o       metric(0,4)
16  p24           o   o       Minkowski(1,3)
17  p26       i       i       
18  q26  o    o   n   i       s Quarks
19  r26  o    n   o   o       c Quarks
20  s26  o    i   o   o
21  l3                     i  Discriminant
22  l4
23  l4p  c    n   c   n
24  l4q  o    n   c   n
25  l4r       n       n
26  l4s  c    n   o   n       Gravity??\
\>", "Text",
  PageWidth->WindowWidth,
  FontFamily->"Courier New"],

Cell[TextData[{
  "This topic needs to be explored in more detail. The implications of \
remainders being split-off have yet to be explored. ",
  StyleBox["GroupLoopTest.nb",
    FontSlant->"Italic"],
  " includes extensive tabulations of functions that are conserved in various \
Dozal operations; I hope to correlate them with particle properties"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["Conservation, general vector.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
Arbitrary vectors (with no sizes zero) are multiplied using the Dozal hoops, \
and conservation is recorded.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(A = { .2, 1. , 1.3,  .7,  .4,  .6,  .5,  .9,  .8, 0,  .1,  .2}; 
    B = { .3, 2. , 1. , 0. , 4,  .66,  .55,  .7,  .8,  .9, 1.1, 1.2}; 
    AB = hoopTimes[A, B, "\<C3C4\>"];\), "\[IndentingNewLine]", 
    \(res = 
      Transpose {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
          Chop[sab - sasb, 10^\(-8\)], Range[26]}; cs = {"\<C3C4\>"}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, i]], {i, 
        39}];\), "\[IndentingNewLine]", 
    \(res = 
      Chop[{sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
          Chop[sab - sasb, 10^\(-8\)]}]; AppendTo[cs, "\<\nNames\>"]; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"C3C4", 1, 2, 5, 6, 8, 9, 11, 12, 22, 25, 32, "\nNames", "o1", "o2", 
      "l22a", "l22b", "q22", "r22", "p23", "q23", "l4p", "l4s", 
      "L4a6"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(AB = hoopTimes[A, B, "\<Q12\>"];\)\), "\[IndentingNewLine]", 
    \(res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[26]}; cs = {"\<Q12\>"}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, i]], {i, 
        39}];\), "\[IndentingNewLine]", 
    \(res = 
      Chop[{sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
          Chop[sab - sasb, 10^\(-8\)]}]; AppendTo[cs, "\<\nNames\>"]; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Q12", 1, 2, 8, 9, 17, 20, "\nNames", "o1", "o2", "q22", "r22", "p26", 
      "s26"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(id[C3K]; AB = hoopTimes[A, B]; 
    res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[26]}; cs = {"\<C3K\>"}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, i]], {i, 
        39}];\), "\[IndentingNewLine]", 
    \(res = 
      Chop[{sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
          Chop[sab - sasb, 10^\(-8\)]}]; AppendTo[cs, "\<\nNames\>"]; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"C3K", 1, 2, 3, 4, 9, 10, 11, 12, 13, 14, 22, 23, 32, 33, "\nNames", 
      "o1", "o2", "o3", "o4", "r22", "s22", "p23", "q23", "r23", "s23", 
      "l4p", "l4q", "L4a6", "L4b6"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(AB = hoopTimes[A, B, "\<D3C2\>"];\)\), "\[IndentingNewLine]", 
    \(res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[26]}; cs = {"\<D3C2\>"}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, i]], {i, 
        39}];\), "\[IndentingNewLine]", 
    \(res = 
      Chop[{sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
          Chop[sab - sasb, 10^\(-8\)]}]; AppendTo[cs, "\<\nNames\>"]; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"D3C2", 1, 2, 3, 4, 9, 10, 17, 18, "\nNames", "o1", "o2", "o3", "o4", 
      "r22", "s22", "p26", "q26"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(AB = hoopTimes[A, B, "\<A4\>"];\)\), "\[IndentingNewLine]", 
    \(res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[26]}; cs = {"\<A4\>"}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, i]], {i, 
        39}];\), "\[IndentingNewLine]", 
    \(res = 
      Chop[{sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
          Chop[sab - sasb, 10^\(-8\)]}]; AppendTo[cs, "\<\nNames\>"]; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A4", 1, 11, 21, "\nNames", "o1", "p23", "l3"}\)], "Output"]
}, Open  ]],

Cell["Summary.", "Text",
  PageWidth->WindowWidth],

Cell["\<\
C3C4 conserves o1, o2, l22a, l22b, q22, r23,       p23, q23,        l4p, l4s, \
L4a6
Q12 conserves   o1, o2,                 q22, r22,            p26,s26
C3K conserves  o1, o2, o3, o4,              r22, s22, p23, q23,  r23, s23, \
l4p, l4q, L4a6,L4b6
D3C2 conserves o1, o2, o3, o4,             r22, s22,     p26,   q26, 
A4 conserves     o1,                                               p23,       \
     l3.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conservation, unitary vector, equal angles.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
Now look at unitary vectors (so A4 must be omitted) and sh12 by inserting the \
names in the hidden cell:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(cs = {id["\<C3C4\>"], "\<conserves\>"}; 
    A = Chop[toVector[{3. , \(-1. \)/3, 4. , 0.1, 1. /4, 0.1, 8. /3, 0.1, 
            3. /5. , 0.1, 5. /8, 0.1}]];\), "\[IndentingNewLine]", 
    \(\(B = 
        Chop[toVector[{2. ,  .5, 3. /5, 0.2, 5/3. , 0.2, 4/7, 0.2, 7/5. , 
              0.2, 4/5, 0.2}]];\)\), "\[IndentingNewLine]", 
    \(\(AB = hoopTimes[A, B];\)\), "\[IndentingNewLine]", 
    \(\(\(res = 
      Chop[Transpose[{sa = sh12[A], sb = sh12[B], sab = sh12[AB], 
            sasb = sa\ sb, Chop[sab - sasb, 10^\(-8\)], 
            Range[39]}]]\)\(;\)\(Do[
      If[res[\([i, 5]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 
        39}]\)\(;\)\(cs\)\( (*\(\(Transpose[Take[res, 13]] // 
            tf\[IndentingNewLine]Transpose[Take[res, {14, 26}]]\) // 
          tf\[IndentingNewLine]Transpose[Drop[res, 26]]\) // 
        tf*) \)\)\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"C3C4", "conserves", "o1", "o2", "l22a", "l22b", "q22", "r22", "p23", 
      "q23", "p26", "q26", "l4p", "l4s", "L4a3", "L4b3", "L4c3", "L4d3", 
      "L4a6"}\)], "Output"]
}, Open  ]],

Cell["Summary", "Text"],

Cell[BoxData[{
    \({"C3C4", "o1", "o2", "l22a", "l22b", "q22", "r22", "p23", "q23", "p26", 
      "q26", "l4p", "l4s", "L4a3", "L4b3", "L4c3", "L4d3", "L4a6"}\), "\n", 
    \({"Q12", "o1", "o2", "q22", "r22", "p26", "s26"}\), "\n", 
    \({"C3K", "o1", "o2", "o3", "o4", "r22", "s22", "p23", "q23", "r23", 
      "s23", "p26", "q26", "l4p", "l4q", "L4a3", "L4b3", "L4c3", "L4d3", 
      "L4a6", "L4b6", "L4c6"}\), "\n", 
    \({"D3C2", "o1", "o2", "o3", "o4", "r22", "s22", "p26", 
      "q26"}\)}], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conservation, unitary vector, no angles zero.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["Random angle:-", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[{
    \(cs = {id[D3C2], "\<random angles\>"}; 
    A = Chop[toVector[{3. , \(-1. \)/3, 4. ,  .1, 1. /4,  .2, 8. /3,  .3, 
            3. /5. , 0.4, 5. /8,  .5}]];\), "\[IndentingNewLine]", 
    \(B = 
      Chop[toVector[{\(-2. \),  .5, 3. /2,  .12, 2/3. ,  .34, 4/5,  .56, 
            4/5. ,  .78, 25/16,  .11}]]; AB = hoopTimes[A, B]; 
    res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[39]}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth],

Cell["Summary", "Text"],

Cell[BoxData[{
    \({"C3C4", "random angles", "o1", "o2", "l22a", "l22b", "q22", "r22", 
      "p23", "q23", "l4p", "l4s", "L4a6"}\), "\n", 
    \({"Q12", "random angles", "o1", "o2", "q22", "r22", "p26", 
      "s26"}\), "\n", 
    \({"C3C4", "random angles", "o1", "o2", "l22a", "l22b", "q22", "r22", 
      "p23", "q23", "l4p", "l4s", "L4a6"}\), "\n", 
    \({"D3C2", "random angles", "o1", "o2", "o3", "o4", "r22", "s22", "p26", 
      "q26"}\)}], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell["Equal angles (except first) :-", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(cs = {id[C3C4], "\< Equal angles\>"}; 
    A = Chop[toVector[{3. , \(-1. \)/3, 4. ,  .1, 1. /4,  .2, 8. /3,  .2, 
            3. /5. , 0.2, 5. /8,  .2}]];\), "\[IndentingNewLine]", 
    \(B = 
      Chop[toVector[{\(-2. \),  .5, 3. /2,  .1, 2/3. ,  .1, 4/5, 0.1, 4/5. , 
            0.1, 25/16, 0.1}]]; AB = hoopTimes[A, B]; 
    res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[39]}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"C3C4", " Equal angles", "o1", "o2", "l22a", "l22b", "q22", "r22", 
      "p23", "q23", "p26", "q26", "l4p", "l4s", "L4a3", "L4b3", "L4c3", 
      "L4d3", "L4a6"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(cs = {id[Q12], "\< Equal angles\>"}; 
    A = Chop[toVector[{3. , \(-1. \)/3, 4. ,  .1, 1. /4,  .2, 8. /3,  .2, 
            3. /5. , 0.2, 5. /8,  .2}]];\), "\[IndentingNewLine]", 
    \(B = 
      Chop[toVector[{\(-2. \),  .5, 3. /2,  .1, 2/3. ,  .1, 4/5, 0.1, 4/5. , 
            0.1, 25/16, 0.1}]]; AB = hoopTimes[A, B]; 
    res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[39]}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"Q12", " Equal angles", "o1", "o2", "q22", "r22", "p26", 
      "s26"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(cs = {id[C3K], "\<Equal angles\>"}; 
    A = Chop[toVector[{3. , \(-1. \)/3, 4. ,  .1, 1. /4,  .2, 8. /3,  .2, 
            3. /5. , 0.2, 5. /8,  .2}]];\), "\[IndentingNewLine]", 
    \(B = 
      Chop[toVector[{\(-2. \),  .5, 3. /2, 0, 2/3. ,  .1, 4/5, 0.1, 4/5. , 
            0.1, 25/16, 0.1}]]; AB = hoopTimes[A, B]; 
    res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[39]}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"C3K", "Equal angles", "o1", "o2", "o3", "o4", "r22", "s22", "p23", 
      "q23", "r23", "s23", "p26", "q26", "l4p", "l4q", "L4a3", "L4b3", 
      "L4c3", "L4d3", "L4a6", "L4b6", "L4c6"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(cs = {id[D3C2], "\<Equal angles\>"}; 
    A = Chop[toVector[{3. , \(-1. \)/3, 4. ,  .1, 1. /4,  .2, 8. /3,  .2, 
            3. /5. , 0.2, 5. /8,  .2}]];\), "\[IndentingNewLine]", 
    \(B = 
      Chop[toVector[{\(-2. \),  .5, 3. /2, 0, 2/3. ,  .1, 4/5, 0.1, 4/5. , 
            0.1, 25/16, 0.1}]]; AB = hoopTimes[A, B]; 
    res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[39]}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"D3C2", "Equal angles", "o1", "o2", "o3", "o4", "r22", "s22", "p26", 
      "q26"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(id[Q12]; 
    A = Chop[toVector[{3. , \(-1. \)/3, 4. ,  .0, 1. /4,  .0, 8. /3,  .0, 
            3. /5. , 0.0, 5. /8,  .0}]];\), "\[IndentingNewLine]", 
    \(B = 
      Chop[toVector[{\(-2. \),  .5, 3. /2,  .1, 2/3. ,  .0, 4/5, 0.0, 4/5. , 
            0.0, 25/16, 0.0}]]; AB = hoopTimes[A, B]; 
    res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[26]}; 
    cs = {"\<Q12uni,zeroangle\>"}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, i]], {i, 
        26}];\), "\[IndentingNewLine]", 
    \(res = 
      Chop[{sa = dozalcons[A], sb = dozalcons[B], sab = dozalcons[AB], 
          sasb = sa\ sb, Chop[sab - sasb, 10^\(-8\)]}]; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, dname[\([i]\)]]], {i, 
        16}]; cs\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Q12uni,zerangle", 1, 2, 3, 4, 5, 6, 8, 9, 10, 11, 12, 17, 20, 22, 23, 
      26, "abef", "agek", "L4a3", "L4b3", "L4a6"}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["zero angles:-", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(cs = {id[C3C4], "\< zero angles\>"}; 
    A = Chop[toVector[{3. , \(-1. \)/3, 1. ,  .2, 1. /3,  .3, 8. /3,  .3, 
            3. /5. ,  .3, 5. /8,  .3}]];\), "\[IndentingNewLine]", 
    \(B = 
      Chop[toVector[{\(-2. \),  .5, 3. /2,  .1, 2/3. ,  .1, 4/5, 0.1, 4/5. , 
            0.1, 25/16, 0.1}]]; AB = hoopTimes[A, B]; 
    res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[39]}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"C3C4", " zero angles", "o1", "o2", "l22a", "l22b", "q22", "r22", 
      "p23", "q23", "p26", "q26", "l4p", "l4s", "L4a3", "L4b3", "L4c3", 
      "L4d3", "L4a6"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(cs = {id[Q12], "\< zero angles\>"}; 
    A = Chop[toVector[{3. , \(-1. \)/3, 1. ,  .2, 1. /3,  .3, 8. /3,  .3, 
            3. /5. ,  .3, 5. /8,  .3}]];\), "\[IndentingNewLine]", 
    \(B = 
      Chop[toVector[{\(-2. \),  .5, 3. /2,  .1, 2/3. ,  .1, 4/5, 0.1, 4/5. , 
            0.1, 25/16, 0.1}]]; AB = hoopTimes[A, B]; 
    res = {sa = sh12[A], sb = sh12[B], sab = sh12[AB], sasb = sa\ sb, 
        Chop[sab - sasb, 10^\(-8\)], Range[39]}; 
    Do[If[res[\([5, i]\)] \[Equal] 0, AppendTo[cs, ds[\([i]\)]]], {i, 39}]; 
    cs\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Q12", " zero angles", "o1", "o2", "q22", "r22", "p26", 
      "s26"}\)], "Output"]
}, Open  ]],

Cell["Summary", "Text"],

Cell[BoxData[
    \({"C3C4", " zero angles", "o1", "o2", "l22a", "l22b", "q22", "r22", 
      "p23", "q23", "p26", "q26", "l4p", "l4s", "L4a3", "L4b3", "L4c3", 
      "L4d3", "L4a6"}\)], "Output"],

Cell[BoxData[
    \({"Q12", " zero angles", "o1", "o2", "q22", "r22", "p26", 
      "s26"}\)], "Output"],

Cell[BoxData[
    \({"D3C2", "abef", "agek", "L4a3", "L4b3", "L4c3", "L4d3", "L4a6", 
      "L4b6", "L4c6"}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.3. Unital Subalgebras, Chirality, Polarization,", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tConstraining any set of sizes to multiply to 1 (ignoring zero sizes) gives \
a constrained sub-algebra. Signed-tables are sub-algebras of loops, for the \
introduction of negation (via equivalence relations) constrains one or more \
of the loop sizes to be zero. The offsets and squared radii of polar algebras \
are sizes in the algebra. Setting some offsets and squared radii to 0 gives \
subalgebras that are even more constrained, being restricted to a subspace of \
the full algebra (which is already a subspace of the parent loop). Setting \
the product of the remaining sizes to 1 gives \"unital\" subalgebras, in \
which the determinant is 1 (after factoring-out the irrelevant zeroes). \
Products in these algebras remain within the constraints. The expressions \
C3Kv & C3Kp for vector-polar interconversions in the C3K hoop were set up in \
section 10.1. They simplify to unital algebras when the offsets and radii are \
constrained to be 1:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 52. ",
  StyleBox["C3K Orbits are Chiral.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \(TraditionalForm\`C3KOrbit\  = \ 
      Simplify[C3Kv /. {o1 \[Rule] 1, o2 \[Rule] 1, o3 \[Rule] 1, 
            o4 \[Rule] 1, p \[Rule] 1, q \[Rule] 1, r \[Rule] 1, s \[Rule] 1, 
            2\ \[Pi]/3 \[Rule] \[Omega], 
            4  \[Pi]/3 \[Rule] 2  \[Omega]}]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({\ \((\ \ \ \ \ \ \ \ \ Cos[pa] + \ \ \ \ \ \ \ \ \ Cos[
              qa] + \ \ \ \ \ \ \ \ \ Cos[ra] + \ \ \ \ \ \ \ \ \ Cos[sa] + 
            2)\), \ \((Cos[\ \ \ \[Omega] + pa] + Cos[\ \ \ \[Omega] + qa] + 
            Cos[\ \ \ \[Omega] + ra] + Cos[\ \ \ \[Omega] + sa] + 
            2)\), \ \((Cos[2  \[Omega] + pa] + Cos[2  \[Omega] + qa] + 
            Cos[2  \[Omega] + ra] + Cos[2  \[Omega] + sa] + 
            2)\), \ \((\ \ \ \ \ \ \ \ Cos[pa] - \ \ \ \ \ \ \ \ \ Cos[
              qa] + \ \ \ \ \ \ \ \ \ Cos[ra] - \ \ \ \ Cos[
              sa])\), \ \((Cos[\ \ \ \[Omega] + pa] - 
            Cos[\ \ \ \[Omega] + qa] + Cos[\ \ \ \[Omega] + ra] - 
            Cos[\ \ \ \[Omega] + sa])\), \ \((Cos[2  \[Omega] + pa] - 
            Cos[2  \[Omega] + qa] + Cos[2  \[Omega] + ra] - 
            Cos[2  \[Omega] + sa])\), \((\ \ \ \ \ \ \ \ Cos[
              pa] + \ \ \ \ \ \ \ \ \ Cos[qa] - \ \ \ \ \ \ \ \ Cos[
              ra] - \ \ \ \ \ \ \ \ \ Cos[
              sa])\), \ \((Cos[\ \ \ \[Omega] + pa] + 
            Cos[\ \ \ \[Omega] + qa] - Cos[\ \ \[Omega] + ra] - 
            Cos[\ \ \ \[Omega] + sa])\), \ \((Cos[2  \[Omega] + pa] + 
            Cos[2  \[Omega] + qa] - Cos[2  \[Omega] + ra] - 
            Cos[2  \[Omega] + sa])\), \ \((\ \ \ \ \ \ \ \ Cos[
              pa] - \ \ \ \ \ \ \ \ \ Cos[qa] - \ \ \ \ \ \ \ \ \ Cos[
              ra] + \ \ \ \ \ \ \ \ \ Cos[
              sa])\), \ \((Cos[\ \ \ \[Omega] + pa] - 
            Cos[\ \ \ \[Omega] + qa] - Cos[\ \ \ \[Omega] + ra] + 
            Cos[\ \ \ \[Omega] + sa])\), \ \((Cos[2  \[Omega] + pa] - 
            Cos[2  \[Omega] + qa] - Cos[2  \[Omega] + ra] + 
            Cos[2  \[Omega] + sa])\)}/6\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9,
  FontWeight->"Plain"],

Cell[TextData[{
  "\tAngle ",
  StyleBox["pa",
    FontSlant->"Italic"],
  " contributes four sets of three-phase sinusoids in a clockwise \
arrangement, Cos[pa], Cos[2 \[Pi]/3+pa], Cos[4 \[Pi]/3+pa]. Angle ",
  StyleBox["qa",
    FontSlant->"Italic"],
  " gives two sets of six-phase sinusoids, Cos[qa], Cos[2 \[Pi]/3+qa], Cos[4 \
\[Pi]/3+qa], -Cos[qa], -Cos[2 \[Pi]/3+qa], -Cos[4 \[Pi]/3+qa]. Angles ",
  StyleBox["ra, sa",
    FontSlant->"Italic"],
  " also give two sets of six-phase sinusoids, but with different sequences. \
These are all chiral; negating the angles reverses the chirality.\n\tIf any \
two angles are linked, e.g. by putting ",
  StyleBox["qa=pa+\[Phi]",
    FontSlant->"Italic"],
  ", they form polarized phases:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 53. ",
  StyleBox["C3K Orbits can exhibit Polarizations.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[C3KOrbit /. {qa -> pa, sa -> ra}]\)], "Input",
  PageWidth->WindowWidth,
  FormatType->TraditionalForm],

Cell[BoxData[
    \({1\/3\ \((1 + Cos[pa] + Cos[ra])\), 
      1\/3\ \((1 + Cos[pa + \(2\ \[Pi]\)\/3] + Cos[\(2\ \[Pi]\)\/3 + ra])\), 
      1\/3\ \((1 + Cos[pa + \(4\ \[Pi]\)\/3] + Cos[\(4\ \[Pi]\)\/3 + ra])\), 
      0, 0, 0, 1\/3\ \((Cos[pa] - Cos[ra])\), 
      1\/3\ \((Cos[pa + \(2\ \[Pi]\)\/3] - Cos[\(2\ \[Pi]\)\/3 + ra])\), 
      1\/3\ \((Cos[pa + \(4\ \[Pi]\)\/3] - Cos[\(4\ \[Pi]\)\/3 + ra])\), 0, 
      0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Closed]],

Cell[BoxData[
    \({\ \((1 + Cos[pa] + Cos[ra])\), \ \((1 + Cos[pa + 2\ \[Pi]/3] + 
            Cos[2\ \[Pi]/3 + ra])\), \ \((1 + Cos[pa + 4\ \[Pi]/3] + 
            Cos[4\ \[Pi]/3 + ra])\), 0, 0, 
        0, \ \((Cos[pa] - Cos[ra])\), \ \((Cos[pa + 2\ \[Pi]/3] - 
            Cos[2\ \[Pi]/3 + ra])\), \ \((Cos[pa + 4\ \[Pi]/3] - 
            Cos[4\ \[Pi]/3 + ra])\), 0, 0, 0}/3\)], "Input",
  PageWidth->WindowWidth,
  FontWeight->"Plain"],

Cell[TextData[{
  "\tAnother unital possibility is that two or more sizes are in a reciprocal \
relationship, with their product constrained to be 1. If two squared radii \
are reciprocal (one very small, the other very large), the result could be \
the so-called \"law of large numbers\", the observation that some large and \
small characteristics of the universe have magnitudes that are \
(approximately) powers of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^40\)]],
  ". This is illustrated in Example 54, by making ",
  StyleBox["rr.ss",
    FontSlant->"Italic"],
  "=1, and writing them as r & R. All the offsets have been set to 1 and ",
  StyleBox["qa=pa",
    FontSlant->"Italic"],
  " for simplicity. The C3K orbits have phases with amplitudes \
(p\[PlusMinus]q)/6, R/6, and r/6. If r is very small & R is very large, the \
other terms resemble \"curled-up\" Kaluza-Klein terms and the R terms \
resemble a space curvature, whilst r is curled much more tightly than the \
Kaluza-Klein terms. Also the amplitudes p+q and p-q can give six phases with \
very small amplitudes if p-q is small. I speculate that this relates to \
point-like particles. "
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 54. ",
  StyleBox["C3K Orbits with reciprocal Radii. \"Law of Large Numbers\"?",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(C3KR = 
      Simplify[C3KOrbit\[IndentingNewLine] /. {qa -> pa, o1 \[Rule] 1, 
              o2 \[Rule] 1, o3 \[Rule] 1, o4 \[Rule] 1}] /. {\@pp \[Rule] 
            p, \@qq \[Rule] q, \@rr \[Rule] R, \@ss \[Rule] r}\)], "Input",
  PageWidth->WindowWidth,
  FormatType->TraditionalForm],

Cell[BoxData[
    \({1\/6\ \((2 + 2\ Cos[pa] + Cos[ra] + Cos[sa])\), 
      1\/6\ \((2 + 2\ Cos[pa + \(2\ \[Pi]\)\/3] + Cos[\(2\ \[Pi]\)\/3 + ra] + 
            Cos[\(2\ \[Pi]\)\/3 + sa])\), 
      1\/6\ \((2 + 2\ Cos[pa + \(4\ \[Pi]\)\/3] + Cos[\(4\ \[Pi]\)\/3 + ra] + 
            Cos[\(4\ \[Pi]\)\/3 + sa])\), 1\/6\ \((Cos[ra] - Cos[sa])\), 
      1\/6\ \((Cos[\(2\ \[Pi]\)\/3 + ra] - Cos[\(2\ \[Pi]\)\/3 + sa])\), 
      1\/6\ \((Cos[\(4\ \[Pi]\)\/3 + ra] - Cos[\(4\ \[Pi]\)\/3 + sa])\), 
      1\/6\ \((2\ Cos[pa] - Cos[ra] - Cos[sa])\), 
      1\/6\ \((2\ Cos[pa + \(2\ \[Pi]\)\/3] - Cos[\(2\ \[Pi]\)\/3 + ra] - 
            Cos[\(2\ \[Pi]\)\/3 + sa])\), 
      1\/6\ \((2\ Cos[pa + \(4\ \[Pi]\)\/3] - Cos[\(4\ \[Pi]\)\/3 + ra] - 
            Cos[\(4\ \[Pi]\)\/3 + sa])\), 1\/6\ \((\(-Cos[ra]\) + Cos[sa])\), 
      1\/6\ \((\(-Cos[\(2\ \[Pi]\)\/3 + ra]\) + Cos[\(2\ \[Pi]\)\/3 + sa])\), 
      1\/6\ \((\(-Cos[\(4\ \[Pi]\)\/3 + ra]\) + 
            Cos[\(4\ \[Pi]\)\/3 + sa])\)}\)], "Output",
  PageWidth->WindowWidth]
}, Closed]],

Cell[BoxData[
    \({\ \ \((\((p + q)\)\ Cos[pa]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
            R\ Cos[ra]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
            r\ Cos[sa]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
            2)\), \ \((\((p + q)\)\ Cos[pa + 2\ \[Pi]/3] + 
            R\ Cos[2\ \[Pi]/3 + ra] + r\ Cos[2\ \[Pi]/3 + sa] + 
            2)\), \ \((\((p + q)\)\ Cos[pa + 4\ \[Pi]/3] + 
            R\ Cos[4\ \[Pi]/3 + ra] + r\ Cos[4\ \[Pi]/3 + sa] + 
            2)\), \ \((\((p - q)\)\ Cos[pa]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
            R\ Cos[ra]\ \ \ \ \ \ \ \ \ \ \ \ \ \  - \ 
            r\ Cos[sa])\), \ \((\((p - q)\)\ Cos[pa + 2\ \[Pi]/3] + 
            R\ Cos[2\ \[Pi]/3 + ra] - 
            r\ Cos[2\ \[Pi]/3 + sa])\), \ \((\((p - q)\)\ Cos[
                pa + 4\ \[Pi]/3] + R\ Cos[4\ \[Pi]/3 + ra] - 
            r\ Cos[4\ \[Pi]/3 + sa])\), \ \((\((p + q)\)\ Cos[
                pa]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  - 
            R\ Cos[ra]\ \ \ \ \ \ \ \ \ \ \ \ \ \  - \ 
            r\ Cos[sa])\), \ \((\((p + q)\)\ Cos[pa + 2\ \[Pi]/3] - 
            R\ Cos[2\ \[Pi]/3 + ra] - 
            r\ Cos[2\ \[Pi]/3 + sa])\), \ \((\((p + q)\)\ Cos[
                pa + 4\ \[Pi]/3] - R\ Cos[4\ \[Pi]/3 + ra] - 
            r\ Cos[4\ \[Pi]/3 + sa])\), \ \((\((p - q)\)\ Cos[
                pa]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  - 
            R\ Cos[ra]\ \ \ \ \ \ \ \ \ \ \ \ \ \  + \ 
            r\ Cos[sa])\), \ \((\((p - q)\)\ Cos[pa + 2\ \[Pi]/3] - 
            R\ Cos[2\ \[Pi]/3 + ra] + 
            r\ Cos[2\ \[Pi]/3 + sa])\), \((\((p - q)\)\ Cos[
                pa + 4\ \[Pi]/3] - R\ Cos[4\ \[Pi]/3 + ra] + 
            r\ Cos[4\ \[Pi]/3 + sa])\)}/6\)], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontSize->9,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.4. Hoops & Anti-Hermitian Matrix Multiplication.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tHoops multiplication is not matrix multiplication, but hoop products can \
be obtained by matrix multiplication of the matrices ",
  StyleBox["lmatrix & rmatrix. ",
    FontSlant->"Italic"],
  "These are the matrix equivalents of the corresponding hoop; the \
multiplication of two vectors can be effected by mapping one vector onto ",
  StyleBox["lmatrix ",
    FontSlant->"Italic"],
  "or",
  StyleBox[" rmatrix",
    FontSlant->"Italic"],
  " and then dot multiplying the result by the second vector. (Hoop \
multiplication is conceptually simpler!) This is demonstrated with the signed \
table C8r :-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example 55. ",
  StyleBox["Hoop multiplication by mapping vecs onto ",
    FontWeight->"Plain"],
  StyleBox["lmatrix",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" or ",
    FontWeight->"Plain"],
  StyleBox["rmatrix",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[".",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \({C8r = ts[ca[8, 5]]; "\<C8r =   \>", C8r // tf, "\<\nlmatrix =\>", 
      l4 = lmatrix[C8r] // tf, "\<\nrmatrix =\>", 
      r4 = rmatrix[C8r] // tf, "\<\nC8r product of A\>", 
      A = {6. , 1, 2, 0}, "\< and B\>", B = {5. , 0. , 3, 7}, "\<\ngives\>", 
      AB\  = hoopTimes[A, 
          B, "\<C8r\>"], \[IndentingNewLine]"\<\nUsing the lmatrix dot \
product gives the same \nA=\>", la4 = gmap[l4, B]; la4 // tf, 
      la4 . A, \[IndentingNewLine]"\<\nSo does the rmatrix dot product\>", 
      ra4 = gmap[r4, A]; "\<\nB.\>", ra4 // tf, "\<=\>", 
      B . ra4, "\<\nPlease ignore the extraneous commas!\>"}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"C8r =   \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", \(-3\), "4", "1"},
                  {"3", "4", \(-1\), \(-2\)},
                  {"4", "1", \(-2\), "3"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nlmatrix =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "4", \(-3\), "2"},
                  {"2", "1", \(-4\), \(-3\)},
                  {"3", \(-2\), "1", "4"},
                  {"4", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nrmatrix =\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"4", "1", \(-2\), "3"},
                  {\(-3\), \(-4\), "1", "2"},
                  {"2", \(-3\), "4", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nC8r product of A\"\>", 
        ",", \({6.`, 1, 2, 0}\), ",", "\<\" and B\"\>", 
        ",", \({5.`, 0.`, 3, 7}\), ",", "\<\"\\ngives\"\>", 
        ",", \({31.`, \(-9.`\), 28.`, 45.`}\), 
        ",", "\<\"\\nUsing the lmatrix dot product gives the same \\nA=\"\>", 
        ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"5.`", "7", \(-3\), "0.`"},
                  {"0.`", "5.`", \(-7\), \(-3\)},
                  {"3", "0.`", "5.`", "7"},
                  {"7", "3", "0.`", "5.`"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", \({31.`, \(-9.`\), 28.`, 45.`}\), 
        ",", "\<\"\\nSo does the rmatrix dot product\"\>", 
        ",", "\<\"\\nB.\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"6.`", "1", "2", "0"},
                  {"0", "6.`", \(-1\), "2"},
                  {\(-2\), "0", "6.`", "1"},
                  {"1", \(-2\), "0", "6.`"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"=\"\>", 
        ",", \({31.`, \(-9.`\), 28.`, 45.`}\), 
        ",", "\<\"\\nPlease ignore the extraneous commas!\"\>"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is true for all hoops, by the definition of ",
  StyleBox["rmatrix & lmatrix",
    FontSlant->"Italic"],
  ".  The matrices are anti-hermitian, insofar as their off-diagonal \
transposed elements are mutual inverses in the hoop table. Consequently, Hoop \
multiplication is always anti-hermitian. "
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.5. Projection & ejection of wavicles.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "If Dozal emulates physics, the stable particles (neutrinos, electron, \
positron, proton, antiproton) must be minimal orbits - they cannot eject \
something to give a simpler system. Electrons and protons have mass & charge, \
but are produced by decay of neutral more-massive particles and from \
uncharged massless photon pairs. This constrains the search space in the \
Dozal conserved functions. The factorization of L4 ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["x",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  "-3",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["y",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  " = (x+",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "y)(x-",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "y)  (which is not found by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ") could be relevant, with (x-",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "y)\[ShortRightArrow]\[HBar]?\nMore work (and inspiration?) needed."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.6. The Lepton family.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
Three \"electrons\" e, \[Mu], \[Tau] and their anti-particles. They have \
charge, half-spin, and mass.
Three \"neutrinos\" and their anti-particles. They have half-spin, and very \
small mass.
All are involved in weak-force interactions and are unaffected by the strong \
force. They do not have quark structures, so C3K & D3C2 are not relevant, as \
they only have terplex orbits. The relevant orbit is based on \[Epsilon] Cos[\
\[Sigma]], with 3 repetitions of the 4 phases. These are common to C3C4 and \
Q12, but are absent from C3K and D3C2, where they are replaced by \[Gamma] & \
\[Delta], which combine to give a hyperbolic orbit. The \[Alpha] & \[Beta] \
terms should relate to the neutrinos and the 3 generations. If \[Alpha] is \
charge, \[Alpha]=0 defines the electron neutrino and \[Beta]=\[PlusMinus]1 \
must relate to muons and tauons. \
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.7. The Hadron family.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tI conjecture that Quarks are different phases of a multiphase system with \
12-fold (Dozal) symmetry. Three, six, and 12-phase wave systems occur in the \
C3C4 and C3K polar duals. \
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["11. Speculations about Mass & Gravity.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tHoop algebras give tantalizing suggestions about the re-interpretation \
of mathematical physics, which (at 77) I cannot expect to explore:-\n  a. \
Hoop multiplication with remainders has analogies with particle interactions, \
and addition/subtraction (which conserves linear sizes) with particle \
combination and decay. \n  b. Time enters orbits as a separate \"direction\" \
parameter that cannot fold to a dimension. It may enter a \"mixed metric\" \
via a \"city-blocks\" contribution, whilst spatial dimensions remain \
pythagorean; ",
  StyleBox["interval",
    FontSlant->"Italic"],
  " = ",
  StyleBox["(t-",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)],
    FontSlant->"Italic"],
  StyleBox[") - Sqrt[",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"x", "-", 
              FormBox[\(x\_0\),
                "TraditionalForm"]}], ")"}], "2"], TraditionalForm]],
    FontSlant->"Italic"],
  StyleBox[" + ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"y", "-", 
              FormBox[\(y\_0\),
                "TraditionalForm"]}], ")"}], "2"], TraditionalForm]],
    FontSlant->"Italic"],
  StyleBox["+ ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"z", "-", 
              FormBox[\(z\_0\),
                "TraditionalForm"]}], ")"}], "2"], TraditionalForm]],
    FontSlant->"Italic"],
  StyleBox["]",
    FontSlant->"Italic"],
  ". The L4 metric (Section 10.6) (",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["a",
                        FontSlant->"Plain"], "-", 
                      StyleBox["b",
                        FontSlant->"Plain"]}], ")"}], "2"],
                "TraditionalForm"], "+", 
              FormBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["b",
                        FontSlant->"Plain"], "-", 
                      StyleBox["c",
                        FontSlant->"Plain"]}], ")"}], "2"],
                "TraditionalForm"], "+", 
              FormBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["c",
                        FontSlant->"Plain"], "-", 
                      StyleBox["a",
                        FontSlant->"Plain"]}], ")"}], "2"],
                "TraditionalForm"], "+", 
              FormBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["d",
                        FontSlant->"Plain"], "-", 
                      StyleBox["e",
                        FontSlant->"Plain"]}], ")"}], "2"],
                "TraditionalForm"], "+", 
              FormBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["e",
                        FontSlant->"Plain"], "-", 
                      StyleBox["f",
                        FontSlant->"Plain"]}], ")"}], "2"],
                "TraditionalForm"], "+", 
              FormBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["f",
                        FontSlant->"Plain"], "-", 
                      StyleBox["d",
                        FontSlant->"Plain"]}], ")"}], "2"],
                "TraditionalForm"]}], ")"}], "2"], TraditionalForm]]],
  "-\n3",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["a",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["e",
                    FontSlant->"Plain"], 
                  StyleBox["-",
                    FontSlant->"Italic"], 
                  StyleBox["f",
                    FontSlant->"Plain"]}], 
                StyleBox[")",
                  FontSlant->"Italic"]}], "+", 
              RowBox[{
                StyleBox["b",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["f",
                    FontSlant->"Plain"], 
                  StyleBox["-",
                    FontSlant->"Italic"], 
                  StyleBox["d",
                    FontSlant->"Plain"]}], 
                StyleBox[")",
                  FontSlant->"Italic"]}], "+", 
              RowBox[{
                StyleBox["c",
                  FontSlant->"Plain"], "(", 
                RowBox[{
                  StyleBox["d",
                    FontSlant->"Plain"], 
                  StyleBox["-",
                    FontSlant->"Italic"], 
                  StyleBox["e",
                    FontSlant->"Plain"]}], 
                StyleBox[")",
                  FontSlant->"Italic"]}]}], ")"}], "2"], TraditionalForm]]],
  "is non-negative. It simplifies (with a-b\[RightArrow]w, b-c\[RightArrow]x, \
d-e\[RightArrow]y, e-f\[RightArrow]z)  to ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox[
                SuperscriptBox[
                  StyleBox["w",
                    FontSlant->"Plain"], "2"],
                "TraditionalForm"], "+", 
              RowBox[{
                StyleBox["w",
                  FontSlant->"Plain"], " ", 
                StyleBox["x",
                  FontSlant->"Plain"]}], "+", 
              FormBox[
                SuperscriptBox[
                  StyleBox["x",
                    FontSlant->"Plain"], "2"],
                "TraditionalForm"], "+", 
              FormBox[\(y\^2\),
                "TraditionalForm"], "+", 
              RowBox[{
                StyleBox["y",
                  FontSlant->"Plain"], " ", 
                StyleBox["z",
                  FontSlant->"Plain"]}], "+", 
              FormBox[
                SuperscriptBox[
                  StyleBox["z",
                    FontSlant->"Plain"], "2"],
                "TraditionalForm"]}], ")"}], "2"], TraditionalForm]]],
  " -3",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["x",
                  FontSlant->"Plain"], " ", 
                StyleBox["y",
                  FontSlant->"Plain"]}], "-", 
              RowBox[{
                StyleBox["w",
                  FontSlant->"Plain"], " ", 
                StyleBox["z",
                  FontSlant->"Plain"]}]}], ")"}], "2"], TraditionalForm]]],
  " and this factorises into  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            SuperscriptBox[
              StyleBox["w",
                FontSlant->"Plain"], "2"],
            "TraditionalForm"], "+", 
          RowBox[{
            StyleBox["w",
              FontSlant->"Plain"], " ", 
            StyleBox["x",
              FontSlant->"Plain"]}], "+", 
          FormBox[
            SuperscriptBox[
              StyleBox["x",
                FontSlant->"Plain"], "2"],
            "TraditionalForm"], "+", 
          FormBox[
            SuperscriptBox[
              StyleBox["y",
                FontSlant->"Plain"], "2"],
            "TraditionalForm"], "+", 
          RowBox[{
            StyleBox["y",
              FontSlant->"Plain"], " ", 
            StyleBox["z",
              FontSlant->"Plain"]}], "+", 
          FormBox[
            SuperscriptBox[
              StyleBox["z",
                FontSlant->"Plain"], "2"],
            "TraditionalForm"]}], TraditionalForm]]],
  " \[PlusMinus]",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontSlant->"Plain"], " ", 
              StyleBox["y",
                FontSlant->"Plain"]}], "-", 
            RowBox[{
              StyleBox["w",
                FontSlant->"Plain"], " ", 
              StyleBox["z",
                FontSlant->"Plain"]}]}], ")"}], TraditionalForm]]],
  "; this may provide a \"6-vector\" metric in which (x y-w z) is related to \
time, which is then a dependent variable. \n  c. A \"Fixed Velocity PDE\" \
describes (see Glossary) non-dispersive disturbances travelling in any number \
of directions at a fixed (light?) speed. If this applies to particles as \
wave-packets, Kaluza-Klein orbital velocities would provide mass by reducing \
spatial velocities below the speed of light; massless packets, with no KK \
velocity, would travel at light speed. Remember that wave-packets decay \
because of \"dispersion\", the variation of wave velocity with period, so \
fixed velocity packets do not decay..\n  d.  Orbits must be \"unital\", the \
product of the non-zero sizes is 1. Some dimensions could be in a reciprocal \
relation, with large (curvature of space, ",
  Cell[BoxData[
      \(TraditionalForm\`10\^40\)]],
  "?) and small (",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-40\)\)]],
  "?) values, leaving some \"force\" (KK Planck-scale) fields. This could \
explain the \"law of large numbers\" conjecture - that several properties of \
the universe scale to powers of approximately ",
  Cell[BoxData[
      \(TraditionalForm\`10\^40\)]],
  ".  Phases in the intermediate dimensions would describe non-point-like \
particles with an intrinsic Planck scale. Does orbit maths underly (and \
simplify) string maths?\n  e. The 4-element Pauli-sigma hoop conserves the \
Minkowski metric ",
  StyleBox["t^2 - x^2 - y^2 - z^2",
    FontSlant->"Italic"],
  ", and is related to a group (describing ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^\(3, 1\)\)]],
  ") obtained by dot multiplication of the Dirac 4x4 gamma matrices. This \
group conserves a square of the Minkowski metric added to another squared \
term; it needs investigating in connection with gravity.\n  f. Ternary \
symmetries occur without invoking octonion triality."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["12. Conclusion.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tPrimal (unsigned continuous) numbers provide a more fundamental basis for \
mathematics than real or complex numbers. Loop multiplications of directors \
(indexed sets of primal coefficients) become algebras when a negation \
operation is supplied. Conservative \"Hoop\" algebras have the Frobenius \
determinant-conservation property, and provide a generalisation that includes \
many standard algebras used in particle physics. Noether's laws relate their \
conserved symmetries to particles and forces\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe generalised function ",
  StyleBox["hoopT",
    FontSlant->"Italic"],
  "i",
  StyleBox["mes ",
    FontSlant->"Italic"],
  "defines multiplication with any multiplication table or \"loop\". For \
conservative Moufang loops, if the shape function has been found for the \
table (or the table is smaller than 12\[Times]12 so the shape can be \
calculated in a reasonable time), ",
  StyleBox[" hoopShape & hoopInverse",
    FontSlant->"Italic"],
  " define division. This will be renormalisable (projecting onto a sub-space \
of reduced symmetry, ejecting remainders to maintain conservation) if there \
are at least two determinant factors - hence all group algebras have \
renormalising division because the sum of the elements always provides a \
first factor. For some tables,",
  StyleBox[" hoopPower, toPolar & toVector",
    FontSlant->"Italic"],
  " give consistent powers and roots via a polar or a hyperbolic \
transformation. hoopTest determines which algebraic properties are valid for \
any table. Algebras without renormalization are degenerate equivalence \
relations, with only one conserved factor, on more general algebras."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tMany algebras have \"signed tables\" as multiplication rules. The signs \
+, - =",
  Cell[BoxData[
      \(TraditionalForm\`\@\(+1\)\)]],
  ", \[ImaginaryI]=",
  Cell[BoxData[
      \(TraditionalForm\`\@\(+1\)\%4\)]],
  ", and -\[ImaginaryI]=",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(\@\(+1\)\%4\),
              "TraditionalForm"], ")"}], "3"], TraditionalForm]]],
  " must be extended to the \"generalized signs\" that are needed in \
mathematical physics; in particular \[DoubleStruckK]=",
  Cell[BoxData[
      \(TraditionalForm\`\@\(+1\)\)]],
  ", \[DoubleStruckCapitalJ]=",
  Cell[BoxData[
      \(TraditionalForm\`\@\(+1\)\%3\)]],
  " and \[DoubleStruckH]=",
  Cell[BoxData[
      \(TraditionalForm\`\@\(+1\)\%6\)]],
  ", which are needed to describe quark symmetries. Complex mathematics is a \
special case of mathematics involving generalized signs, such as multi-phase \
sinusoids.\n\n\tRenormalizing Orbit-Generating Equivalence Relation \"ROGER\" \
algebras may provide an explanation of fundamental particle properties. They \
have integer-spin and half-integer-spin quantum operators with multi-phase \
(polar or chiral) deBroglie-wave-like orbits and a stable finite \
Planck-area-like amplitude."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tRenormalization corresponds to symmetry breaking by ejecting remainders and \
projecting the result into a constrained sub-algebra, which may relate to \
different full algebras (e.g. O4 is a sub-algebra of both C3K and C4K). \
Bosonic integer spin algebras (e.g. C3C2) are supersymmetries of fermionic \
half-integer spin algebras (e.g. C3K again) that describe quantum phenomena. \
In this interpretation, there are fewer supersymmetric particles than their \
(subsymmetric) partner particles! Pauli and Dirac matrix sub-algebras \
conserve the Minkowski metric; their full algebras conserve a quartic \
function that may relate to general relativity. The algebras that combine \
these particle and relativistic properties are too large for the author to \
investigate properly (even if he had the ability), but the properties of the \
universe may be emergent properties of conservative Moufang loop algebras.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tI have made many discoveries that appear to be new, and I claim to have \
opened up a new area of mathematics and mathematical physics.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["13. Appendix A. Loop operations.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". Some operations that are relevant to groups and loops rather than hoops \
are collected here. Tests for group properties and the development of ge \
rules are included."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["13.1 Loop Properties.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tExample A1 demonstrates various property tests on Q12 and on the \
16-element octonion groupoid \"Oct\", which is shown to be alternative & \
conservative. ",
  StyleBox["conservativeQ",
    FontSlant->"Italic"],
  " substitutes small random numbers into A & B and tests whether the product \
determinant equals the product of the multiplicand determinants. The groupoid \
\"Alt12n\" is then shown to be alternative but not conservative - \
alternativity does not imply conservativity. Functions for Q12 and some \
subgroups of Q12 are then evaluated."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ \(Example\ A1 . \ 
              Properties\  &\)\ Functions\ *) \)\(\ \)\({"\<Q12 properties \
\>", glo = Q12; "\<\nabelian     \>", abelianQ[], "\<\nassociative \>", 
      associativeQ[], "\<\nalternative \>", 
      alternativeQ[], "\<\nconservative\>", 
      conservativeQ[], "\<\nmoufang     \>", 
      moufangQ[], "\<\nflexible    \>", flexibleQ[], "\<\nflex        \>", 
      flexQ[], "\<\nentropic    \>", entropicQ[], "\<\nfenyves     \>", 
      fenyvesQ[], "\<\nnegatable   \>", negatableQ[], "\<\nhamiltonian \>", 
      hamiltonianQ[], "\<\njacobi      \>", jacobiQ[], "\<\njordan      \>", 
      jordanQ[], "\<\n\nOct properties \>", 
      glo = cd[{\(-1\), \(-1\)}]; "\<\nabelian     \>", 
      abelianQ[], "\<\nassociative \>", associativeQ[], "\<\nalternative \>", 
      alternativeQ[], "\<\nconservative\>", 
      conservativeQ[], "\<\nmoufang     \>", 
      moufangQ[], "\<\nflexible    \>", flexibleQ[], "\<\nflex        \>", 
      flexQ[], "\<\nentropic    \>", entropicQ[], "\<\nfenyves     \>", 
      fenyvesQ[], "\<\nnegatable   \>", negatableQ[], "\<\nhamiltonian \>", 
      hamiltonianQ[], "\<\njacobi      \>", jacobiQ[], "\<\njordan      \>", 
      jordanQ[], "\<\n\nAlt12n properties \>", 
      glo = Alt12n; "\<\nalternative \>", 
      alternativeQ[], "\<\nconservative\>", 
      conservativeQ[], \n"\<\n\nQ12 centralizer \>", 
      centralizer[3, Q12], "\<\nQ12 period\>", 
      period[Q12], "\<\nQ12 orderCount\>", 
      orderCount[Q12], "\<\nQ12 centre\>", 
      centre[Q12], "\<\nQ12 inverses \>", 
      gInverse[Q12], "\<\nQ12 subgroups=\>", 
      subgroups[Q12], "\<\nQ12 subgroups are identified as \>", 
      collect[subgroupTypes[sg]], "\<\nNormal {1,4,7,10} in Q12?\>", 
      normalSubgroup[{1, 4, 7, 10}, 
        Q12], "\<\nfactorGroup of {1,2,3} in Q12 =\>", 
      factorGroup[{1, 2, 3}, Q12], "\<\nallFactorGroups in Q12 =\>", 
      allFactorGroups[Q12], "\<\nlcoset {1,2,3} in Q12 =\>", 
      lcoset[{1, 2, 3}, 
        Q12], "\<\nC3C4 (q1202) is a 12-element subgroup of Q24 (shown by \
returning '2')\>", subgroups[ca[24, 11], 0, 12, 12, {2}]}\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Q12 properties ", "\nabelian     ", False, "\nassociative ", True, 
      "\nalternative ", True, "\nconservative", True, "\nmoufang     ", True, 
      "\nflexible    ", True, "\nflex        ", True, "\nentropic    ", True, 
      "\nfenyves     ", False, "\nnegatable   ", True, "\nhamiltonian ", 
      True, "\njacobi      ", False, "\njordan      ", True, 
      "\n\nOct properties ", "\nabelian     ", False, "\nassociative ", True, 
      "\nalternative ", True, "\nconservative", True, "\nmoufang     ", True, 
      "\nflexible    ", False, "\nflex        ", True, "\nentropic    ", 
      True, "\nfenyves     ", True, "\nnegatable   ", False, 
      "\nhamiltonian ", True, "\njacobi      ", False, "\njordan      ", 
      True, "\n\nAlt12n properties ", "\nalternative ", True, 
      "\nconservative", False, "\n\nQ12 centralizer ", {1, 2, 3, 7, 8, 9}, 
      "\nQ12 period", {1, 3, 3, 4, 4, 4, 2, 6, 6, 4, 4, 4}, 
      "\nQ12 orderCount", {1, 1, 2, 6, 0, 2}, "\nQ12 centre", {1, 7}, 
      "\nQ12 inverses ", {1, 3, 2, 10, 11, 12, 7, 9, 8, 4, 5, 6}, 
      "\nQ12 subgroups=", 6, 
      "\nQ12 subgroups are identified as ", {{1, "C2"}, {1, "C3"}, {3, 
          "C4"}, {1, "C3C2"}}, "\nNormal {1,4,7,10} in Q12?", False, 
      "\nfactorGroup of {1,2,3} in Q12 =", "C4", 
      "\nallFactorGroups in Q12 =", {"D3", "C4", "C4", "C4", "C4", "C2"}, 
      "\nlcoset {1,2,3} in Q12 =", {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}, {10, 11, 
          12}}, "\nC3C4 (q1202) is a 12-element subgroup of Q24 (shown by \
returning '2')", 2}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "Example A2 demonstrates loops that have different combinations of \
properties. \"type\" is taken from ",
  StyleBox["dico",
    FontSlant->"Italic"],
  ", so that Abelian tables give real numbers, non-abelian tables give \
integers, signed tables give negated numbers, and unrecognised tables give \
zero. The tables with names \"?\" are not groups (but are shown to have \
normal subgroups by the ",
  StyleBox["hamiltonianQ",
    FontSlant->"Italic"],
  " test in Ex A3). The second row named ? is a non-conservative quasigroup \
created by ",
  StyleBox["cd[{-1,-1,1,{2}}]",
    FontSlant->"Italic"],
  " that is not in the database but has the same ",
  StyleBox["dico",
    FontSlant->"Italic"],
  " as Q8C2. "
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Example\ A2 . \ 
          Properties\ of\ different\ tables\ *) \)\(\ \)\(res = {{"\<loop\>", \
"\<len\>", "\<type\>", "\<Abl'n\>", "\<AbelGr\>", "\<Alt\>", "\<Cons.\>", \
"\<Entr.\>", "\<Flex\>", "\<mouf\>"}, {"\<test\>", "\<\>", "\<\>", "\<xy=\>", \
"\<xy.z=\>", "\<xx.y=\>", "\<DetADetB=\>", "\<wx.yz=\>", "\<xy.z\>", \
"\<|zx.yx|=\>"}, {"\<\>", "\<\>", "\<\>", "\<yx\>", "\<x.yz\>", "\<x.xy\>", "\
\<DetAB\>", "\<wz.yx\>", "\<x.yz\>", "\<|z.xy.z|\>"}}; 
    inc = {C3, cd[{\(-1\), \(-1\)}], P4, ts[ca[8, 5]], C5n, D3, C6n, 
        ca[8, 3], ca[10, 3], co[C3, C4, 2], Alt12n, 
        cd[{\(-1\), \(-1\), 1, {2}}], cd[{4. , 1, 1}], 
        cd[{\(-1\), \(-1\), \(-1\), {2}}], 
        cd[{\(-1\), \(-1\), \(-1\), \(-1\)}]};\[IndentingNewLine]
    Do[AppendTo[
        res, {i = id[tst = inc[\([i]\)]]; 
          If[\ i == "\<Q8C2\>" || i === "\<Unrecognised\>", "\<?\>", i], 
          Length[tst], 
          If[i === "\<Unrecognised\>", 0, Sign[\(gd[]\)[\([3, 2, 1]\)]]], 
          abelianQ[tst], abelGrassmanQ[tst], alternativeQ[tst], 
          conservativeQ[tst], entropicQ[tst], flexQ[tst], 
          moufangQ[tst]}], {i, Length[inc]}]; res // tf\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FormatType->TraditionalForm],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"loop\"\>", "\<\"len\"\>", "\<\"type\"\>", "\<\"Abl'n\"\>", \
"\<\"AbelGr\"\>", "\<\"Alt\"\>", "\<\"Cons.\"\>", "\<\"Entr.\"\>", \
"\<\"Flex\"\>", "\<\"mouf\"\>"},
            {"\<\"test\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"xy=\"\>", \
"\<\"xy.z=\"\>", "\<\"xx.y=\"\>", "\<\"DetADetB=\"\>", "\<\"wx.yz=\"\>", \
"\<\"xy.z\"\>", "\<\"|zx.yx|=\"\>"},
            {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"yx\"\>", \
"\<\"x.yz\"\>", "\<\"x.xy\"\>", "\<\"DetAB\"\>", "\<\"wz.yx\"\>", "\<\"x.yz\"\
\>", "\<\"|z.xy.z|\"\>"},
            {"\<\"C3\"\>", "3", "1", "True", "True", "True", "True", "True", 
              "True", "True"},
            {"\<\"Qr\"\>", "4", \(-1\), "False", "True", "True", "True", 
              "True", "True", "True"},
            {"\<\"P4\"\>", "4", \(-\[ImaginaryI]\), "False", "True", "True", 
              "True", "True", "True", "True"},
            {"\<\"C8r\"\>", "4", \(-1\), "True", "True", "True", "True", 
              "True", "True", "True"},
            {"\<\"C5n\"\>", "5", "1", "False", "False", "False", "False", 
              "False", "True", "False"},
            {"\<\"D3\"\>", "6", "1", "False", "False", "True", "True", "True",
               "True", "True"},
            {"\<\"C6n\"\>", "6", "1", "False", "False", "False", "False", 
              "False", "False", "False"},
            {"\<\"Q8\"\>", "8", "1", "False", "False", "True", "True", "True",
               "True", "True"},
            {"\<\"?\"\>", "10", "0", "False", "False", "False", "False", 
              "False", "False", "False"},
            {"\<\"Q12\"\>", "12", "1", "False", "False", "True", "True", 
              "True", "True", "True"},
            {"\<\"Alt12n\"\>", "12", "1", "False", "False", "True", "False", 
              "False", "False", "False"},
            {"\<\"?\"\>", "16", "1", "False", "False", "False", "False", 
              "False", "False", "False"},
            {"\<\"\\!\\(C2\\^5\\)r\"\>", "16", \(-1\), "True", "True", "True",
               "True", "True", "True", "True"},
            {"\<\"Oct\"\>", "16", "1", "False", "False", "True", "True", 
              "False", "True", "True"},
            {"\<\"Sed\"\>", "16", \(-1\), "False", "True", "True", "False", 
              "True", "True", "True"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  FontSize->9]
}, Open  ]],

Cell["\<\
Example A3 demonstrates further properties with the same set of loops.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Example\ A3 . \ 
          Further\ \(\(properties\)\(.\)\)\ *) \)\(\ \)\(res = {{"\<loop\>", \
"\<len\>", "\<type\>", "\<A_m\>", "\<bol\>", "\<C\>", "\<Hamilton\>", "\<Mouf\
\>", "\<moufL\>", "\<RIFF\>"}, {"\<test\>", "\<\>", "\<\>", "\<x(yx.zx)=\>", \
"\<(z.yz)x=\>", "\<(xy.y)z=\>", "\<Normal\>", "\<zx.yx=\>", "\<|(zy.z)x|=\>", \
"\<xy(z.xy)=\>"}, {"\<\>", "\<\>", "\<\>", "\<(xy.xz)x\>", "\<z(y.zx)\>", \
"\<x(yy.z)\>", "\<subgrps\>", "\<z.xy.z\>", "\<|z(y.zx)|\>", \
"\<((x.yz))x)y\>"}}; 
    inc = {C3, cd[{\(-1\), \(-1\)}], P4, ts[ca[8, 5]], C5n, D3, C6n, 
        ca[8, 3], ca[10, 3], co[C3, C4, 2], Alt12n, 
        cd[{\(-1\), \(-1\), 1, {2}}], cd[{4. , 1, 1}], 
        cd[{\(-1\), \(-1\), \(-1\), {2}}], 
        cd[{\(-1\), \(-1\), \(-1\), \(-1\)}]};\[IndentingNewLine]
    Do[AppendTo[
        res, {i = id[tst = inc[\([i]\)]]; 
          If[\ i == "\<Q8C2\>" || i === "\<Unrecognised\>", "\<?\>", i], 
          Length[tst], 
          If[i === "\<Unrecognised\>", 0, Sign[\(gd[]\)[\([3, 2, 1]\)]]], 
          amQ[tst], bolQ[tst], cQ[tst], hamiltonianQ[tst], MoufangQ[tst], 
          moufangLQ[tst], riffQ[tst]}], {i, Length[inc]}]; 
    res // tf\[IndentingNewLine]
    inc =. \)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FormatType->TraditionalForm],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"loop\"\>", "\<\"len\"\>", "\<\"type\"\>", "\<\"A_m\"\>", \
"\<\"bol\"\>", "\<\"C\"\>", "\<\"Hamilton\"\>", "\<\"Mouf\"\>", \
"\<\"moufL\"\>", "\<\"RIFF\"\>"},
            {"\<\"test\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"x(yx.zx)=\"\>", "\<\
\"(z.yz)x=\"\>", "\<\"(xy.y)z=\"\>", "\<\"Normal\"\>", "\<\"zx.yx=\"\>", \
"\<\"|(zy.z)x|=\"\>", "\<\"xy(z.xy)=\"\>"},
            {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"(xy.xz)x\"\>", \
"\<\"z(y.zx)\"\>", "\<\"x(yy.z)\"\>", "\<\"subgrps\"\>", "\<\"z.xy.z\"\>", \
"\<\"|z(y.zx)|\"\>", "\<\"((x.yz))x)y\"\>"},
            {"\<\"C3\"\>", "3", "1", "True", "True", "True", "False", "True", 
              "True", "True"},
            {"\<\"Qr\"\>", "4", \(-1\), "False", "False", "True", "True", 
              "False", "True", "True"},
            {"\<\"P4\"\>", "4", \(-\[ImaginaryI]\), 
              "False", "\<\"Complex\"\>", "True", "True", "False", "True", 
              "True"},
            {"\<\"C8r\"\>", "4", \(-1\), "True", "False", "False", "False", 
              "False", "True", "True"},
            {"\<\"C5n\"\>", "5", "1", "True", "False", "False", "True", 
              "False", "False", "True"},
            {"\<\"D3\"\>", "6", "1", "True", "True", "True", "True", "True", 
              "True", "True"},
            {"\<\"C6n\"\>", "6", "1", "False", "False", "False", "True", 
              "False", "False", "False"},
            {"\<\"Q8\"\>", "8", "1", "True", "True", "True", "True", "True", 
              "True", "True"},
            {"\<\"?\"\>", "10", "0", "False", "False", "False", "True", 
              "False", "False", "False"},
            {"\<\"Q12\"\>", "12", "1", "True", "True", "True", "True", "True",
               "True", "True"},
            {"\<\"Alt12n\"\>", "12", "1", "False", "False", "True", "True", 
              "False", "False", "False"},
            {"\<\"?\"\>", "16", "1", "False", "False", "False", "True", 
              "False", "False", "False"},
            {"\<\"\\!\\(C2\\^5\\)r\"\>", "16", \(-1\), "True", "False", 
              "True", "False", "False", "True", "True"},
            {"\<\"Oct\"\>", "16", "1", "False", "True", "True", "True", 
              "True", "True", "True"},
            {"\<\"Sed\"\>", "16", \(-1\), "False", "False", "True", "True", 
              "False", "True", "True"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["conservativeQ",
    FontSlant->"Italic"],
  " test does not match any of the other tests exactly.  ",
  StyleBox["moufangQ",
    FontSlant->"Italic"],
  "  is the nearest, but passes ",
  StyleBox["Sed",
    FontSlant->"Italic"],
  "; ",
  StyleBox["AbelGrassmann ",
    FontSlant->"Italic"],
  "is split by C8r / D3; ",
  StyleBox["alternativeQ",
    FontSlant->"Italic"],
  " is split by Octi / Alt12n; ",
  StyleBox["entropicQ",
    FontSlant->"Italic"],
  " fails for Oct; ",
  StyleBox["A_m",
    FontSlant->"Italic"],
  " fails for Qr; ",
  StyleBox["bolQ, CQ &HamiltonQ",
    FontSlant->"Italic"],
  " fail for C8r.\n\tExample A4 is a test-bed for newly discovered tables. It \
tests the signed table ",
  StyleBox["tst10 ",
    FontSlant->"Italic"],
  " (from Example 10) for most of the programmed properties:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(\( (*\ Example\ A4 . \ Property\ List\ *) \)\(\ \)\)\)], "Input",
  PageWidth->WindowWidth,
  FormatType->TraditionalForm],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{"\<abelian    \>", 
      abelianQ(tst), "\<\nassociative \>", 
      associativeQ(tst), "\<\nabelGrassman\>", 
      abelGrassmanQ(tst), "\<\nalternative \>", 
      alternativeQ(tst), "\<\nam          \>", 
      amQ(tst), "\<\nbol         \>", bolQ(tst), "\<\nc           \>", 
      cQ(tst), "\<\nentropic    \>", entropicQ(tst), "\<\nflexible    \>", 
      flexibleQ(tst), "\<\nfenyves     \>", 
      fenyvesQ(tst), "\<\nflex        \>", flexQ(tst), "\<\nhamiltonian \>", 
      hamiltonianQ(tst), "\<\njacobi      \>", 
      jacobiQ(tst), "\<\njordan      \>", jordanQ(tst), "\<\nmoufang     \>", 
      moufangQ(tst), "\<\nnegatable   \>", 
      negatableQ(tst), "\<\nriff        \>", riffQ(tst)}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier New"],

Cell[BoxData[
    \({"abelian    ", abelianQ[tst], "\nassociative ", associativeQ[tst], 
      "\nabelGrassman", abelGrassmanQ[tst], "\nalternative ", 
      alternativeQ[tst], "\nam          ", amQ[tst], "\nbol         ", 
      bolQ[tst], "\nc           ", cQ[tst], "\nentropic    ", entropicQ[tst], 
      "\nflexible    ", flexibleQ[tst], "\nfenyves     ", fenyvesQ[tst], 
      "\nflex        ", flexQ[tst], "\nhamiltonian ", hamiltonianQ[tst], 
      "\njacobi      ", jacobiQ[tst], "\njordan      ", jordanQ[tst], 
      "\nmoufang     ", moufangQ[tst], "\nnegatable   ", negatableQ[tst], 
      "\nriff        ", riffQ[tst]}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\thoopTimes[A,B,tst,1] uses a minimal multiplication routine, developed to \
test conservation of large tables that need not be in the databank. It is \
used below to test which compositions of Oct are conservative. (Only \
compositions with Abelian groups.) The table is conservative if one result is \
0. Repeat the test if both are zero, as this means that the product has a \
zero size. \
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tst = co[Oct, tst1 = mp[16, 7]]; id[tst1]\), "\[IndentingNewLine]", 
    \(A = Table[Random[Integer, {\(-9\), 9}], {i, Length[tst]}]; 
    B = Table[
        Random[Integer, {\(-9\), 9}], {i, 
          Length[tst]}];\), "\[IndentingNewLine]", 
    \(\(AB = hoopTimes[A, B, tst, 1];\)\), "\[IndentingNewLine]", 
    \(sA = Det[gmap[tst, A]]; 
    sB = Det[gmap[tst, B]];\), "\[IndentingNewLine]", 
    \(sAB = 
      Det[gmap[tst, 
          AB]]; {Chop[\((sA\ sB + sAB)\)/\((sA + 
              sB)\)], \[IndentingNewLine]Chop[\((sA\ sB - sAB)\)/\((sA + 
              sB)\)]}\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("D8"\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13.2. ",
  StyleBox["Groups from Relators", "Text"],
  "."
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tMost of the ",
  StyleBox["ge",
    FontSlant->"Italic"],
  " rules were discovered empirically, retaining the shortest wherever more \
than one gave a particular group. I later learned that they could be found by \
the GAP instruction:- ",
  StyleBox["gap>RelatorsOfFpGroup(Image(IsomorphismFpGroup(SmallGroup(mm,nn)))\
)",
    FontSlant->"Italic"],
  ";\nthis gives the result in terms of F1, F2, etc. The result can be copied \
(e.g. from a Wordpad document) and processed as in Example A6. The GAP \
formulation {2,2,3},{aa\[Rule]b,ca\[Rule]acc} is not the most compact form; \
the database rule for Q12 is {3,4},{\"ba\"\[Rule]\"a2b\"}:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example A5. Gap relators & generators for SmallGroup(12,1)", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "\"\<The GAP Relators for SmallGroup{12,1) are F1^2*F2^-1, \
F2^-1*F1^-1*F2*F1, F3^-1*F1^-1*F3*F1*F3^-1, F2^2, \n  F3^-1*F2^-1*F3*F2, F3^3\
\\nThey convert to\>\"", ",", 
        StyleBox[\(Hold[\ F1^2*F2^\(-1\), \ F2^\(-1\)*F1^\(-1\)*F2*F1, \ 
              F3^\(-1\)*F1^\(-1\)*F3*F1*F3^\(-1\), \ 
              F2^2, \ \n\ \ F3^\(-1\)*F2^\(-1\)*F3*F2, \ F3^3] /. {F1 -> a, 
              F2 -> b, F3 -> c}\),
          FormatType->StandardForm], 
        StyleBox[",",
          FormatType->StandardForm], 
        StyleBox[
          "\"\<\\nwhich translates to \
{2,2,3},{aa\[Rule]b,ca\[Rule]acc}.\\nThis generates\>\"",
          FormatType->StandardForm], 
        StyleBox[",",
          FormatType->StandardForm], \(id[
          ge[{2, 2, 3}, {aa \[Rule] b, ca \[Rule] acc}]]\), ",", 
        "\"\<\\nData\>\"", ",", \(gd[]\)}], 
      StyleBox["}",
        FormatType->StandardForm]}]], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"The GAP Relators for SmallGroup{12,1) are F1^2*F2^-1, \
F2^-1*F1^-1*F2*F1, F3^-1*F1^-1*F3*F1*F3^-1, F2^2,    F3^-1*F2^-1*F3*F2, F3^3\n\
They convert to", 
      Hold[a\^2\/b, \(b\ a\)\/\(b\ a\), \(c\ a\)\/\(c\ a\ c\), 
        b\^2, \(c\ b\)\/\(c\ b\), c\^3], 
      "\nwhich translates to {2,2,3},{aa\[Rule]b,ca\[Rule]acc}.\nThis \
generates", "Q12", 
      "\nData", {12, 
        1, {"Q12", {2, 2\_2, 6}, 0, 
          "co[C3,C4,2]", {3, 4}, {"ba" \[Rule] "a2b"}, {10, 13}, {8, 36}, {8, 
            16}}}}\)], "Output",
  PageWidth->WindowWidth]
}, Closed]],

Cell[TextData[{
  "The ",
  StyleBox["ba/ba",
    FontSlant->"Italic"],
  " etc cases are handled automatically by ",
  StyleBox["ge",
    FontSlant->"Italic"],
  " and are ignored. \nThe ",
  Cell[BoxData[
      \(TraditionalForm\`a\^n\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\^n\), 
          StyleBox["/",
            FontSlant->"Italic"], 
          StyleBox["b",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " & ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\^n\), 
          StyleBox["/",
            FontSlant->"Italic"], 
          StyleBox[\(b\^m\),
            FontSlant->"Italic"]}], TraditionalForm]]],
  " etc. cases define ",
  StyleBox["n",
    FontSlant->"Italic"],
  " for the members of the generator power list. \n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\^n\), 
          StyleBox["/",
            FontSlant->"Italic"], 
          StyleBox["b",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " & ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\^n\), 
          StyleBox["/",
            FontSlant->"Italic"], 
          StyleBox[\(b\^m\),
            FontSlant->"Italic"]}], TraditionalForm]]],
  " imply non-abelian rules \"an\"->\"b\" & \"an\"->\"bm\". \n",
  StyleBox["ba/(ba,c)",
    FontSlant->"Italic"],
  "  becomes \"ba\"->\"abc\". (KnC4)\n",
  StyleBox["ba/(ba,cb) ",
    FontSlant->"Italic"],
  "becomes \"ba\"->\"abc\".",
  StyleBox["  \nca/(ca,c)",
    FontSlant->"Italic"],
  " becomes \"ca\"->\"acc\". (Q12)\n",
  StyleBox["ba/(ba,",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(n - 1\)\)]],
  ") becomes \"ba\"->\"anb\" (g2003)\n",
  StyleBox["cb/(cb,",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`c\^\(n - 1\)\)]],
  ") becomes \"cb\"->\"bcn\"\n",
  StyleBox["ba/(ba,yxc)",
    FontSlant->"Italic"],
  "  becomes \"ba\"->\"abcxy\"\n",
  StyleBox["ba/(ba,yxb)",
    FontSlant->"Italic"],
  "  becomes \"ba\"->\"abxy\" (SL23).  \ng4828, g4829 and g6005 (\"A5\") have \
terms that have not been resolved. E.g. A5 gives a5/b5, a5/baba, 1/aa bb/aa \
bb."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14. Appendix B. ",
  StyleBox["Signed Table Search.", "Text"]
}], "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThis appendix demonstrates the search for a reordering that allows a \
table to be folded. ",
  StyleBox["dico",
    FontSlant->"Italic"],
  " is first inspected. The counts must be divisible by ",
  StyleBox["r",
    FontSlant->"Italic"],
  " to allow ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold folding. In the example they are ",
  Cell[BoxData[
      \(12, 4, 8\_2\)]],
  " (the 23 is a diagnostic, not a count) and so ",
  StyleBox["r",
    FontSlant->"Italic"],
  " may be 2 or 4."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tst2 = mp["\<KiC4M\>"]\ ;\)\), "\[IndentingNewLine]", 
    \(id[tst2]\), "\[IndentingNewLine]", 
    \(gd[]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("KiC4M"\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({32, 
      59, {"KiC4M", {12, 4, 8\_2, 23}, 0, 
        "md[co[K,C4,2],{1,4,3,2,7,8,5,6,9,12,11,10,15,16,13,14}]", {}, {}, \
{}, {}, {}}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tA partial reordering is compared with the required form for the (",
  StyleBox["m",
    FontSlant->"Italic"],
  "/2+1)th row, and modified in an obvious way to correct the errors. In this \
case, the 17'th column is not correct, and the table does not 2-fold."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(ord = 
      Flatten[Table[
          Position[tst2[\([17]\)], Mod[i + 16, 32, 1]], {i, 32}]]\)], "Input",\

  PageWidth->WindowWidth],

Cell[BoxData[
    \({1, 4, 3, 2, 7, 8, 5, 6, 9, 12, 11, 10, 15, 16, 13, 14, 17, 20, 19, 18, 
      23, 24, 21, 22, 25, 28, 27, 26, 31, 32, 29, 30}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tst = reorder[tst2, ord];\)\), "\[IndentingNewLine]", 
    \({Range[17, 32], Take[tst[\([17]\)], 16], Take[tst[\([17]\)], \(-16\)], 
        Range[16]} // tf\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27",
               "28", "29", "30", "31", "32"},
            {"17", "20", "19", "18", "23", "24", "21", "22", "25", "28", "27",
               "26", "31", "32", "29", "30"},
            {"1", "4", "3", "2", "7", "8", "5", "6", "9", "12", "11", "10", 
              "15", "16", "13", "14"},
            {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", 
              "13", "14", "15", "16"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tst = 
        reorder[tst2, {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
            17, 20, 19, 18, 23, 24, 21, 22, 25, 28, 27, 26, 31, 32, 29, 
            30}];\)\), "\[IndentingNewLine]", 
    \({Take[tst[\([17]\)], 16], Take[tst[\([17]\)], \(-16\)]} // 
      tf\), "\[IndentingNewLine]", 
    \(\(Transpose[tst]\)[\([17]\)]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27",
               "28", "29", "30", "31", "32"},
            {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", 
              "13", "14", "15", "16"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({17, 20, 19, 18, 23, 24, 21, 22, 25, 28, 27, 26, 31, 32, 29, 30, 1, 4, 
      3, 2, 7, 8, 5, 6, 9, 12, 11, 10, 15, 16, 13, 14}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["The other 32-element Moufang Loops also fail:-", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tstp = mp["\<P16M\>"]\ ;\)\), "\[IndentingNewLine]", 
    \(name = id[tstp]\), "\[IndentingNewLine]", 
    \(gd[]\), "\[IndentingNewLine]", 
    \(ord = 
      Flatten[{Range[16], 
          Table[Position[tstp[\([17]\)], Mod[i + 16, 32, 1]], {i, 17, 
              32}]}]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("P16M"\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({32, 
      57, {"P16M", {16, 16, 15}, 0, 
        "md[co[P4,C4],{1,10,11,12,5,14,15,16,9,2,3,4,13,6,7,8}]", {}, {}, {}, \
{}, {}}}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 26, 27, 28, 
      21, 30, 31, 32, 25, 18, 19, 20, 29, 22, 23, 24}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tst = reorder[tstp, ord];\)\), "\[IndentingNewLine]", 
    \({Take[tst[\([17]\)], 16], Take[tst[\([17]\)], \(-16\)]} // 
      tf\), "\[IndentingNewLine]", 
    \(\(Transpose[tst]\)[\([17]\)]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27",
               "28", "29", "30", "31", "32"},
            {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", 
              "13", "14", "15", "16"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({17, 26, 27, 28, 21, 30, 31, 32, 25, 18, 19, 20, 29, 22, 23, 24, 1, 10, 
      11, 12, 5, 14, 15, 16, 9, 2, 3, 4, 13, 6, 7, 8}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tstc = mp["\<C8pC2M\>"]\ ;\)\), "\[IndentingNewLine]", 
    \(name = id[tstc]\), "\[IndentingNewLine]", 
    \(gd[]\), "\[IndentingNewLine]", 
    \(ord = 
      Flatten[{Range[16], 
          Table[Position[tstc[\([17]\)], Mod[i + 16, 32, 1]], {i, 17, 
              32}]}]\), "\[IndentingNewLine]", 
    \(\(tst = reorder[tstc, ord];\)\), "\[IndentingNewLine]", 
    \({Take[tst[\([17]\)], 16], Take[tst[\([17]\)], \(-16\)]} // 
      tf\), "\[IndentingNewLine]", 
    \(\(Transpose[tst]\)[\([17]\)]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("C8pC2M"\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({32, 
      58, {"C8pC2M", {8, 8\_3, 7}, 99, 
        "md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]", {}, \
{}, {}, {}, {}}}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 22, 19, 24, 
      21, 18, 23, 20, 29, 30, 31, 32, 25, 26, 27, 28}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27",
               "28", "29", "30", "31", "32"},
            {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", 
              "13", "14", "15", "16"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({17, 22, 19, 24, 21, 18, 23, 20, 29, 30, 31, 32, 25, 26, 27, 28, 1, 6, 
      3, 8, 5, 2, 7, 4, 13, 14, 15, 16, 9, 10, 11, 12}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tstq = mp["\<Q8C2M\>"]\ ;\)\), "\[IndentingNewLine]", 
    \(name = id[tstq]\), "\[IndentingNewLine]", 
    \(gd[]\), "\[IndentingNewLine]", 
    \(ord = 
      Flatten[{Range[16], 
          Table[Position[tstq[\([17]\)], Mod[i + 16, 32, 1]], {i, 17, 
              32}]}]\), "\[IndentingNewLine]", 
    \(\(tst = reorder[tstq, ord];\)\), "\[IndentingNewLine]", 
    \({Take[tst[\([17]\)], 16], Take[tst[\([17]\)], \(-16\)]} // 
      tf\), "\[IndentingNewLine]", 
    \(\(Transpose[tst]\)[\([17]\)]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("Q8C2M"\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({32, 
      60, {"Q8C2M", {20, 12, 31}, 0, 
        "md[co[Q8,C2]]", {}, {}, {}, {}, {}}}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 22, 23, 24, 
      21, 18, 19, 20, 25, 30, 31, 32, 29, 26, 27, 28}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27",
               "28", "29", "30", "31", "32"},
            {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", 
              "13", "14", "15", "16"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({17, 22, 23, 24, 21, 18, 19, 20, 25, 30, 31, 32, 29, 26, 27, 28, 1, 6, 
      7, 8, 5, 2, 3, 4, 9, 14, 15, 16, 13, 10, 11, 12}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tsto = mp["\<O16\>"]\ ;\)\), "\[IndentingNewLine]", 
    \(name = id[tsto]\), "\[IndentingNewLine]", 
    \(gd[]\), "\[IndentingNewLine]", 
    \(ord = 
      Flatten[{Range[16], 
          Table[Position[tsto[\([17]\)], Mod[i + 16, 32, 1]], {i, 17, 
              32}]}]\), "\[IndentingNewLine]", 
    \(\(tst = reorder[tsto, ord];\)\), "\[IndentingNewLine]", 
    \({Take[tst[\([17]\)], 16], Take[tst[\([17]\)], \(-16\)]} // 
      tf\), "\[IndentingNewLine]", 
    \(\(Transpose[tst]\)[\([17]\)]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("O16"\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({32, 
      62, {"O16", {\(-16.`\), 16, 35}, 0, 
        "cd[{-1,1,1,1,1}]", {}, {}, {}, {}, {}}}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27",
               "28", "29", "30", "31", "32"},
            {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", 
              "13", "14", "15", "16"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 1, 2, 
      3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["Unresolved problem with ts??", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(id[tst = ts[cd[{\(-1\), 1, 1}]]]\), "\[IndentingNewLine]", 
    \(tst // tf\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("Fail, not an indexTable."\)], "Print"],

Cell[BoxData[
    \("C3C4j"\)], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-3\), \(-4\), "1", "2"},
            {\(-4\), \(-3\), "2", "1"},
            {"1", "2", "3", "4"},
            {"2", "1", "4", "3"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15. Appendix C. ",
  StyleBox["T", "Text"],
  "he Hypercomplex Plane, ",
  StyleBox["arcTanh", "Text"],
  "."
}], "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\t",
  StyleBox["toHypolar & toHyvector ",
    FontSlant->"Italic"],
  "provide coordinates in the hypercomplex plane. (I have not explored the \
relationship between this and the \"Projected Hyperbolic Plane\" discussed in \
Penrose 2004.) An extended definition of ArcTanh (as arcTanh[adj,opp]) \
accounts for the octant of the arguments (this makes the resulting angle \
complex in 6 octants). ",
  StyleBox["Cosh",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Sinh",
    FontSlant->"Italic"],
  " are used in definitions of ",
  StyleBox["tohyVec",
    FontSlant->"Italic"],
  " such as:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[{
    \(tohyPol[{a_, b_}, "\<C2\>"] := 
      Chop[{a\^2 - b\^2, arcTanh[a, b]}]\), "\[IndentingNewLine]", 
    \(tohyVec[{uu_, \[Phi]_}, "\<C2\>"] := 
      Chop[\@uu\ {Cosh[\[Phi]], Sinh[\[Phi]]}]\)}], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FormatType->TraditionalForm],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?? arcTanh\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("arcTanh[adj_,opp_] or arcTanh[{adj_,opp_}] calculates an angle that \
takes account of the octant of the arguments; the angle has an imaginary part \
for three non-standard hyperbolae. Note that opp,adj is the argument order \
used by many mathematicians."\)], "Print",
  PageWidth->WindowWidth,
  CellTags->"Info3308460589-1429071"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(Attributes[arcTanh] = {Protected}\)},
          {" "},
          {GridBox[{
                {\(arcTanh[a_, 0] := If[a \[Equal] 0, \[Infinity], 0, 0]\)},
                {" "},
                {\(arcTanh[a_, opp_] := 
                    N[If[Chop[a\^2 - opp\^2] \[Equal] 0, \[Infinity], 
                        Log[\(a + opp\)\/\@\(a\^2 - opp\^2\)]]]\)},
                {" "},
                {\(arcTanh[{a_, opp_}] := arcTanh[a, opp]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "arcTanh"],
      Editable->False]], "Print",
  PageWidth->WindowWidth,
  CellTags->"Info3308460589-1429071"]
}, Closed]],

Cell[TextData[{
  "\tThis definition was brought to my attention by \"Klueless\", \
sci.math.symbolic, May 2001, and implemented by me in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for ",
  StyleBox["tohyPol ",
    FontSlant->"Italic"],
  "&",
  StyleBox[" tohyVec",
    FontSlant->"Italic"],
  ". Example 35 (Section 6.2) showed that complex values are handled \
successfully. The different combinations of real coordinates and complex \
angles are illustrated below. "
}], "Text",
  PageWidth->WindowWidth],

Cell["Example C1. arcTanh.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{"\<arcTanh[2, 1]  is  \>", 
      arcTanh[2, 1], "\<\narcTanh[-2, 1]  is \>", 
      arcTanh[\(-2\), 1], "\<\narcTanh[-2,-1]  is  \>", 
      arcTanh[\(-2\), \(-1\)], "\<\narcTanh[ 2,-1]  is \>", 
      arcTanh[2, \(-1\)], "\<\narcTanh[ 1, 2]  is  \>", 
      arcTanh[1, 2], "\<\narcTanh[-1, 2]  is \>", 
      arcTanh[\(-1\), 2], "\<\narcTanh[-1,-2]  is  \>", 
      arcTanh[\(-1\), \(-2\)], "\<\narcTanh[ 1,-2]  is \>", 
      arcTanh[1, \(-2\)], "\<\narcTanh[1,2+\[ImaginaryI]]  is  \>", 
      arcTanh[1, 2 + \[ImaginaryI]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FormatType->StandardForm],

Cell[BoxData[
    \({"arcTanh[2, 1]  is  ", 0.5493061443340548`, 
      "\narcTanh[-2, 1]  is ", \(-0.5493061443340549`\) + 
        3.141592653589793`\ \[ImaginaryI], 
      "\narcTanh[-2,-1]  is  ", \
\(\(0.5493061443340548`\)\(\[InvisibleSpace]\)\) + 
        3.141592653589793`\ \[ImaginaryI], 
      "\narcTanh[ 2,-1]  is ", \(-0.5493061443340549`\), 
      "\narcTanh[ 1, 2]  is  ", \
\(\(0.5493061443340548`\)\(\[InvisibleSpace]\)\) - 
        1.5707963267948966`\ \[ImaginaryI], 
      "\narcTanh[-1, 2]  is ", \(-0.5493061443340549`\) - 
        1.5707963267948966`\ \[ImaginaryI], 
      "\narcTanh[-1,-2]  is  ", \
\(\(0.5493061443340548`\)\(\[InvisibleSpace]\)\) + 
        1.5707963267948966`\ \[ImaginaryI], 
      "\narcTanh[ 1,-2]  is ", \(-0.5493061443340549`\) + 
        1.5707963267948966`\ \[ImaginaryI], 
      "\narcTanh[1,2+\[ImaginaryI]]  is  ", \(\(0.40235947810852524`\)\(\
\[InvisibleSpace]\)\) + 1.3389725222944935`\ \[ImaginaryI]}\)], "Output"]
}, Open  ]],

Cell["Example C2. Hyperbolic Plane. ", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    FormBox[\(xy = 
          Table[tohyVec[{1, th}, "\<C2\>"], {th, \(-1.6\), 1.6,  .1}];\), 
      TraditionalForm], "\n", 
    FormBox[
      FormBox[\(xy1 = \[ImaginaryI]\ Table[
                tohyVec[{1, th}, "\<C2\>"], {th, 
                  1.6 - \[ImaginaryI]\ \[Pi]/
                        2, \(-1.6\) - \[ImaginaryI]\ \[Pi]/2, \(- .1\)}];\),
        "TraditionalForm"], TraditionalForm], "\n", 
    FormBox[
      FormBox[\(xy2 = 
            Table[tohyVec[{1, 
                  th}, "\<C2\>"], {th, \(-1.6\) + \[ImaginaryI]\ \[Pi], 
                1.6 + \[ImaginaryI]\ \[Pi],  .1}];\),
        "TraditionalForm"], TraditionalForm], "\n", 
    FormBox[
      FormBox[\(xy3 = \[ImaginaryI]\ Table[
                tohyVec[{1, th}, "\<C2\>"], {th, 
                  1.6 + \[ImaginaryI]\ \[Pi]/
                        2, \(-1.6\) + \[ImaginaryI]\ \[Pi]/2, \(- .1\)}];\),
        "TraditionalForm"], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[\(xy7 = \[ImaginaryI]\ Table[
              tohyVec[{\(-1.5\), th}, "\<C2\>"], {th, \(-1.4\), 1.4,  .1}];\),
       TraditionalForm], "\n", 
    FormBox[
      FormBox[\(xy6 = 
            Table[tohyVec[{\(-1.5\), th}, "\<C2\>"], {th, 
                1.4 - \[ImaginaryI]\ \[Pi]/2, \(-1.4\) - \[ImaginaryI]\ \[Pi]/
                      2, \(- .1\)}];\),
        "TraditionalForm"], TraditionalForm], "\n", 
    FormBox[
      FormBox[\(xy5 = \[ImaginaryI]\ Table[
                tohyVec[{\(-1.5\), 
                    th}, "\<C2\>"], {th, \(-1.4\) + \[ImaginaryI]\ \[Pi], 
                  1.4 + \[ImaginaryI]\ \[Pi],  .1}];\),
        "TraditionalForm"], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[\(xy8 = 
          Table[tohyVec[{\(-1.5\), th}, "\<C2\>"], {th, 
              1.4 + \[ImaginaryI]\ \[Pi]/2, \(-1.4\) + \[ImaginaryI]\ \[Pi]/
                    2, \(- .1\)}];\), TraditionalForm], "\[IndentingNewLine]",
   
    FormBox[
      RowBox[{\(xy9 = 
          Table[Re[
              tohyVec[{ .8  \[ImaginaryI], th}, "\<C2\>"]], {th, \(-2.05\), 
              2.05,  .1}]\), ";", 
        FormBox[\(xy10 = 
              Table[Re[tohyVec[{ .8  \[ImaginaryI], th}, "\<C2\>"]], {th, 
                  2.05 - \[ImaginaryI]\ \[Pi]/
                        2, \(-2.05\) - \[ImaginaryI]\ \[Pi]/2, \(- .1\)}];\),
          "TraditionalForm"]}], TraditionalForm], "\n", 
    FormBox[
      FormBox[\(xy11 = 
            Table[Re[
                tohyVec[{ .8  \[ImaginaryI], 
                    th}, "\<C2\>"]], {th, \(-2.05\) + \[ImaginaryI]\ \[Pi], 
                2.05 + \[ImaginaryI]\ \[Pi],  .1}];\),
        "TraditionalForm"], TraditionalForm], "\n", 
    FormBox[
      FormBox[\(xy12 = 
            Table[Re[tohyVec[{ .8  \[ImaginaryI], th}, "\<C2\>"]], {th, 
                2.05 + \[ImaginaryI]\ \[Pi]/
                      2, \(-2.05\) + \[ImaginaryI]\ \[Pi]/2, \(- .1\)}];\),
        "TraditionalForm"], TraditionalForm], "\n", 
    FormBox[
      FormBox[\(xyp = 
            Flatten[{xy9, xy10, xy11, xy12, xy, xy1, xy2, xy3, xy5, xy6, xy7, 
                xy8}, 1];\),
        "TraditionalForm"], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[\(ListPlot[xyp, PlotJoined -> True, 
          AspectRatio \[Rule] Automatic, 
          PlotRange \[Rule] {{\(-2\), 2}, {\(-2\), 2}}\ ];\), 
      TraditionalForm]}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
1 .02572 m
.96868 .0588 L
.92683 .10353 L
.88925 .14431 L
.85557 .18152 L
.82545 .21554 L
.79859 .24671 L
.77471 .27536 L
.75358 .30175 L
.73499 .32616 L
.71876 .34882 L
.70471 .36998 L
.69271 .38983 L
.68264 .40859 L
.67439 .42642 L
.6679 .44352 L
.66308 .46006 L
.6599 .47619 L
.65831 .49209 L
.65831 .50791 L
.6599 .52381 L
.66308 .53994 L
.6679 .55648 L
.67439 .57358 L
.68264 .59141 L
.69271 .61017 L
.70471 .63002 L
.71876 .65118 L
.73499 .67384 L
.75358 .69825 L
.77471 .72464 L
.79859 .75329 L
.82545 .78446 L
.85557 .81848 L
.88925 .85569 L
.92683 .89647 L
.96868 .9412 L
s
.96868 .9412 m
1 .97428 L
s
.97428 1 m
.9412 .96868 L
.89647 .92683 L
.85569 .88925 L
.81848 .85557 L
.78446 .82545 L
.75329 .79859 L
.72464 .77471 L
.69825 .75358 L
.67384 .73499 L
.65118 .71876 L
.63002 .70471 L
.61017 .69271 L
.59141 .68264 L
.57358 .67439 L
.55648 .6679 L
.53994 .66308 L
.52381 .6599 L
.50791 .65831 L
.49209 .65831 L
.47619 .6599 L
.46006 .66308 L
.44352 .6679 L
.42642 .67439 L
.40859 .68264 L
.38983 .69271 L
.36998 .70471 L
.34882 .71876 L
.32616 .73499 L
.30175 .75358 L
.27536 .77471 L
.24671 .79859 L
.21554 .82545 L
.18152 .85557 L
.14431 .88925 L
.10353 .92683 L
.0588 .96868 L
s
.0588 .96868 m
.02572 1 L
s
0 .97428 m
.03132 .9412 L
.07317 .89647 L
.11075 .85569 L
.14443 .81848 L
.17455 .78446 L
.20141 .75329 L
.22529 .72464 L
.24642 .69825 L
.26501 .67384 L
.28124 .65118 L
.29529 .63002 L
.30729 .61017 L
.31736 .59141 L
.32561 .57358 L
.3321 .55648 L
.33692 .53994 L
.3401 .52381 L
.34169 .50791 L
.34169 .49209 L
.3401 .47619 L
.33692 .46006 L
.3321 .44352 L
.32561 .42642 L
.31736 .40859 L
.30729 .38983 L
.29529 .36998 L
.28124 .34882 L
.26501 .32616 L
.24642 .30175 L
.22529 .27536 L
.20141 .24671 L
.17455 .21554 L
.14443 .18152 L
.11075 .14431 L
.07317 .10353 L
.03132 .0588 L
s
.03132 .0588 m
0 .02572 L
s
.02572 0 m
.0588 .03132 L
.10353 .07317 L
.14431 .11075 L
.18152 .14443 L
.21554 .17455 L
.24671 .20141 L
.27536 .22529 L
.30175 .24642 L
.32616 .26501 L
.34882 .28124 L
.36998 .29529 L
.38983 .30729 L
.40859 .31736 L
.42642 .32561 L
.44352 .3321 L
.46006 .33692 L
.47619 .3401 L
.49209 .34169 L
.50791 .34169 L
.52381 .3401 L
.53994 .33692 L
.55648 .3321 L
.57358 .32561 L
.59141 .31736 L
.61017 .30729 L
.63002 .29529 L
.65118 .28124 L
.67384 .26501 L
.69825 .24642 L
.72464 .22529 L
.75329 .20141 L
.78446 .17455 L
.81848 .14443 L
.85569 .11075 L
.89647 .07317 L
.9412 .03132 L
s
.9412 .03132 m
.97428 0 L
s
1 .06709 m
.99273 .0754 L
.95266 .12263 L
.91713 .16609 L
.88577 .2062 L
.85827 .24337 L
.83436 .27797 L
.81379 .31035 L
.79637 .34084 L
.78191 .36973 L
.77027 .39731 L
.76133 .42387 L
.75502 .44967 L
.75125 .47496 L
.75 .5 L
.75125 .52504 L
.75502 .55033 L
.76133 .57613 L
.77027 .60269 L
.78191 .63027 L
.79637 .65916 L
.81379 .68965 L
.83436 .72203 L
.85827 .75663 L
.88577 .7938 L
.91713 .83391 L
.95266 .87737 L
.99273 .9246 L
s
.99273 .9246 m
1 .93291 L
s
.93291 1 m
.9246 .99273 L
.87737 .95266 L
.83391 .91713 L
.7938 .88577 L
.75663 .85827 L
.72203 .83436 L
.68965 .81379 L
.65916 .79637 L
.63027 .78191 L
.60269 .77027 L
.57613 .76133 L
.55033 .75502 L
.52504 .75125 L
.5 .75 L
.47496 .75125 L
.44967 .75502 L
.42387 .76133 L
.39731 .77027 L
.36973 .78191 L
.34084 .79637 L
.31035 .81379 L
.27797 .83436 L
.24337 .85827 L
.2062 .88577 L
.16609 .91713 L
.12263 .95266 L
.0754 .99273 L
s
.0754 .99273 m
.06709 1 L
s
0 .93291 m
.00727 .9246 L
.04734 .87737 L
.08287 .83391 L
.11423 .7938 L
.14173 .75663 L
.16564 .72203 L
.18621 .68965 L
.20363 .65916 L
.21809 .63027 L
.22973 .60269 L
.23867 .57613 L
.24498 .55033 L
.24875 .52504 L
.25 .5 L
.24875 .47496 L
.24498 .44967 L
.23867 .42387 L
.22973 .39731 L
.21809 .36973 L
.20363 .34084 L
.18621 .31035 L
.16564 .27797 L
.14173 .24337 L
.11423 .2062 L
.08287 .16609 L
.04734 .12263 L
.00727 .0754 L
s
.00727 .0754 m
0 .06709 L
s
.06709 0 m
.0754 .00727 L
.12263 .04734 L
.16609 .08287 L
.2062 .11423 L
.24337 .14173 L
.27797 .16564 L
.31035 .18621 L
.34084 .20363 L
.36973 .21809 L
.39731 .22973 L
.42387 .23867 L
.44967 .24498 L
.47496 .24875 L
.5 .25 L
.52504 .24875 L
.55033 .24498 L
.57613 .23867 L
.60269 .22973 L
.63027 .21809 L
.65916 .20363 L
.68965 .18621 L
.72203 .16564 L
.75663 .14173 L
.7938 .11423 L
.83391 .08287 L
.87737 .04734 L
.9246 .00727 L
s
.9246 .00727 m
.93291 0 L
s
1 .10496 m
.97247 .14017 L
.93879 .18569 L
.9095 .22807 L
.88432 .26773 L
.86297 .30507 L
.84526 .34045 L
.83101 .37423 L
.82007 .40676 L
.81233 .43835 L
.80772 .46933 L
.80619 .5 L
.80772 .53067 L
.81233 .56165 L
.82007 .59324 L
.83101 .62577 L
.84526 .65955 L
.86297 .69493 L
.88432 .73227 L
.9095 .77193 L
.93879 .81431 L
.97247 .85983 L
s
.97247 .85983 m
1 .89504 L
s
.89504 1 m
.85983 .97247 L
.81431 .93879 L
.77193 .9095 L
.73227 .88432 L
.69493 .86297 L
.65955 .84526 L
.62577 .83101 L
.59324 .82007 L
.56165 .81233 L
.53067 .80772 L
.5 .80619 L
.46933 .80772 L
.43835 .81233 L
.40676 .82007 L
.37423 .83101 L
.34045 .84526 L
.30507 .86297 L
.26773 .88432 L
.22807 .9095 L
.18569 .93879 L
.14017 .97247 L
s
.14017 .97247 m
.10496 1 L
s
0 .89504 m
.02753 .85983 L
.06121 .81431 L
.0905 .77193 L
.11568 .73227 L
.13703 .69493 L
.15474 .65955 L
.16899 .62577 L
.17993 .59324 L
.18767 .56165 L
.19228 .53067 L
.19381 .5 L
.19228 .46933 L
.18767 .43835 L
.17993 .40676 L
.16899 .37423 L
.15474 .34045 L
.13703 .30507 L
.11568 .26773 L
.0905 .22807 L
.06121 .18569 L
.02753 .14017 L
s
.02753 .14017 m
0 .10496 L
s
.10496 0 m
.14017 .02753 L
.18569 .06121 L
.22807 .0905 L
.26773 .11568 L
.30507 .13703 L
.34045 .15474 L
.37423 .16899 L
.40676 .17993 L
.43835 .18767 L
.46933 .19228 L
.5 .19381 L
.53067 .19228 L
.56165 .18767 L
.59324 .17993 L
.62577 .16899 L
.65955 .15474 L
.69493 .13703 L
.73227 .11568 L
.77193 .0905 L
.81431 .06121 L
.85983 .02753 L
s
.85983 .02753 m
.89504 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@2000`400?l00000o`00003oo`3ooooo
0?oood80oooo003o0?ooool0oooo@P3oool00?l0ooooo`3ooom20?ooo`00o`3ooooo0?oood80oooo
003o0?ooool0oooo@P3oool00?l0oooo4P3oool800000?l0oooo:03oool00?l0oooo4P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo9P3oool00?l0oooo4`3oool00`000000
oooo0?ooo`3o0?ooob`0oooo003o0?oooa@0oooo00<000000?ooo`3oool0o`3oool[0?ooo`00o`3o
oolE0?ooo`030000003oool0oooo0?l0oooo:P3oool001X0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0;`0oooo200000080?ooo`030000003oool0
oooo00X0oooo1000003H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0C0?ooo`006`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0180oooo0P00003=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0e`3oool20000
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`00703oool00`000000
oooo0?ooo`0D0?ooo`800000503oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool05@3oool001d0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0F0?ooo`007P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo0P00
003;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0d`3oool2000001D0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`007`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0603oool00200oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0=40oooo00<000000?oo
o`3oool04`3oool2000001H0oooo00<000000?ooo`3oool06@3oool00240oooo00<000000?ooo`3o
ool05@3oool2000001@0oooo0P0000320?ooo`@000002`3oool00`000000oooo0?ooo`3?0?ooo`80
00005@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo000R0?ooo`800000
5`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo0P00000M0?ooo`00903o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0c@3o
ool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0M0?ooo`009@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01<0oooo0P00003=0?ooo`030000003oool0oooo0</0oooo0P00000F0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool07P3oool002H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0bP3oool00`00
0000oooo0?ooo`0D0?ooo`8000005P3oool00`000000oooo0?ooo`0O0?ooo`009`3oool00`000000
oooo0?ooo`0E0?ooo`8000005@3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo0<T0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0200
oooo000X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04`3oool200000<T0oooo
0`0000370?ooo`8000005P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0240oooo
000<0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`050?ooo`003@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo0<D0oooo00<00000
0?ooo`3oool0503oool2000001L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`06
0?ooo`003P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo0<@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool01`3oool000l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01@0oooo0P0000340?ooo`030000003oool0oooo0<80oooo0P00000F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`00
403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo0P00000F0?ooo`030000
003oool0oooo0<40oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`004@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`300?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0503o
ool2000001P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`004P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0503oool2
00000<00oooo00<000000?ooo`3oool0_P3oool2000001H0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo000C0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0;d0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0<0?ooo`00503oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`2l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool001D0oooo
00<000000?ooo`3oool06P3oool2000001P0oooo0P00000F0?ooo`800000_03oool00`000000oooo
0?ooo`2j0?ooo`8000005`3oool00`000000oooo0?ooo`0F0?ooo`8000007@3oool00`000000oooo
0?ooo`0=0?ooo`005@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0;T0oooo00<0
00000?ooo`3oool05@3oool2000001P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0>0?ooo`005P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0;P0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool03`3oool001L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01D0oooo0P00002h0?ooo`030000003oool0oooo0;H0oooo0P00000G0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0@0?oo
o`00603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`2e0?ooo`<00000]@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0A0?ooo`00
6@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo0P00000G0?ooo`030000
003oool0oooo0;@0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0E0?ooo`800000
6@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo000J0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0E0?ooo`800000]03o
ool00`000000oooo0?ooo`2b0?ooo`8000005`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool04`3oool001/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01@0oooo000L0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0;00oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0E0?ooo`007@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05P3oool200000;00
oooo00<000000?ooo`3oool0[P3oool2000001P0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo000N0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0603oool2000001P0oooo00<000000?ooo`3oool0[@3oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo01H0oooo0P00000J0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool05`3oool001l0oooo00<000000?ooo`3oool0703oool2000001X0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0:`0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0H0?ooo`8000007P3oool00`000000oooo0?oo
o`0H0?ooo`00803oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05P3oool200000:`0oooo00<000000?ooo`3oool0ZP3oool2000001P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01T0oooo000Q0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?oo
o`00303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0G0?ooo`800000Z@3oool00`000000oooo0?ooo`2W0?ooo`80
00006@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`050?ooo`003@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0603oool2000001T0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo01L0oooo0P00000J0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`003P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0G0?ooo`800000YP3oool00`000000oooo0?ooo`2T0?ooo`8000006@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`070?ooo`003`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0:<0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00P0oooo000@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo0P00002S0?ooo`<00000X@3oool20000
01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool02@3oool00140oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`2P0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0:0?ooo`004P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool06@3oool2000001X0oooo0P00002P0?ooo`030000003oool0oooo09h0oooo
0P00000J0?ooo`8000006`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool02`3oool00180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0;0?ooo`004`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0oooo0P00000K
0?ooo`030000003oool0oooo01T0oooo0P00002M0?ooo`030000003oool0oooo09/0oooo0P00000K
0?ooo`030000003oool0oooo01T0oooo0P00000P0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0303oool001@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`2J0?oo
o`030000003oool0oooo09X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?oo
o`005@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0J0?ooo`800000VP3oool00`000000oooo0?ooo`2H0?ooo`80
0000703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0>0?ooo`005P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool06@3oool2000001`0oooo00<000000?ooo`3oool0
U`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo01X0oooo0P00000K0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`005`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`800000U`3oool00`000000oooo0?ooo`2E0?ooo`800000703o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0@0?ooo`005`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0100oooo000H0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0J0?ooo`800000703oool2000009@0oooo00<000000?ooo`3oool0TP3oool20000
01`0oooo0P00000L0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0A0?ooo`006@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180
oooo000J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01/0oooo0P00002A0?ooo`030000003oool0oooo08l0oooo
0P00000M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo000K0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0K0?ooo`8000007@3oool2000008l0oooo00<0
00000?ooo`3oool0S@3oool2000001d0oooo0P00000M0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`006`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo08`0oooo0`00002<0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0503oool001`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0P0?oo
o`8000007@3oool00`000000oooo0?ooo`0L0?ooo`800000S03oool00`000000oooo0?ooo`2:0?oo
o`8000007P3oool00`000000oooo0?ooo`0K0?ooo`8000008P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01D0oooo000M0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool05P3oool000`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool06`3oool2000001h0oooo0P0000290?ooo`030000
003oool0oooo08L0oooo0P00000N0?ooo`8000007@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`003@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`060?ooo`003P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01d0oooo0P0000260?ooo`030000003oool0oooo08@0oooo0P00000O0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01P3oool000h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0703oool20000
01l0oooo0P0000240?ooo`030000003oool0oooo0880oooo0P00000O0?ooo`8000007P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`070?ooo`003`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`00403oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01h0oooo0P0000210?ooo`030000003oool0oooo07l0oooo
0P00000P0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00140oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07@3oool200000200oooo00<000000?ooo`3oool0EP3oool7000000H0oooo0`00
00090?ooo`@000002`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01h0oooo0P00
000O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00T0oooo000A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool07P3oool2000005T0oooo00<000000?ooo`3oool01`3oool3000000P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07`0oooo0P00000P
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool00180oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0280oooo0P00000O0?oo
o`030000003oool0oooo01l0oooo0P00001G0?ooo`030000003oool0oooo00L0oooo0`0000070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1j0?oo
o`8000008@3oool00`000000oooo0?ooo`0M0?ooo`800000903oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool001<0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool07@3oool200000240oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0O0?ooo`80
00007`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0<0?ooo`00503oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01l0oooo0P00001D0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1g0?ooo`8000008@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00`0oooo000D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo0P00000Q0?ooo`800000@P3o
ool8000000P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`@00000M03o
ool200000240oooo0P00000P0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo000E0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0180oooo0P0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool0
01H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`800000C`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool00000008000002`3oool00`000000oooo0?ooo`1b0?oo
o`8000008P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo000G0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01l0oooo0P00000R0?ooo`800000C@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0L03oool200000280oooo0P00000Q0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo000G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0@0?ooo`00603oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`8000008P3o
ool2000004X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo06d0oooo0P00000R0?ooo`8000008P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`006@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0903oool2
00000280oooo00<000000?ooo`3oool08@3oool2000004@0oooo0`0000000`3oool000000?ooo`0C
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0J`3oool2000002<0oooo00<00000
0?ooo`3oool0803oool2000002H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0180oooo000J0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool08P3oool2000004D0oooo0P00000D0?ooo`H000002P3oool00`000000oooo0?ooo`1Y0?oo
o`800000903oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo000J0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0200oooo0P00000T0?ooo`800000J@3oool00`000000oooo0?ooo`1W0?ooo`80
0000903oool200000280oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool001/0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0S0?ooo`800000I`3oool00`000000oooo0?ooo`1U0?ooo`800000
9@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo000L0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0240oooo0P00000U0?ooo`800000I@3oool00`000000oooo0?ooo`1S0?ooo`8000009@3o
ool2000002<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool05@3oool001d0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0T0?ooo`800000H`3oool00`000000oooo0?ooo`1Q0?ooo`8000009P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo000M0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool09@3oool200000640oooo00<000000?ooo`3oool0G`3oool20000
02L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`007P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0R0?ooo`8000009`3oool2000005l0oooo00<000000?ooo`3oool0G@3oool2000002L0
oooo0P00000T0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo000O0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool09P3oool2000005d0oooo0`00001K0?ooo`800000:03oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01P0oooo000P0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0U0?ooo`800000903oool00`000000oooo0?oo
o`0W0?ooo`800000F`3oool00`000000oooo0?ooo`1I0?ooo`800000:@3oool00`000000oooo0?oo
o`0R0?ooo`8000009`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool06@3oool00200oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08P3oool2000002T0oooo0P00001I
0?ooo`030000003oool0oooo05L0oooo0P00000Y0?ooo`800000903oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I
0?ooo`008@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0oooo0P00001G0?oo
o`030000003oool0oooo05D0oooo0P00000Z0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool06P3oool00280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Y0?ooo`80
0000E@3oool00`000000oooo0?ooo`1C0?ooo`800000:`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01/0oooo000S0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02<0oooo0P00000[0?ooo`800000
D`3oool00`000000oooo0?ooo`1A0?ooo`800000:`3oool2000002D0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
703oool002<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Z0?ooo`<00000D03o
ool00`000000oooo0?ooo`1>0?ooo`<00000;03oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01`0oooo000T0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;03oool2
000004h0oooo00<000000?ooo`3oool0C03oool2000002h0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0M0?ooo`009@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0T0?ooo`800000;P3oool30000
04/0oooo00<000000?ooo`3oool0B@3oool3000002h0oooo0P00000V0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01h0oooo000V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;P3oool2000004T0
oooo00<000000?ooo`3oool0A`3oool200000300oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0O0?ooo`009P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool09`3oool2000002H0oooo0P00000`0?ooo`800000A`3oool00`000000oooo
0?ooo`150?ooo`800000<03oool2000002H0oooo0P00000Y0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?ooo`009`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0U0?ooo`800000<03oool3000004@0oooo00<000000?ooo`3oool0@P3oool300000300oooo0P00
000W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0200oooo000X0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0<03oool300000440oooo00<000000?ooo`3oool0?`3oool300000380oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0Q0?ooo`00:@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0V0?oo
o`800000<`3oool3000003h0oooo00<000000?ooo`3oool0?03oool3000003<0oooo0P00000X0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0280oooo000Y0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02L0oooo0P00000d0?ooo`<0
0000>`3oool3000003T0oooo0`00000d0?ooo`800000:@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0R0?ooo`00
:P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03@0oooo0`00000h0?ooo`030000
003oool0oooo03H0oooo0`00000f0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
8`3oool002/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool2000003L0oooo0`00000e0?ooo`030000003o
ool0oooo03<0oooo0`00000g0?ooo`800000:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0T0?ooo`00;03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03L0oooo1000000a0?ooo`030000003oool0
oooo02l0oooo1000000i0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool0
02`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
02T0oooo0P00000Z0?ooo`800000>`3oool4000002d0oooo00<000000?ooo`3oool0:`3oool40000
03/0oooo0P00000Z0?ooo`800000:`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool09@3oool002d0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool2000003d0
oooo1@00000X0?ooo`030000003oool0oooo02H0oooo1@00000m0?ooo`800000:`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0V0?ooo`00;P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03l0oooo
1000000T0?ooo`030000003oool0oooo0280oooo100000110?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool09`3oool002l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool2000004<0oooo1@00
000O0?ooo`030000003oool0oooo01d0oooo1@0000130?ooo`800000;03oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0X0?ooo`00;`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0[0?ooo`800000AP3oool6000001T0oooo00<00000
0?ooo`3oool05`3oool6000004H0oooo0P00000]0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02P0oooo000`0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0B@3oool6000001<0oooo00<000000?oo
o`3oool04@3oool6000004/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Y0?oo
o`00<@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0/0?ooo`800000C`3ooolW000004l0oooo0P00000^0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo02X0oooo000a0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0[0?ooo`800000;P3oool200000600oooo00<000000?ooo`3oool0
GP3oool2000002h0oooo0P00000]0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0Z0?ooo`00<P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`800000GP3o
ool00`000000oooo0?ooo`1L0?ooo`800000;`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0[0?ooo`00<`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
02h0oooo0P00001K0?ooo`<00000F@3oool200000300oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;03oool003@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0;`3oool2000005T0oooo00<000000?ooo`3oool0E`3oool200000340
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0;@3oool003D0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0<03oool2000005L0oooo
00<000000?ooo`3oool0E@3oool200000380oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;P3oool003D0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02`0oooo0P00
000b0?ooo`800000E@3oool00`000000oooo0?ooo`1C0?ooo`800000<P3oool2000002h0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02h0oooo000f
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo0340oooo0P00001C0?ooo`030000003oool0oooo0540oooo0P00000c
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo02l0oooo000g0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0380oooo0P00001A0?oo
o`030000003oool0oooo04l0oooo0P00000d0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0300oooo000g0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo03<0oooo0P00001?0?ooo`030000003oool0oooo04d0oooo0P00000e0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0300oooo000h0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0^0?ooo`800000=@3oool2000004d0oooo00<000000?ooo`3oool0
B`3oool2000003D0oooo0P00000`0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0a0?ooo`00>@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0d0?ooo`800000B`3o
ool00`000000oooo0?ooo`190?ooo`800000=P3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0b0?ooo`00>@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0e0?ooo`800000B@3oool00`000000oooo0?ooo`170?ooo`800000=`3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0b0?ooo`00>P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0f0?ooo`800000A`3oool00`00
0000oooo0?ooo`150?ooo`800000>03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0c0?ooo`00>`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0g0?ooo`<00000A03oool00`000000oooo0?ooo`120?ooo`<00000>@3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0;`3oool2000003X0oooo0P0000120?ooo`030000003oool0oooo0400oooo
0P00000j0?ooo`800000<@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0=03oool003`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0>@3oool3000003l0oooo00<0
00000?ooo`3oool0?@3oool3000003/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=@3oool003d0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0>`3oool3000003`0oooo0`00000j0?ooo`<00000?@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0f
0?ooo`00?@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0m0?ooo`800000>P3oool00`000000oooo0?ooo`0h0?oo
o`800000?`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0f0?ooo`00?P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0<@3oool2000003l0oooo0`00000g0?ooo`03
0000003oool0oooo03D0oooo0`00000o0?ooo`800000<`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0=`3oool003l0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
?`3oool3000003@0oooo00<000000?ooo`3oool0<P3oool300000440oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>03oool003l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0@@3oool300000340oooo00<000000?ooo`3oool0;`3o
ool3000004<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0>03oool00400oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0@`3oool3
000002h0oooo00<000000?ooo`3oool0;03oool3000004D0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>@3oool0
0440oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0380oooo0P0000160?ooo`<00000:`3oool00`000000oooo0?ooo`0Y0?ooo`<00000AP3oool20000
03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
03X0oooo00110?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo04H0oooo0`00000X0?ooo`030000003oool0oooo02H0
oooo0`0000180?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo03X0oooo00120?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04P0oooo
1000000T0?ooo`030000003oool0oooo0280oooo1000001:0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03/0oooo
00120?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo04/0oooo0`00000A0?ooo`L000002@3oool00`000000oooo0?oo
o`0O0?ooo`<00000C@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0k0?ooo`00@`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool2000004h0oooo1000000@
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool06`3oool4000004h0oooo0P00000f
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0l
0?ooo`00A03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`1?0?ooo`D000002`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo1@00001A0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03d0oooo00140?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo05<0oooo1`0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03`3oool7000005D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0?@3oool004D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
F@3oool;000000H0oooo00<000000?ooo`3oool0103oool;000005/0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
?P3oool004H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo03D0oooo0P00001=0?ooo`P00000203oool00`000000oooo0?ooo`040?ooo`d00000I03o
ool2000003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo03l0oooo00160?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03l0oooo00170?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0400oooo00180?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0g0?ooo`800000F@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06@0
oooo0P00000i0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`110?ooo`00B03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`110?ooo`00B@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`120?ooo`00B@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0>03oool200000540oooo0`0000000`3oool000000?ooo`0;0?ooo`030000003oool0
oooo0600oooo0P00000k0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`120?ooo`00BP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1A0?ooo`800000303oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04<0oooo001;0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`140?ooo`00B`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>P3oool2000005h0oooo
00<000000?ooo`3oool0G03oool2000003`0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04@0oooo001<0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`150?ooo`00C@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>`3oool2000005/0oooo00<00000
0?ooo`3oool0F@3oool2000003d0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04H0oooo001=0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`160?ooo`00CP3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0A`3oool004h0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03d0oooo0P00001G0?ooo`<00000
E@3oool2000003l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo04L0oooo001?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`180?ooo`00D03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0?P3oool2000005@0oooo00<000000?ooo`3oool0DP3oool2
00000400oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo04T0oooo001@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`190?ooo`00D@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0@03oool200000540oooo00<000000?ooo`3oool0C`3oool200000480
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04X0
oooo001A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`1:0?ooo`00DP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0@@3oool2000004h0oooo00<000000?ooo`3oool0C03oool2000004<0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04/0oooo001C
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1<
0?ooo`00D`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0@`3oool2000004/0oooo00<000000?ooo`3oool0B@3oool2000004D0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04`0oooo001D0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1=0?ooo`00
E03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
A03oool2000004P0oooo00<000000?ooo`3oool0AP3oool2000004H0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04d0oooo001E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1>0?ooo`00EP3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0A@3oool2
000004D0oooo00<000000?ooo`3oool0@`3oool2000004L0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04l0oooo001F0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1?0?ooo`00E`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0A`3oool200000480
oooo0`0000100?ooo`800000B@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0D03oool005L0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo04P0oooo0P0000100?ooo`030000003oool0oooo03h0oooo
0P00001:0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1@0?ooo`00F03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0D@3oool005T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo04T0oooo0P00000m0?ooo`030000003oool0oooo03/0oooo0P00001;
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1A
0?ooo`00F@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0B`3oool2000003/0oooo00<000000?ooo`3oool0>@3oool2000004d0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0580oooo001J0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1<0?ooo`80
0000>@3oool00`000000oooo0?ooo`0g0?ooo`800000CP3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0DP3oool005X0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04d0oooo0P00000g0?ooo`030000
003oool0oooo03D0oooo0P00001?0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`1C0?ooo`00F`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0CP3oool2000003D0oooo00<000000?ooo`3oool0<`3o
ool200000500oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05<0oooo001K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`1@0?ooo`800000<`3oool00`000000oooo0?ooo`0a0?ooo`800000DP3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0E03oool0
05`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0540oooo0P00000a0?ooo`030000003oool0oooo02l0oooo0P00001C0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1D0?ooo`00G03oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0DP3oool2000002l0
oooo00<000000?ooo`3oool0;@3oool2000005@0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo05D0oooo001M0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1C0?ooo`800000;@3oool00`000000oooo
0?ooo`0[0?ooo`800000E@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0E@3oool005d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo05D0oooo0P00000[0?ooo`030000003oool0oooo02T0oooo0P00
001G0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`1F0?ooo`00GP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0EP3oool2000002T0oooo00<000000?ooo`3oool09`3oool2000005P0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05H0oooo001N0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1G0?oo
o`8000009`3oool3000002D0oooo0P00001I0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`1G0?ooo`00G`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0F03oool4000002<0oooo00<000000?ooo`3o
ool08@3oool4000005X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo05L0oooo001O0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`1L0?ooo`<00000803oool00`000000oooo0?ooo`0N0?ooo`<00000
GP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
F03oool00600oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo05h0oooo0`00000M0?ooo`030000003oool0oooo01/0oooo0`00001P0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1H0?ooo`00H03oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0H03oool3
000001X0oooo00<000000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05T0oooo001Q0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1S0?ooo`<000005`3oool00`00
0000oooo0?ooo`0E0?ooo`<00000I@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0F@3oool00640oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo06D0oooo1000000C0?ooo`030000003oool0oooo0140
oooo1000001W0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1J0?ooo`00HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0J03oool4000000l0oooo00<000000?ooo`3oool03@3oool4000006X0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05X0oooo
001R0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`1[0?ooo`L00000203oool00`000000oooo0?ooo`060?ooo`L00000K@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0F`3oool00680oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0780oooo4@00001d
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1K
0?ooo`00H`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`1L0?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1L0?ooo`00
I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1M0?ooo`00I03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0M`3oool3000007L0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05d0oooo001U0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05h0oooo001U0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo05h0oooo001U0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05h0
oooo001V0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo05l0oooo001V0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05l0oooo001W
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0600oooo001W0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0780oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0600oooo001W0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0600oooo001X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`1:0?ooo`@00000203oool3000000T0oooo1000000;0?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0640oooo001X0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool3000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0640oooo001Y0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool3
000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0680oooo001Y0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0680oooo001Z0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06h0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06<0
oooo001Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0i0?ooo`P00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01`3oool4000006d0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo06<0oooo001Z0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool2000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`1S0?ooo`00J`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`0000000P00000;0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06@0oooo001[0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
06@0oooo001[0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo06@0oooo001/0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06/0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06D0oooo
001/0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo06D0oooo001/0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`120?ooo`@000004`3oool6000000X0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0I@3oool006d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0IP3oool006d0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0IP3oool006d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0IP3oool006h0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0I`3o
ool006h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0I`3oool006h0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0I`3oool006l0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06D0
oooo0`00001V0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1X0?ooo`00K`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1X0?ooo`00K`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1X0?ooo`00L03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1Y0?ooo`00L03oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1Y0?oo
o`00L03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`1Y0?ooo`00L03oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1Y0?ooo`00L@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1Z0?ooo`00L@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1Z0?ooo`00L@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0H@3oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1Z0?ooo`00L@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1Z0?ooo`00LP3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1[0?ooo`00LP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1[0?ooo`00LP3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1[
0?ooo`00LP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0GP3oool3000005l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo06/0oooo001b0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06/0oooo001c0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo06`0oooo001c0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06`0oooo001c0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo06`0oooo001c0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo06`0oooo001d0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06d0
oooo001d0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo06d0oooo001d0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06d0oooo001d
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo06d0oooo001d0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0oooo001e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo06h0oooo001e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06h0oooo001e0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo06h0oooo001e0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`1J0?ooo`<00000FP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0KP3oool007D0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0KP3oool007D0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0KP3oool007H0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0K`3oool007H0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0K`3oool000h0oooo2000000b0?ooo`L000001P3oool3000000T0oooo1000000A
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool7000002H0oooo00<00000
0?ooo`3oool02P3oool4000000P0oooo0`0000090?ooo`@00000<P3oool00`000000oooo0?ooo`0e
0?ooo`@00000203oool3000000T0oooo100000070?ooo`030000003oool0oooo02X0oooo1`00000M
0?ooo`030000003oool0oooo01<0oooo1`0000060?ooo`<000002@3oool4000003<0oooo20000004
0?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool01`3oool3000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`<00000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`0000080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0000001h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?oo
o`<00000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`003`3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00L0oooo0`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool3000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`<0
00001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0000000N0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool01`3oool3000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00P0oooo000@0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0000001h0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
1`3oool00140oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`0000007@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`060?ooo`000P3oool8
000000P0oooo00<000000?ooo`3oool09P3oool8000000P0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo2@0000070?ooo`030000003oool0
oooo02H0oooo200000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0000000M0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00D0oooo000C0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool04P3oool2000000<0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool20000
00<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03`3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0^0?ooo`8000007P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0180oooo0P0000030?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0103oool001@0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`030000003oool000000080
00004P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0000000200000380oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000000P0000060?ooo`03
0000003oool0oooo02h0oooo0P00000N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo00000002000003T0oooo00<000000?ooo`3oool00`3oool001D0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02l0oooo
0P00000N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0080oooo000E0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03@0oooo0`00
000c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02l0oooo0P00000N0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo000>
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02l0oooo0P00000N0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?oo
o`<0000000<0oooo0000003oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`0Z0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`<0000000<0oooo0000
000000007P3oool00`000000oooo0?ooo`0C0?ooo`<0000000<0oooo0000003oool04`3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00100
oooo1000000f0?ooo`800000503oool600000140oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`800000:`3oool00`000000oooo0?ooo`080?ooo`@000004`3oool600000340
oooo00<000000?ooo`3oool0=@3oool4000001<0oooo1P0000040?ooo`030000003oool0oooo02h0
oooo0`00000N0?ooo`030000003oool0oooo01H0oooo0P00000D0?ooo`H00000=03oool4000000H0
oooo001g0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0700oooo001g0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0700oooo001g
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0700oooo001g0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0700oooo001g0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0700oooo001g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0700oooo001g0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0700oooo001g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0700oooo001g0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0700oooo001g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0700oooo000<0?ooool00000o`00000_000000L0oooo
000<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?oo
o`3oool0000000d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`050?ooo`00303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000090?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool000`0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
1@3oool007L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0L03oool007L0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0L03oool0
07L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0L03oool007L0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0L03oool007L0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0L03oool007L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0L03oool007L0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0L03oool007L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0L03oool007L0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0L03oool007L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0L03oool007L0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05H0oooo0`00001F0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1`0?ooo`00M`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`1`0?ooo`00M`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1`0?ooo`00M`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1`0?ooo`00M`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1`0?ooo`00M`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`1`0?ooo`00MP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1_0?ooo`00MP3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1_0?oo
o`00MP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1_0?ooo`00MP3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1_0?ooo`00MP3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`1_0?ooo`00MP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1_0?ooo`00M@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`1^0?ooo`00M@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1^0?ooo`00M@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0FP3oool3000005X0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06h0oooo
001e0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo06h0oooo001e0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06h0oooo001e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo06h0oooo001d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0oooo001d0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo06d0oooo001d0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06d0oooo001d0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo06d0oooo001d0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo06d0oooo001c0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06`0
oooo001c0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1M0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo06`0oooo001c0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06`0oooo001c
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo06`0oooo001b0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06/0oooo001b0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1N0?ooo`<0
0000G`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0J`3oool00780oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0J`3oool00780oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0J`3o
ool00780oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0J`3oool00740oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0H@3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0JP3oool00740
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0JP3oool00740oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0JP3oool00740oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0JP3oool00700oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0J@3oool00700oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0J@3oool00700oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0J@3oool00700oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
J@3oool006l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0J03oool006l0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0J03oool0
06l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
06D0oooo0`00001V0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1X0?ooo`00KP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1W0?ooo`00KP3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1W0?ooo`00KP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1W0?ooo`00K@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1V
0?ooo`00K@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0J03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1V0?ooo`00K@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1V0?ooo`00
K03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1U0?ooo`00K03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1U0?ooo`00K03oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0A03oool4
000000P0oooo0`0000090?ooo`@000002`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1U0?ooo`00J`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`0000080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1T0?ooo`00J`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`0000070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1T0?ooo`00J`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`1T0?ooo`00JP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1S0?ooo`00JP3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool4000006d0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06<0oooo001Z0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool2000000<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1S0?ooo`00J@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`0000000P00000;0?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0680
oooo001Y0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0680oooo001X0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0640oooo001X
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0640oooo001W0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0780oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0600oooo001W0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1;0?ooo`@0
00004`3oool6000000X0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0H03oool006L0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
H03oool006H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0G`3oool006H0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0G`3oool0
06D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0GP3oool006D0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0GP3oool006D0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0GP3oool006@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo07L0oooo0`00001g0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1M0?ooo`00I03oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1M
0?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`1L0?ooo`00H`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1L0?ooo`00
HP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
LP3ooolA000007@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo05/0oooo001R0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`1[0?ooo`L00000203oool00`000000oooo0?ooo`060?ooo`L00000K@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0F`3o
ool00680oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo06P0oooo1000000?0?ooo`030000003oool0oooo00d0oooo1000001Z0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1J0?ooo`00H@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0I@3oool40000
01<0oooo00<000000?ooo`3oool04@3oool4000006L0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo05X0oooo001Q0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1S0?ooo`<000005`3oool00`000000
oooo0?ooo`0E0?ooo`<00000I@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0F@3oool00600oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0600oooo0`00000J0?ooo`030000003oool0oooo01P0oooo
0`00001R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`1I0?ooo`00H03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0GP3oool3000001d0oooo00<000000?ooo`3oool06`3oool300000600oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05P0oooo001O
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1K
0?ooo`@00000803oool00`000000oooo0?ooo`0N0?ooo`@00000G@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0F03oool005l0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05P0oooo0`00000T0?oo
o`030000003oool0oooo0280oooo0`00001J0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`1G0?ooo`00GP3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0EP3oool3000002L0oooo0`00000U0?ooo`<0
0000F03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0E`3oool005h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo05D0oooo0P00000Z0?ooo`030000003oool0oooo02P0oooo0P00001G0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1F0?ooo`00G@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0E03o
ool2000002`0oooo00<000000?ooo`3oool0:P3oool2000005H0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05H0oooo001M0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1B0?ooo`800000;P3oool0
0`000000oooo0?ooo`0/0?ooo`800000E03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0E@3oool005`0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0540oooo0P00000`0?ooo`030000003oool0oooo
02h0oooo0P00001C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1E0?ooo`00G03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0D03oool200000380oooo00<000000?ooo`3oool0<03oool200000580
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05@0
oooo001K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`1?0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000D@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0E03oool005/0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04d0oooo0P00
000f0?ooo`030000003oool0oooo03@0oooo0P00001?0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`1C0?ooo`00FP3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0C03oool2000003P0oooo00<00000
0?ooo`3oool0=P3oool2000004h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo05<0oooo001J0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`1;0?ooo`800000>P3oool00`000000oooo0?ooo`0h0?oo
o`800000C@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0DP3oool005T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0580oooo001I0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`190?ooo`800000?@3oool00`000000oooo0?ooo`0k0?ooo`800000
B`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
D@3oool005P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0540oooo001G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`180?ooo`800000@03oool00`000000oooo0?ooo`0n0?ooo`800000BP3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0D03oool0
05L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
04L0oooo0P0000120?ooo`<00000@03oool2000004T0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0500oooo001F0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1?0?ooo`00EP3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0A@3oool2000004D0oooo
00<000000?ooo`3oool0@`3oool2000004L0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04l0oooo001E0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`1>0?ooo`00E03oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0A03oool2000004P0oooo00<00000
0?ooo`3oool0AP3oool2000004H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04d0oooo001D0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`1=0?ooo`00D`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0@`3oool2000004/0oooo00<000000?ooo`3o
ool0B@3oool2000004D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo04`0oooo001C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`1<0?ooo`00DP3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0@@3oool2000004h0oooo00<000000?ooo`3oool0C03o
ool2000004<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo04/0oooo001A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`1:0?ooo`00D@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0@03oool200000540oooo00<000000?ooo`3oool0C`3oool20000
0480oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
04X0oooo001@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`190?ooo`00D03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0?P3oool2000005@0oooo00<000000?ooo`3oool0DP3oool200000400oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04T0oooo
001?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`180?ooo`00CP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0?@3oool2000005L0oooo0`00001E0?ooo`800000?`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A`3oool004h0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04L0oooo001=0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`160?ooo`00
C@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
>`3oool2000005/0oooo00<000000?ooo`3oool0F@3oool2000003d0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo001<0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`150?ooo`00B`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>P3oool2
000005h0oooo00<000000?ooo`3oool0G03oool2000003`0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04@0oooo001;0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`140?ooo`00BP3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool004T0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03P0oooo
0P00001R0?ooo`030000003oool0oooo0600oooo0P00000k0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`120?ooo`00B@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`1B0?ooo`L000002@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0480oooo0018
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0440oooo00180?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0g0?ooo`800000F@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo06@0oooo0P00000i0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`110?ooo`00A`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`100?ooo`00
AP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0o0?ooo`00AP3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0=@3oool2000005d0oooo00<000000?ooo`3oool00`3o
ool?000006<0oooo0P00000g0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0o0?ooo`00A@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1I0?ooo`X000001`3oool0
0`000000oooo0?ooo`050?ooo`X00000F`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0n0?ooo`00A03oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1C0?ooo`L00000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00l0oooo1`00001E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo03d0oooo00140?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo04l0
oooo1@00000;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool500000540
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0?@3oool004<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03@0oooo0P00001>0?ooo`@00000403oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01/0oooo1000001>0?ooo`800000=P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?03oool00480oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0B`3oool3000001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0O0?ooo`<00000C@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0k0?ooo`00@P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`18
0?ooo`@000004`3oool3000000030?ooo`000000oooo00/0oooo00<000000?ooo`3oool08P3oool4
000004X0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0>`3oool00440oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0AP3oool30000
01X0oooo0P00000<0?ooo`030000003oool0oooo02H0oooo0`0000180?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
03X0oooo00110?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0b0?ooo`800000AP3oool3000002/0oooo00<000000?ooo`3oool0:@3oool3000004H0
oooo0P00000d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0j0?ooo`00@03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`130?ooo`<00000;P3oool00`000000oooo
0?ooo`0/0?ooo`<00000A@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`110?ooo`<00000<@3oool00`000000oooo0?ooo`0_0?ooo`<00000@`3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0h0?ooo`00?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0o0?ooo`<00000=03oool00`000000oooo0?ooo`0b
0?ooo`<00000@@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0h0?ooo`00?P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<@3oool2000003l0oooo0`00000g0?oo
o`030000003oool0oooo03D0oooo0`00000o0?ooo`800000<`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=`3oool003d0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0?03oool3000003X0oooo00<000000?ooo`3oool0>03oool3000003h0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0=P3oool003d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0>`3oool2000003d0oooo0`00000k0?ooo`800000
?@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0f0?ooo`00?03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0i0?ooo`<00000?`3o
ool00`000000oooo0?ooo`0m0?ooo`<00000>`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0e0?ooo`00>`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;`3oool2
000003T0oooo0`0000120?ooo`030000003oool0oooo0400oooo0`00000i0?ooo`800000<@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=03oool0
03/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0=`3oool2000004D0oooo00<000000?ooo`3oool0@`3oool20000
03T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0=03oool003X0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0=@3oool3000004L0
oooo00<000000?ooo`3oool0A@3oool3000003L0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<`3oool003T0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0=03oool2000004X0oooo00<000000?ooo`3oool0B03oool2000003H0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0<P3oool003T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02h0oooo0P00000e0?ooo`800000C03oool00`000000oooo0?oo
o`1:0?ooo`800000=@3oool200000300oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0380oooo000h0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03<0oooo0P00001>
0?ooo`030000003oool0oooo04`0oooo0P00000e0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0340oooo000g0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0380oooo0P00001@0?ooo`030000003oool0oooo04h0oooo0P00000d0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0300oooo000g0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0340oooo0P00001B0?ooo`03
0000003oool0oooo0500oooo0P00000c0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0300oooo000f0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0300oooo0P00001D0?ooo`030000003oool0oooo0580oooo0P00000b0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo02l0oooo000e0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0/0?ooo`800000<@3oool2000005H0oooo00<000000?ooo`3oool0E03o
ool200000340oooo0P00000^0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0^0?ooo`00=@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo02h0oooo000d0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo0P00001I0?ooo`030000003oool0oooo
05L0oooo0P00000a0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo02d0oooo000c0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02h0
oooo0P00001K0?ooo`<00000F@3oool200000300oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;03oool003<0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0/0?ooo`00<P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0]0?ooo`800000GP3oool00`000000oooo0?ooo`1L0?ooo`800000;`3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0[0?ooo`00<@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0:`3oool2000002h0oooo0P00001P0?ooo`030000003oool0oooo05h0oooo0P00000^
0?ooo`800000;@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0:P3oool00340oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;03oool2000004l0oooo9`00001?0?oo
o`800000;P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0Z0?ooo`00<03oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo04T0oooo1P00000C0?ooo`030000003oool0oooo0140oooo1P00001;0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0:@3oool002l0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
:`3oool2000004H0oooo1P00000I0?ooo`030000003oool0oooo01L0oooo1P0000160?ooo`800000
;@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0X0?ooo`00;`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`800000@`3o
ool5000001l0oooo00<000000?ooo`3oool07@3oool5000004<0oooo0P00000/0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo02P0oooo000^0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0?`3oool4
000002@0oooo00<000000?ooo`3oool08P3oool400000440oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0W0?ooo`00;@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`800000?@3oool50000
02P0oooo00<000000?ooo`3oool09P3oool5000003d0oooo0P00000[0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
02H0oooo000/0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0Y0?ooo`800000:P3oool2000003/0oooo1000000]0?ooo`030000003oool0oooo02/0
oooo1000000k0?ooo`800000:P3oool2000002/0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo02D0oooo000/0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0=`3oool400000340oooo00<000000?ooo`3oool0;`3oool4000003T0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`00:`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0X0?ooo`800000=`3oool3000003D0oooo00<000000?ooo`3oool0<`3oool3000003L0oooo0P00
000Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo02@0oooo000Z0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02L0oooo0P00000f
0?ooo`<00000>03oool00`000000oooo0?ooo`0f0?ooo`<00000=P3oool2000002T0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool08`3oool002T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0c0?oo
o`<00000>`3oool3000003T0oooo0`00000e0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool08P3oool002T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool09P3oool2000003<0oooo0`00000n0?ooo`03
0000003oool0oooo03`0oooo0`00000c0?ooo`800000:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0R0?ooo`00
:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0300oooo0`0000110?ooo`030000
003oool0oooo03l0oooo0`00000b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
8@3oool002L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool09@3oool200000300oooo0`0000140?ooo`030000003o
ool0oooo0480oooo0`00000`0?ooo`8000009`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0P0?ooo`009P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool09`3oool2
000002H0oooo0P00000`0?ooo`800000A`3oool00`000000oooo0?ooo`150?ooo`800000<03oool2
000002H0oooo0P00000Y0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0O0?ooo`009P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02h0oooo0P0000190?ooo`030000003oool0oooo04L0oooo0P00000`0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool07`3oool002D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0903oool2000002h0
oooo0`00001;0?ooo`030000003oool0oooo04T0oooo0`00000^0?ooo`8000009P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0N0?ooo`00903oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02`0oooo
0P00001>0?ooo`030000003oool0oooo04`0oooo0P00000^0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool07@3oool002<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0Z0?ooo`<00000D03oool00`000000oooo0?ooo`1>0?ooo`<00000;03oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01`0oooo000S0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02<0oooo0P00000[
0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000:`3oool2000002D0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0703oool00280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Y0?oo
o`800000E@3oool00`000000oooo0?ooo`1C0?ooo`800000:`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01/0oooo000Q0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool09`3oool3000005L0oooo00<000000?ooo`3oool0E@3oool3000002T0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0J0?ooo`00803oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`800000
:03oool2000005X0oooo00<000000?ooo`3oool0F03oool2000002P0oooo0P00000T0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01T0oooo000P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0U0?ooo`800000903oool00`000000oooo0?ooo`0V0?ooo`800000G03o
ool00`000000oooo0?ooo`1J0?ooo`800000:03oool00`000000oooo0?ooo`0R0?ooo`8000009`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06@3o
ool001l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0U0?ooo`800000GP3oool3
000005`0oooo0P00000W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool0
01h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool08P3oool2000002H0oooo0P00001P0?ooo`030000003oool0oooo
05h0oooo0P00000V0?ooo`800000903oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`007@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo02@0oooo0P00001R0?ooo`030000003oool0oooo0600
oooo0P00000V0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool001d0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`800000I03oool00`000000oooo
0?ooo`1R0?ooo`8000009@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo
000L0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo0240oooo0P00000T0?ooo`800000IP3oool00`000000oooo0?oo
o`1T0?ooo`800000903oool2000002<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05@3oool001/0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`800000J03oool00`000000oooo0?ooo`1V
0?ooo`800000903oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo000J0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo0200oooo0P00000S0?ooo`800000JP3oool00`000000oooo0?ooo`1X0?oo
o`8000008`3oool200000280oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool001X0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04P3oool001T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo02@0oooo0P00000R0?ooo`030000003oool0oooo0240oooo0P00001]0?ooo`030000
003oool0oooo06/0oooo0P00000S0?ooo`030000003oool0oooo0200oooo0P00000V0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`00603o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0P0?ooo`8000008P3oool2000004L0oooo1`0000060?ooo`<000002@3o
ool4000000/0oooo00<000000?ooo`3oool0K@3oool200000280oooo0P00000R0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0140oooo000G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00L0oooo0`0000080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`005`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0O0?ooo`8000008P3oool2000004d0oooo00<000000?ooo`3oool01`3oool30000
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0700oooo0P00000R0?ooo`8000008@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`005P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo0P00001?0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1b0?ooo`8000008P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo000E0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`00503oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0N0?ooo`8000008@3oool200000580oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`070?ooo`@00000M03oool200000240oooo0P00000P0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo000D
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07`3oool2000005@0oooo00<00000
0?ooo`3oool04P3oool2000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1g
0?ooo`8000008@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo000C0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01d0oooo0P00000Q0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool04P3oool00`000000oooo00000002000000/0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`0O0?ooo`8000007`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`004P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08P3oool2000001l0
oooo00<000000?ooo`3oool07`3oool2000005L0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo07X0oooo0P00000Q0?ooo`030000003oool0oooo01d0
oooo0P00000T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0;0?ooo`004@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo
0P00001I0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1l0?ooo`800000803oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo
000A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo01d0oooo0P00000P0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool07P3oool2000001l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00100oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`800000F03oool3000000030?ooo`000000
oooo01<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1o0?ooo`800000803oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo000?0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1K0?ooo`800000503oool60000
00X0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0203oool000h0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0703oool2000001l0
oooo0P0000240?ooo`030000003oool0oooo0880oooo0P00000O0?ooo`8000007P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`070?ooo`003P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo
0P0000260?ooo`030000003oool0oooo08@0oooo0P00000O0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01P3oool000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool000`0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool06`3oool2000001h0oooo0P0000290?ooo`030000003oool0oooo08L0oooo0P00000N
0?ooo`8000007@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`007@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01H0oooo000L0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0803oool2000001d0oooo00<000000?ooo`3oool0703oool2000008`0oooo00<000000?ooo`3o
ool0RP3oool2000001h0oooo00<000000?ooo`3oool06`3oool200000280oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0E0?ooo`006`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool06`3oool2000001h0oooo00<000000?ooo`3oool0
S03oool3000008`0oooo00<000000?ooo`3oool0703oool2000001d0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo000J0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo0P00002?0?ooo`030000003oool0oooo08d0oooo0P00000N0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo000I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo0P00002A0?ooo`030000003oool0
oooo08l0oooo0P00000M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo000H0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool04@3oool001P0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01X0oooo0P00000L0?ooo`800000U03oool00`000000
oooo0?ooo`2B0?ooo`800000703oool2000001`0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000G0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0403oool001H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool2000009L0oooo00<0
00000?ooo`3oool0U@3oool2000001`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool001D0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01T0oooo0P00000L
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0J
0?ooo`8000006`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool03P3oool001@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool2000009X0oooo00<000000?oo
o`3oool0V03oool2000001`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool001<0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0<0?ooo`004`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01h0oooo0P00000K0?ooo`030000003oool0oooo01T0oooo0P00002M0?ooo`030000
003oool0oooo09/0oooo0P00000K0?ooo`030000003oool0oooo01T0oooo0P00000P0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00180oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01T0oooo0P00000K0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0I0?ooo`8000006`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3o
ool00140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool06@3oool200000:00oooo00<000000?ooo`3oool0WP3oool2
000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool02P3oool00100oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`2P0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`090?ooo`003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`800000X`3oool300000:40
oooo0P00000J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000>0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool01`3oool000h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01P0oooo0P00000I0?ooo`800000YP3oool00`000000oooo0?oo
o`2T0?ooo`8000006@3oool2000001X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00L0oooo000=0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool01P3oool000`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool200000:T0oooo00<000000?oo
o`3oool0Y`3oool2000001T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0Z@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo000P0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0F0?ooo`800000
[03oool00`000000oooo0?ooo`2Z0?ooo`800000603oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool06@3oool001l0oooo00<000000?ooo`3oool0703o
ool2000001T0oooo0P00000H0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0[03o
ool00`000000oooo0?ooo`0F0?ooo`8000006@3oool2000001h0oooo00<000000?ooo`3oool0603o
ool001h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01L0oooo000M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0F0?ooo`800000/03oool00`000000oooo0?ooo`2^0?ooo`800000603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05P3oool001`0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0
oooo000K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0D0?ooo`006P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo0P00
000G0?ooo`800000]03oool00`000000oooo0?ooo`2b0?ooo`8000005`3oool2000001T0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`006@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04P3oool001P0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0]@3oool300000;D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool04@3oool001L0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01D0oooo0P00002h0?ooo`03
0000003oool0oooo0;H0oooo0P00000G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0@0?ooo`005P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2h0?ooo`030000
003oool0oooo0;P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool03`3oool001D0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0^@3o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01D0oooo0P00000H0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool03P3oool001D0oooo00<000000?ooo`3oool06P3oool2
000001P0oooo0P00000F0?ooo`800000_03oool00`000000oooo0?ooo`2j0?ooo`8000005`3oool0
0`000000oooo0?ooo`0F0?ooo`8000007@3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`2l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool001<0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0
oooo000B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0D0?ooo`800000`03oool00`000000oooo0?ooo`2n0?ooo`8000005P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02`3oool00140oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0`03oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01@0oooo0P00
000H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02P3oool00100oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`8000005P3oool00`000000oooo0?ooo`31
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool000l0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01@0oooo0P0000340?oo
o`030000003oool0oooo0<80oooo0P00000F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`080?ooo`003P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`340?ooo`03
0000003oool0oooo0<@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool000d0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
a@3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo01@0oooo0P00000G0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000`0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo0P0000380?ooo`030000003o
ool0oooo0<H0oooo0P00000F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0b03oool300000<P0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0240oooo000W0?ooo`030000003oool0oooo
01D0oooo0P00000E0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0803oool002H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`800000c03oool00`000000
oooo0?ooo`3:0?ooo`8000005@3oool2000001H0oooo00<000000?ooo`3oool07`3oool002D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0<`0oooo
00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool07P3oool002<0oooo0P00000G0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0c@3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0503oool2000001h0oooo000R0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool04P3oool200000=00oooo00<000000?ooo`3oool0cP3oool2000001D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`008@3oool00`000000oooo0?ooo`0E0?oo
o`800000503oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo0=00oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo000P0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3A0?ooo`03
0000003oool0oooo0=40oooo00<000000?ooo`3oool04`3oool2000001H0oooo00<000000?ooo`3o
ool06@3oool001l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`800000
``3oool8000000T0oooo00<000000?ooo`3oool0dP3oool2000001D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0H0?ooo`007P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool05`3oool001d0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0F0?ooo`00703oool00`000000oooo0?ooo`0D0?ooo`8000004`3oool20000
0<T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3F0?ooo`800000503oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo000K0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool001X0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02P3oool400000=P0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo
003o0?oooaL0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00o`3ooolH0?ooo`030000003oool0
oooo0?l0oooo9`3oool00?l0oooo6@3oool00`000000oooo0?ooo`3o0?ooobH0oooo003o0?oooaT0
oooo00<000000?ooo`3oool0o`3ooolV0?ooo`00o`3ooolB0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o`3ooolV0?ooo`00o`3ooolC0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooolW0?ooo`00o`3ooolD0?ooo`@00000o`3ooolZ0?ooo`00o`3ooooo0?oo
od80oooo003o0?ooool0oooo@P3oool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {-2.0862, -2.06465, 0.0143628, \
0.0143628}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["16. Appendix D. Loop Factors, Shapes, Duals.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". Shapes are the factors of protoloops. Many loop factors are tabulated. \
Techniques to find factors are discussed. "
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[TextData[{
  "D.1 Significance of & Tables for ",
  StyleBox["Loop Determinant Factors", "Text"],
  "."
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tEvery group, and many hoops, have more than one determinant factor. \
Non-abelian hoops have repeated factors [11]. The structure of the factors \
provides a significant indicator of loop inter-relationships, as well as \
indicating whether polar duals can be defined. In many cases the structure \
can be found by ",
  StyleBox["fp",
    FontSlant->"Italic"],
  " and expressed compactly by ",
  StyleBox["abbrFactors",
    FontSlant->"Italic"],
  ". The following tables give these compact expressions for hoops of various \
sizes. Monosized hoops are omitted. The output lists linear, quadratic, cubic \
and quartic factors in order, with superscripts to show repeated factors, \
subscripts to show the number of instances. E.g. S4 has the determinant \
structure ",
  Cell[BoxData[
      \(TraditionalForm\`{"1"\_2, "2"\^"2", "3"\_2\%\("3"\)}\)],
    PageWidth->PaperWidth,
    GeneratedCell->False,
    CellAutoOverwrite->False,
    FontSize->9],
  ", indicating two different linear factors, one quadratic factor that is \
repeated, and two cubic factors, each repeated three times. "
}], "Text",
  PageWidth->WindowWidth],

Cell["Ex. D1. Loop factor structure.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Unprotect[j]; tst = {}; ll = {3, 4, 6, 8, 12, 16}; 
    Do[j = ll[\([n]\)]; 
      Do[len = abbrFactors[test = mp[j, i]]; 
        If[len \[NotEqual] {"\<0\>"}, AppendTo[tst, {len, id[test]}]], {i, 
          Length[loop[\([j]\)]]}], {n, Length[ll]}]; 
    len = Floor[Length[tst]/5];\), "\[IndentingNewLine]", 
    \(Table[{tst[\([i]\)], tst[\([i + len]\)], tst[\([i + 2  len]\)], 
          tst[\([i + 3  len]\)], tst[\([i + 4  len]\)]}, {i, len}] // 
      tf\)}], "Input",
  PageWidth->WindowWidth,
  FormatType->TraditionalForm,
  FontSize->9],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\({{"1", "2"}, "C3"}\), \({{"1"\_2, "2"\_2}, 
                  "KC3c"}\), \({{"2"\_2, "2"\^"2"}, 
                  "C4iC4c"}\), \({{"4", "4"\^"2"}, 
                  "C3iC8c"}\), \({{"2"\_2, "4"\_2}, "C24rb"}\)},
              {\({{"1", "2"}, "C3C2c"}\), \({{"1"\_2, "2"\_2}, 
                  "C3Kr"}\), \({{"1"\_4, "2"\^"2"}, 
                  "Q8C2r"}\), \({{"2"\_2, "4"\^"2"}, 
                  "D3C4c"}\), \({{"1", "2", "3"\^"3"}, "A4C2r"}\)},
              {\({{"1", "2"}, "C3C2r"}\), \({{"2", "4"}, 
                  "C3C4c"}\), \({{"2"\_2, "2"\^"2"}, 
                  "KiC4r"}\), \({{"2"\^"2", "4"\^"2"}, 
                  "D12r"}\), \({{"1"\_2, "2", "4", "8"}, "C16"}\)},
              {\({{"1", "2"}, "C4C3c"}\), \({{"2", "2"\^"2"}, 
                  "g2401c"}\), \({{"2"\_2, "2"\^"2"}, 
                  "C4Kn"}\), \({{"2"\_2, "2"\_2\%\("2"\)}, 
                  "Q12C2c"}\), \({{"1"\_4, "2"\_6}, "C4C4"}\)},
              {\({{"1", "2"}, "C12c"}\), \({{"1"\_2, "2"\^"2"}, 
                  "D3C2c"}\), \({{"1"\_2, "2", "2"\_2\%\("2"\)}, 
                  "Q12"}\), \({{"2"\_2, "2"\_2\%\("2"\)}, 
                  "Q12C2r"}\), \({{"1"\_4, "2"\_2, "2"\_2\%\("2"\)}, 
                  "KiC4"}\)},
              {\({{"1", "2"}, "C3i"}\), \({{"2", "4"}, 
                  "Clm3r"}\), \({{"1"\_2, "2"\_3, "4"}, 
                  "C3C4"}\), \({{"2"\^"2", "4"\^"2"}, 
                  "C3iC4iC2r"}\), \({{"1"\_4, "2"\_2, "2"\_2\%\("2"\)}, 
                  "C4iC4"}\)},
              {\({{"1"\_2, "2"}, "C4"}\), \({{"2", "4"}, 
                  "Cl3r"}\), \({{"1", "2", "3"\^"3"}, 
                  "A4"}\), \({{"2"\_2, "4"\_2}, 
                  "C3r8"}\), \({{"1"\_4, "2"\_2, "4"\_2}, "C8C2"}\)},
              {\({{"1"\_2, "2"}, "C4C2r"}\), \({{"1"\_2, "2"\_2}, 
                  "C6n"}\), \({{"1"\_4, "2"\_2\%\("2"\)}, 
                  "D3C2"}\), \({{"1"\_4, "2"\_4}, 
                  "C6Kc"}\), \({{"1"\_4, "2"\_2, "4"\^"2"}, "C8pC2"}\)},
              {\({{"1"\_2, "2"}, "C3C4j"}\), \({{"1", "2", "3"}, 
                  "C6an"}\), \({{"1"\_4, "2"\_4}, 
                  "C3K"}\), \({{"1"\_4, "2"\_4}, 
                  "C3KC2r"}\), \({{"1"\_4, "2"\^"2", "4"\^"2"}, "D8"}\)},
              {\({{"1"\_2, "2"\^"2"}, "D3"}\), \({{"1"\_2, "2", "4"}, 
                  "C8"}\), \({{"1"\_4, "4"\_2}, 
                  "Alt12n"}\), \({{"1"\_4, "2"\_4}, 
                  "C6Kr"}\), \({{"1"\_4, "2"\^"2", "4"\^"2"}, "Q8iC2"}\)},
              {\({{"1"\_2, "2"\_2}, "C3C2"}\), \({{"1"\_4, "2"\_2}, 
                  "C4C2"}\), \({{"2"\^"2", "4"\^"2"}, 
                  "C3Qr"}\), \({{"4", "8"}, 
                  "C3C8c"}\), \({{"1"\_4, "2"\^"2", "4"\^"2"}, "Q16"}\)},
              {\({{"2", "2"\^"2"}, "Q12c"}\), \({{"1"\_4, "2"\^"2"}, 
                  "D4"}\), \({{"2"\^"2", "4"\^"2"}, 
                  "C3P4"}\), \({{"2"\_2, "4"\_2}, 
                  "C24r"}\), \({{"1"\_8, "2"\_4}, "C4K"}\)},
              {\({{"2", "2"\^"2"}, "Q12r"}\), \({{"1"\_4, "2"\^"2"}, 
                  "Q8"}\), \({{"2"\_2, "4"\_2}, 
                  "C3Dav"}\), \({{"2"\_2, "4"\_2}, 
                  "C24ra"}\), \({{"1"\_8, "2"\_2\%\("2"\)}, "D4C2"}\)},
              {\({{"1"\_2, "2"\^"2"}, "D6r"}\), \({{"2"\_2, "2"\^"2"}, 
                  "KiC4c"}\), \({{"2"\^"2", "4"\^"2"}, 
                  "SL23r"}\), \({{"2"\_2, "4"\_2}, 
                  "Cm311"}\), \({{"1"\_8, "2"\_2\%\("2"\)}, "Q8C2"}\)}
              }], "\[NoBreak]", ")"}],
        MatrixForm[ {{{{"1", "2"}, "C3"}, {{
          Subscript[ "1", 2], 
          Subscript[ "2", 2]}, "KC3c"}, {{
          Subscript[ "2", 2], 
          Power[ "2", "2"]}, "C4iC4c"}, {{"4", 
          Power[ "4", "2"]}, "C3iC8c"}, {{
          Subscript[ "2", 2], 
          Subscript[ "4", 2]}, "C24rb"}}, {{{"1", "2"}, "C3C2c"}, {{
          Subscript[ "1", 2], 
          Subscript[ "2", 2]}, "C3Kr"}, {{
          Subscript[ "1", 4], 
          Power[ "2", "2"]}, "Q8C2r"}, {{
          Subscript[ "2", 2], 
          Power[ "4", "2"]}, "D3C4c"}, {{"1", "2", 
          Power[ "3", "3"]}, "A4C2r"}}, {{{"1", "2"}, "C3C2r"}, {{"2", "4"}, 
          "C3C4c"}, {{
          Subscript[ "2", 2], 
          Power[ "2", "2"]}, "KiC4r"}, {{
          Power[ "2", "2"], 
          Power[ "4", "2"]}, "D12r"}, {{
          Subscript[ "1", 2], "2", "4", "8"}, "C16"}}, {{{"1", "2"}, 
          "C4C3c"}, {{"2", 
          Power[ "2", "2"]}, "g2401c"}, {{
          Subscript[ "2", 2], 
          Power[ "2", "2"]}, "C4Kn"}, {{
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"]}, "Q12C2c"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 6]}, "C4C4"}}, {{{"1", "2"}, "C12c"}, {{
          Subscript[ "1", 2], 
          Power[ "2", "2"]}, "D3C2c"}, {{
          Subscript[ "1", 2], "2", 
          Power[ 
            Subscript[ "2", 2], "2"]}, "Q12"}, {{
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"]}, "Q12C2r"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"]}, "KiC4"}}, {{{"1", "2"}, "C3i"}, {{"2", 
          "4"}, "Clm3r"}, {{
          Subscript[ "1", 2], 
          Subscript[ "2", 3], "4"}, "C3C4"}, {{
          Power[ "2", "2"], 
          Power[ "4", "2"]}, "C3iC4iC2r"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"]}, "C4iC4"}}, {{{
          Subscript[ "1", 2], "2"}, "C4"}, {{"2", "4"}, "Cl3r"}, {{"1", "2", 
          Power[ "3", "3"]}, "A4"}, {{
          Subscript[ "2", 2], 
          Subscript[ "4", 2]}, "C3r8"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Subscript[ "4", 2]}, "C8C2"}}, {{{
          Subscript[ "1", 2], "2"}, "C4C2r"}, {{
          Subscript[ "1", 2], 
          Subscript[ "2", 2]}, "C6n"}, {{
          Subscript[ "1", 4], 
          Power[ 
            Subscript[ "2", 2], "2"]}, "D3C2"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 4]}, "C6Kc"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ "4", "2"]}, "C8pC2"}}, {{{
          Subscript[ "1", 2], "2"}, "C3C4j"}, {{"1", "2", "3"}, "C6an"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 4]}, "C3K"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 4]}, "C3KC2r"}, {{
          Subscript[ "1", 4], 
          Power[ "2", "2"], 
          Power[ "4", "2"]}, "D8"}}, {{{
          Subscript[ "1", 2], 
          Power[ "2", "2"]}, "D3"}, {{
          Subscript[ "1", 2], "2", "4"}, "C8"}, {{
          Subscript[ "1", 4], 
          Subscript[ "4", 2]}, "Alt12n"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 4]}, "C6Kr"}, {{
          Subscript[ "1", 4], 
          Power[ "2", "2"], 
          Power[ "4", "2"]}, "Q8iC2"}}, {{{
          Subscript[ "1", 2], 
          Subscript[ "2", 2]}, "C3C2"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 2]}, "C4C2"}, {{
          Power[ "2", "2"], 
          Power[ "4", "2"]}, "C3Qr"}, {{"4", "8"}, "C3C8c"}, {{
          Subscript[ "1", 4], 
          Power[ "2", "2"], 
          Power[ "4", "2"]}, "Q16"}}, {{{"2", 
          Power[ "2", "2"]}, "Q12c"}, {{
          Subscript[ "1", 4], 
          Power[ "2", "2"]}, "D4"}, {{
          Power[ "2", "2"], 
          Power[ "4", "2"]}, "C3P4"}, {{
          Subscript[ "2", 2], 
          Subscript[ "4", 2]}, "C24r"}, {{
          Subscript[ "1", 8], 
          Subscript[ "2", 4]}, "C4K"}}, {{{"2", 
          Power[ "2", "2"]}, "Q12r"}, {{
          Subscript[ "1", 4], 
          Power[ "2", "2"]}, "Q8"}, {{
          Subscript[ "2", 2], 
          Subscript[ "4", 2]}, "C3Dav"}, {{
          Subscript[ "2", 2], 
          Subscript[ "4", 2]}, "C24ra"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"]}, "D4C2"}}, {{{
          Subscript[ "1", 2], 
          Power[ "2", "2"]}, "D6r"}, {{
          Subscript[ "2", 2], 
          Power[ "2", "2"]}, "KiC4c"}, {{
          Power[ "2", "2"], 
          Power[ "4", "2"]}, "SL23r"}, {{
          Subscript[ "2", 2], 
          Subscript[ "4", 2]}, "Cm311"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"]}, "Q8C2"}}}, TableDepth -> 2]], 
      TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  FontSize->9]
}, Open  ]],

Cell["The following cases needed tables from other files:-", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\({{"1"\_2, "16", "2", "4", "8"}, 
                  "C32"}\), \({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), 
                    "4"\_2\%\("2"\)}, 
                  "C8nC4"}\), \({{"1"\_8, "2"\_6\%\("2"\)}, 
                  "P32"}\), \({{"1"\_8, "2"\_2\%\("2"\), "8"\^"2"}, 
                  "g3242"}\)},
              {\({{"1"\_4, "2"\_6, "2"\_4\%\("2"\)}, 
                  "g3202"}\), \({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "8"\^"2"}, 
                  "g3215"}\), \({{"1"\_8, "2"\_4\%\("2"\), "4"\^"2"}, 
                  "KnD4"}\), \({{"1"\_8, "2"\_2\%\("2"\), "4"\^"4"}, 
                  "g3243"}\)},
              {\({{"1"\_4, "2"\_6, "4"\_4}, 
                  "C8C4"}\), \({{"1"\_4, "2"\_2, "4"\_2, "8"\_2}, 
                  "C16C2"}\), \({{"1"\_8, "2"\_4\%\("2"\), "4"\^"2"}, 
                  "KnQ8"}\), \({{"1"\_8, "2"\_2\%\("2"\), "4"\^"4"}, 
                  "g3244"}\)},
              {\({{"1"\_4, "2"\_6, "4"\_2\%\("2"\)}, 
                  "C8pC4"}\), \({{"1"\_4, "2"\_2, "4"\_2, "8"\^"2"}, 
                  "g3217"}\), \({{"1"\_8, "2"\_2\%\("2"\), "4"\_2\%\("2"\)}, 
                  "g3230"}\), \({{"1"\_16, "2"\_8}, "C4KC2"}\)},
              {\({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "4"\_2, "4"\^"2"}, 
                  "KnC8"}\), \({{"1"\_4, "2"\^"2", "4"\^"2", "8"\^"2"}, 
                  "D16"}\), \({{"1"\_8, "2"\_2\%\("2"\), "4"\_2\%\("2"\)}, 
                  "g3231"}\), \({{"1"\_16, "2"\_4\%\("2"\)}, "D4K"}\)},
              {\({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "4"\^"4"}, 
                  "g3206"}\), \({{"1"\_4, "2"\^"2", "4"\^"2", "8"\^"2"}, 
                  "Q16nC2"}\), \({{"1"\_8, "2"\_2\%\("2"\), "4"\_2\%\("2"\)}, 
                  "Q8C4a"}\), \({{"1"\_16, "2"\_4\%\("2"\)}, "Q8K"}\)},
              {\({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "4"\^"4"}, 
                  "g3207"}\), \({{"1"\_4, "2"\^"2", "4"\^"2", "8"\^"2"}, 
                  "Q32"}\), \({{"1"\_8, "4"\_3\%\("2"\)}, 
                  "g3233"}\), \({{"1"\_16, "4"\_2\%\("2"\)}, "PC2"}\)},
              {\({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "4"\^"4"}, 
                  "g3208"}\), \({{"1"\_8, "2"\_12}, 
                  "C4C4C2"}\), \({{"1"\_8, "2"\_6\%\("2"\)}, 
                  "C4nD4"}\), \({{"1"\_16, "4"\^"4"}, "CL31C2"}\)},
              {\({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "4"\_2\%\("2"\)}, 
                  "D4nC4"}\), \({{"1"\_8, "2"\_4, "2"\_4\%\("2"\)}, 
                  "KnC4C2"}\), \({{"1"\_8, "2"\_6\%\("2"\)}, 
                  "C4nQ8"}\), \({{"1"\_16, "4"\^"4"}, "CL4C2"}\)},
              {\({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "4"\_2\%\("2"\)}, 
                  "Q8nC4"}\), \({{"1"\_8, "2"\_4, "2"\_4\%\("2"\)}, 
                  "C4nC4C2"}\), \({{"1"\_8, "2"\_4, "4"\_4}, 
                  "C8K"}\), \({{"1"\_32}, "KKC2"}\)},
              {\({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "4"\_4}, 
                  "g3211"}\), \({{"1"\_8, "2"\_4, "4"\_2\%\("2"\)}, 
                  "C2C4pC4"}\), \({{"1"\_8, "2"\_4, "4"\_2\%\("2"\)}, 
                  "C2C8pC2"}\), \({{"4"\_2\%\("4"\)}, "CL5?"}\)},
              {\({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "4"\_2, "4"\^"2"}, 
                  "C4nC8"}\), \({{"1"\_8, "2"\_4, "2"\_2\%\("2"\), "4"\^"2"}, 
                  "D4C4"}\), \({{"1"\_8, "2"\_2\%\("2"\), "4"\_2\%\("2"\)}, 
                  "Q8nK"}\), \({{"8"\^"4"}, "CL41?"}\)},
              {\({{"1"\_4, "2"\_2, "2"\_2\%\("2"\), "4"\_2\%\("2"\)}, 
                  "Q8pC4"}\), \({{"1"\_8, "2"\_4, "2"\_2\%\("2"\), "4"\^"2"}, 
                  "Q8C4"}\), \({{"1"\_8, "2"\_2\%\("2"\), "4"\_2\%\("2"\)}, 
                  "Q16C2"}\), \({Null, Null}\)}
              }], "\[NoBreak]", ")"}],
        MatrixForm[ {{{{
          Subscript[ "1", 2], "16", "2", "4", "8"}, "C32"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "C8nC4"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 6], "2"]}, "P32"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ "8", "2"]}, "g3242"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 6], 
          Power[ 
            Subscript[ "2", 4], "2"]}, "g3202"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ "8", "2"]}, "g3215"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 4], "2"], 
          Power[ "4", "2"]}, "KnD4"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ "4", "4"]}, "g3243"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 6], 
          Subscript[ "4", 4]}, "C8C4"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Subscript[ "4", 2], 
          Subscript[ "8", 2]}, "C16C2"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 4], "2"], 
          Power[ "4", "2"]}, "KnQ8"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ "4", "4"]}, "g3244"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 6], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "C8pC4"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Subscript[ "4", 2], 
          Power[ "8", "2"]}, "g3217"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "g3230"}, {{
          Subscript[ "1", 16], 
          Subscript[ "2", 8]}, "C4KC2"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Subscript[ "4", 2], 
          Power[ "4", "2"]}, "KnC8"}, {{
          Subscript[ "1", 4], 
          Power[ "2", "2"], 
          Power[ "4", "2"], 
          Power[ "8", "2"]}, "D16"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "g3231"}, {{
          Subscript[ "1", 16], 
          Power[ 
            Subscript[ "2", 4], "2"]}, "D4K"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ "4", "4"]}, "g3206"}, {{
          Subscript[ "1", 4], 
          Power[ "2", "2"], 
          Power[ "4", "2"], 
          Power[ "8", "2"]}, "Q16nC2"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "Q8C4a"}, {{
          Subscript[ "1", 16], 
          Power[ 
            Subscript[ "2", 4], "2"]}, "Q8K"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ "4", "4"]}, "g3207"}, {{
          Subscript[ "1", 4], 
          Power[ "2", "2"], 
          Power[ "4", "2"], 
          Power[ "8", "2"]}, "Q32"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "4", 3], "2"]}, "g3233"}, {{
          Subscript[ "1", 16], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "PC2"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ "4", "4"]}, "g3208"}, {{
          Subscript[ "1", 8], 
          Subscript[ "2", 12]}, "C4C4C2"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 6], "2"]}, "C4nD4"}, {{
          Subscript[ "1", 16], 
          Power[ "4", "4"]}, "CL31C2"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "D4nC4"}, {{
          Subscript[ "1", 8], 
          Subscript[ "2", 4], 
          Power[ 
            Subscript[ "2", 4], "2"]}, "KnC4C2"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 6], "2"]}, "C4nQ8"}, {{
          Subscript[ "1", 16], 
          Power[ "4", "4"]}, "CL4C2"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "Q8nC4"}, {{
          Subscript[ "1", 8], 
          Subscript[ "2", 4], 
          Power[ 
            Subscript[ "2", 4], "2"]}, "C4nC4C2"}, {{
          Subscript[ "1", 8], 
          Subscript[ "2", 4], 
          Subscript[ "4", 4]}, "C8K"}, {{
          Subscript[ "1", 32]}, "KKC2"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Subscript[ "4", 4]}, "g3211"}, {{
          Subscript[ "1", 8], 
          Subscript[ "2", 4], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "C2C4pC4"}, {{
          Subscript[ "1", 8], 
          Subscript[ "2", 4], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "C2C8pC2"}, {{
          Power[ 
            Subscript[ "4", 2], "4"]}, "CL5?"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Subscript[ "4", 2], 
          Power[ "4", "2"]}, "C4nC8"}, {{
          Subscript[ "1", 8], 
          Subscript[ "2", 4], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ "4", "2"]}, "D4C4"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "Q8nK"}, {{
          Power[ "8", "4"]}, "CL41?"}}, {{{
          Subscript[ "1", 4], 
          Subscript[ "2", 2], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "Q8pC4"}, {{
          Subscript[ "1", 8], 
          Subscript[ "2", 4], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ "4", "2"]}, "Q8C4"}, {{
          Subscript[ "1", 8], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "Q16C2"}, {Null, Null}}}, TableDepth -> 
          2]], TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  GeneratedCell->False,
  CellAutoOverwrite->False,
  FontSize->9],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\({{1\_2, 2, 2\_2\%2, 6\_2\%2}, 
                  Q36}\), \({{1\_4, 2\_2\%2, 6\_2\%2}, 
                  D18}\), \({{1\_2, 2, 2\_8\%2}, 
                  C3nQ12}\), \({{1\_4, 2\_4\%2, 4\^4}, 
                  D3D3}\), \({{1\_4, 2\_8\%2}, E18C2}\)},
              {\({{1\_2, 12, 2\_3, 4, 6\_2}, C36}\), \({{1\_4, 2\_4, 6\_4}, 
                  C18C2}\), \({{1\_2, 2\_9, 4\_4}, 
                  C12C3}\), \({{1, 2\_4, 3\^3, 6\^3}, 
                  A4C3}\), \({{1\_4, 2\_16}, C6C6}\)},
              {\({{1, 2, 3\^3, 6, 6\^3}, 
                  g3603}\), \({{1\_2, 2\_3, 2\_2\%2, 4, 4\_2\%2}, 
                  Q12C3}\), \({{1\_2, 2, 4\_2\%4}, 
                  g3609}\), \({{1\_4, 2\_4, 2\_2\%2, 4\_2\%2}, 
                  D6C3}\), \({}\)}
              }], "\[NoBreak]", ")"}],
        MatrixForm[ {{{{
          Subscript[ "1", 2], "2", 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "6", 2], "2"]}, "Q36"}, {{
          Subscript[ "1", 4], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "6", 2], "2"]}, "D18"}, {{
          Subscript[ "1", 2], "2", 
          Power[ 
            Subscript[ "2", 8], "2"]}, "C3nQ12"}, {{
          Subscript[ "1", 4], 
          Power[ 
            Subscript[ "2", 4], "2"], 
          Power[ "4", "4"]}, "D3D3"}, {{
          Subscript[ "1", 4], 
          Power[ 
            Subscript[ "2", 4], "2"], 
          Power[ "4", "4"]}, "D3D3"}}, {{{
          Subscript[ "1", 2], "12", 
          Subscript[ "2", 3], "4", 
          Subscript[ "6", 2]}, "C36"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 4], 
          Subscript[ "6", 4]}, "C18C2"}, {{
          Subscript[ "1", 2], 
          Subscript[ "2", 9], 
          Subscript[ "4", 4]}, "C12C3"}, {{"1", 
          Subscript[ "2", 4], 
          Power[ "3", "3"], 
          Power[ "6", "3"]}, "A4C3"}, {{"1", 
          Subscript[ "2", 4], 
          Power[ "3", "3"], 
          Power[ "6", "3"]}, "A4C3"}}, {{{"1", "2", 
          Power[ "3", "3"], "6", 
          Power[ "6", "3"]}, "g3603"}, {{
          Subscript[ "1", 2], 
          Subscript[ "2", 3], 
          Power[ 
            Subscript[ "2", 2], "2"], "4", 
          Power[ 
            Subscript[ "4", 2], "2"]}, "Q12C3"}, {{
          Subscript[ "1", 2], "2", 
          Power[ 
            Subscript[ "4", 2], "4"]}, "g3609"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 4], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "D6C3"}, {{
          Subscript[ "1", 4], 
          Subscript[ "2", 4], 
          Power[ 
            Subscript[ "2", 2], "2"], 
          Power[ 
            Subscript[ "4", 2], "2"]}, "D6C3"}}}, TableDepth -> 2]], 
      TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontSize->10,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["D.2 Creating Shapes and Duals.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?hoopShape\)\)], "Input"],

Cell[BoxData[
    \("hoopShape[X_,o_:0] accepts either a valid Protoloop identifier \
({mm,nn} or mnemonic) or a loop table. If the loop is symbolic, it creates a \
rule that will apply the symbols to the final result. If the specific \
shape[X] is not available, the indexTable (up to 11\[Cross]11) is found, put \
into 'glo' and used to set 'gi' for use by 'hoopInverse' and to find the \
generalised shape. The output is converted to the loop symbols if necessary. \
Non-conservative loops are rejected unless o<0"\)], "Print",
  CellTags->"Info3368192290-2639046"]
}, Open  ]],

Cell[TextData[{
  "\tKnown shapes are stored as ",
  StyleBox["sh[\"mnemonic\"]",
    FontSlant->"Italic"],
  ", which also defines the lists ",
  StyleBox["gi",
    FontSlant->"Italic"],
  ", together with (where polar duals occur) ",
  StyleBox["gp",
    FontSlant->"Italic"],
  ", and (where known) ",
  StyleBox["plex",
    FontSlant->"Italic"],
  ". ",
  StyleBox["hoopShape",
    FontSlant->"Italic"],
  " will attempt to create a shape if it is not in the database. ",
  StyleBox["gi",
    FontSlant->"Italic"],
  " contains the location of the 1's in the protoloop, with signs attached \
(see below about \[ImaginaryI] & \[DoubleStruckCapitalJ] signed tables), \
followed by the multiplicity ",
  StyleBox["m",
    FontSlant->"Italic"],
  " of the sizes in the determinant. ",
  StyleBox["hoopIn",
    FontSlant->"Italic"],
  StyleBox["verse",
    FontSlant->"Italic"],
  " needs the location and the sign of the 1's to define the Cramer's method \
",
  Cell[BoxData[
      \(\[PartialD]\_variable\)],
    FontSlant->"Italic"],
  StyleBox["[",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(size\^m\),
          FontSlant->"Italic"], TraditionalForm]]],
  StyleBox["]/",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(size\^m\),
          FontSlant->"Italic"], TraditionalForm]]],
  " terms. The exponent becomes a multiplier for the size. Powers do not \
result in the usual sets of partial fractions for repeated factors, because \
of the form of the derivation expression; a single partial fraction is \
created, weighted by the multiplicity. ",
  StyleBox["gp",
    FontSlant->"Italic"],
  " is a list used by ",
  StyleBox["hoopPo",
    FontSlant->"Italic"],
  StyleBox["wer",
    FontSlant->"Italic"],
  " to distinguish between sizes (1) and angles (0.) in polar forms. Finally, \
the sizes (stripped of multiplicities) are provided. Example D.2 demonstrated \
the process for the ",
  StyleBox["Q12r",
    FontSlant->"Italic"],
  " loop, which is a signed table obtained from ",
  StyleBox["Q12, ca[12,5]",
    FontSlant->"Italic"],
  ".",
  StyleBox[" ",
    FontSlant->"Italic"],
  "In this case,",
  StyleBox[" frag",
    FontSlant->"Italic"],
  " fails with the second size, but the correct fragmentation was deduced by \
inspection of the diagnostic output given by frag[ff[[2]],1]."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["Example D.2 Shape Creation for Q12r", "Subsubsection",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(tst = ts[ca[12, 5]]; {"\<Q12r Table\>", tst // tf, "\<\nFactors\>", 
      ff = fa[tst], "\<\nFragmented first size\>", 
      frag[ff[\([1]\)]]}\)], "Input",
  PageWidth->WindowWidth,
  FormatType->TraditionalForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Q12r Table\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", \(-1\), "4", \(-3\), "6", \(-5\)},
                  {"3", \(-6\), "5", "2", \(-1\), "4"},
                  {"4", "5", "6", \(-1\), \(-2\), \(-3\)},
                  {"5", \(-4\), \(-1\), \(-6\), \(-3\), "2"},
                  {"6", "3", \(-2\), "5", \(-4\), \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nFactors\"\>", 
        ",", \(\((a\^2 + b\^2 - 2\ a\ c + c\^2 - 2\ b\ d + d\^2 + 2\ a\ e - 
              2\ c\ e + e\^2 + 2\ b\ f - 2\ d\ f + 
              f\^2)\)\ \((a\^2 + b\^2 + a\ c + c\^2 + b\ d + d\^2 - a\ e + c\ \
e + e\^2 - b\ f + d\ f + f\^2)\)\^2\), 
        ",", "\<\"\\nFragmented first size\"\>", 
        ",", \({\((a - c + e)\)\^2 + \((b - d + f)\)\^2}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(frag[ff[\([2]\)], 1]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"i,p1,res", 
      1, {a, c, 
        e}, {\((a - c)\)\^2, \((c - e)\)\^2, \((a - e)\)\^2}}\)], "Print"],

Cell[BoxData[
    \({"i,p1,res", 
      2, {b, d, 
        f}, {\((a - c)\)\^2, \((c - e)\)\^2, \((a - e)\)\^2, \((b - d)\)\^2, \
\((d - f)\)\^2, \((b - f)\)\^2}}\)], "Print"],

Cell[BoxData[
    \({"i,p1,res", 
      3, {}, {\((a - c)\)\^2, \((c - e)\)\^2, \((a - e)\)\^2, \((b - d)\)\^2, \
\((d - f)\)\^2, \((b - f)\)\^2}}\)], "Print"],

Cell[BoxData[
    \({"i,p1,res", 
      4, {}, {\((a - c)\)\^2, \((c - e)\)\^2, \((a - e)\)\^2, \((b - d)\)\^2, \
\((d - f)\)\^2, \((b - f)\)\^2}}\)], "Print"],

Cell[BoxData[
    \("Frag2 failed to correct an error"\)], "Print"],

Cell[BoxData[
    \($Aborted\)], "Output"]
}, Open  ]],

Cell["\<\
The signs in the proposed fragments can be corrected by inspection:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Expand[\((a\^2 + b\^2 + a\ c + c\^2 + b\ d + d\^2 - 
            a\ e + c\ e + e\^2 - b\ f + d\ f + 
            f\^2)\) - \((\((a + c)\)\^2 + \((c + e)\)\^2 + \((a - e)\)\^2 + \
\((b + d)\)\^2 + \((d + f)\)\^2 + \((b - f)\)\^2)\)/2]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe 1's are in columns 1, 2, 5, 4, 3, & 6, and all but the first are \
negated; the size multiplicities are 1 & 2; this fixes ",
  StyleBox["gi",
    FontSlant->"Italic"],
  ".\n As there are no shapes larger than quadratics, a polar form exists. It \
is created below, and has alternating sizes and angles, so ",
  StyleBox["gp",
    FontSlant->"Italic"],
  " can be specified. (The following cells are copied from the database, and \
are made non-evaluatable here.)"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(sh["\<Q12r\>"] := 
        Module[{}, gi = {1, \(-2\), \(-5\), \(-4\), \(-3\), \(-6\), 1, 2}; 
          gp = {1, 0. , 1, 0. , 1, 
              0. }; {\((a - c + e)\)\^2 + \((b - d + f)\)\^2, \((\((a + \
c)\)\^2 + \((c + e)\)\^2 + \((a - e)\)\^2 + \((b + d)\)\^2 + \((d + f)\)\^2 + \
\((b - f)\)\^2)\)/2}];\)\)], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FormatType->TraditionalForm],

Cell[TextData[{
  "\tThe first size gives a four-phase contribution to the polar form ",
  StyleBox["toPol",
    FontSlant->"Italic"],
  ", whilst the repeated second size has to be split into two three-phase \
contributions. The ",
  StyleBox["toVec",
    FontSlant->"Italic"],
  " elements relate directly to the (signed) elements in the ArcTan \
expressions",
  ":-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[{
    \(toPol[{a_, b_, c_, d_, e_, f_}, "\<Q12r\>"] := 
      Module[{}, {\((a - c + e)\)\^2 + \((b - d + f)\)\^2, 
          If[b + f \[Equal] d, 0, 
            ArcTan[a - c + e, 
              b - d + f]], \((\((a + c)\)\^2 + \((c + e)\)\^2 + \((a - \
e)\)\^2)\)/2, 
          If[c \[Equal] \(-e\), 0, 
            ArcTan[2\ a + c - e, 
              Sqrt[3] \((c + 
                    e)\)]], \((\((b + d)\)\^2 + \((d + f)\)\^2 + \((b - \
f)\)\^2)\)/2, 
          If[d \[Equal] \(-f\), 0, 
            ArcTan[2\ b + d - f, Sqrt[3] \((d + f)\)]]}]\), "\n", 
    \(toVec[{\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Eta]\[Eta]_, \[Chi]_, \
\[Kappa]\[Kappa]_, \[Psi]_}, "\<Q12r\>"] := 
      Module[{\[Epsilon] = \@\[Epsilon]\[Epsilon]/3, \[Eta] = 
            2 \@ \[Eta]\[Eta]/3, \[Kappa] = 
            2 \@ \[Kappa]\[Kappa]/
                3}, {\ \ \[Epsilon]\ Cos[\[Sigma]] + \[Eta]\ Cos[\[Chi]]\ , \
\[IndentingNewLine]\ \ \[Epsilon]\ Sin[\[Sigma]] + \[Kappa]\ Cos[\[Psi]], \
\[IndentingNewLine]\(-\[Epsilon]\)\ Cos[\[Sigma]] - \[Eta]\ Cos[\[Chi] + 
                  2\ \[Pi]/
                      3], \[IndentingNewLine]\(-\[Epsilon]\)\ Sin[\[Sigma]] - \
\[Kappa]\ \ Cos[\[Psi] + 
                  2\ \[Pi]/
                      3], \[IndentingNewLine]\ \ \[Epsilon]\ Cos[\[Sigma]] + \
\[Eta]\ Cos[\[Chi] + 
                  4\ \[Pi]/
                      3], \[IndentingNewLine]\ \ \[Epsilon]\ Sin[\[Sigma]] + \
\[Kappa]\ \ Cos[\[Psi] + 4\ \[Pi]/3]}]\)}], "Input",
  Editable->False,
  PageWidth->WindowWidth,
  Evaluatable->False,
  FormatType->TraditionalForm],

Cell["\<\
Finally, the hoopTest procedure confirms that the sizes are conserved on \
multiplication, that the inverse provides division, that the polar-vector \
interconversions are correct, and that powers and roots are correct.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopTest["\<Q12r\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("Conservative Q12r, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
D.3 Shapes for \[ImaginaryI], \[DoubleStruckCapitalJ]-signed Conservative \
Division Algebra.\
\>", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["\tP4",
    FontSlant->"Italic"],
  " has \[ImaginaryI] & -\[ImaginaryI] as signs in the multiplication table, \
and the correct shape was obtained by the standard procedure. On 20/9/03 I \
found two more \[ImaginaryI]-signed tables with Det conservation & division, \
C12c & g2401c. Their shapes did not match the form for \[PlusMinus]signed \
tables, but were found by experiment."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example D.3 C12c", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["{tf[C12c], id[co[C12c, C4]], fa[C12c]}", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "3", \(-\[ImaginaryI]\)},
                  {"3", \(-\[ImaginaryI]\), \(\(-2\)\ \[ImaginaryI]\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"C3C4\"\>", 
        ",", \(\((a - \[ImaginaryI]\ b - 
              c)\)\ \((a\^2 + \[ImaginaryI]\ a\ b - b\^2 + 
              a\ c - \[ImaginaryI]\ b\ c + c\^2)\)\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "I found that the \[ImaginaryI] & -\[ImaginaryI] terms have to be exchanged \
in ",
  StyleBox["gi ",
    FontSlant->"Italic"],
  "& ",
  StyleBox["a-\[ImaginaryI] b-c",
    FontSlant->"Italic"],
  " to give the correct shape:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
sh[\"C12c\"]:=Module[{},gi={1,3*I,2*I,1,1};gp=.;{a+I*b-c,((a-I*b)^2+(a+c)^2+(\
c+I*b)^2)/2}]; \
\>", "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell["I then investigated g2401c:- ", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
{tst = ts[mp[{24, 1}], -4];id[tst],tst//tf,
  \"\\nfa=\", fa[tst]}\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"g2401c\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "6", "4", "5"},
                  {"3", "1", "2", "5", "6", "4"},
                  {"4", "5", "6", 
                    "\[ImaginaryI]", \(2\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\
\)},
                  {"5", "6", "4", \(3\ \[ImaginaryI]\), 
                    "\[ImaginaryI]", \(2\ \[ImaginaryI]\)},
                  {"6", "4", "5", \(2\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\), 
                    "\[ImaginaryI]"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nfa=\"\>", 
        ",", \(\[ImaginaryI]\ \((a\^2 - a\ b + b\^2 - a\ c - b\ c + c\^2 + \
\[ImaginaryI]\ d\^2 - \[ImaginaryI]\ d\ e + \[ImaginaryI]\ e\^2 - \
\[ImaginaryI]\ d\ f - \[ImaginaryI]\ e\ f + \[ImaginaryI]\ f\^2)\)\^2\ \
\((a\^2 + 2\ a\ b + b\^2 + 2\ a\ c + 2\ b\ c + c\^2 + \[ImaginaryI]\ d\^2 + 
              2\ \[ImaginaryI]\ d\ e + \[ImaginaryI]\ e\^2 + 
              2\ \[ImaginaryI]\ d\ f + 
              2\ \[ImaginaryI]\ e\ f + \[ImaginaryI]\ f\^2)\)\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here, the \[ImaginaryI] & -\[ImaginaryI] terms are exchanged in ",
  StyleBox["gi ",
    FontSlant->"Italic"],
  "& both sizes to give the correct shape. The plex relates directly to the \
sizes as the difference of the first two and as sum of all three elements:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
sh[\"g2401c\"]:=Module[{},gi={1,3,2,-4*I,-5*I,-6*I,2,1};gp=.;{plex={a,c,b,-d,-\
e,-f};((a-b)^2+(a-c)^2+(b-c)^2-I*((d-e)^2+(d-f)^2+(e-f)^2))/2, \
(a+b+c)^2-I*(d+e+f)^2}]\
\>", "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  " On 21/9/03 I found inverses of C3C3J & C9J by Solve, and constructed \
suitable shapes. The ",
  StyleBox["gi",
    FontSlant->"Italic"],
  " elements \[DoubleStruckCapitalJ]\[LeftRightArrow]",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^2\)]],
  ", \[ImaginaryI]\[LeftRightArrow]-\[ImaginaryI], so they are divisors \
rather than multipliers. This is equivalent to using the conjugate."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
id[C3C3j];mi=minsign[C3C3j];
Simplify[Solve[Chop[hoopTimes[{p,q,r},{a,b,c}]/.mi]=={1,0,0},{p,q,r}]]/.mi\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] \(a\^2 - b\ c\ \[DoubleStruckCapitalJ]\)\/\(a\^3 + b\^3 + c\
\^3 - 3\ a\ b\ c\ \[DoubleStruckCapitalJ]\), 
        q \[Rule] \(\(-a\)\ b + c\^2\ \[DoubleStruckCapitalJ]\^2\)\/\(a\^3 + \
b\^3 + c\^3 - 3\ a\ b\ c\ \[DoubleStruckCapitalJ]\), 
        r \[Rule] \(\(-a\)\ c + b\^2\ \[DoubleStruckCapitalJ]\^2\)\/\(a\^3 + \
b\^3 + c\^3 - 3\ a\ b\ c\ \[DoubleStruckCapitalJ]\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
id[C9J];mi=minsign[C9J];Simplify[Solve[Chop[hoopTimes[{p,q,r},{a,b,c}]/.mi]=={\
1,0,0},{p,q,r}]]/.mi\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] \(a\^2 - b\ c\)\/\(a\^3 - 3\ a\ b\ c + \
\[DoubleStruckCapitalJ]\ \((c\^3 + b\^3\ \[DoubleStruckCapitalJ])\)\), 
        q \[Rule] \(\(-a\)\ b + c\^2\ \[DoubleStruckCapitalJ]\)\/\(a\^3 - 3\ \
a\ b\ c + \[DoubleStruckCapitalJ]\ \((c\^3 + b\^3\ \[DoubleStruckCapitalJ])\)\
\), r \[Rule] \(\(-a\)\ c + b\^2\ \[DoubleStruckCapitalJ]\^2\)\/\(a\^3 - 3\ a\
\ b\ c + \[DoubleStruckCapitalJ]\ \((c\^3 + b\^3\ \
\[DoubleStruckCapitalJ])\)\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
id[C9J];mi=minsign[C9J];Simplify[Solve[Chop[hoopTimes[{p,q,r},{a,b,c}]/.mi]=={\
1,0,0},{p,q,r}]]/.mi\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] \(a\^2 - b\ c\ \[DoubleStruckCapitalJ]\)\/\(a\^3 - 3\ a\ b\ \
c\ \[DoubleStruckCapitalJ] + \[DoubleStruckCapitalJ]\ \((b\^3 + c\^3\ \
\[DoubleStruckCapitalJ])\)\), 
        q \[Rule] \(\(-a\)\ b + c\^2\ \[DoubleStruckCapitalJ]\)\/\(a\^3 - 3\ \
a\ b\ c\ \[DoubleStruckCapitalJ] + \[DoubleStruckCapitalJ]\ \((b\^3 + c\^3\ \
\[DoubleStruckCapitalJ])\)\), 
        r \[Rule] \(b\^2 - a\ c\)\/\(a\^3 - 3\ a\ b\ c\ \
\[DoubleStruckCapitalJ] + \[DoubleStruckCapitalJ]\ \((b\^3 + c\^3\ \
\[DoubleStruckCapitalJ])\)\)}}\)], "Output"]
}, Open  ]],

Cell["The C4C3c shape was found in the same way:-", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
id[C4C3c];mi=minsign[C4C3c];Simplify[Solve[Chop[hoopTimes[{p,q,r},{a,b,c}]/.\
mi]=={1,0,0},{p,q,r}]]/.mi\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] \(a\^2 + b\ c\)\/\(a\^3 + 3\ a\ b\ c - \[ImaginaryI]\ \
\((b\^3 + c\^3)\)\), 
        q \[Rule] \(-\(\(\[ImaginaryI]\ a\ b + 
                  c\^2\)\/\(\[ImaginaryI]\ a\^3 + b\^3 + 
                  3\ \[ImaginaryI]\ a\ b\ c + c\^3\)\)\), 
        r \[Rule] \(\[ImaginaryI]\ b\^2 - a\ c\)\/\(a\^3 + 3\ a\ b\ c - \
\[ImaginaryI]\ \((b\^3 + c\^3)\)\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
sh[\"C4C3c\"]:=Module[{},gi={1,-3,-2,1,1};{a+\[ImaginaryI] b+\[ImaginaryI] \
c,((a-\[ImaginaryI] b)^2+(a-\[ImaginaryI] c)^2-(b-c)^2)/2}];\
\>", "Input",
  PageWidth->WindowWidth],

Cell["\<\
\t The conserved properties are conjugate to the determinant factor. This \
corresponds to Frobenius's use of the inverse group table in his development \
of group characters.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "D.4 Finding ",
  StyleBox["Loop Determinant Factors", "Text"],
  "."
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tFor loops with fewer than 11 elements, the symbolic determinant can be \
calculated and factorised by ",
  StyleBox["fa[G]",
    FontSlant->"Italic"],
  ", which is an abbreviation for ",
  StyleBox["Factor[ Det[ gmap[ G,alph]]]",
    FontSlant->"Italic"],
  ". The time taken increases roughly as ",
  StyleBox["m",
    FontSlant->"Italic"],
  "!; it is greatly reduced if integers replace most of the symbols, and \
becomes feasible (but much less informative) for groups with up to at least \
72 elements if all but one of the elements are integers."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\t",
  StyleBox["fa",
    FontSlant->"Italic"],
  " gives the result as symmetric polynomials, which can be voluminous. \
\"Fragmentation\" is a generalization of factorization; it expresses \
symmetric polynomials as signed sums of powers of smaller \"fragment\" \
polynomials. A number of these were found by trial and error, including the \
cubic and quartic factors of A4 and C3C4. Plex-conjugation led to other \
quartics, but no general approach has been found. The most important factors \
are the quadratics, because they lead to polar forms; ",
  StyleBox["frag2",
    FontSlant->"Italic"],
  " was developed to help with their fragmentation."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["frag2",
    FontSlant->"Italic"],
  " heuristically converts quadratic factors of loop tables into signed sums \
of squared terms, putting them into ",
  StyleBox["res",
    FontSlant->"Italic"],
  ", which is initialized as ",
  StyleBox["{}",
    FontSlant->"Italic"],
  ". ",
  StyleBox["polsort ",
    FontSlant->"Italic"],
  "is used to set up a matrix of coefficients for the expanded polynomial; if \
this is not a matrix the polynomial is rejected as asymmetrical. Polynomials \
higher than quadratic are returned unchanged. An ",
  StyleBox["addnew",
    FontSlant->"Italic"],
  " function is defined; it adds new terms to ",
  StyleBox["res",
    FontSlant->"Italic"],
  ", ignoring any already present. Factors of length = 1 ( and ",
  Cell[BoxData[
      \(\(-a\^2\) - b\^2\)],
    PageWidth->WindowWidth,
    InitializationCell->True],
  ") are passed through unchanged. Non-ternary terms are created with a \
positive first component. Ternary terms have a divisor ",
  StyleBox["d",
    FontSlant->"Italic"],
  "=2 and are handled next, with various adjustments. The result is compared \
with the original, and errors are fiddled. Incorrect results can be reported, \
so that manual correction can be attempted, as in Example D.2 (above)."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tAs linear factors are always signed sums of loop elements, they can be \
found for quite large groups after using ",
  StyleBox["Factor[Det[gmap[G,pow2]]]",
    FontSlant->"Italic"],
  " (abbreviated to ",
  StyleBox["fp[G,pow2]",
    FontSlant->"Italic"],
  "), which maps ",
  StyleBox["pow2",
    FontSlant->"Italic"],
  "= {a,1,2,4,8...} onto the table. The factors appear as \[PlusMinus]a\
\[PlusMinus]integer. ",
  StyleBox["linearFactor[f_,l_]",
    FontSlant->"Italic"],
  " then adds or subtracts decreasing powers of 2 from the integer and builds \
up the signed elements in the factor. Example D4 finds the two linear sizes \
for C3C4:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Ex. D4. C3C4 linearFactor identification.", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["fp[mp[\"C3C4\"], pow2]", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(-\((\(-1593\) + a)\)\)\ \((2047 + a)\)\ \((599479 - 1171\ a + 
          a\^2)\)\ \((3160537 - 442\ a + a\^2)\)\ \((361839 + 909\ a + 
          a\^2)\)\ \((203771700409 + 113614798\ a + 156399\ a\^2 + 
          250\ a\^3 + a\^4)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["{j=.;linearFactor[-1593+a,12],linearFactor[2047+a,12]}", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c - d - e - f + g + h + i - j - k - l, 
      a + b + c + d + e + f + g + h + i + j + k + l}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tQuadratic factors of small groups can be found explicitly, and ",
  StyleBox["frag",
    FontSlant->"Italic"],
  " will then help to simplify them."
}], "Text",
  PageWidth->WindowWidth],

Cell[" Ex. D4.1. Quadratic Factor identification.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["frag[fa[C3C3]]", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c + d + e + f + g + h + i, 
      1\/2\ \((\((\(-a\) + c + e - f + g - h)\)\^2 + \((\(-b\) + c - d + e + \
g - i)\)\^2 + \((a - b - d + f + h - i)\)\^2)\), 
      1\/2\ \((\((b - c - d + f + g - h)\)\^2 + \((\(-a\) + b - e + f + g - \
i)\)\^2 + \((\(-a\) + c + d - e + h - i)\)\^2)\), 
      1\/2\ \((\((a - b + d - e + g - h)\)\^2 + \((a - c + d - f + g - \
i)\)\^2 + \((b - c + e - f + h - i)\)\^2)\), 
      1\/2\ \((\((a + b + c - d - e - f)\)\^2 + \((a + b + c - g - h - \
i)\)\^2 + \((d + e + f - g - h - i)\)\^2)\)}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["fC4iC4c=frag[fa[mp[\"C4iC4c\"]]]", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({\((a - c)\)\^2 + \((b - d)\)\^2 + \((e - g)\)\^2 + \((f - h)\)\^2, \
\((a - b + c - d)\)\^2 + \((e - f + g - h)\)\^2, \((a + b + c + d)\)\^2 + \
\((e + f + g + h)\)\^2}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tWhen factors for the determinant of a folded table such as C4iC4c (in the \
previous example) have been found, they can be \"unfolded\" to give the \
larger factors of the un-folded table (linearFactor giving the linear \
factors). C4iC4c is created by folding C4iC4 so the shape of C4iC4 was found \
in this way; :-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(gd["\<C4iC4c\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({8, 
      10, {"C4iC4c", {\(-4\), 2\_2, 16}, 0, 
        "ts[co[C4,C4,2]]", {}, {}, {16, 24}, {}, {}}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
fC4iC4c/.{a->a-i,b->b-j,c->c-k,d->d-l,e->e-m,f->f-n,g->g-o,h->h-p}\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({\((a - c - i + k)\)\^2 + \((b - d - j + l)\)\^2 + \((e - g - m + \
o)\)\^2 + \((f - h - n + p)\)\^2, \((a - b + c - d - i + j - k + l)\)\^2 + \
\((e - f + g - h - m + n - o + p)\)\^2, \((a + b + c + d - i - j - k - \
l)\)\^2 + \((e + f + g + h - m - n - o - p)\)\^2}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tSome quartic factors involve a fragment that is the squared sum of the \
squared elements; another fragment then may \"drop-out\":- \
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
Factor[fa[mp[\"C8c\"]]]
Factor[%-(a^2+b^2+c^2+d^2)^2]\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(a\^4 + b\^4 - 4\ a\ b\^2\ c + 2\ a\^2\ c\^2 + c\^4 + 4\ a\^2\ b\ d - 
      4\ b\ c\^2\ d + 2\ b\^2\ d\^2 + 4\ a\ c\ d\^2 + d\^4\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(-2\)\ \((a\ b + b\ c - a\ d + c\ d)\)\^2\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "This is not the simplest shape, for the plex {a,-b,c,-d} gives ",
  Cell[BoxData[
      \(\((a\^2 - c\^2 + 2\ b\ d)\)\^2 + \((\(-b\^2\) + 2\ a\ c + \
d\^2)\)\^2\)]]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
Factor[fa[mp[\"C8r\"]]]
Factor[%-(a^2+b^2+c^2+d^2)^2]\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(a\^4 + b\^4 + 4\ a\ b\^2\ c + 2\ a\^2\ c\^2 + c\^4 - 4\ a\^2\ b\ d + 
      4\ b\ c\^2\ d + 2\ b\^2\ d\^2 - 4\ a\ c\ d\^2 + d\^4\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(-2\)\ \((a\ b - b\ c + a\ d + c\ d)\)\^2\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tSome loops have plex-conjugates (see Section 7) that give products with \
many zero elements. These can often be used to deduce the fragmentation of \
some sizes. The signs of the conjugate have to be found:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["C4C4r Plex-Conjugate Quartic Fragmentation.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
{hoopTimes[{a,b,c,d,e,f,g,h},{a,-b,-c,d,e,-f,-g,h},tst=\"C4C4r\"],\"\\\
nFactors\",fp[mp[tst]]}\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{a\^2 - c\^2 - e\^2 + g\^2, 0, 
        b\^2 - d\^2 - f\^2 + h\^2, \(-2\)\ b\ c + 2\ a\ d + 2\ f\ g - 
          2\ e\ h, 2\ a\ e - 2\ c\ g, 0, 2\ b\ f - 2\ d\ h, 
        2\ d\ e - 2\ c\ f - 2\ b\ g + 2\ a\ h}, 
      "\nFactors", \((8109 - 156\ a + a\^2)\)\ \((5209 - 10\ a + 
            a\^2)\)\ \((577 + 2\ a + a\^2)\)\ \((7949 + 164\ a + 
            a\^2)\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Some experimentation using ",
  StyleBox["fromAlph[Take[pow2,8]]",
    FontSlant->"Italic"],
  " led to the correct factors:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
Expand[{(b+d+e+g)^2+(a+c-f-h)^2,(a+b-c-d)^2+(e+f-g-h)^2, \
(a-b-c+d)^2+(e-f-g+h)^2,(b+d-e-g)^2+(a+c+f+h)^2}/.fromAlph[Take[pow2,8]]]\
\>", "Input",
  PageWidth->WindowWidth,
  FontFamily->"Courier New"],

Cell[BoxData[
    \({8109 - 156\ a + a\^2, 5209 - 10\ a + a\^2, 577 + 2\ a + a\^2, 
      7949 + 164\ a + a\^2}\)], "Output"]
}, Open  ]],

Cell["\<\
This shape was not previously known, and was added to the databank on 17th \
Aug. 2003. \
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Fragmentation of Clifford Quartic sizes.", "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["\<\
{\"Symbolic Factor for CL12\",tsts=fa[tst=cl[1,2]],\"\\nProduct with \
Plex-conjugate\",tstf=hoopTimes[{a,b,c,d,e,f,g,h},{a,-b,-c,-d,-e,-f,-g,h},tst]\
,\"\\nCheck the fragmentation\",
Expand[tsts[[1]]-(tstf[[1]]^2+tstf[[-1]]^2)]}\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"Symbolic Factor for CL12", \((a\^4 + 2\ a\^2\ b\^2 + b\^4 + 2\ a\^2\ \
c\^2 + 2\ b\^2\ c\^2 + c\^4 + 2\ a\^2\ d\^2 + 2\ b\^2\ d\^2 + 2\ c\^2\ d\^2 + \
d\^4 - 2\ a\^2\ e\^2 - 2\ b\^2\ e\^2 - 2\ c\^2\ e\^2 + 2\ d\^2\ e\^2 + e\^4 - \
8\ c\ d\ e\ f - 2\ a\^2\ f\^2 - 2\ b\^2\ f\^2 + 2\ c\^2\ f\^2 - 2\ d\^2\ f\^2 \
+ 2\ e\^2\ f\^2 + f\^4 + 8\ b\ d\ e\ g - 8\ b\ c\ f\ g - 2\ a\^2\ g\^2 + 2\ b\
\^2\ g\^2 - 2\ c\^2\ g\^2 - 2\ d\^2\ g\^2 + 2\ e\^2\ g\^2 + 2\ f\^2\ g\^2 + g\
\^4 - 8\ a\ d\ e\ h + 8\ a\ c\ f\ h - 8\ a\ b\ g\ h + 2\ a\^2\ h\^2 - 2\ b\^2\
\ h\^2 - 2\ c\^2\ h\^2 - 2\ d\^2\ h\^2 + 2\ e\^2\ h\^2 + 2\ f\^2\ h\^2 + 2\ g\
\^2\ h\^2 + h\^4)\)\^2, 
      "\nProduct with Plex-conjugate", {a\^2 + b\^2 + c\^2 + d\^2 - e\^2 - 
          f\^2 - g\^2 - h\^2, 0, 0, 0, 0, 0, 
        0, \(-2\)\ d\ e + 2\ c\ f - 2\ b\ g + 2\ a\ h}, 
      "\nCheck the fragmentation", 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
{\"Symbolic Factor for CL3\",tsts=fa[tst=cl[3]],\"\\nProduct with \
plex-conjugate\",tstf=hoopTimes[{a,b,c,d,e,f,g,h},{a,-b,-c, \
-d,-e,-f,-g,h},tst],\"\\nCheck the fragmentation\", 
  Expand[tsts[[1]]-(tstf[[1]]^2+tstf[[-1]]^2)]}\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"Symbolic Factor for CL3", \((a\^4 - 2\ a\^2\ b\^2 + b\^4 - 2\ a\^2\ c\
\^2 + 2\ b\^2\ c\^2 + c\^4 + 2\ a\^2\ d\^2 - 2\ b\^2\ d\^2 - 2\ c\^2\ d\^2 + \
d\^4 - 2\ a\^2\ e\^2 + 2\ b\^2\ e\^2 + 2\ c\^2\ e\^2 + 2\ d\^2\ e\^2 + e\^4 - \
8\ c\ d\ e\ f + 2\ a\^2\ f\^2 - 2\ b\^2\ f\^2 + 2\ c\^2\ f\^2 + 2\ d\^2\ f\^2 \
- 2\ e\^2\ f\^2 + f\^4 + 8\ b\ d\ e\ g - 8\ b\ c\ f\ g + 2\ a\^2\ g\^2 + 2\ b\
\^2\ g\^2 - 2\ c\^2\ g\^2 + 2\ d\^2\ g\^2 - 2\ e\^2\ g\^2 + 2\ f\^2\ g\^2 + g\
\^4 - 8\ a\ d\ e\ h + 8\ a\ c\ f\ h - 8\ a\ b\ g\ h + 2\ a\^2\ h\^2 + 2\ b\^2\
\ h\^2 + 2\ c\^2\ h\^2 - 2\ d\^2\ h\^2 + 2\ e\^2\ h\^2 - 2\ f\^2\ h\^2 - 2\ g\
\^2\ h\^2 + h\^4)\)\^2, 
      "\nProduct with plex-conjugate", {a\^2 - b\^2 - c\^2 + d\^2 - e\^2 + 
          f\^2 + g\^2 - h\^2, 0, 0, 0, 0, 0, 
        0, \(-2\)\ d\ e + 2\ c\ f - 2\ b\ g + 2\ a\ h}, 
      "\nCheck the fragmentation", 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
hoopTimes[{a,b,c,d,e,f,g,h},{a,-b,-c,-d,-e,-f,-g,h},cl[3,{2}]]\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 - b\^2 + c\^2 - d\^2 - e\^2 + f\^2 - g\^2 + h\^2, 0, 0, 0, 0, 0, 
      0, \(-2\)\ d\ e + 2\ c\ f - 2\ b\ g + 2\ a\ h}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
{\"Numeric Factor for \
CL4\",tsts=fp[tst=cl[4]],tstf=hoopTimes[{a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p},{a,\
b,c,-d,e,-f,-g,-h,i,-j,-k,-l,-m,-n,-o,p},tst],\"\\nShape in \
DataBase\",sh[\"CL4\"]}\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"Numeric Factor for CL4", \((35345327484971257 + 733986816\ a - \
357979754\ a\^2 + a\^4)\)\^4, {a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + 
          g\^2 + h\^2 + i\^2 + j\^2 + k\^2 + l\^2 + m\^2 + n\^2 + o\^2 + 
          p\^2, 2\ a\ b + 2\ c\ d + 2\ e\ f + 2\ g\ h + 2\ i\ j + 2\ k\ l + 
          2\ m\ n + 2\ o\ p, 
        2\ a\ c - 2\ b\ d + 2\ e\ g - 2\ f\ h + 2\ i\ k - 2\ j\ l + 2\ m\ o - 
          2\ n\ p, 0, 
        2\ a\ e - 2\ b\ f - 2\ c\ g + 2\ d\ h + 2\ i\ m - 2\ j\ n - 2\ k\ o + 
          2\ l\ p, 0, 0, 0, 
        2\ a\ i - 2\ b\ j - 2\ c\ k + 2\ d\ l - 2\ e\ m + 2\ f\ n + 2\ g\ o - 
          2\ h\ p, 0, 0, 0, 0, 0, 0, 
        2\ h\ i - 2\ g\ j + 2\ f\ k - 2\ e\ l - 2\ d\ m + 2\ c\ n - 2\ b\ o + 
          2\ a\ p}, 
      "\nShape in DataBase", {\((a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + \
g\^2 + h\^2 + i\^2 + j\^2 + k\^2 + l\^2 + m\^2 + n\^2 + o\^2 + p\^2)\)\^2 - 
          4\ \((\((h\ i - g\ j + f\ k - e\ l - d\ m + c\ n - b\ o + a\ \
p)\)\^2 + \((a\ i - b\ j - c\ k + d\ l - e\ m + f\ n + g\ o - h\ p)\)\^2 + \
\((a\ e - b\ f - c\ g + d\ h + i\ m - j\ n - k\ o + l\ p)\)\^2 + \((a\ c - b\ \
d + e\ g - f\ h + i\ k - j\ l + m\ o - n\ p)\)\^2 + \((a\ b + c\ d + e\ f + g\
\ h + i\ j + k\ l + m\ n + o\ p)\)\^2)\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t(This is not the only plex-conjugate for CL4; See Polymorphs, Section \
18.3.)\n\tThe above result gave the first shape to be found for a 32-element \
group, CL4C2, by the expansion ",
  StyleBox["a\[ShortRightArrow] a-q",
    FontSlant->"Italic"],
  ", etc, and the ",
  StyleBox["linearFactor",
    FontSlant->"Italic"],
  " procedure. "
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Cubic Factor for A4", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
A4 is the smallest group with a cubic factor. The compact form of this \
factor, as the sum of six triple products, was obtained by a long process of \
trial and error. This involved repeatedly factorizing the determinant with 8 \
symbolic and 4 zero elements (more symbolic elements overloaded the available \
computer) to build up a pattern. It is shown below. It could be used to \
define the shape of A4C2 by unfolding, and might provide a starting point for \
the development of sh[\"S4\"]\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
(* Example A4 Shape *)
sh[\"A4\"]\
\>", "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c + d + e + f + g + h + i + j + k + l, 
      1\/2\ \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f + h \
- i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\), \((a + 
              d - g - j)\)\ \((a - d + g - j)\)\ \((a - d - g + j)\) + \((b + 
              e - h - k)\)\ \((b - e + h - k)\)\ \((b - e - h + k)\) - \((a - 
              d + g - j)\)\ \((b - e - h + k)\)\ \((c + f - i - l)\) - \((a - 
              d - g + j)\)\ \((b + e - h - k)\)\ \((c - f + i - l)\) - \((a + 
              d - g - j)\)\ \((b - e + h - k)\)\ \((c - f - i + l)\) + \((c + 
              f - i - l)\)\ \((c - f + i - l)\)\ \((c - f - i + 
              l)\)}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["17. Appendix E. Multi-phase & Power-Sinusoids.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". Differential equations generate multi-phase and power-sinusoids, \
generalizing ",
  Cell[BoxData[
      \(TraditionalForm\`Cos[\[Theta]]\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`Sin[\[Theta]]\^2\)]],
  "=1. Multi-phase sinusoids are exponents of generalized signs."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[TextData[{
  "\tBanded sets of differential equations generate multi-phase sinusoids \
(just as ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)\& . \)]],
  StyleBox[" = a ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_\(\(2\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(x\_2\)\& . \)\)\)]],
  StyleBox["= -a",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ", equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  " = -",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "x, generates ordinary sinusoids). A simple set is the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " equations (with ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-1 being independent):- \n     ",
  Cell[BoxData[
      StyleBox[\(D[x\_j, t] = \(c'\)[t] + 
            a \((x\_\(Mod[j + k, m]\) - x\_\(Mod[j - k, m]\))\), 
        j = \(0.  .. \)\ m - 1, k < m/2. \),
        FontFamily->"Times New Roman",
        FontWeight->"Plain"]], "Input"],
  "\nSubstituting the trial function ",
  Cell[BoxData[
      \(x\_j = c[t] + \(c\_1\) Sin[c\_2\ t + \[Phi] + 2  j\ k\ \[Pi]/m]\)],
    FontFamily->"Times New Roman"],
  " leads to          ",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \)\(x\_j = 
        c[t] + \[Sum]\_p\( c\_p\) 
              Sin[2  a\ Sin[2  k\ \[Pi]/m]\ t + \[Phi]\_p + 
                  2  j\ k\ \[Pi]/m]\)\)\)], "Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  ".\n",
  StyleBox["j",
    FontSlant->"Italic"],
  " is one of the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " phases; c[t] gives freedom from the origin;",
  StyleBox[" ",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(c\_p\)],
    FontFamily->"Times New Roman"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Phi]\_p\),
        FontFamily->"Times New Roman"]]],
  " are phase amplitude and phase offset constants which are subscripted \
because independent sets can arise; ",
  StyleBox["k",
    FontSlant->"Italic"],
  " is a phase step. Sin[2k \[Pi]/m] is a constant that determines the \
frequency & period.  When ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=4, ",
  StyleBox["k",
    FontSlant->"Italic"],
  " must be 1; folding then removes the c[t] term and reproduces the ordinary \
sinusoid equation-pair with double the amplitude. Other values of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " give a frequency reduction.\n\tThe period is 2\[Pi]/Sin[2k \[Pi]/m], and \
the function is non-sinusoidal (constant) if 2/m is integral; ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=12 gives half-spin with a period of 4\[Pi]. Spin-2 is ",
  Cell[BoxData[
      \(TraditionalForm\`Sin\^2\)]],
  " with period \[Pi]; the spin-2 sinusoids (gravity waves) are essentially \
non-negative."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tSome years ago I generalised ",
  Cell[BoxData[
      \(TraditionalForm\`Sin[\[Theta]]\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`Cos[\[Theta]]\^2\)]],
  "=1 to give the polyhelix identity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 0\)\%\(n = m - 1\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`Sin[\[Theta] + 2  n\ \[Pi]/m]\^2\)]],
  "/",
  StyleBox["m",
    FontSlant->"Italic"],
  "\[Congruent]1. On 17/11/2000 I generalised this to other powers. Firstly I \
found that the sum of fourth powers of ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-phase sinusoids, apart from ",
  StyleBox["m",
    FontSlant->"Italic"],
  "={1,2,4}, is 3",
  StyleBox["m",
    FontSlant->"Italic"],
  "/8. Example E1 demonstrates this for 3, 5, & 6 phases. An arbitrary value \
of the angle \[Tau]=1.1 is employed because the simplification of the \
symbolic expressions is very slow in early versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example E1. Sums of 4'th powers of multiphase sinusoids.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tau = 
      1.1; {"\<Eight times the sum of\nthree equispaced 4'th power sinusoids \
=\>", 8*Simplify[
          Sin[tau]\^4 + Sin[tau + 2  \[Pi]/3]\^4 + 
            Sin[tau + 4  \[Pi]/3]\^4], "\<\nfive equispaced 4'th power \
sinusoids  =\>", 
      8*Simplify[
          Sin[tau]\^4 + Sin[tau + 2  \[Pi]/5]\^4 + Sin[tau + 4  \[Pi]/5]\^4 + 
            Sin[tau + 6  \[Pi]/5]\^4 + 
            Sin[tau + 8  \[Pi]/5]\^4], "\<\nsix equispaced 4'th power \
sinusoids   =\>", 
      8*Simplify[
          Sin[tau]\^4 + Sin[tau + \[Pi]/3]\^4 + Sin[tau + 2  \[Pi]/3]\^4 + 
            Sin[tau + \[Pi]]\^4 + Sin[tau + 4  \[Pi]/3]\^4 + 
            Sin[tau + 5  \[Pi]/3]\^4]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Eight times the sum of\nthree equispaced 4'th power sinusoids =", 
      9.`, "\nfive equispaced 4'th power sinusoids  =", 15.000000000000005`, 
      "\nsix equispaced 4'th power sinusoids   =", 
      17.999999999999993`}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tI developed this \"Power-Sinusoid\" identity as an empirical \
observation. The correct relationship was derived for me by John Thwaites \
(Fellow of Caius College, Cambridge) and is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 0\)\%\(n = m - 1\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((Sin[t + 2  n\ \[Pi]/m])\)\^\(2  p\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`4\^\(-p\)\)]],
  StyleBox["m ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(2  p\)},
              {"p"}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  ", {p<m if m is even, else p<2m}.  (If p exceeds the stated limit, the sum \
has a small high-frequency ripple.) The ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(2  p\)},
              {"p"}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  " term is the Binomial, sometimes written ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisiblePrefixScriptBase]\_\(2  
              p\)\)\(C\_p\)\)]],
  ".  He derived this relationship by converting to exponential form, \
performing a binomial expansion, and summing typical terms. This gives ",
  Cell[BoxData[
      \(TraditionalForm\`4\^\(-n\)\)]],
  "m ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(2  p\)},
              {"r"}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`E\^\(2 \( j(p - r)\) i\)\)]],
  " multiplied by a geometric series that is zero unless ",
  StyleBox["p = n",
    FontSlant->"Italic"],
  ", when it sums to ",
  StyleBox["m",
    FontSlant->"Italic"],
  ". Replacing ",
  StyleBox["2p",
    FontSlant->"Italic"],
  " by an odd integer always gives zero.\n\tExample E2 shows the 4'th power \
of the 3-phase sinusoids in red, green, and blue, and their sum (the straight \
line at y=9/8) in black. "
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example E2. Plots of 4'th powers of 3-phase sinusoids and their sum.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{Sin[\[Tau]]\^4, Sin[\[Tau] + 2  \[Pi]/3]\^4, 
          Sin[\[Tau] + 4  \[Pi]/3]\^4, 
          Sin[\[Tau]]\^4 + Sin[\[Tau] + 2  \[Pi]/3]\^4 + 
            Sin[\[Tau] + 4  \[Pi]/3]\^4}, {\[Tau], 0, 2  \[Pi]}, 
        PlotStyle \[Rule] {{RGBColor[1, 0, 0]}, {RGBColor[0, 1, 
                0]}, {RGBColor[0, 0, 1]}, {RGBColor[0, 0, 0]}}, 
        PlotLabel \[Rule] "\<Fig.1 4th Power Sinusoid Summation\>"];\)\)], \
"Input",
  PageWidth->WindowWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.0147151 0.523203 [
[.17539 .00222 -3 -9 ]
[.17539 .00222 3 0 ]
[.32696 .00222 -3 -9 ]
[.32696 .00222 3 0 ]
[.47854 .00222 -3 -9 ]
[.47854 .00222 3 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -3 -9 ]
[.78169 .00222 3 0 ]
[.93327 .00222 -3 -9 ]
[.93327 .00222 3 0 ]
[.01131 .11936 -18 -4.5 ]
[.01131 .11936 0 4.5 ]
[.01131 .224 -18 -4.5 ]
[.01131 .224 0 4.5 ]
[.01131 .32864 -18 -4.5 ]
[.01131 .32864 0 4.5 ]
[.01131 .43328 -18 -4.5 ]
[.01131 .43328 0 4.5 ]
[.01131 .53792 -6 -4.5 ]
[.01131 .53792 0 4.5 ]
[.5 .63053 -104 0 ]
[.5 .63053 104 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
[(1)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(2)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(3)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(4)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(5)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(6)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11936 m
.03006 .11936 L
s
[(0.2)] .01131 .11936 1 0 Mshowa
.02381 .224 m
.03006 .224 L
s
[(0.4)] .01131 .224 1 0 Mshowa
.02381 .32864 m
.03006 .32864 L
s
[(0.6)] .01131 .32864 1 0 Mshowa
.02381 .43328 m
.03006 .43328 L
s
[(0.8)] .01131 .43328 1 0 Mshowa
.02381 .53792 m
.03006 .53792 L
s
[(1)] .01131 .53792 1 0 Mshowa
.125 Mabswid
.02381 .04088 m
.02756 .04088 L
s
.02381 .06704 m
.02756 .06704 L
s
.02381 .0932 m
.02756 .0932 L
s
.02381 .14552 m
.02756 .14552 L
s
.02381 .17168 m
.02756 .17168 L
s
.02381 .19784 m
.02756 .19784 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27632 m
.02756 .27632 L
s
.02381 .30248 m
.02756 .30248 L
s
.02381 .3548 m
.02756 .3548 L
s
.02381 .38096 m
.02756 .38096 L
s
.02381 .40712 m
.02756 .40712 L
s
.02381 .45944 m
.02756 .45944 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51176 m
.02756 .51176 L
s
.02381 .56408 m
.02756 .56408 L
s
.02381 .59024 m
.02756 .59024 L
s
.02381 .6164 m
.02756 .6164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -165 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.1) show
99.000 12.750 moveto
(4) show
105.000 12.750 moveto
(th) show
123.000 12.750 moveto
(Power) show
159.000 12.750 moveto
(Sinusoid) show
213.000 12.750 moveto
(Summation) show
267.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01473 L
.0352 .01473 L
.03638 .01474 L
.03746 .01475 L
.03873 .01476 L
.04011 .01478 L
.04141 .01481 L
.04262 .01484 L
.04521 .01492 L
.04765 .01503 L
.04984 .01516 L
.05221 .01535 L
.05481 .0156 L
.05754 .01596 L
.06244 .01683 L
.06507 .01745 L
.06746 .01812 L
.07283 .02005 L
.07781 .02246 L
.08253 .02537 L
.09309 .03456 L
.09906 .04164 L
.10458 .04956 L
.12324 .08714 L
.13387 .1164 L
.14385 .14895 L
.18253 .30899 L
.20218 .39506 L
.21257 .4364 L
.22367 .47478 L
.23443 .50446 L
.23951 .51549 L
.2442 .5238 L
.24891 .53028 L
.2514 .53291 L
.25402 .5351 L
.25512 .53583 L
.25631 .53649 L
.25733 .53696 L
.25844 .53737 L
.25974 .53771 L
Mistroke
.26098 .53788 L
.26218 .53791 L
.2633 .53783 L
.26459 .53759 L
.26524 .53741 L
.26595 .53717 L
.26721 .53664 L
.26839 .53601 L
.27105 .53412 L
.27389 .53141 L
.27911 .52458 L
.28386 .51634 L
.29343 .49426 L
.30248 .46727 L
.34086 .31085 L
.36028 .22546 L
.3817 .14296 L
.39147 .11184 L
.40199 .08365 L
.41185 .06236 L
.42101 .04685 L
.43061 .03468 L
.43568 .02975 L
.44109 .0255 L
.44679 .02203 L
.45216 .01957 L
.45699 .01793 L
.4595 .01726 L
.46221 .01666 L
.46477 .01619 L
.46711 .01584 L
.46949 .01555 L
.4717 .01534 L
.47426 .01514 L
.47705 .01499 L
.47951 .01489 L
.48075 .01485 L
.48212 .01482 L
.48345 .01479 L
.48484 .01477 L
.48604 .01475 L
.48734 .01474 L
.48875 .01473 L
.48954 .01473 L
.49026 .01472 L
.49093 .01472 L
.49166 .01472 L
.49298 .01472 L
.4942 .01472 L
.4949 .01472 L
Mistroke
.49555 .01472 L
.49687 .01472 L
.49761 .01472 L
.49828 .01472 L
.49948 .01472 L
.50079 .01472 L
.50203 .01472 L
.50318 .01472 L
.50447 .01472 L
.50511 .01472 L
.50583 .01472 L
.50708 .01472 L
.50826 .01472 L
.50897 .01472 L
.50965 .01472 L
.51091 .01473 L
.51162 .01473 L
.51227 .01474 L
.51376 .01475 L
.51494 .01476 L
.51605 .01478 L
.51737 .0148 L
.51859 .01483 L
.52105 .01491 L
.52235 .01496 L
.52371 .01502 L
.52594 .01516 L
.52832 .01534 L
.53261 .0158 L
.53523 .01619 L
.5377 .01664 L
.54233 .01773 L
.54696 .01924 L
.55206 .02144 L
.55738 .02448 L
.56236 .02809 L
.57126 .03674 L
.58081 .04963 L
.59095 .06791 L
.602 .09368 L
.62211 .1563 L
.66283 .32737 L
.68168 .40867 L
.70203 .4814 L
.70748 .49664 L
.71322 .51036 L
.71854 .52074 L
.7235 .52829 L
.72815 .53343 L
.73076 .53547 L
Mistroke
.73191 .53618 L
.73313 .5368 L
.73377 .53707 L
.73448 .53732 L
.73573 .53766 L
.73643 .53779 L
.73719 .53788 L
.7379 .53792 L
.73855 .53791 L
.73981 .53778 L
.74052 .53765 L
.74118 .53748 L
.74239 .53708 L
.74368 .5365 L
.74629 .53487 L
.74904 .53249 L
.75396 .52656 L
.75926 .51784 L
.76509 .50561 L
.77551 .4773 L
.78525 .44445 L
.82415 .2791 L
.84395 .19474 L
.8655 .11832 L
.87553 .09022 L
.88619 .06599 L
.89528 .04977 L
.90533 .03629 L
.91024 .03123 L
.91542 .02685 L
.91989 .02379 L
.92467 .02118 L
.92983 .01902 L
.93463 .01753 L
.93756 .01683 L
.94033 .01629 L
.94301 .01588 L
.94552 .01557 L
.94921 .01523 L
.95117 .0151 L
.95327 .01498 L
.95547 .0149 L
.95756 .01483 L
.95943 .01479 L
.96049 .01477 L
.96148 .01476 L
.96241 .01475 L
.96342 .01474 L
.96425 .01474 L
.96517 .01473 L
Mistroke
.96617 .01473 L
.96722 .01472 L
.9682 .01472 L
.96911 .01472 L
.97003 .01472 L
.9709 .01472 L
.97168 .01472 L
.97253 .01472 L
.97345 .01472 L
.97443 .01472 L
.97527 .01472 L
.97619 .01472 L
Mfstroke
0 1 0 r
.02381 .30902 m
.04262 .22634 L
.06244 .14916 L
.08255 .08851 L
.09396 .06319 L
.10458 .04536 L
.10961 .03871 L
.11508 .03269 L
.11989 .02833 L
.125 .02458 L
.12959 .02189 L
.13466 .01959 L
.13926 .01801 L
.14357 .0169 L
.14854 .016 L
.15134 .01563 L
.15395 .01536 L
.15646 .01516 L
.15873 .01503 L
.15999 .01497 L
.16135 .01491 L
.16263 .01487 L
.16382 .01484 L
.16606 .01479 L
.16724 .01477 L
.16851 .01475 L
.16984 .01474 L
.1711 .01473 L
.17224 .01473 L
.17347 .01472 L
.17453 .01472 L
.1757 .01472 L
.17693 .01472 L
.17808 .01472 L
.17915 .01472 L
.18013 .01472 L
.18121 .01472 L
.18234 .01472 L
.18358 .01472 L
.18428 .01472 L
.18492 .01472 L
.1861 .01472 L
.18735 .01472 L
.18846 .01472 L
.18951 .01472 L
.19066 .01472 L
.19189 .01472 L
.1932 .01473 L
.19394 .01473 L
.19462 .01474 L
Mistroke
.19588 .01475 L
.19722 .01476 L
.19853 .01478 L
.19977 .0148 L
.20209 .01486 L
.20433 .01494 L
.20669 .01505 L
.2087 .01517 L
.21092 .01534 L
.2133 .01558 L
.21585 .0159 L
.22045 .01668 L
.22303 .01725 L
.22575 .01799 L
.23065 .01968 L
.23592 .02212 L
.24173 .0257 L
.24674 .02964 L
.25212 .03489 L
.26187 .04736 L
.27146 .06385 L
.28195 .08707 L
.30306 .15064 L
.34367 .31978 L
.36244 .40142 L
.38277 .47592 L
.38818 .49174 L
.3939 .5062 L
.3992 .51734 L
.40416 .52567 L
.40879 .53156 L
.41139 .53404 L
.41376 .53577 L
.41511 .53653 L
.41636 .53709 L
.41773 .53753 L
.41842 .53769 L
.41918 .53782 L
.42046 .53792 L
.42117 .53791 L
.42183 .53785 L
.42304 .53765 L
.42432 .5373 L
.42555 .53682 L
.42689 .53614 L
.42931 .5345 L
.43167 .5324 L
.43385 .53002 L
.43879 .52308 L
.44404 .51347 L
Mistroke
.45277 .4926 L
.4624 .46335 L
.5027 .2969 L
.52125 .21608 L
.54149 .13934 L
.55246 .10529 L
.56264 .07911 L
.5723 .05914 L
.58274 .04263 L
.58825 .03587 L
.59332 .03073 L
.59807 .02677 L
.60328 .02328 L
.60796 .02082 L
.61233 .01903 L
.61694 .01759 L
.62189 .01647 L
.62445 .01604 L
.62718 .01567 L
.62951 .01542 L
.63207 .01521 L
.63482 .01503 L
.63637 .01496 L
.63778 .0149 L
.6404 .01483 L
.64171 .0148 L
.64314 .01477 L
.6445 .01476 L
.64579 .01474 L
.64694 .01473 L
.64819 .01473 L
.64884 .01472 L
.64955 .01472 L
.65029 .01472 L
.65099 .01472 L
.65223 .01472 L
.65293 .01472 L
.65357 .01472 L
.65481 .01472 L
.65595 .01472 L
.65721 .01472 L
.65791 .01472 L
.65855 .01472 L
.65972 .01472 L
.66098 .01472 L
.66217 .01472 L
.66327 .01472 L
.66454 .01472 L
.66574 .01472 L
.66682 .01472 L
Mistroke
.66799 .01472 L
.66926 .01473 L
.66991 .01473 L
.67062 .01473 L
.67187 .01474 L
.67304 .01476 L
.67421 .01477 L
.67533 .01479 L
.67743 .01483 L
.67968 .0149 L
.68215 .01501 L
.68487 .01517 L
.68734 .01536 L
.69019 .01566 L
.69287 .01602 L
.69765 .01689 L
.70035 .01754 L
.70283 .01826 L
.70752 .01996 L
.71256 .02236 L
.71731 .02528 L
.72164 .02855 L
.72672 .03322 L
.73225 .03944 L
.7423 .05412 L
.7517 .07215 L
.76207 .09722 L
.78307 .16442 L
.82326 .33499 L
.84173 .41402 L
.8522 .45352 L
.86194 .48488 L
.87162 .50965 L
.87704 .52035 L
.88197 .52795 L
.8845 .53104 L
.88718 .53369 L
.88857 .53483 L
.89011 .53587 L
.89153 .53664 L
.89282 .53719 L
.89413 .53759 L
.89537 .53782 L
.89668 .53792 L
.89743 .5379 L
.89811 .53784 L
.89937 .53762 L
.90051 .5373 L
.90183 .53678 L
.90307 .53615 L
Mistroke
.90548 .53451 L
.90773 .53252 L
.91285 .52633 L
.91784 .51813 L
.92318 .50708 L
.94166 .45279 L
.97619 .30902 L
Mfstroke
0 0 1 r
.02381 .30902 m
.04262 .39157 L
.06244 .46676 L
.07286 .49742 L
.08255 .51885 L
.08813 .52769 L
.09076 .53094 L
.0932 .5334 L
.096 .53558 L
.09748 .53644 L
.09824 .53681 L
.09905 .53714 L
.09976 .53739 L
.10041 .53757 L
.10168 .53782 L
.10239 .53789 L
.10317 .53792 L
.1039 .53789 L
.10458 .53783 L
.10587 .53759 L
.10651 .53741 L
.10722 .53717 L
.10848 .53664 L
.10966 .53601 L
.11231 .53413 L
.11515 .53142 L
.12035 .52462 L
.1251 .5164 L
.13466 .49437 L
.14371 .4674 L
.18204 .31126 L
.20142 .22601 L
.22282 .14346 L
.23257 .11234 L
.24307 .0841 L
.25292 .06273 L
.26209 .04714 L
.27166 .03492 L
.27672 .02995 L
.28213 .02567 L
.28781 .02216 L
.29318 .01967 L
.298 .018 L
.30052 .01732 L
.30323 .01671 L
.30578 .01623 L
.30812 .01587 L
.31049 .01558 L
.31269 .01536 L
.31525 .01516 L
Mistroke
.31803 .015 L
.32049 .0149 L
.32186 .01485 L
.3231 .01482 L
.32442 .01479 L
.32582 .01477 L
.32701 .01476 L
.32832 .01474 L
.32972 .01473 L
.33051 .01473 L
.33123 .01473 L
.3319 .01472 L
.33262 .01472 L
.33395 .01472 L
.33517 .01472 L
.33587 .01472 L
.33652 .01472 L
.33783 .01472 L
.33857 .01472 L
.33925 .01472 L
.34039 .01472 L
.34164 .01472 L
.34294 .01472 L
.34415 .01472 L
.34543 .01472 L
.34607 .01472 L
.34678 .01472 L
.34804 .01472 L
.34921 .01472 L
.34992 .01472 L
.3506 .01472 L
.35186 .01473 L
.35256 .01473 L
.35322 .01474 L
.3547 .01475 L
.35588 .01476 L
.35699 .01478 L
.35831 .0148 L
.35952 .01482 L
.36198 .0149 L
.36328 .01494 L
.36464 .01501 L
.36687 .01513 L
.36924 .01531 L
.37352 .01576 L
.37614 .01613 L
.37861 .01657 L
.38324 .01764 L
.38786 .0191 L
.39295 .02126 L
Mistroke
.39826 .02423 L
.40323 .02778 L
.41212 .03628 L
.42168 .049 L
.43179 .06703 L
.44283 .09252 L
.46292 .15466 L
.50359 .32509 L
.5224 .40644 L
.54274 .47971 L
.54817 .49512 L
.5539 .50907 L
.55921 .51969 L
.56416 .52748 L
.56881 .53286 L
.57141 .53504 L
.57378 .5365 L
.57513 .5371 L
.57638 .53751 L
.57703 .53767 L
.57775 .5378 L
.5785 .53788 L
.57921 .53792 L
.5805 .53786 L
.58168 .53768 L
.58297 .53733 L
.58363 .53709 L
.58434 .53679 L
.58688 .53535 L
.58963 .53314 L
.59223 .53043 L
.59462 .5274 L
.60396 .51096 L
.60881 .49964 L
.61415 .48518 L
.62492 .45023 L
.66528 .27972 L
.68387 .20017 L
.70412 .12656 L
.71512 .09456 L
.72531 .0704 L
.73505 .05217 L
.74046 .04401 L
.74542 .03765 L
.75574 .02758 L
.76117 .02379 L
.76689 .02073 L
.77187 .01874 L
.77652 .01737 L
.78162 .01629 L
Mistroke
.78448 .01585 L
.78707 .01554 L
.78937 .01532 L
.7919 .01513 L
.79455 .01498 L
.79702 .01489 L
.79821 .01485 L
.79933 .01482 L
.80145 .01478 L
.80263 .01476 L
.80373 .01475 L
.80493 .01474 L
.80621 .01473 L
.80689 .01473 L
.80762 .01472 L
.80891 .01472 L
.80963 .01472 L
.8103 .01472 L
.81103 .01472 L
.81182 .01472 L
.8125 .01472 L
.81324 .01472 L
.81394 .01472 L
.81459 .01472 L
.81581 .01472 L
.81711 .01472 L
.81827 .01472 L
.81953 .01472 L
.82072 .01472 L
.82181 .01472 L
.82301 .01472 L
.82433 .01472 L
.825 .01472 L
.82571 .01472 L
.82699 .01472 L
.82822 .01473 L
.82892 .01473 L
.82958 .01474 L
.8309 .01475 L
.83232 .01476 L
.83363 .01478 L
.83488 .01481 L
.83723 .01486 L
.83856 .01491 L
.83998 .01497 L
.84254 .0151 L
.84558 .01532 L
.84833 .01559 L
.85093 .01592 L
.85332 .01629 L
Mistroke
.85871 .01745 L
.86346 .01889 L
.86848 .02094 L
.87345 .0236 L
.87797 .02666 L
.88285 .03071 L
.88815 .0361 L
.89757 .04854 L
.90649 .06406 L
.92629 .11273 L
.94731 .18532 L
.97619 .30902 L
Mfstroke
0 0 0 r
.02381 .60332 m
.02846 .60332 L
.02952 .60332 L
.03068 .60332 L
.03178 .60332 L
.03279 .60332 L
.03399 .60332 L
.03527 .60332 L
.03635 .60332 L
.03754 .60332 L
.0388 .60332 L
.03951 .60332 L
.04016 .60332 L
.04145 .60332 L
.04262 .60332 L
.04384 .60332 L
.04514 .60332 L
.04634 .60332 L
.04748 .60332 L
.04812 .60332 L
.0488 .60332 L
.05003 .60332 L
.05134 .60332 L
.05209 .60332 L
.05278 .60332 L
.05745 .60332 L
.05987 .60332 L
.06051 .60332 L
.0612 .60332 L
.06244 .60332 L
.06314 .60332 L
.06378 .60332 L
.0645 .60332 L
.06526 .60332 L
.0665 .60332 L
.06721 .60332 L
.06787 .60332 L
.06857 .60332 L
.06933 .60332 L
.07005 .60332 L
.07072 .60332 L
.07149 .60332 L
.07231 .60332 L
.073 .60332 L
.07376 .60332 L
.07448 .60332 L
.07516 .60332 L
.07643 .60332 L
.07715 .60332 L
.07781 .60332 L
Mistroke
.0793 .60332 L
.08448 .60332 L
.10458 .60332 L
.11374 .60332 L
.12341 .60332 L
.13402 .60332 L
.14376 .60332 L
.154 .60332 L
.16521 .60332 L
.1854 .60332 L
.20658 .60332 L
.21145 .60332 L
.2139 .60332 L
.21661 .60332 L
.21773 .60332 L
.21891 .60332 L
.2202 .60332 L
.22139 .60332 L
.22243 .60332 L
.22353 .60332 L
.22475 .60332 L
.22587 .60332 L
.23081 .60332 L
.23324 .60332 L
.23547 .60332 L
.23674 .60332 L
.23739 .60332 L
.23809 .60332 L
.2388 .60332 L
.23956 .60332 L
.24028 .60332 L
.24093 .60332 L
.24215 .60332 L
.24284 .60332 L
.24348 .60332 L
.24465 .60332 L
.24589 .60332 L
.26483 .60332 L
.2845 .60332 L
.30255 .60332 L
.31196 .60332 L
.31669 .60332 L
.31799 .60332 L
.3187 .60332 L
.31938 .60332 L
.32069 .60332 L
.32187 .60332 L
.32308 .60332 L
.32376 .60332 L
.3244 .60332 L
Mistroke
.32569 .60332 L
.32635 .60332 L
.32708 .60332 L
.32836 .60332 L
.32958 .60332 L
.33077 .60332 L
.33187 .60332 L
.33256 .60332 L
.33329 .60332 L
.33399 .60332 L
.33463 .60332 L
.33584 .60332 L
.33713 .60332 L
.34272 .60332 L
.38071 .60332 L
.40024 .60332 L
.40155 .60332 L
.40226 .60332 L
.40293 .60332 L
.40366 .60332 L
.40445 .60332 L
.40586 .60332 L
.40711 .60332 L
.40842 .60332 L
.40911 .60332 L
.40986 .60332 L
.41118 .60332 L
.41368 .60332 L
.41434 .60332 L
.41506 .60332 L
.41635 .60332 L
.41766 .60332 L
.41887 .60332 L
.42116 .60332 L
.43098 .60332 L
.44153 .60332 L
.45149 .60332 L
.46058 .60332 L
.4617 .60332 L
.46291 .60332 L
.46404 .60332 L
.46509 .60332 L
.46632 .60332 L
.46761 .60332 L
.4687 .60332 L
.46989 .60332 L
.47121 .60332 L
.47194 .60332 L
.47261 .60332 L
.47383 .60332 L
Mistroke
.47515 .60332 L
.47646 .60332 L
.47766 .60332 L
.47881 .60332 L
.48003 .60332 L
.48426 .60332 L
.4866 .60332 L
.48881 .60332 L
.49006 .60332 L
.49077 .60332 L
.49142 .60332 L
.49381 .60332 L
.49849 .60332 L
.50356 .60332 L
.50495 .60332 L
.50642 .60332 L
.50767 .60332 L
.50838 .60332 L
.50905 .60332 L
.519 .60332 L
.52798 .60332 L
.52914 .60332 L
.53039 .60332 L
.53156 .60332 L
.53265 .60332 L
.53377 .60332 L
.535 .60332 L
.53627 .60332 L
.53761 .60332 L
.53893 .60332 L
.53967 .60332 L
.54034 .60332 L
.54156 .60332 L
.54225 .60332 L
.54289 .60332 L
.54411 .60332 L
.5454 .60332 L
.54653 .60332 L
.54777 .60332 L
.54845 .60332 L
.54919 .60332 L
.54988 .60332 L
.55053 .60332 L
.55128 .60332 L
.55207 .60332 L
.55282 .60332 L
.55349 .60332 L
.55418 .60332 L
.55481 .60332 L
.55551 .60332 L
Mistroke
.55624 .60332 L
.55748 .60332 L
.55818 .60332 L
.55884 .60332 L
.56009 .60332 L
.56145 .60332 L
.56273 .60332 L
.56392 .60332 L
.56855 .60332 L
.5736 .60332 L
.57895 .60332 L
.58834 .60332 L
.59327 .60332 L
.59846 .60332 L
.60302 .60332 L
.60427 .60332 L
.6056 .60332 L
.60686 .60332 L
.608 .60332 L
.60913 .60332 L
.61016 .60332 L
.6113 .60332 L
.6125 .60332 L
.61348 .60332 L
.61452 .60332 L
.61567 .60332 L
.61675 .60332 L
.61796 .60332 L
.61865 .60332 L
.6193 .60332 L
.62061 .60332 L
.62134 .60332 L
.62202 .60332 L
.62315 .60332 L
.62439 .60332 L
.62569 .60332 L
.6269 .60332 L
.62759 .60332 L
.62833 .60332 L
.62904 .60332 L
.62969 .60332 L
.63093 .60332 L
.63224 .60332 L
.63291 .60332 L
.63364 .60332 L
.63496 .60332 L
.63576 .60332 L
.63652 .60332 L
.6372 .60332 L
.63795 .60332 L
Mistroke
.63861 .60332 L
.63931 .60332 L
.6406 .60332 L
.64185 .60332 L
.643 .60332 L
.64425 .60332 L
.64496 .60332 L
.64562 .60332 L
.64631 .60332 L
.64695 .60332 L
.64769 .60332 L
.64838 .60332 L
.64955 .60332 L
.65079 .60332 L
.65185 .60332 L
.65302 .60332 L
.65427 .60332 L
.65497 .60332 L
.65562 .60332 L
.65681 .60332 L
.65806 .60332 L
.6593 .60332 L
.65999 .60332 L
.66064 .60332 L
.66182 .60332 L
.66306 .60332 L
.66418 .60332 L
.66523 .60332 L
.66638 .60332 L
.66761 .60332 L
.66892 .60332 L
.66966 .60332 L
.67034 .60332 L
.6716 .60332 L
.67294 .60332 L
.67426 .60332 L
.6755 .60332 L
.67661 .60332 L
.67781 .60332 L
.67896 .60332 L
.68003 .60332 L
.68121 .60332 L
.68247 .60332 L
.68738 .60332 L
.69618 .60332 L
.70113 .60332 L
.70243 .60332 L
.70317 .60332 L
.70384 .60332 L
.70514 .60332 L
Mistroke
.70638 .60332 L
.70769 .60332 L
.70843 .60332 L
.70912 .60332 L
.70989 .60332 L
.71058 .60332 L
.71139 .60332 L
.71214 .60332 L
.71279 .60332 L
.71347 .60332 L
.7147 .60332 L
.71602 .60332 L
.71676 .60332 L
.71746 .60332 L
.71871 .60332 L
.72007 .60332 L
.72254 .60332 L
.72718 .60332 L
.7298 .60332 L
.73044 .60332 L
.73113 .60332 L
.73188 .60332 L
.73259 .60332 L
.73386 .60332 L
.7352 .60332 L
.73635 .60332 L
.7376 .60332 L
.73892 .60332 L
.74013 .60332 L
.74076 .60332 L
.74146 .60332 L
.74219 .60332 L
.74288 .60332 L
.74413 .60332 L
.74528 .60332 L
.74591 .60332 L
.7466 .60332 L
.74786 .60332 L
.75719 .60332 L
.76245 .60332 L
.76806 .60332 L
.76936 .60332 L
.7701 .60332 L
.77078 .60332 L
.772 .60332 L
.7727 .60332 L
.77334 .60332 L
.77447 .60332 L
.77567 .60332 L
.77696 .60332 L
Mistroke
.77813 .60332 L
.77932 .60332 L
.78042 .60332 L
.78164 .60332 L
.78295 .60332 L
.78425 .60332 L
.7849 .60332 L
.78562 .60332 L
.78688 .60332 L
.78806 .60332 L
.79035 .60332 L
.7925 .60332 L
.79369 .60332 L
.79498 .60332 L
.79616 .60332 L
.79724 .60332 L
.79844 .60332 L
.79972 .60332 L
.80094 .60332 L
.80205 .60332 L
.80335 .60332 L
.80408 .60332 L
.80476 .60332 L
.80601 .60332 L
.8067 .60332 L
.80733 .60332 L
.81801 .60332 L
.82741 .60332 L
.83731 .60332 L
.83982 .60332 L
.84048 .60332 L
.8412 .60332 L
.8425 .60332 L
.8433 .60332 L
.84404 .60332 L
.84472 .60332 L
.84544 .60332 L
.84674 .60332 L
.84748 .60332 L
.84818 .60332 L
.84946 .60332 L
.85069 .60332 L
.85179 .60332 L
.85298 .60332 L
.85428 .60332 L
.85566 .60332 L
.85697 .60332 L
.85815 .60332 L
.85936 .60332 L
.86048 .60332 L
Mistroke
.86303 .60332 L
.8643 .60332 L
.86551 .60332 L
.86618 .60332 L
.86691 .60332 L
.86818 .60332 L
.8705 .60332 L
.87167 .60332 L
.87297 .60332 L
.87407 .60332 L
.87525 .60332 L
.87637 .60332 L
.8774 .60332 L
.87861 .60332 L
.87991 .60332 L
.88113 .60332 L
.88224 .60332 L
.88754 .60332 L
.89822 .60332 L
.89941 .60332 L
.90054 .60332 L
.90184 .60332 L
.90303 .60332 L
.90415 .60332 L
.90518 .60332 L
.90632 .60332 L
.90753 .60332 L
.9088 .60332 L
.91 .60332 L
.91107 .60332 L
.91223 .60332 L
.91354 .60332 L
.9142 .60332 L
.91492 .60332 L
.9162 .60332 L
.9174 .60332 L
.91807 .60332 L
.9188 .60332 L
.91949 .60332 L
.92013 .60332 L
.92262 .60332 L
.92822 .60332 L
.93819 .60332 L
.94268 .60332 L
.94752 .60332 L
.94975 .60332 L
.95209 .60332 L
.95305 .60332 L
.95408 .60332 L
.95521 .60332 L
Mistroke
.95627 .60332 L
.95692 .60332 L
.95761 .60332 L
.95885 .60332 L
.95949 .60332 L
.96018 .60332 L
.96093 .60332 L
.96164 .60332 L
.96289 .60332 L
.96359 .60332 L
.96424 .60332 L
.96542 .60332 L
.96671 .60332 L
.96795 .60332 L
.96911 .60332 L
.97034 .60332 L
.97103 .60332 L
.97167 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00IP3oool700000380oooo1P00000c0?ooo`@00000=@3oool4000003@0oooo1000000e0?oo
o`@00000:P3oool006T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool006T0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
9`3oool006T0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo0300oooo1P00000h0?ooo`030000003oool0oooo0340oooo0P0000030?ooo`030000003o
ool0oooo02L0oooo001Y0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=@3oool2
000003@0oooo00@000000?ooo`3oool00000>@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0000000800000:P3oool006T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo0340oooo00@000000?ooo`3oool00000=@3oool4000003@0oooo00<0
00000?ooo`3oool0;03oool006T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0000000e
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0:`3oool006L0oooo0`00000e0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0380oooo00<000000?ooo`000000=@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo02X0oooo001Y0?ooo`030000003oool0oooo03@0oooo1000000d0?ooo`@0
0000=P3oool2000003D0oooo1@00000f0?ooo`<00000:@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0
o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0
oooo0?l0ooooO@3oool002P0oooo2@00000>0?l0024000006P00o`0P000001`0003o7P00000M0?l0
01l000006`00o`0P000001`0003o7`00000>0?l000T000004`3oool00340oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?l000030?l000D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`060?ooo`@00?l02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo0`00o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool30000o`P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`@0003o2P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080o`001P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo103o00070?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3o
ool0oooo1000o`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo003o0003003o00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?oo
o`@0003o00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo10000?l20?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool40?l0
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`00<@3oool00`000000
oooo0?ooo`0?0?ooo`80o`00503oool3003o00h0oooo00<000000?ooo`3oool0403oool2003o01H0
oooo0P000?l;0?ooo`030000003oool0oooo01D0oooo0P000?lC0?ooo`<0o`00203oool00`000000
oooo0?ooo`0H0?ooo`80o`00503oool00`00o`00oooo0?ooo`050?ooo`030000003oool0oooo01T0
oooo0P00o`0E0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool07@3oool00`000?l0
oooo0?ooo`0B0?ooo`80o`000P3oool00`000000oooo0?ooo`0Y0?ooo`00<@3oool00`000000oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00l0oooo0P00o`0V0?ooo`800?l04P3oool20000obL0oooo
0P000?l?0?ooo`80o`00:03oool20?l00100oooo0P00o`0V0?ooo`03003o003oool0oooo0100oooo
0P000?lV0?ooo`80003o4@3oool00`3o0000oooo0?ooo`0^0?ooo`00<@3oool00`000000oooo0?oo
o`0B0?ooo`80o`003P3oool00`00o`00oooo0?ooo`0X0?ooo`800?l03P3oool20000obX0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00/0oooo0P00
o`0Y0?ooo`800?l03P3oool20000obX0oooo0P000?l=0?ooo`80o`00<@3oool00340oooo00<00000
0?ooo`3oool0503oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0oooo02/0oooo0P00o`0:
0?ooo`80003o;@3oool00`000?l0oooo0?ooo`090?ooo`80o`00;P3oool00`3o0000oooo0?ooo`09
0?ooo`03003o003oool0oooo02/0oooo0P00o`0;0?ooo`030000o`3oool0oooo02`0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0a0?ooo`00<@3oool00`000000oooo0?ooo`0E0?oo
o`80o`00203oool2003o0300oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?ooo`0^0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`070?oo
o`03003o003oool0oooo02h0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`0^0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0<P3oool00340oooo00<000000?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo0340oooo00<00?l00?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0`0?ooo`80003o1`3oool00`3o0000oooo0?ooo`0`0?ooo`03
0?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool0<03oool00`00o`00oooo0?ooo`050?ooo`03
0000o`3oool0oooo0300oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0c0?ooo`00
<@3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0
<P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0b0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0
<P3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo0380oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0d0?ooo`00<@3oool3000001P0oooo00<0o`000?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`0d0?ooo`05003o003oool0oooo0?ooo`000?l0=P3oool01@000?l0oooo
0?ooo`3oool0o`0003H0oooo00D0o`000?ooo`3oool0oooo003o000f0?ooo`05003o003oool0oooo
0?ooo`000?l0=P3oool01@000?l0oooo0?ooo`3oool0o`0003L0oooo000a0?ooo`030000003oool0
oooo01T0oooo00@0o`000?ooo`3oool00?l0=`3oool01000o`00oooo0?ooo`000?lg0?ooo`050000
o`3oool0oooo0?ooo`3o0000=P3oool0103o0000oooo0?ooo`00o`0h0?ooo`04003o003oool0oooo
0000ocH0oooo00@0003o0?ooo`3oool0o`00>03oool00340oooo00<000000?ooo`3oool06P3oool0
0`3o00000?l00?ooo`0h0?ooo`03003o003oool0003o03P0oooo00<0003o0?ooo`3o0000>03oool0
0`3o00000?l00?ooo`0h0?ooo`03003o003oool0003o03P0oooo00<0003o0?ooo`3o0000>03oool0
0340oooo00<000000?ooo`3oool06P3oool00`00o`00oooo0?ooo`0i0?ooo`030000o`3oool0oooo
03L0oooo00<0003o0?l0003oool0>03oool00`3o00000?l00?ooo`0i0?ooo`030000o`3oool0oooo
03P0oooo00<0003o0?ooo`3oool0=`3oool00340oooo00<000000?ooo`3oool06P3oool00`00o`00
o`000?ooo`0h0?ooo`030000o`00o`00oooo03P0oooo00<0o`000000o`3oool0>03oool00`00o`00
o`000?ooo`0i0?ooo`030000o`3oool0oooo03L0oooo00<0o`000?ooo`000?l0>03oool00340oooo
00<000000?ooo`3oool06@3oool00`00o`00oooo0?l0000i0?ooo`030000o`3oool00?l003P0oooo
00<0o`000?ooo`000?l0=`3oool01000o`00oooo0?ooo`3o000h0?ooo`030000o`3oool00?l003L0
oooo00@0o`000?ooo`3oool0003o>03oool00340oooo00<000000?ooo`3oool06@3oool01000o`00
oooo0?ooo`3o000g0?ooo`040000o`3oool0oooo003o03L0oooo00@0o`000?ooo`3oool0003o=`3o
ool01000o`00oooo0?ooo`3o000g0?ooo`050000o`3oool0oooo0?ooo`00o`00=P3oool01@3o0000
oooo0?ooo`3oool0003o03L0oooo000a0?ooo`030000003oool0oooo01P0oooo00D00?l00?ooo`3o
ool0oooo0?l0000g0?ooo`050000o`3oool0oooo0?ooo`00o`00=P3oool01@3o0000oooo0?ooo`3o
ool0003o03D0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0d0?ooo`050000o`3o
ool0oooo0?ooo`00o`00=@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03@0oooo
000a0?ooo`030000003oool0oooo01P0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0c0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool0<`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0380oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0c0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool0<P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo03@0oooo000a0?ooo`030000003oool0oooo01L0oooo00<00?l0
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00<0oooo00<00?l0
0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0340oooo00<00?l0
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0a0?ooo`030000o`3oool0oooo00@0oooo00<00?l0
0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo03<0oooo000a0?oo
o`<000005`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo0340oooo00<0003o0?oo
o`3oool0103oool00`00o`00oooo0?ooo`0a0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0<03oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo0340oooo00<0003o0?oo
o`3oool01@3oool00`00o`00oooo0?ooo`0`0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0<`3oool00340oooo00<000000?ooo`3oool05P3oool00`00o`00oooo0?ooo`050?ooo`03
0?l0003oool0oooo0340oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0_0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0;`3oool00`00o`00oooo0?ooo`060?ooo`03
0?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`0`0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0<P3oool00340oooo00<000000?ooo`3oool0
5P3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`0_0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
;P3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`0^0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
<P3oool00340oooo00<000000?ooo`3oool05@3oool00`00o`00oooo0?ooo`070?ooo`030?l0003o
ool0oooo02l0oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0]0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0;P3oool00`00o`00oooo0?ooo`070?ooo`030?l0003o
ool0oooo02d0oooo00<0003o0?ooo`3oool0203oool00`00o`00oooo0?ooo`0^0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool05@3oool0
0`00o`00oooo0?ooo`080?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0203oool0
0`00o`00oooo0?ooo`0]0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0;03oool0
0`00o`00oooo0?ooo`080?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool02@3oool0
0`00o`00oooo0?ooo`0/0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0<@3oool0
0340oooo00<000000?ooo`3oool0503oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo
02d0oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`0[0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool0;03oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo
02/0oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo0?ooo`0/0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0503oool00`00o`00
oooo0?ooo`0:0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool02P3oool00`00o`00
oooo0?ooo`0[0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0;03oool00`00o`00
oooo0?ooo`090?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool02`3oool00`00o`00
oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0<03oool00340oooo
00<000000?ooo`3oool04`3oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo02/0oooo
00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0:P3oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo02T0oooo
00<0003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool04`3oool00`00o`00oooo0?oo
o`0<0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0:P3oool00`00o`00oooo0?oo
o`0;0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool03@3oool00`00o`00oooo0?oo
o`0X0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0<03oool00340oooo00<00000
0?ooo`3oool04`3oool00`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo02T0oooo00<0003o
0?ooo`3oool0303oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0:03oool00`00o`00oooo0?ooo`0=0?ooo`030?l0003oool0oooo02L0oooo00<0003o
0?ooo`3oool03P3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0;`3oool00340oooo0`00000B0?ooo`03003o003oool0oooo00h0oooo00<0o`000?oo
o`3oool0:03oool00`000?l0oooo0?ooo`0=0?ooo`03003o003oool0oooo02P0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0X0?ooo`03003o003oool0oooo00d0oooo00<0o`000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`0?0?ooo`03003o003oool0oooo02L0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0_0?ooo`00<@3oool00`000000oooo0?ooo`0B0?ooo`03
003o003oool0oooo00h0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0>0?ooo`03
003o003oool0oooo02L0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0W0?ooo`03
003o003oool0oooo00h0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0?0?ooo`03
003o003oool0oooo02H0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0^0?ooo`00
<@3oool00`000000oooo0?ooo`0B0?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo02L0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0V0?ooo`03003o003oool0oooo00l0oooo00<0o`000?ooo`3oool0
9@3oool00`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo02H0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0^0?ooo`00<@3oool00`000000oooo0?ooo`0A0?ooo`03003o003o
ool0oooo0100oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0?0?ooo`03003o003o
ool0oooo02D0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0U0?ooo`03003o003o
ool0oooo0100oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0A0?ooo`03003o003o
ool0oooo02@0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0^0?ooo`00<@3oool0
0`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo02D0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0U0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`0A0?ooo`03003o003oool0oooo02@0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0]0?ooo`00<@3oool00`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo
0140oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo
02D0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0T0?ooo`03003o003oool0oooo
0140oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0B0?ooo`03003o003oool0oooo
02@0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0]0?ooo`00503oool4000000H0
oooo0P0000050?ooo`H000001P3oool00`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo0140
oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0B0?ooo`03003o003oool0oooo02<0
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0S0?ooo`03003o003oool0oooo0180
oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0C0?ooo`03003o003oool0oooo0280
oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0/0?ooo`004`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`03003o003oool0oooo0180oooo
00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0B0?ooo`03003o003oool0oooo02<0oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0S0?ooo`03003o003oool0oooo0180oooo
00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0C0?ooo`03003o003oool0oooo0280oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0/0?ooo`004`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0@0?ooo`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?oo
o`0B0?ooo`03003o003oool0oooo02<0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0R0?ooo`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?oo
o`0D0?ooo`03003o003oool0oooo0240oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`0/0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`03003o003oool0oooo01<0oooo00<0o`00
0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0D0?ooo`03003o003oool0oooo0240oooo00<0o`00
0?ooo`3oool0503oool00`000?l0oooo0?ooo`0Q0?ooo`03003o003oool0oooo01@0oooo00<0o`00
0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0E0?ooo`03003o003oool0oooo0200oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0[0?ooo`004`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool4000000h0oooo00<00?l00?oo
o`3oool0503oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01@0oooo00<00?l00?oo
o`3oool08@3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0240oooo00<00?l00?oo
o`3oool0503oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01D0oooo00<00?l00?oo
o`3oool0803oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo02/0oooo000C0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00l0oooo00<00?l00?ooo`3oool05@3oool00`3o0000oooo0?ooo`0P0?ooo`03
0000o`3oool0oooo01D0oooo00<00?l00?ooo`3oool0803oool00`3o0000oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo0200oooo00<00?l00?ooo`3oool05@3oool00`3o0000oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo01H0oooo00<00?l00?ooo`3oool07`3oool00`3o0000oooo0?ooo`0F0?ooo`03
0000o`3oool0oooo02/0oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3`3oool00`00o`00oooo0?ooo`0E0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool0
5P3oool00`00o`00oooo0?ooo`0O0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0
803oool00`00o`00oooo0?ooo`0E0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool0
5`3oool00`00o`00oooo0?ooo`0N0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0
:`3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`03003o003o
ool0oooo01H0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0F0?ooo`03003o003o
ool0oooo01l0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0N0?ooo`03003o003o
ool0oooo01L0oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0G0?ooo`03003o003o
ool0oooo01h0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0Z0?ooo`00503oool4
000000h0oooo100000070?ooo`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool05`3oool0
0`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo01L0oooo00<00?l00?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01h0oooo00<00?l00?ooo`3oool05`3oool0
0`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo01P0oooo00<00?l00?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo02X0oooo000a0?ooo`030000003oool0oooo
00h0oooo00<00?l00?ooo`3oool05`3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
01P0oooo00<00?l00?ooo`3oool07@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
01h0oooo00<00?l00?ooo`3oool05`3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
01P0oooo00<00?l00?ooo`3oool07@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
02X0oooo000a0?ooo`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool05`3oool00`3o0000
oooo0?ooo`0M0?ooo`030000o`3oool0oooo01P0oooo00<00?l00?ooo`3oool07@3oool00`3o0000
oooo0?ooo`0I0?ooo`030000o`3oool0oooo01`0oooo00<00?l00?ooo`3oool06@3oool00`3o0000
oooo0?ooo`0L0?ooo`030000o`3oool0oooo01T0oooo00<00?l00?ooo`3oool0703oool00`3o0000
oooo0?ooo`0I0?ooo`030000o`3oool0oooo02T0oooo000a0?ooo`030000003oool0oooo00d0oooo
00<00?l00?ooo`3oool06@3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo01T0oooo
00<00?l00?ooo`3oool06`3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01`0oooo
00<00?l00?ooo`3oool06@3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo01T0oooo
00<00?l00?ooo`3oool0703oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo02T0oooo
000a0?ooo`030000003oool0oooo00d0oooo00<00?l00?ooo`3oool06@3oool00`3o0000oooo0?oo
o`0K0?ooo`030000o`3oool0oooo01X0oooo00<00?l00?ooo`3oool06`3oool00`3o0000oooo0?oo
o`0J0?ooo`030000o`3oool0oooo01`0oooo00<00?l00?ooo`3oool06@3oool00`3o0000oooo0?oo
o`0K0?ooo`030000o`3oool0oooo01X0oooo00<00?l00?ooo`3oool0703oool00`3o0000oooo0?oo
o`0I0?ooo`030000o`3oool0oooo02T0oooo000a0?ooo`<000003@3oool00`00o`00oooo0?ooo`0I
0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool06P3oool00`00o`00oooo0?ooo`0K
0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool06P3oool00`00o`00oooo0?ooo`0K
0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool06`3oool00`00o`00oooo0?ooo`0J
0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0:03oool00340oooo00<000000?oo
o`3oool0303oool00`00o`00oooo0?ooo`0K0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?oo
o`3oool06`3oool00`00o`00oooo0?ooo`0I0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?oo
o`3oool06P3oool00`00o`00oooo0?ooo`0K0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?oo
o`3oool06`3oool00`00o`00oooo0?ooo`0J0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?oo
o`3oool0:03oool00340oooo00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool0703oool00`00o`00oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool06P3oool00`00o`00oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool06`3oool00`00o`00oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0:03oool00340oooo00<000000?ooo`3oool0
303oool00`00o`00oooo0?ooo`0K0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool0
703oool00`00o`00oooo0?ooo`0I0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool0
6@3oool00`00o`00oooo0?ooo`0L0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0
7@3oool00`00o`00oooo0?ooo`0H0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0
:03oool00340oooo00<000000?ooo`3oool02`3oool00`00o`00oooo0?ooo`0L0?ooo`030?l0003o
ool0oooo01T0oooo00<0003o0?ooo`3oool0703oool00`00o`00oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo01d0oooo00<0003o0?ooo`3oool0603oool00`00o`00oooo0?ooo`0M0?ooo`030?l0003o
ool0oooo01P0oooo00<0003o0?ooo`3oool07@3oool00`00o`00oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo01d0oooo00<0003o0?ooo`3oool09`3oool00340oooo00<000000?ooo`3oool02`3oool0
0`00o`00oooo0?ooo`0M0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool07@3oool0
0`00o`00oooo0?ooo`0G0?ooo`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool0603oool0
0`00o`00oooo0?ooo`0M0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool07@3oool0
0`00o`00oooo0?ooo`0H0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool09`3oool0
0340oooo00<000000?ooo`3oool02`3oool00`00o`00oooo0?ooo`0M0?ooo`030?l0003oool0oooo
01L0oooo00<0003o0?ooo`3oool07P3oool00`00o`00oooo0?ooo`0G0?ooo`030?l0003oool0oooo
01h0oooo00<0003o0?ooo`3oool0603oool00`00o`00oooo0?ooo`0M0?ooo`030?l0003oool0oooo
01P0oooo00<0003o0?ooo`3oool07P3oool00`00o`00oooo0?ooo`0G0?ooo`030?l0003oool0oooo
01d0oooo00<0003o0?ooo`3oool09`3oool00340oooo00<000000?ooo`3oool02`3oool00`00o`00
oooo0?ooo`0M0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool07P3oool00`00o`00
oooo0?ooo`0G0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool05`3oool00`00o`00
oooo0?ooo`0N0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool07`3oool00`00o`00
oooo0?ooo`0F0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool09P3oool00340oooo
00<000000?ooo`3oool02P3oool00`00o`00oooo0?ooo`0N0?ooo`030?l0003oool0oooo01L0oooo
00<0003o0?ooo`3oool07P3oool00`00o`00oooo0?ooo`0G0?ooo`030?l0003oool0oooo01l0oooo
00<0003o0?ooo`3oool05P3oool00`00o`00oooo0?ooo`0O0?ooo`030?l0003oool0oooo01H0oooo
00<0003o0?ooo`3oool07`3oool00`00o`00oooo0?ooo`0F0?ooo`030?l0003oool0oooo01l0oooo
00<0003o0?ooo`3oool09P3oool00340oooo00<000000?ooo`3oool02P3oool00`00o`00oooo0?oo
o`0O0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool07`3oool00`00o`00oooo0?oo
o`0E0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool05P3oool00`00o`00oooo0?oo
o`0O0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool07`3oool00`00o`00oooo0?oo
o`0F0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool09P3oool00340oooo0`00000:
0?ooo`03003o003oool0oooo01l0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0P
0?ooo`03003o003oool0oooo01D0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0F
0?ooo`03003o003oool0oooo01l0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0P
0?ooo`03003o003oool0oooo01@0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0U
0?ooo`00<@3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo0200oooo00<0o`000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`0P0?ooo`03003o003oool0oooo01D0oooo00<0o`000?oo
o`3oool08@3oool00`000?l0oooo0?ooo`0D0?ooo`03003o003oool0oooo0240oooo00<0o`000?oo
o`3oool0503oool00`000?l0oooo0?ooo`0Q0?ooo`03003o003oool0oooo01@0oooo00<0o`000?oo
o`3oool08@3oool00`000?l0oooo0?ooo`0U0?ooo`00<@3oool00`000000oooo0?ooo`090?ooo`03
003o003oool0oooo0200oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0P0?ooo`03
003o003oool0oooo01D0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0D0?ooo`03
003o003oool0oooo0240oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0Q0?ooo`03
003o003oool0oooo01@0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0U0?ooo`00
<@3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo0240oooo00<0o`000?ooo`3oool0
503oool00`000?l0oooo0?ooo`0Q0?ooo`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool0
8P3oool00`000?l0oooo0?ooo`0D0?ooo`03003o003oool0oooo0240oooo00<0o`000?ooo`3oool0
503oool00`000?l0oooo0?ooo`0Q0?ooo`03003o003oool0oooo01@0oooo00<0o`000?ooo`3oool0
8@3oool00`000?l0oooo0?ooo`0U0?ooo`00<@3oool00`000000oooo0?ooo`090?ooo`03003o003o
ool0oooo0240oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0R0?ooo`03003o003o
ool0oooo01<0oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0D0?ooo`03003o003o
ool0oooo0240oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0R0?ooo`03003o003o
ool0oooo0180oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0T0?ooo`00<@3oool0
0`000000oooo0?ooo`080?ooo`03003o003oool0oooo0280oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0R0?ooo`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool08`3oool0
0`000?l0oooo0?ooo`0B0?ooo`03003o003oool0oooo02<0oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0S0?ooo`03003o003oool0oooo0180oooo00<0o`000?ooo`3oool08`3oool0
0`000?l0oooo0?ooo`0T0?ooo`00<@3oool00`000000oooo0?ooo`080?ooo`03003o003oool0oooo
0280oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0R0?ooo`03003o003oool0oooo
01<0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0B0?ooo`03003o003oool0oooo
02<0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0S0?ooo`03003o003oool0oooo
0180oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0T0?ooo`00<@3oool00`000000
oooo0?ooo`080?ooo`03003o003oool0oooo02<0oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0T0?ooo`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool0903oool00`000?l0
oooo0?ooo`0B0?ooo`03003o003oool0oooo02<0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0S0?ooo`03003o003oool0oooo0180oooo00<0o`000?ooo`3oool08`3oool00`000?l0
oooo0?ooo`0T0?ooo`00<@3oool00`000000oooo0?ooo`070?ooo`03003o003oool0oooo02@0oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0T0?ooo`03003o003oool0oooo0140oooo
00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`0A0?ooo`03003o003oool0oooo02@0oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0T0?ooo`03003o003oool0oooo0100oooo
00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0S0?ooo`00<@3oool00`000000oooo0?oo
o`070?ooo`03003o003oool0oooo02@0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0T0?ooo`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?oo
o`0@0?ooo`03003o003oool0oooo02D0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0U0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?oo
o`0S0?ooo`00<@3oool3000000L0oooo00<00?l00?ooo`3oool0903oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo02@0oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo0100oooo00<00?l00?ooo`3oool09@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo02D0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo02<0oooo000a0?ooo`030000003oool0oooo00L0oooo00<00?l00?oo
o`3oool09@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02H0oooo00<00?l00?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0100oooo00<00?l00?oo
o`3oool09@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo02D0oooo00<00?l00?oo
o`3oool0403oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo02<0oooo000a0?ooo`03
0000003oool0oooo00H0oooo00<00?l00?ooo`3oool09P3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo02H0oooo00<00?l00?ooo`3oool03`3oool00`3o0000oooo0?ooo`0V0?ooo`03
0000o`3oool0oooo00l0oooo00<00?l00?ooo`3oool09P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo02H0oooo00<00?l00?ooo`3oool03P3oool00`3o0000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo0280oooo000a0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0
9P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02H0oooo00<00?l00?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00h0oooo00<00?l00?ooo`3oool0
9P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo02H0oooo00<00?l00?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0280oooo000a0?ooo`030000003o
ool0oooo00H0oooo00<00?l00?ooo`3oool09P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo02H0oooo00<00?l00?ooo`3oool03`3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo00h0oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo02L0oooo00<00?l00?ooo`3oool03P3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo0280oooo000a0?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo02L0oooo00<00?l00?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00h0oooo00<00?l00?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo02L0oooo00<00?l00?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0280oooo000D0?ooo`@000001P3oool20000
00L0oooo100000060?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo02P0oooo00<00?l00?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00d0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo02L0oooo00<00?l00?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0280oooo000C0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0X0?ooo`03003o003oool0oooo00d0oooo00<0o`000?ooo`3oool0:03oool00`000?l0
oooo0?ooo`0=0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0X0?ooo`03003o003oool0oooo00`0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`0Q0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo02P0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0X0?ooo`03003o003oool0oooo00d0oooo
00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo02T0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0Y0?ooo`03003o003oool0oooo00`0oooo
00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0Q0?ooo`004`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo1P0000060?ooo`030000003oool0oooo00@0oooo00<0
0?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo02T0oooo00<0
0?l00?ooo`3oool0303oool00`3o0000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00`0oooo00<0
0?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo02T0oooo00<0
0?l00?ooo`3oool0303oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0240oooo000C
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00
00070?ooo`@000000`3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0:P3oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo02X0oooo00<0
003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo02T0oooo00<0
003o0?ooo`3oool08@3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0103oool00`00o`00oooo0?oo
o`0Z0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0:P3oool00`00o`00oooo0?oo
o`0;0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?oo
o`0Z0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0:P3oool00`00o`00oooo0?oo
o`0:0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool08@3oool001<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool0103oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0:P3oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo02/0oooo00<0003o
0?ooo`3oool02P3oool00`00o`00oooo0?ooo`0[0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo02/0oooo00<0003o
0?ooo`3oool0803oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0[0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0:0?oo
o`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo0?ooo`0[0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0:0?oo
o`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0803oool001@0oooo1000000@0?ooo`80
00001`3oool00`000000oooo0?ooo`030?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0/0?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3o
ool0;03oool00`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0[0?ooo`03003o003oool0oooo00X0oooo00<0o`000?ooo`3o
ool0:`3oool00`000?l0oooo0?ooo`0P0?ooo`00<@3oool00`000000oooo0?ooo`030?ooo`03003o
003oool0oooo02`0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0/0?ooo`03003o
003oool0oooo00T0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`090?ooo`03003o
003oool0oooo02`0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0/0?ooo`03003o
003oool0oooo00P0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0P0?ooo`00<@3o
ool00`000000oooo0?ooo`030?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0/0?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0]0?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`0O0?ooo`00<@3oool00`000000oooo0?ooo`020?ooo`03003o003oool0
oooo02d0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0]0?ooo`03003o003oool0
oooo00P0oooo00<0o`000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0
oooo02d0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0]0?ooo`03003o003oool0
oooo00P0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0O0?ooo`00<@3oool00`00
0000oooo0?ooo`020?ooo`03003o003oool0oooo02h0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0^0?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`3oool0;P3oool00`00
0?l0oooo0?ooo`070?ooo`03003o003oool0oooo02h0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0]0?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool0;@3oool00`00
0?l0oooo0?ooo`0O0?ooo`00<@3oool300000080oooo00<00?l00?ooo`3oool0;P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo02h0oooo00<00?l00?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0^0?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool0;P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo02d0oooo00<00?l00?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0^0?ooo`030000o`3oool0oooo01l0oooo000a0?ooo`030000003oool0oooo0080oooo
00<00?l00?ooo`3oool0;P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo02h0oooo
00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo00H0oooo
00<00?l00?ooo`3oool0;P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo02l0oooo
00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`0^0?ooo`030000o`3oool0oooo01l0oooo
000a0?ooo`030000003oool0oooo0080oooo00<00?l00?ooo`3oool0;P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo02h0oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0_0?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0;`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo02l0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0_0?ooo`030000o`3oool0oooo01h0oooo000a0?ooo`050000003oool0oooo0?ooo`00o`00<@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0300oooo00<00?l00?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool0<03o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo02l0oooo00<00?l00?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo01h0oooo000a0?ooo`050000003oool0
oooo0?ooo`00o`00<P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0300oooo00<0
0?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00D0oooo00<0
0?l00?ooo`3oool0<03oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo02l0oooo00<0
0?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo01h0oooo000a
0?ooo`050000003oool0oooo0?ooo`00o`00<P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo0300oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`0a0?ooo`030000o`3o
ool0oooo00@0oooo00<00?l00?ooo`3oool0<03oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo0340oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`0`0?ooo`030000o`3o
ool0oooo01h0oooo000a0?ooo`050000003oool0oooo0?ooo`00o`00<P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo0300oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0a0?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0<@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo0340oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?oo
o`0a0?ooo`030000o`3oool0oooo01d0oooo000a0?ooo`040000003oool0oooo003o03<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0a0?ooo`03003o003oool0oooo00@0oooo00<0
o`000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo0340oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0a0?ooo`03003o003oool0oooo00@0oooo00<0
o`000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0M0?ooo`00<@3oool010000000oooo0?ooo`00
o`0d0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0<P3oool00`00o`00oooo0?oo
o`030?ooo`030?l0003oool0oooo0380oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?oo
o`0b0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0<@3oool00`00o`00oooo0?oo
o`040?ooo`030?l0003oool0oooo0340oooo00<0003o0?ooo`3oool07@3oool00340oooo00@00000
0?ooo`3oool00?l0=03oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0380oooo00<0
0?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00<0oooo00<0
0?l00?ooo`3oool0<P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03<0oooo00<0
0?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo01d0oooo000a
0?ooo`<0000000<00?l00?ooo`3oool0<P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0380oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0
oooo0080oooo00<00?l00?ooo`3oool0<`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo03<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0
oooo01d0oooo000a0?ooo`030000003oool00?l003D0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0b0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0<`3oool00`00
0?l0oooo0?ooo`020?ooo`03003o003oool0oooo03<0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0c0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0<`3oool00`00
0?l0oooo0?ooo`0L0?ooo`00<@3oool00`000000oooo003o000f0?ooo`050?l0003oool0oooo0?oo
o`000?l0=P3oool01@00o`00oooo0?ooo`3oool0o`0003H0oooo00D0003o0?ooo`3oool0oooo003o
000f0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0<`3oool00`00o`00oooo0?oo
o`020?ooo`030?l0003oool0oooo03<0oooo00<0003o0?ooo`3oool0703oool00340oooo00<00000
0?ooo`00o`00=P3oool01@3o0000oooo0?ooo`3oool0003o03H0oooo00D00?l00?ooo`3oool0oooo
0?l0000f0?ooo`050000o`3oool0oooo0?ooo`00o`00=P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo03@0oooo00D00?l00?ooo`3oool0oooo0?l0000e0?ooo`030000o`3oool0oooo
01`0oooo000a0?ooo`030000003oool00?l003H0oooo00D0o`000?ooo`3oool0oooo0000o`0f0?oo
o`05003o003oool0oooo0?ooo`3o0000=`3oool010000?l0oooo0?ooo`00o`0f0?ooo`050?l0003o
ool0oooo0?ooo`000?l0=`3oool01000o`00oooo0?ooo`3o000f0?ooo`030000o`3oool0oooo01`0
oooo000a0?ooo`030000003oool00?l003H0oooo00D0o`000?ooo`3oool0oooo0000o`0f0?ooo`05
003o003oool0oooo0?ooo`3o0000=`3oool010000?l0oooo0?ooo`00o`0g0?ooo`040?l0003oool0
oooo0000ocL0oooo00@00?l00?ooo`3oool0o`00=P3oool00`000?l0oooo0?ooo`0L0?ooo`00<@3o
ool00`0000000?l00?ooo`0g0?ooo`040?l0003oool0oooo0000ocL0oooo00@00?l00?ooo`3oool0
o`00=`3oool00`000?l0oooo003o000h0?ooo`040?l0003oool0oooo0000ocL0oooo00@00?l00?oo
o`3oool0o`00=`3oool00`000?l0oooo0?ooo`0K0?ooo`00<@3oool00`0000000?l00?ooo`0g0?oo
o`030?l0003oool0003o03P0oooo00<00?l00?ooo`3o0000>03oool00`000?l0oooo003o000h0?oo
o`040?l0003oool0oooo0000ocL0oooo00@00?l00?ooo`3oool0o`00=`3oool00`000?l0oooo0?oo
o`0K0?ooo`00<@3oool00`0000000?l00?ooo`0g0?ooo`030?l0003oool0003o03P0oooo00<00?l0
0?ooo`3o0000>@3oool00`000?l00?l00?ooo`0g0?ooo`030?l0003oool0003o03T0oooo00<00?l0
0?l0003oool0=`3oool00`000?l0oooo0?ooo`0K0?ooo`00<@3oool00`0000000?l00?ooo`0g0?oo
o`030?l0003oool0003o03P0oooo00<00?l00?ooo`3o0000>@3oool00`000?l00?l00?ooo`0h0?oo
o`030?l000000?l0oooo03P0oooo00<00?l00?l0003oool0=`3oool00`000?l0oooo0?ooo`0K0?oo
o`00<@3oool00`00o`0000000000000h0?ooo`030?l000000?l0oooo03P0oooo00<00?l00?l0003o
ool0>03oool00`000?l00?l00?ooo`0h0?ooo`030?l000000?l0oooo03P0oooo00<00?l00?l0003o
ool0>03oool00`000?l0oooo0?ooo`0J0?ooo`00<@3oool00`00o`00oooo0?ooo`0h0?ooo`030000
o`3oool0oooo03P0oooo00<00?l00?ooo`3oool0>03oool00`000?l0oooo0?ooo`0h0?ooo`030?l0
00000?l0oooo03P0oooo00<00?l00?l0003oool0>03oool00`000?l0oooo0?ooo`0J0?ooo`00<@3o
ool00`000?l0oooo0?ooo`0h0?ooo`030000o`3oool0oooo03P0oooo00<00?l00?ooo`3oool0>03o
ool00`00o`00003o0?ooo`0h0?ooo`030000o`3oool0oooo03P0oooo00<0o`00003o003oool0>03o
ool00`000?l0oooo0?ooo`0J0?ooo`00<@3oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3oool0
oooo03P0oooo00<00?l00?ooo`3oool0>03oool00`00o`00003o0?ooo`0h0?ooo`030000o`3o0000
oooo03P0oooo00<0o`00003o003oool0>03oool00`00o`00oooo0?ooo`0J0?ooo`00<@3oool00`00
0?l0oooo0?ooo`0h0?ooo`030000o`3oool0oooo03P0oooo00<0o`00003o003oool0>03oool00`00
o`00003o0?ooo`0h0?ooo`030000o`3o0000oooo03P0oooo00<0o`00003o003oool0>03oool00`00
o`00oooo0?ooo`0J0?ooo`00<@3oool00`000000003o0?ooo`0h0?ooo`030000o`3o0000oooo03P0
oooo00<0o`00003o003oool0=`3oool00`00o`00oooo0000o`0i0?ooo`030000o`3o0000oooo03P0
oooo00<0o`00003o003oool0=`3oool00`00o`00oooo0?ooo`0K0?ooo`00503oool4000000H0oooo
0P0000070?ooo`@000001P3oool00`000000003o0?ooo`0g0?ooo`030000o`3oool0o`0003P0oooo
00<0o`000?ooo`00o`00>03oool01000o`00oooo0?ooo`000?lg0?ooo`030000o`3oool0o`0003P0
oooo00@0o`000?ooo`3oool00?l0=`3oool00`00o`00oooo0?ooo`0K0?ooo`004`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000003o0?ooo`0g0?ooo`030000o`3oool0o`0003P0
oooo00<0o`000?ooo`00o`00>03oool01000o`00oooo0?ooo`000?lg0?ooo`040000o`3oool0oooo
0?l003L0oooo00@0o`000?ooo`3oool00?l0=`3oool00`00o`00oooo0?ooo`0K0?ooo`004`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`03000000000?l0oooo03L0oooo00<0003o0?ooo`3o0000>03oool0
0`3o0000oooo003o000h0?ooo`04003o003oool0oooo0000ocL0oooo00@0003o0?ooo`3oool0o`00
=`3oool0103o0000oooo0?ooo`00o`0g0?ooo`03003o003oool0oooo01/0oooo000C0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool2000000<0oooo00<000000?ooo`3oool0
0`3oool2000000030000o`000000oooo03D0oooo00@0003o0?ooo`3oool0o`00=`3oool0103o0000
oooo0?ooo`00o`0f0?ooo`05003o003oool0oooo0?ooo`000?l0=`3oool010000?l0oooo0?ooo`3o
000g0?ooo`040?l0003oool0oooo003o03H0oooo00<00?l00?ooo`3oool0703oool001<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool00000008000001P3o
ool00`000000oooo0000o`0f0?ooo`050000o`3oool0oooo0?ooo`3o0000=P3oool01@3o0000oooo
0?ooo`3oool00?l003H0oooo00D00?l00?ooo`3oool0oooo0000o`0g0?ooo`040000o`3oool0oooo
0?l003H0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0c0?ooo`03003o003oool0
oooo01`0oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0003o03H0oooo00D0003o0?ooo`3oool0oooo0?l0000f
0?ooo`050?l0003oool0oooo0?ooo`00o`00=P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3o
ool0oooo03<0oooo00D0003o0?ooo`3oool0oooo0?l0000f0?ooo`030?l0003oool0oooo0080oooo
00<00?l00?ooo`3oool0<`3oool00`00o`00oooo0?ooo`0L0?ooo`004`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
o`0f0?ooo`050000o`3oool0oooo0?ooo`3o0000=P3oool01@3o0000oooo0?ooo`3oool00?l003H0
oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo03<0
oooo00<00?l00?ooo`3oool0703oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000?l0=P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo
0?ooo`0b0?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo
0?ooo`0c0?ooo`03003o003oool0oooo01`0oooo000D0?ooo`@000004@3oool3000000D0oooo00@0
00000?ooo`3oool0003o=03oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0380oooo
00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0b0?ooo`03003o003oool0oooo00<0oooo
00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0380oooo
00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0b0?ooo`03003o003oool0oooo01d0oooo
000a0?ooo`040000003oool0oooo0000oc@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0b0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0<P3oool00`00o`00oooo
0?ooo`040?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0b0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0<@3oool00`00o`00oooo
0?ooo`0M0?ooo`00<@3oool010000000oooo0?ooo`000?ld0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0380oooo
00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo0340oooo
00<00?l00?ooo`3oool07@3oool00340oooo00@000000?ooo`3oool0003o=03oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo
0?ooo`0a0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool0<@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo
0?ooo`0a0?ooo`03003o003oool0oooo01d0oooo000a0?ooo`050000003oool0oooo0?ooo`000?l0
<P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0300oooo00<0o`000?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`0`0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool0
<@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0300oooo00<0o`000?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`0`0?ooo`03003o003oool0oooo01h0oooo000a0?ooo`<0000000<0
oooo0000o`3oool0<@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0300oooo00<0
o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0`0?ooo`03003o003oool0oooo00H0oooo00<0
003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0300oooo00<0
o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0`0?ooo`03003o003oool0oooo01h0oooo000a
0?ooo`050000003oool0oooo0?ooo`000?l0<P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo0300oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0`0?ooo`03003o003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo02l0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0_0?ooo`03003o003o
ool0oooo01h0oooo000a0?ooo`050000003oool0oooo0?ooo`000?l0<P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo02l0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?oo
o`0_0?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo02l0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?oo
o`0_0?ooo`03003o003oool0oooo01h0oooo000a0?ooo`030000003oool0oooo0080oooo00<0003o
0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo02h0oooo00<0o`00
0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0^0?ooo`03003o003oool0oooo00L0oooo00<0003o
0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo02h0oooo00<0o`00
0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0_0?ooo`03003o003oool0oooo01h0oooo000a0?oo
o`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo02h0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0^0?oo
o`03003o003oool0oooo00L0oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo02h0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0^0?oo
o`03003o003oool0oooo01l0oooo000a0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3o
ool0;P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo02h0oooo00<0o`000?ooo`3o
ool01`3oool00`00o`00oooo0?ooo`0^0?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0;@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo02h0oooo00<0o`000?ooo`3o
ool01`3oool00`00o`00oooo0?ooo`0^0?ooo`03003o003oool0oooo01l0oooo000a0?ooo`030000
003oool0oooo0080oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo02d0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0]0?ooo`03003o
003oool0oooo00T0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo02d0oooo00<0o`000?ooo`3oool0203oool00`00o`00oooo0?ooo`0]0?ooo`03003o
003oool0oooo01l0oooo000a0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool02@3o
ool00`00o`00oooo0?ooo`0/0?ooo`03003o003oool0oooo00T0oooo00<0003o0?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo02d0oooo00<0o`000?ooo`3oool0203o
ool00`00o`00oooo0?ooo`0]0?ooo`03003o003oool0oooo01l0oooo000a0?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo02`0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0?ooo`0/0?ooo`03003o003oool0
oooo00T0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo02`0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0?ooo`0/0?ooo`03003o003oool0
oooo0200oooo000a0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0;03oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool02@3oool00`00
o`00oooo0?ooo`0/0?ooo`03003o003oool0oooo00X0oooo00<0003o0?ooo`3oool0:`3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool02@3oool00`00
o`00oooo0?ooo`0/0?ooo`03003o003oool0oooo0200oooo000a0?ooo`<000000`3oool00`000?l0
oooo0?ooo`0/0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000
oooo0?ooo`090?ooo`03003o003oool0oooo02/0oooo00<00?l00?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0[0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000
oooo0?ooo`0:0?ooo`03003o003oool0oooo02/0oooo00<00?l00?ooo`3oool0803oool00340oooo
00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0oooo02/0oooo
00<00?l00?ooo`3oool02`3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0oooo02/0oooo
00<00?l00?ooo`3oool0803oool00340oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?oo
o`0Z0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`0;0?ooo`03003o003oool0oooo02X0oooo00<00?l00?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0[0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`0;0?ooo`03003o003oool0oooo02/0oooo00<00?l00?ooo`3oool0803oool00340oooo00<00000
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo02X0oooo00<00?l0
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo02X0oooo00<00?l0
0?ooo`3oool08@3oool00340oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0;0?oo
o`03003o003oool0oooo02X0oooo00<00?l00?ooo`3oool0303oool00`000?l0oooo0?ooo`0Y0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0;0?oo
o`03003o003oool0oooo02X0oooo00<00?l00?ooo`3oool08@3oool00340oooo00<000000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0:@3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo02T0oooo00<00?l00?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0:@3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo02T0oooo00<00?l00?ooo`3o
ool08@3oool00340oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0X0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0=0?ooo`03003o
003oool0oooo02P0oooo00<00?l00?ooo`3oool03@3oool00`000?l0oooo0?ooo`0Y0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0=0?ooo`03003o
003oool0oooo02T0oooo00<00?l00?ooo`3oool08@3oool00340oooo00<000000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0:03o
ool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo02P0oooo00<00?l00?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0:03o
ool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo02P0oooo00<00?l00?ooo`3oool08P3o
ool00340oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0
oooo02P0oooo00<00?l00?ooo`3oool03P3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0
oooo02P0oooo00<00?l00?ooo`3oool08P3oool00340oooo00<000000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool09`3oool00`3o
0000oooo0?ooo`0=0?ooo`03003o003oool0oooo02L0oooo00<00?l00?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool09`3oool00`3o
0000oooo0?ooo`0=0?ooo`03003o003oool0oooo02P0oooo00<00?l00?ooo`3oool08P3oool00340
oooo0`0000060?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0V0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool09P3oool00`00o`00
oooo0?ooo`0?0?ooo`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0V0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool09`3oool00`00o`00
oooo0?ooo`0R0?ooo`00<@3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo02H0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00l0oooo
00<00?l00?ooo`3oool09P3oool00`00o`00oooo0?ooo`0?0?ooo`030000o`3oool0oooo02L0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00l0oooo
00<00?l00?ooo`3oool09`3oool00`00o`00oooo0?ooo`0R0?ooo`00<@3oool00`000000oooo0?oo
o`060?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0U0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool09P3oool00`00o`00oooo0?oo
o`0@0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0U0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool09P3oool00`00o`00oooo0?oo
o`0S0?ooo`00<@3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo02D0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00l0oooo00<00?l0
0?ooo`3oool09@3oool00`00o`00oooo0?ooo`0A0?ooo`030000o`3oool0oooo02D0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00l0oooo00<00?l0
0?ooo`3oool09P3oool00`00o`00oooo0?ooo`0S0?ooo`00<@3oool00`000000oooo0?ooo`070?oo
o`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0T0?oo
o`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool0903oool00`00o`00oooo0?ooo`0A0?oo
o`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0T0?oo
o`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool09@3oool00`00o`00oooo0?ooo`0S0?oo
o`00<@3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3o
ool0903oool00`00o`00oooo0?ooo`0A0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3o
ool09@3oool00`00o`00oooo0?ooo`0S0?ooo`00503oool4000000H0oooo0P0000060?ooo`@00000
1`3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool0
903oool00`00o`00oooo0?ooo`0B0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool0
903oool00`00o`00oooo0?ooo`0T0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0180oooo00<00?l00?ooo`3oool08P3o
ool00`00o`00oooo0?ooo`0C0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool0903o
ool00`00o`00oooo0?ooo`0T0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00P0oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo0280oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo0?ooo`0R0?ooo`03003o003oool0
oooo01<0oooo00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0
oooo0280oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo0?ooo`0S0?ooo`03003o003oool0
oooo02@0oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo100000070?ooo`030000o`3oool0oooo
0280oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo
01<0oooo00<00?l00?ooo`3oool08P3oool00`00o`00oooo0?ooo`0C0?ooo`030000o`3oool0oooo
02<0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo
01<0oooo00<00?l00?ooo`3oool08`3oool00`00o`00oooo0?ooo`0T0?ooo`004`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo100000070?ooo`030000003oool0oooo00T0
oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0240
oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`0Q0?ooo`03003o003oool0oooo01@0
oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0240
oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo0?ooo`0S0?ooo`03003o003oool0oooo02@0
oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo
0?ooo`0D0?ooo`03003o003oool0oooo0200oooo00<00?l00?ooo`3oool05@3oool00`000?l0oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo
0?ooo`0C0?ooo`03003o003oool0oooo0280oooo00<00?l00?ooo`3oool09@3oool001<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo0200oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo01D0oooo00<0
0?l00?ooo`3oool0803oool00`00o`00oooo0?ooo`0E0?ooo`030000o`3oool0oooo0240oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01D0oooo00<0
0?l00?ooo`3oool08@3oool00`00o`00oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0F
0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool05@3oool00`00o`00oooo0?ooo`0P
0?ooo`03003o003oool0oooo01D0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0E
0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool05@3oool00`00o`00oooo0?ooo`0Q
0?ooo`03003o003oool0oooo02D0oooo000D0?ooo`@000003P3oool4000000L0oooo00<000000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`0F0?ooo`03003o003oool0oooo01l0oooo00<00?l00?oo
o`3oool05P3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`0E0?ooo`03003o003oool0oooo0240oooo00<00?l00?oo
o`3oool09@3oool00340oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0F0?ooo`03
003o003oool0oooo01h0oooo00<00?l00?ooo`3oool05`3oool00`000?l0oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0E0?ooo`03
003o003oool0oooo0200oooo00<00?l00?ooo`3oool09P3oool00340oooo00<000000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0
7P3oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0oooo01h0oooo00<00?l00?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0
7@3oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0oooo01l0oooo00<00?l00?ooo`3oool0
9P3oool00340oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3o
ool0oooo01P0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0H0?ooo`03003o003o
ool0oooo01d0oooo00<00?l00?ooo`3oool05`3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo01L0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0G0?ooo`03003o003o
ool0oooo01l0oooo00<00?l00?ooo`3oool09P3oool00340oooo00<000000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`0H0?ooo`03003o003oool0oooo01d0oooo00<00?l00?ooo`3oool0603oool0
0`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`0G0?ooo`03003o003oool0oooo01l0oooo00<00?l00?ooo`3oool09P3oool0
0340oooo0`00000;0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0603oool00`3o
0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01P0oooo00<00?l00?ooo`3oool0703oool00`00
o`00oooo0?ooo`0I0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool06@3oool00`3o
0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo01P0oooo00<00?l00?ooo`3oool07@3oool00`00
o`00oooo0?ooo`0W0?ooo`00<@3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo01`0
oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01X0
oooo00<00?l00?ooo`3oool06`3oool00`00o`00oooo0?ooo`0I0?ooo`030000o`3oool0oooo01d0
oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01T0
oooo00<00?l00?ooo`3oool07@3oool00`00o`00oooo0?ooo`0W0?ooo`00<@3oool00`000000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo01X0oooo00<00?l00?ooo`3oool06`3oool00`00o`00oooo
0?ooo`0I0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo01T0oooo00<00?l00?ooo`3oool07@3oool00`00o`00oooo
0?ooo`0W0?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo00<0
003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01X0oooo00<0
0?l00?ooo`3oool06`3oool00`00o`00oooo0?ooo`0J0?ooo`030000o`3oool0oooo01/0oooo00<0
003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo01X0oooo00<0
0?l00?ooo`3oool06`3oool00`00o`00oooo0?ooo`0X0?ooo`00<@3oool00`000000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0K
0?ooo`030?l0003oool0oooo01X0oooo00<00?l00?ooo`3oool06P3oool00`00o`00oooo0?ooo`0K
0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0J
0?ooo`030?l0003oool0oooo01X0oooo00<00?l00?ooo`3oool06`3oool00`00o`00oooo0?ooo`0X
0?ooo`00<@3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?oo
o`3oool0703oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo01`0oooo00<00?l00?oo
o`3oool06@3oool00`00o`00oooo0?ooo`0K0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?oo
o`3oool06`3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo01/0oooo00<00?l00?oo
o`3oool06`3oool00`00o`00oooo0?ooo`0X0?ooo`00<@3oool00`000000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo01`0oooo00<00?l00?ooo`3oool06@3oool00`00o`00oooo0?ooo`0K0?ooo`03
0000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo01`0oooo00<00?l00?ooo`3oool06@3oool00`00o`00oooo0?ooo`0Y0?ooo`00
<@3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0
703oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo01`0oooo00<00?l00?ooo`3oool0
603oool00`00o`00oooo0?ooo`0M0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0
7@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo01`0oooo00<00?l00?ooo`3oool0
6@3oool00`00o`00oooo0?ooo`0Y0?ooo`00<@3oool00`000000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo01L0oooo00<0003o0?ooo`3oool07P3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003o
ool0oooo01h0oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo0?ooo`0M0?ooo`030000o`3o
ool0oooo01T0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo01`0oooo00<00?l00?ooo`3oool0603oool00`00o`00oooo0?ooo`0Z0?ooo`00<@3oool0
0`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo01h0oooo00<00?l00?ooo`3oool05`3oool0
0`00o`00oooo0?ooo`0M0?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo01h0oooo00<00?l00?ooo`3oool05`3oool0
0`00o`00oooo0?ooo`0Z0?ooo`00<@3oool3000000l0oooo00<0003o0?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool07P3oool00`00
o`00oooo0?ooo`0G0?ooo`03003o003oool0oooo01h0oooo00<0003o0?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool07P3oool00`00
o`00oooo0?ooo`0G0?ooo`03003o003oool0oooo02X0oooo000a0?ooo`030000003oool0oooo00l0
oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo01H0
oooo00<0o`000?ooo`3oool07`3oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo01l0
oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo01D0
oooo00<0o`000?ooo`3oool07`3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo02/0
oooo000a0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo
0?ooo`0P0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0803oool00`00o`00oooo
0?ooo`0E0?ooo`03003o003oool0oooo0200oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo
0?ooo`0P0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0803oool00`00o`00oooo
0?ooo`0E0?ooo`03003o003oool0oooo02/0oooo000a0?ooo`030000003oool0oooo0100oooo00<0
003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo01@0oooo00<0
o`000?ooo`3oool0803oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo0200oooo00<0
003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo01@0oooo00<0
o`000?ooo`3oool0803oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo02/0oooo000a
0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0R
0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool08P3oool00`00o`00oooo0?ooo`0C
0?ooo`03003o003oool0oooo0240oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0R
0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool08P3oool00`00o`00oooo0?ooo`0C
0?ooo`03003o003oool0oooo02`0oooo000a0?ooo`030000003oool0oooo0100oooo00<0003o0?oo
o`3oool04`3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?oo
o`3oool08P3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo0280oooo00<0003o0?oo
o`3oool04`3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?oo
o`3oool08P3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo02`0oooo000a0?ooo`03
0000003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0T0?ooo`03
0?l0003oool0oooo0140oooo00<0o`000?ooo`3oool08`3oool00`00o`00oooo0?ooo`0B0?ooo`03
003o003oool0oooo02<0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0T0?ooo`03
0?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0903oool00`00o`00oooo0?ooo`0B0?ooo`03
003o003oool0oooo02`0oooo000a0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0
903oool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo02<0oooo00<0003o0?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0
903oool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo02d0oooo000a0?ooo`030000003o
ool0oooo0140oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0U0?ooo`030?l0003o
ool0oooo0100oooo00<0o`000?ooo`3oool09@3oool00`00o`00oooo0?ooo`0A0?ooo`03003o003o
ool0oooo02@0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003o
ool0oooo0100oooo00<0o`000?ooo`3oool09@3oool00`00o`00oooo0?ooo`0@0?ooo`03003o003o
ool0oooo02d0oooo000a0?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool09@3oool0
0`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo02D0oooo00<0003o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool09P3oool0
0`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo02h0oooo000a0?ooo`<000004P3oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0W0?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0V0?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool0;P3oool00340
oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo02P0
oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0W0?ooo`03003o003oool0oooo00h0
oooo00<00?l00?ooo`3oool09`3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo02P0
oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00d0
oooo00<00?l00?ooo`3oool0;`3oool00340oooo00<000000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo
0?ooo`0Y0?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3oool09`3oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0X0?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3oool0;`3oool00340oooo00<0
00000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo02X0oooo00<0
o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0Z0?ooo`03003o003oool0oooo00/0oooo00<0
0?l00?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo02X0oooo00<0
o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0Z0?ooo`03003o003oool0oooo00/0oooo00<0
0?l00?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo02/0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0[
0?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo02`0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0Z
0?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool0<03oool00340oooo00<000000?oo
o`3oool0503oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo02d0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`0]0?ooo`03003o003oool0oooo00T0oooo00<00?l00?oo
o`3oool0;03oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo02`0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0/0?ooo`03003o003oool0oooo00T0oooo00<00?l00?oo
o`3oool0<@3oool002D0oooo1`0000050?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool0;@3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo02h0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool0;@3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo0380oooo000X0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0300oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0_0?ooo`03003o
003oool0oooo00H0oooo00<00?l00?ooo`3oool0<03oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo02h0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0_0?ooo`03003o
003oool0oooo00H0oooo00<00?l00?ooo`3oool0<`3oool002P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0G0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool0<@3oool00`00o`00oooo0?ooo`040?ooo`03003o003o
ool0oooo0380oooo00<0003o0?ooo`3oool00`3oool20000oc80oooo0P3o00050?ooo`030?l0003o
ool0oooo0340oooo0P00o`050?ooo`03003o003oool0oooo03@0oooo000X0?ooo`030000003oool0
oooo00H0oooo1000000H0?ooo`D0003o=@3oool60?l003D0oooo1P00o`0f0?ooo`D0003o=P3oool5
0?l003D0oooo1P00o`0g0?ooo`00:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0?l0ooooO@3oool002P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooogd0
oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`009P3o
ool3000000P0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00:03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?oo
o`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0oooo
O@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool300000?l0ooooO@3oool0
0340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0
oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3o
oomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo
0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo0`00003o
0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3o
ool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003o
ool0oooo0?l0ooooO@3oool00340ooooo`00001T000001`0oooo000a0?ooo`030000003oool0oooo
0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooogd0oooo000a0?ooo`<00000o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooogd0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo001M0?ooo`@00000o`3ooom@0?ooo`00H@3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo001Q0?ooo`030000003oool0oooo0?l0ooooC@3oool0
04X0oooo100000050?ooo`L000000`3oool3000000030?ooo`000000oooo00@0oooo0P0000050?oo
o`L000003@3oool4000000H0oooo100000020?ooo`<000000P3oool3000000X0oooo1@0000060?oo
o`@00000103oool01@000000oooo0?ooo`3oool0000000D0oooo100000040?ooo`D000003@3oool0
0`000000oooo00000002000000<0oooo1`0000020?ooo`<000000P3oool3000000<0oooo0`000000
0`3oool00000000000020?ooo`D000001@3oool4000000<0oooo1`0000030?ooo`<0000000<0oooo
000000000000303oool00`000000oooo00000002000000D0oooo0`0000000`3oool0000000000003
000000040?ooo`00000000000?ooo`D0000000@0oooo000000000000oooo0P0000030?ooo`D00000
1@3oool400000080oooo1`0000040?ooo`@000000`3oool300000080oooo0`00000e0?ooo`00B`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo
0P0000050?ooo`800000203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`0:0000003oool0oooo0000
003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00h0oooo0P0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000`3oool2000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
0?ooo`8000003@3oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0=03oool004/0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo03@0oooo001;0?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0303oool6000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo1@0000040?ooo`030000003oool0oooo0080oooo
00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool6000000@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`@000001@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0=03oool004/0oooo1000
00070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000?0?ooo`030000
003oool0oooo00d0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`050?ooo`80
00000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00000@0?ooo`@000001P3o
ool00`000000oooo0?ooo`040?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000>
0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080000000D0oooo
000000000000oooo000000020?ooo`80000000D0oooo000000000000oooo000000030?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?oo
o`3oool0=03oool004/0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`<000001P3oool3
000000030?ooo`000000000000h0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00
00040?ooo`L000000`3oool00`000000oooo00000002000000d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`@000000P3oool3000000<0oooo0`0000030?ooo`@00000103o
ool2000000040?ooo`0000000000000000`0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`3oool3000000D0oooo0P000000103oool000000000000000030?ooo`8000000`3oool20000
00@0oooo1@0000040?ooo`@00000103oool3000000H0oooo0`0000000`3oool000000?ooo`0<0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`80000000D0oooo0000
00000000oooo000000020?ooo`030000003oool0oooo0080000000D0oooo0000003oool0oooo0000
00050?ooo`<00000103oool7000000<0oooo0`0000070?ooo`@000000`3oool2000000040?ooo`00
00000000000003L0oooo001;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3o
ool010000000oooo0?ooo`3oool2000003d0oooo00<000000?ooo`3oool02`3oool010000000oooo
0?ooo`3oool2000002P0oooo00<000000?ooo`3oool0D`3oool004X0oooo1`00000N0?ooo`<00000
403oool00`000000oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3P3oool600000380oooo0`0000000`3oool000000?ooo`0l0?ooo`030000003oool0oooo00`0oooo
0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo05<0oooo001F0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03`3oool2000000d0oooo0P00001B0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool01`3oool2000004D0oooo00<000000?ooo`3oool0B@3o
ool005H0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0B@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359.063}, {221.438, 0}} -> {-0.884257, -0.093282, \
0.0266146, 0.00771046}, {{0, 430.875}, {265.875, 0}} -> {-0.884257, \
-0.093282, 0.0266146, 0.00771046}}]
}, Open  ]],

Cell[TextData[{
  "\tWhen the power is large, the phases take the form of isolated pulses of \
near-gaussian form, approaching ",
  Cell[BoxData[
      \(TraditionalForm\`E\^\(\(-n\)\ \(\(k\^2\)(\[Pi]/2  k\  - \
t)\)\^2/2\)\)]],
  " as the power tends to infinity. Example E3 compares the Gaussian \
expression with the 10'th power of a 12-phase sinusoid. Higher powers give \
closer approximations. Note the analogy with ",
  StyleBox["JacobiCN",
    FontSlant->"Italic"],
  " periodic pulse solitonic solutions to the KdV non-linear PDE. They go to \
",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["Sech",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  " pulses as the period becomes infinite. Modulated Gaussian pulses are \
dispersive wave-packet solutions to the Schroedinger equation; I have not \
found a power-sinusoid analogue."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example E3. Plotting ",
  Cell[BoxData[
      \(TraditionalForm\`Sin[12\ t]\^10\)]],
  " & Exp[-",
  Cell[BoxData[
      \(TraditionalForm\`12*\(10\^2\) \((\[Pi]/20 - t)\)\^2\)]],
  "/2]."
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(pp = 12\), ";", \(kk = 10\), ";", \(s1210 = Sin[kk\ t]^pp\), 
      ";", 
      RowBox[{"Plot", "[", 
        RowBox[{\({s1210, Exp[\(-pp\)\ kk\^2/2 \((\(\[Pi]/2\)/kk - t)\)^2]}\),
           ",", \({t, \(\[Pi]/2\)/kk -  .9/kk, \(\[Pi]/2\)/kk +  .9/kk}\), 
          ",", \(PlotStyle \[Rule] {{RGBColor[1, 0, 0]}, {RGBColor[0, 1, 
                  0]}}\), ",", \(PlotRange \[Rule] {0, 1}\), ",", 
          RowBox[{"PlotLabel", "\[Rule]", "\"\<Fig.2 \!\(\*
StyleBox[\"Power\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"Sinusoid\",\nFontColor->RGBColor[1, 0, 0]]\) vs \!\(\*
StyleBox[\"Gauss\",\nFontColor->RGBColor[0, 1, 0]]\)\>\""}]}], "]"}], 
      ";"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.331109 5.29101 0 0.618034 [
[.06572 -0.0125 -15 -9 ]
[.06572 -0.0125 15 0 ]
[.33027 -0.0125 -15 -9 ]
[.33027 -0.0125 15 0 ]
[.46254 -0.0125 -12 -9 ]
[.46254 -0.0125 12 0 ]
[.59482 -0.0125 -15 -9 ]
[.59482 -0.0125 15 0 ]
[.72709 -0.0125 -9 -9 ]
[.72709 -0.0125 9 0 ]
[.85937 -0.0125 -15 -9 ]
[.85937 -0.0125 15 0 ]
[.99164 -0.0125 -12 -9 ]
[.99164 -0.0125 12 0 ]
[.18549 .12361 -18 -4.5 ]
[.18549 .12361 0 4.5 ]
[.18549 .24721 -18 -4.5 ]
[.18549 .24721 0 4.5 ]
[.18549 .37082 -18 -4.5 ]
[.18549 .37082 0 4.5 ]
[.18549 .49443 -18 -4.5 ]
[.18549 .49443 0 4.5 ]
[.18549 .61803 -6 -4.5 ]
[.18549 .61803 0 4.5 ]
[.5 .63053 -89 0 ]
[.5 .63053 89 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06572 0 m
.06572 .00625 L
s
[(0.075)] .06572 -0.0125 0 1 Mshowa
.33027 0 m
.33027 .00625 L
s
[(0.125)] .33027 -0.0125 0 1 Mshowa
.46254 0 m
.46254 .00625 L
s
[(0.15)] .46254 -0.0125 0 1 Mshowa
.59482 0 m
.59482 .00625 L
s
[(0.175)] .59482 -0.0125 0 1 Mshowa
.72709 0 m
.72709 .00625 L
s
[(0.2)] .72709 -0.0125 0 1 Mshowa
.85937 0 m
.85937 .00625 L
s
[(0.225)] .85937 -0.0125 0 1 Mshowa
.99164 0 m
.99164 .00625 L
s
[(0.25)] .99164 -0.0125 0 1 Mshowa
.125 Mabswid
.09217 0 m
.09217 .00375 L
s
.11863 0 m
.11863 .00375 L
s
.14508 0 m
.14508 .00375 L
s
.17154 0 m
.17154 .00375 L
s
.22445 0 m
.22445 .00375 L
s
.2509 0 m
.2509 .00375 L
s
.27736 0 m
.27736 .00375 L
s
.30381 0 m
.30381 .00375 L
s
.35672 0 m
.35672 .00375 L
s
.38318 0 m
.38318 .00375 L
s
.40963 0 m
.40963 .00375 L
s
.43609 0 m
.43609 .00375 L
s
.489 0 m
.489 .00375 L
s
.51545 0 m
.51545 .00375 L
s
.54191 0 m
.54191 .00375 L
s
.56836 0 m
.56836 .00375 L
s
.62127 0 m
.62127 .00375 L
s
.64773 0 m
.64773 .00375 L
s
.67418 0 m
.67418 .00375 L
s
.70064 0 m
.70064 .00375 L
s
.75355 0 m
.75355 .00375 L
s
.78 0 m
.78 .00375 L
s
.80646 0 m
.80646 .00375 L
s
.83291 0 m
.83291 .00375 L
s
.88582 0 m
.88582 .00375 L
s
.91228 0 m
.91228 .00375 L
s
.93873 0 m
.93873 .00375 L
s
.96519 0 m
.96519 .00375 L
s
.03926 0 m
.03926 .00375 L
s
.01281 0 m
.01281 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.19799 .12361 m
.20424 .12361 L
s
[(0.2)] .18549 .12361 1 0 Mshowa
.19799 .24721 m
.20424 .24721 L
s
[(0.4)] .18549 .24721 1 0 Mshowa
.19799 .37082 m
.20424 .37082 L
s
[(0.6)] .18549 .37082 1 0 Mshowa
.19799 .49443 m
.20424 .49443 L
s
[(0.8)] .18549 .49443 1 0 Mshowa
.19799 .61803 m
.20424 .61803 L
s
[(1)] .18549 .61803 1 0 Mshowa
.125 Mabswid
.19799 .0309 m
.20174 .0309 L
s
.19799 .0618 m
.20174 .0618 L
s
.19799 .09271 m
.20174 .09271 L
s
.19799 .15451 m
.20174 .15451 L
s
.19799 .18541 m
.20174 .18541 L
s
.19799 .21631 m
.20174 .21631 L
s
.19799 .27812 m
.20174 .27812 L
s
.19799 .30902 m
.20174 .30902 L
s
.19799 .33992 m
.20174 .33992 L
s
.19799 .40172 m
.20174 .40172 L
s
.19799 .43262 m
.20174 .43262 L
s
.19799 .46353 m
.20174 .46353 L
s
.19799 .52533 m
.20174 .52533 L
s
.19799 .55623 m
.20174 .55623 L
s
.19799 .58713 m
.20174 .58713 L
s
.25 Mabswid
.19799 0 m
.19799 .61803 L
s
gsave
.5 .63053 -150 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.2) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Power) show
135.000 12.750 moveto
(Sinusoid) show
189.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vs) show
207.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
(Gauss) show
237.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .00206 m
.03279 .00265 L
.04262 .00345 L
.06244 .00574 L
.07298 .0074 L
.08426 .00962 L
.10458 .01499 L
.1148 .0185 L
.12589 .02305 L
.14603 .03355 L
.16586 .04724 L
.18689 .06602 L
.22473 .11256 L
.26501 .18163 L
.30379 .26554 L
.34501 .36656 L
.38472 .46379 L
.42291 .54388 L
.44259 .5758 L
.45351 .59002 L
.46356 .60068 L
.47384 .60903 L
.47925 .61236 L
.48201 .61376 L
.48497 .61505 L
.48757 .61599 L
.48994 .6167 L
.49233 .61725 L
.49459 .61765 L
.49586 .61781 L
.49656 .61788 L
.49721 .61793 L
.49837 .618 L
.49964 .61803 L
.50031 .61803 L
.50102 .61802 L
.50229 .61796 L
.50299 .61792 L
.50365 .61786 L
.50514 .61768 L
.50642 .61749 L
.50777 .61724 L
.51019 .61666 L
.5128 .61587 L
.51566 .61479 L
.5208 .61233 L
.5256 .60941 L
.53456 .6024 L
.54419 .59268 L
.56536 .56383 L
Mistroke
.58546 .52812 L
.62371 .44386 L
.6644 .34298 L
.70359 .24849 L
.74522 .16219 L
.76613 .12646 L
.78534 .09847 L
.82394 .05576 L
.8428 .04081 L
.86348 .0282 L
.88303 .01933 L
.90396 .01249 L
.91416 .00997 L
.92524 .00772 L
.93482 .00614 L
.94537 .00472 L
.96033 .00319 L
.96851 .00255 L
.97619 .00206 L
Mfstroke
0 1 0 r
.02381 .00479 m
.04262 .00698 L
.06244 .01021 L
.08255 .01476 L
.10458 .02166 L
.12415 .02993 L
.14509 .04155 L
.16639 .0569 L
.18653 .07523 L
.22495 .12213 L
.26581 .19078 L
.30517 .27395 L
.343 .3644 L
.38329 .46155 L
.42206 .54259 L
.44319 .57674 L
.45292 .58936 L
.46328 .60043 L
.46863 .60514 L
.47367 .60892 L
.47858 .61198 L
.48309 .61426 L
.48739 .61593 L
.48955 .61659 L
.49192 .61717 L
.49431 .6176 L
.49564 .61778 L
.49686 .6179 L
.498 .61798 L
.49923 .61803 L
.5004 .61803 L
.50148 .61801 L
.50265 .61794 L
.50389 .61783 L
.50495 .61771 L
.50611 .61754 L
.5087 .61703 L
.5111 .6164 L
.51547 .61487 L
.52014 .61268 L
.52569 .60935 L
.53094 .60549 L
.54074 .59643 L
.56076 .57102 L
.57921 .54027 L
.61861 .45715 L
.6565 .36563 L
.69684 .26938 L
.73566 .18796 L
.77694 .11943 L
Mistroke
.79757 .09264 L
.8167 .07201 L
.83641 .05465 L
.85495 .04153 L
.87551 .0301 L
.89413 .02214 L
.91425 .01562 L
.93273 .01117 L
.95159 .00781 L
.97227 .00519 L
.97619 .00479 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`007@3oool4000000H0oooo0P0000060?ooo`@000001`3oool00`000000oooo0?ooo`040?oo
o`@00000>03oool4000000H0oooo0P0000050?ooo`L000000P3oool6000000@0oooo1000000=0?oo
o`@000001P3oool2000000D0oooo1`0000030?ooo`@00000303oool4000000H0oooo0P0000050?oo
o`L000001@3oool00`000000oooo0?ooo`040?ooo`@000004P3oool4000000H0oooo0P0000050?oo
o`H00000403oool4000000H0oooo0P0000050?ooo`H000000`3oool6000000@0oooo1000000<0?oo
o`@000001P3oool2000000D0oooo1P0000040?ooo`@000007`3oool001`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`80
0000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo01`0oooo000L0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0703oool001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L
0?ooo`00703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo000L0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool4000003L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool4000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00@0oooo1000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo1000000A0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo1000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`@000007`3oool001`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803oool001`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo0`0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool3000000H0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo0`0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0200oooo000M0?ooo`@000003P3oool4000000@0oooo1P0000040?ooo`D00000=`3oool400000100
oooo00<000000?ooo`3oool0103oool4000000D0oooo1@00000<0?ooo`@00000403oool00`000000
oooo0?ooo`040?ooo`D000002`3oool400000100oooo00<000000?ooo`3oool00`3oool6000000@0
oooo1@00000A0?ooo`@000003P3oool400000140oooo1000000>0?ooo`@000001@3oool4000000D0
oooo1@00000;0?ooo`@000003P3oool4000000D0oooo1@00000N0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`006P3ooooo000006d00000:P3oool001l0oooo00@000000?ooo`3o
ool0oooo0`00o`070?l000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?l0003o00002P3o00000`3oool00?l00?ooo`030?oo
o`030000003oool0oooo02/0oooo000V0?ooo`L00?l02@3o000/0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`L0o`00203oool5003o00D0
oooo00<000000?ooo`3oool0:`3oool002d0oooo1P00o`030?ooo`@0o`00:03oool00`000000oooo
0?ooo`3o0?ooo`40oooo103o00080?ooo`L00?l0>03oool003<0oooo1000o`030?ooo`@0o`00903o
ool00`000000oooo0?ooo`3l0?ooo`@0o`001@3oool7003o03l0oooo000g0?ooo`<00?l0103oool4
0?l00200oooo00<000000?ooo`3oool0nP3oool20?l000@0oooo1@00o`160?ooo`00>P3oool2003o
00H0oooo0`3o000M0?ooo`030000003oool0oooo0?P0oooo0P3o00040?ooo`800?l0B`3oool003`0
oooo0`00o`060?ooo`80o`006`3oool00`000000oooo0?ooo`3e0?ooo`<0o`00103oool2003o04d0
oooo000o0?ooo`<00?l01@3oool20?l001T0oooo00<000000?ooo`3oool0l`3oool20?l000@0oooo
0`00o`1?0?ooo`00@P3oool2003o00D0oooo0P3o000G0?ooo`030000003oool0oooo0?40oooo0P3o
00040?ooo`800?l0DP3oool004@0oooo0P00o`050?ooo`80o`005@3oool00`000000oooo0?ooo`3_
0?ooo`80o`00103oool2003o05@0oooo00160?ooo`800?l01@3oool20?l001<0oooo0P00003^0?oo
o`80o`00103oool2003o05H0oooo00180?ooo`800?l01@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0>/0oooo0P3o00040?ooo`800?l0F03oool004X0oooo0P00o`040?ooo`80o`00
403oool00`000000oooo0?ooo`3Y0?ooo`80o`00103oool2003o05X0oooo001<0?ooo`800?l0103o
ool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo0>L0oooo0P3o00040?ooo`800?l0G03o
ool004h0oooo0P00o`030?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool0iP3oool0
0`3o0000oooo0?ooo`020?ooo`800?l0GP3oool00500oooo0P00o`020?ooo`80o`00303oool00`00
0000oooo0?ooo`3U0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0GP3oool00580
oooo00D00?l00?ooo`3oool0oooo0?l0000;0?ooo`030000003oool0oooo0><0oooo0P3o00040?oo
o`03003o003oool0oooo05l0oooo001C0?ooo`05003o003oool0oooo0?ooo`3o00002P3oool00`00
0000oooo0?ooo`3R0?ooo`030?l0003oool0oooo0080oooo0P00o`1R0?ooo`00E03oool2003o0080
oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`3Q0?ooo`030?l0003oool0oooo0080
oooo00<00?l00?ooo`3oool0HP3oool005H0oooo00@00?l00?ooo`3oool0o`00203oool00`000000
oooo0?ooo`3P0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0H`3oool005L0oooo
00<00?l00?ooo`3oool00P3o00060?ooo`030000003oool0oooo0=l0oooo00<0o`000?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`1T0?ooo`00F03oool01@00o`00oooo0?ooo`3oool0o`0000D0oooo
0P00003O0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0I@3oool005T0oooo00D0
0?l00?ooo`3oool0oooo0?l000040?ooo`030000003oool0oooo0=d0oooo00@0o`000?ooo`3oool0
oooo0P00o`1X0?ooo`00FP3oool2003o0080oooo00D0o`000?ooo`3oool0oooo0000003N0?ooo`05
0?l0003oool0oooo0?ooo`00o`00JP3oool005`0oooo00@00?l00?ooo`3oool0o`000P3oool00`00
0000oooo0?ooo`3K0?ooo`050?l0003oool0oooo0?ooo`00o`00J`3oool005d0oooo00H00?l00?oo
o`3oool0o`000?ooo`00003L0?ooo`050?l0003oool0oooo0?ooo`00o`00K03oool005h0oooo00D0
0?l00?ooo`3o0000oooo0000003K0?ooo`050?l0003oool0oooo0?ooo`00o`00K@3oool005l0oooo
00@00?l00?ooo`3o00000000f`3oool0103o0000oooo0?ooo`00o`1^0?ooo`00H03oool00`00o`00
oooo0?l0003J0?ooo`040?l0003oool0oooo003o06l0oooo001P0?ooo`04003o003oool000000?l0
0=P0oooo00@0o`000?ooo`3oool00?l0L03oool00640oooo00@00?l00000003oool0o`00eP3oool0
103o0000oooo0?ooo`00o`1a0?ooo`00HP3oool01000o`00oooo0?ooo`3o003D0?ooo`040?l0003o
ool0oooo003o0780oooo001R0?ooo`0400000000o`00oooo0?l00=<0oooo00@0o`000?ooo`3oool0
0?l0L`3oool00680oooo00D000000?ooo`00o`00oooo0?l0003A0?ooo`040?l0003oool0oooo003o
07@0oooo001R0?ooo`060000003oool0oooo003o003oool0o`00c`3oool0103o0000oooo0?ooo`00
o`1e0?ooo`00HP3oool010000000oooo0?ooo`00o`020?ooo`030?l0003oool0oooo0</0oooo00D0
o`000?ooo`3oool0oooo003o001e0?ooo`00HP3oool01@000000oooo0?ooo`3oool00?l00080oooo
00<0o`000?ooo`3oool0bP3oool0103o0000oooo0?ooo`00o`1f0?ooo`00HP3oool00`000000oooo
0?ooo`020?ooo`04003o003oool0oooo0?l00<X0oooo00@0o`000?ooo`3oool00?l0M`3oool00680
oooo00<000000?ooo`3oool00`3oool00`00o`00oooo0?l000390?ooo`040?l0003oool0oooo003o
07P0oooo001R0?ooo`030000003oool0oooo00@0oooo00<00?l00?ooo`3o0000b03oool00`3o0000
oooo003o001i0?ooo`00A03oool4000000H0oooo0P0000050?ooo`H000001`3oool00`000000oooo
0?ooo`050?ooo`03003o003oool0o`000<H0oooo00@0o`000?ooo`3oool00?l0N@3oool004<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool01000o`00oooo
0?ooo`3o00350?ooo`030?l0003oool00?l007X0oooo00130?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo
00<00?l00?ooo`3o0000a03oool00`3o0000oooo003o001k0?ooo`00@`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`03003o003oool0o`000<80oooo00<0o`000?ooo`00o`00O03oool004<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo0`000008
0?ooo`03003o003o0000oooo0<40oooo00<0o`000?ooo`00o`00O03oool004<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool00`00o`00oooo0?l000300?ooo`030?l0003oool00?l007d0oooo00130?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00o`00o`000?ooo`2n0?ooo`04
0?l0003oool0oooo003o07d0oooo00130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02@3oool00`00o`00oooo0?l0002n0?ooo`030?l0003oool00?l007h0oooo00140?ooo`@00000
3P3oool4000000P0oooo00<000000?ooo`3oool02P3oool00`00o`00o`000?ooo`2l0?ooo`030?l0
003oool00?l007l0oooo001R0?ooo`030000003oool0oooo00X0oooo00<00?l00?ooo`3o0000_03o
ool00`3o0000oooo003o001o0?ooo`00HP3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0
o`000;X0oooo00<0o`000?ooo`00o`00P03oool00680oooo00<000000?ooo`3oool02`3oool00`00
o`00oooo0?l0002j0?ooo`030?l0003oool00?l00800oooo001R0?ooo`030000003oool0oooo00`0
oooo00<00?l00?ooo`3o0000^03oool00`3o0000oooo003o00210?ooo`00HP3oool00`000000oooo
0?ooo`0=0?ooo`03003o003o0000oooo0;L0oooo00<0o`00003o003oool0P@3oool00680oooo00<0
00000?ooo`3oool03@3oool00`00o`00oooo0?l0002f0?ooo`030?l0003oool00?l00880oooo001R
0?ooo`8000003`3oool00`00o`00o`000?ooo`2e0?ooo`030?l00000o`00oooo0880oooo001R0?oo
o`030000003oool0oooo00h0oooo00<00?l00?ooo`3o0000]03oool00`3o0000oooo003o00230?oo
o`00HP3oool00`000000oooo0?ooo`0?0?ooo`03003o003oool0o`000;<0oooo00<0o`00003o003o
ool0P`3oool00680oooo00<000000?ooo`3oool03`3oool00`00o`00oooo0?l0002b0?ooo`030?l0
0000o`00oooo08@0oooo001R0?ooo`030000003oool0oooo0100oooo00<00?l00?ooo`3o0000/03o
ool00`3o0000oooo003o00250?ooo`00HP3oool00`000000oooo0?ooo`0A0?ooo`03003o003o0000
oooo0:l0oooo00<0o`00003o003oool0Q@3oool00680oooo00<000000?ooo`3oool04@3oool00`00
o`00oooo0?l0002^0?ooo`030?l0003oool00?l008H0oooo001R0?ooo`030000003oool0oooo0180
oooo00<00?l00?l0003oool0[@3oool00`3o00000?l00?ooo`260?ooo`00HP3oool00`000000oooo
0?ooo`0B0?ooo`03003o003oool0o`000:`0oooo00<0o`00003o003oool0Q`3oool00680oooo00<0
00000?ooo`3oool04`3oool00`00o`00o`000?ooo`2[0?ooo`030?l00000o`00oooo08L0oooo001R
0?ooo`030000003oool0oooo01<0oooo00<00?l00?ooo`3o0000ZP3oool00`3o00000?l00?ooo`28
0?ooo`00HP3oool2000001D0oooo00<00?l00?l0003oool0Z@3oool00`3o00000?l00?ooo`280?oo
o`00HP3oool00`000000oooo0?ooo`0D0?ooo`03003o003oool0o`000:P0oooo00<0o`00003o003o
ool0R@3oool00680oooo00<000000?ooo`3oool05@3oool00`00o`00o`000?ooo`2W0?ooo`030?l0
0000o`00oooo08T0oooo001R0?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3o0000YP3o
ool00`3o00000?l00?ooo`2:0?ooo`00HP3oool00`000000oooo0?ooo`0F0?ooo`03003o003o0000
oooo0:D0oooo00<0o`00003o003oool0RP3oool00680oooo00<000000?ooo`3oool05P3oool00`00
o`00oooo0?l0002T0?ooo`030?l00000o`00oooo08/0oooo001R0?ooo`030000003oool0oooo01L0
oooo00<00?l00?l0003oool0X`3oool00`3o00000?l00?ooo`2;0?ooo`00HP3oool00`000000oooo
0?ooo`0G0?ooo`03003o003oool0o`000:80oooo00<0o`00003o003oool0S03oool00680oooo00<0
00000?ooo`3oool0603oool00`00o`00o`000?ooo`2Q0?ooo`030?l00000o`00oooo08`0oooo001R
0?ooo`030000003oool0oooo01P0oooo00<00?l00?ooo`3o0000X03oool00`3o00000?l00?ooo`2=
0?ooo`00HP3oool00`000000oooo0?ooo`0I0?ooo`03003o003o0000oooo09l0oooo00<0o`00003o
003oool0S@3oool00680oooo0P00000J0?ooo`03003o003oool0o`0009h0oooo00<0o`00003o003o
ool0SP3oool00680oooo00<000000?ooo`3oool06P3oool00`00o`00o`000?ooo`2M0?ooo`030?l0
0000o`00oooo08h0oooo001R0?ooo`030000003oool0oooo01X0oooo00<00?l00?ooo`3o0000W03o
ool00`3o00000?l00?ooo`2?0?ooo`00HP3oool00`000000oooo0?ooo`0K0?ooo`03003o003o0000
oooo09/0oooo00<0o`00003o003oool0S`3oool00680oooo00<000000?ooo`3oool06`3oool00`00
o`00o`000?ooo`2J0?ooo`030?l00000o`00oooo0900oooo001R0?ooo`030000003oool0oooo01`0
oooo00<00?l00?l0003oool0V@3oool00`3o00000?l00?ooo`2@0?ooo`00HP3oool00`000000oooo
0?ooo`0L0?ooo`03003o003o0000oooo09P0oooo00<0o`000?ooo`00o`00T@3oool00680oooo00<0
00000?ooo`3oool07@3oool00`00o`00o`000?ooo`2G0?ooo`030?l00000o`00oooo0940oooo0014
0?ooo`@000001P3oool2000000L0oooo100000070?ooo`030000003oool0oooo01d0oooo00<00?l0
0?l0003oool0UP3oool00`3o0000oooo003o002B0?ooo`00@`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool07P3oool00`00o`00o`000?ooo`2E0?ooo`030?l00000o`00oooo0980oooo00130?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01h0oooo00<00?l00?l0003oool0U03oool00`3o0000oooo003o002C0?ooo`00
@`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo1P0000070?ooo`<00000
7`3oool00`00o`00o`000?ooo`2C0?ooo`030?l00000o`00oooo09<0oooo00130?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo01l0oooo00<00?l00?l0003oool0TP3oool00`3o0000oooo003o002D0?ooo`00@`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`0P0?ooo`03003o003o0000oooo0940oooo00<0o`00003o003oool0
U03oool004<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000P0oooo00<000000?ooo`3oool0803oool00`00o`00o`000?ooo`2@0?ooo`030?l0003o
ool00?l009D0oooo00130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`000000oooo000000080?ooo`030000003oool0oooo0240oooo00<00?l00?l0003oool0S`3oool0
0`3o00000?l00?ooo`2E0?ooo`00A03oool400000100oooo0P0000080?ooo`030000003oool0oooo
0240oooo00<00?l00?l0003oool0SP3oool00`3o0000oooo003o002F0?ooo`00HP3oool00`000000
oooo0?ooo`0R0?ooo`03003o003o0000oooo08d0oooo00<0o`00003o003oool0UP3oool00680oooo
00<000000?ooo`3oool08P3oool00`00o`00o`000?ooo`2=0?ooo`030?l00000o`00oooo09H0oooo
001R0?ooo`030000003oool0oooo02<0oooo00<00?l00?ooo`3oool0R`3oool00`3o00000?l00?oo
o`2G0?ooo`00HP3oool00`000000oooo0?ooo`0S0?ooo`03003o003o0000oooo08/0oooo00<0o`00
003o003oool0U`3oool00680oooo00<000000?ooo`3oool0903oool00`00o`00oooo0?ooo`290?oo
o`030?l0003oool00?l009P0oooo001R0?ooo`030000003oool0oooo02@0oooo00<00?l00?l0003o
ool0R@3oool00`3o00000?l00?ooo`2H0?ooo`00HP3oool2000002H0oooo00<00?l00?ooo`3oool0
Q`3oool00`3o0000oooo003o002I0?ooo`00HP3oool00`000000oooo0?ooo`0U0?ooo`03003o003o
ool0oooo08L0oooo00<0o`00003o003oool0V@3oool00680oooo00<000000?ooo`3oool09P3oool0
0`00o`00oooo0?ooo`260?ooo`030?l00000o`00oooo09T0oooo001R0?ooo`030000003oool0oooo
02H0oooo00<00?l00?ooo`3oool0Q@3oool00`3o00000?l00?ooo`2J0?ooo`00HP3oool00`000000
oooo0?ooo`0V0?ooo`03003o003o0000oooo08D0oooo00<0o`00003o003oool0VP3oool00680oooo
00<000000?ooo`3oool09`3oool00`00o`00oooo0?ooo`230?ooo`030?l0003oool00?l009/0oooo
001R0?ooo`030000003oool0oooo02L0oooo00<00?l00?ooo`3oool0P`3oool00`3o00000?l00?oo
o`2K0?ooo`00HP3oool00`000000oooo0?ooo`0X0?ooo`03003o003oool0oooo0880oooo00<0o`00
003o003oool0V`3oool00680oooo00<000000?ooo`3oool0:03oool00`00o`00oooo0?ooo`210?oo
o`030?l00000o`00oooo09`0oooo001R0?ooo`030000003oool0oooo02P0oooo00<00?l00?l0003o
ool0P@3oool00`3o00000?l00?ooo`2L0?ooo`00HP3oool00`000000oooo0?ooo`0Y0?ooo`03003o
003oool0oooo07l0oooo00<0o`00003o003oool0W@3oool00680oooo0P00000Z0?ooo`03003o003o
ool0oooo07l0oooo00<0o`00003o003oool0W@3oool00680oooo00<000000?ooo`3oool0:P3oool0
0`00o`00oooo0?ooo`1n0?ooo`030?l00000o`00oooo09d0oooo001R0?ooo`030000003oool0oooo
02X0oooo00<00?l00?ooo`3oool0O@3oool00`3o00000?l00?ooo`2N0?ooo`00HP3oool00`000000
oooo0?ooo`0Z0?ooo`03003o003o0000oooo07d0oooo00<0o`00003o003oool0WP3oool00680oooo
00<000000?ooo`3oool0:`3oool00`00o`00oooo0?ooo`1k0?ooo`030?l00000o`00oooo09l0oooo
001R0?ooo`030000003oool0oooo02/0oooo00<00?l00?l0003oool0N`3oool00`3o00000?l00?oo
o`2O0?ooo`00HP3oool00`000000oooo0?ooo`0[0?ooo`03003o003o0000oooo07X0oooo00<0o`00
003o003oool0X03oool00680oooo00<000000?ooo`3oool0;03oool00`00o`00oooo0?ooo`1i0?oo
o`030?l00000o`00oooo0:00oooo001R0?ooo`030000003oool0oooo02`0oooo00<00?l00?l0003o
ool0N@3oool00`3o00000?l00?ooo`2P0?ooo`00HP3oool00`000000oooo0?ooo`0]0?ooo`03003o
003oool0oooo07L0oooo00<0o`00003o003oool0X@3oool00680oooo00<000000?ooo`3oool0;@3o
ool00`00o`00o`000?ooo`1g0?ooo`030?l00000o`00oooo0:40oooo001R0?ooo`800000;P3oool0
0`00o`00o`000?ooo`1f0?ooo`030?l00000o`00oooo0:80oooo001R0?ooo`030000003oool0oooo
02h0oooo00<00?l00?ooo`3oool0M@3oool00`3o00000?l00?ooo`2R0?ooo`00HP3oool00`000000
oooo0?ooo`0^0?ooo`03003o003o0000oooo07D0oooo00<00?l00?ooo`3oool0XP3oool00680oooo
00<000000?ooo`3oool0;`3oool00`00o`00oooo0?ooo`1c0?ooo`030?l00000o`00oooo0:<0oooo
001R0?ooo`030000003oool0oooo02l0oooo00<00?l00?l0003oool0L`3oool00`3o00000?l00?oo
o`2S0?ooo`00HP3oool00`000000oooo0?ooo`0_0?ooo`03003o003o0000oooo0780oooo00<0o`00
003o003oool0Y03oool00680oooo00<000000?ooo`3oool0<03oool00`00o`00oooo0?ooo`1a0?oo
o`030?l00000o`00oooo0:@0oooo001R0?ooo`030000003oool0oooo0300oooo00<00?l00?l0003o
ool0L@3oool00`00o`00oooo0?ooo`2T0?ooo`00A03oool4000000H0oooo0P0000070?ooo`@00000
1`3oool00`000000oooo0?ooo`0a0?ooo`03003o003oool0oooo06l0oooo00<0o`00003o003oool0
Y@3oool004<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<@3o
ool00`00o`00o`000?ooo`1_0?ooo`03003o003oool0oooo0:D0oooo00130?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0<@3oool00`00o`00o`000?ooo`1^0?ooo`030?l00000o`00
oooo0:H0oooo00130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool20000
00<0oooo00<000000?ooo`3oool0103oool300000380oooo00<00?l00?ooo`3oool0K@3oool00`3o
00000?l00?ooo`2V0?ooo`00@`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000000P0000070?ooo`030000003oool0oooo0380oooo00<00?l00?l0003o
ool0K@3oool00`00o`00oooo0?ooo`2V0?ooo`00@`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0c0?ooo`03003o
003oool0oooo06/0oooo00<0o`00003o003oool0Y`3oool004<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0<`3o
ool00`00o`00o`000?ooo`1[0?ooo`03003o003oool0oooo0:L0oooo00130?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo03@0oooo00<00?l00?ooo`3oool0J@3oool00`3o00000?l00?ooo`2X0?ooo`00A03oool40000
0140oooo0`0000060?ooo`030000003oool0oooo03@0oooo00<00?l00?l0003oool0J@3oool00`3o
00000?l00?ooo`2X0?ooo`00HP3oool00`000000oooo0?ooo`0d0?ooo`03003o003o0000oooo06T0
oooo00<00?l00?ooo`3oool0Z03oool00680oooo00<000000?ooo`3oool0=@3oool00`00o`00oooo
0?ooo`1W0?ooo`030?l00000o`00oooo0:T0oooo001R0?ooo`030000003oool0oooo03D0oooo00<0
0?l00?l0003oool0I`3oool00`00o`00oooo0?ooo`2Y0?ooo`00HP3oool00`000000oooo0?ooo`0f
0?ooo`03003o003oool0oooo06D0oooo00<0o`00003o003oool0ZP3oool00680oooo00<000000?oo
o`3oool0=P3oool00`00o`00o`000?ooo`1U0?ooo`030?l00000o`00oooo0:X0oooo001R0?ooo`03
0000003oool0oooo03L0oooo00<00?l00?ooo`3oool0H`3oool00`3o00000?l00?ooo`2[0?ooo`00
HP3oool2000003P0oooo00<00?l00?l0003oool0H`3oool00`3o00000?l00?ooo`2[0?ooo`00HP3o
ool00`000000oooo0?ooo`0g0?ooo`03003o003o0000oooo06<0oooo00<00?l00?ooo`3oool0Z`3o
ool00680oooo00<000000?ooo`3oool0>03oool00`00o`00oooo0?ooo`1Q0?ooo`030?l00000o`00
oooo0:`0oooo001R0?ooo`030000003oool0oooo03P0oooo00<00?l00?l0003oool0H@3oool00`3o
00000?l00?ooo`2/0?ooo`00HP3oool00`000000oooo0?ooo`0i0?ooo`03003o003oool0oooo05l0
oooo00<0o`00003o003oool0[@3oool00680oooo00<000000?ooo`3oool0>@3oool00`00o`00o`00
0?ooo`1O0?ooo`030?l00000o`00oooo0:d0oooo001R0?ooo`030000003oool0oooo03X0oooo00<0
0?l00?ooo`3oool0GP3oool00`3o00000?l00?ooo`2]0?ooo`00HP3oool00`000000oooo0?ooo`0j
0?ooo`03003o003o0000oooo05d0oooo00<0o`00003o003oool0[P3oool00680oooo00<000000?oo
o`3oool0>P3oool00`00o`00o`000?ooo`1M0?ooo`030?l00000o`00oooo0:h0oooo001R0?ooo`03
0000003oool0oooo03/0oooo00<00?l00?ooo`3oool0F`3oool00`3o00000?l00?ooo`2_0?ooo`00
HP3oool00`000000oooo0?ooo`0k0?ooo`03003o003o0000oooo05/0oooo00<0o`00003o003oool0
[`3oool00680oooo0P00000m0?ooo`03003o003oool0oooo05X0oooo00<0o`00003o003oool0[`3o
ool00680oooo00<000000?ooo`3oool0?03oool00`00o`00o`000?ooo`1I0?ooo`030?l00000o`00
oooo0;00oooo001R0?ooo`030000003oool0oooo03d0oooo00<00?l00?ooo`3oool0F03oool00`3o
00000?l00?ooo`2`0?ooo`00HP3oool00`000000oooo0?ooo`0m0?ooo`03003o003o0000oooo05L0
oooo00<0o`00003o003oool0/@3oool00680oooo00<000000?ooo`3oool0?@3oool00`00o`00o`00
0?ooo`1G0?ooo`030?l00000o`00oooo0;40oooo001R0?ooo`030000003oool0oooo03h0oooo00<0
0?l00?ooo`3oool0EP3oool00`3o00000?l00?ooo`2a0?ooo`00HP3oool00`000000oooo0?ooo`0n
0?ooo`03003o003o0000oooo05D0oooo00<0o`00003o003oool0/P3oool00680oooo00<000000?oo
o`3oool0?`3oool00`00o`00oooo0?ooo`1D0?ooo`030?l00000o`00oooo0;80oooo001R0?ooo`03
0000003oool0oooo03l0oooo00<00?l00?l0003oool0D`3oool00`3o00000?l00?ooo`2c0?ooo`00
HP3oool00`000000oooo0?ooo`100?ooo`03003o003oool0oooo0580oooo00<0o`00003o003oool0
/`3oool00680oooo00<000000?ooo`3oool0@03oool00`00o`00o`000?ooo`1A0?ooo`030?l00000
o`00oooo0;@0oooo001R0?ooo`800000@@3oool00`00o`00o`000?ooo`1A0?ooo`030?l00000o`00
oooo0;@0oooo001R0?ooo`030000003oool0oooo0440oooo00<00?l00?ooo`3oool0D03oool00`00
o`00oooo0?ooo`2d0?ooo`00HP3oool00`000000oooo0?ooo`110?ooo`03003o003o0000oooo04l0
oooo00<0o`00003o003oool0]@3oool00680oooo00<000000?ooo`3oool0@P3oool00`00o`00oooo
0?ooo`1>0?ooo`03003o003oool0oooo0;D0oooo001R0?ooo`030000003oool0oooo0480oooo00<0
0?l00?l0003oool0C@3oool00`3o00000?l00?ooo`2f0?ooo`00HP3oool00`000000oooo0?ooo`13
0?ooo`03003o003oool0oooo04`0oooo00<00?l00?ooo`3oool0]P3oool00680oooo00<000000?oo
o`3oool0@`3oool00`00o`00o`000?ooo`1<0?ooo`03003o003oool0oooo0;H0oooo001R0?ooo`03
0000003oool0oooo04@0oooo00<00?l00?ooo`3oool0BP3oool00`00o`00oooo0?ooo`2g0?ooo`00
A03oool4000000H0oooo0P0000060?ooo`@00000203oool00`000000oooo0?ooo`140?ooo`03003o
003o0000oooo04X0oooo00<00?l00?ooo`3oool0]`3oool004<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0A@3oool00`00o`00oooo0?ooo`180?ooo`03003o003o
ool0oooo0;P0oooo00130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A@3oool0
0`00o`00o`000?ooo`180?ooo`03003o003oool0oooo0;P0oooo00130?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo0`0000160?ooo`03003o003oool0oooo04H0oooo00<00?l00?ooo`3oool0^@3oool004<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000203oool00`000000
oooo0?ooo`160?ooo`03003o003o0000oooo04H0oooo00<00?l00?ooo`3oool0^@3oool004<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`170?ooo`03003o003oool0oooo04@0oooo
00<00?l00?l0003oool0^P3oool004<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`170?ooo`03003o003o0000oooo04@0oooo00<00?l00?ooo`3oool0^P3oool004<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`170?ooo`03003o003o0000oooo04<0oooo00<00?l0
0?l0003oool0^`3oool004@0oooo1000000>0?ooo`@00000203oool00`000000oooo0?ooo`180?oo
o`03003o003o0000oooo0480oooo00<00?l00?ooo`3oool0^`3oool00680oooo00<000000?ooo`3o
ool0B03oool00`00o`00o`000?ooo`110?ooo`03003o003o0000oooo0;`0oooo001R0?ooo`030000
003oool0oooo04T0oooo00<00?l00?l0003oool0@03oool00`00o`00o`000?ooo`2l0?ooo`00HP3o
ool00`000000oooo0?ooo`190?ooo`03003o003o0000oooo03l0oooo00<00?l00?l0003oool0_@3o
ool00680oooo00<000000?ooo`3oool0BP3oool00`00o`00o`000?ooo`0n0?ooo`03003o003o0000
oooo0;d0oooo001R0?ooo`030000003oool0oooo04X0oooo00<00?l00?l0003oool0?@3oool00`00
o`00o`000?ooo`2n0?ooo`00HP3oool00`000000oooo0?ooo`1;0?ooo`03003o003o0000oooo03`0
oooo00<00?l00?l0003oool0_P3oool00680oooo0P00001<0?ooo`03003o003o0000oooo03/0oooo
00<00?l00?l0003oool0_`3oool00680oooo00<000000?ooo`3oool0C03oool00`00o`00o`000?oo
o`0j0?ooo`03003o003o0000oooo0;l0oooo001R0?ooo`030000003oool0oooo04`0oooo00<00?l0
0?l0003oool0>@3oool00`00o`00o`000?ooo`300?ooo`00HP3oool00`000000oooo0?ooo`1=0?oo
o`03003o003o0000oooo03P0oooo00<00?l00?l0003oool0`03oool00680oooo00<000000?ooo`3o
ool0C@3oool00`00o`00o`000?ooo`0g0?ooo`03003o003o0000oooo0<40oooo001R0?ooo`030000
003oool0oooo04h0oooo00<00?l00?l0003oool0=P3oool00`00o`00o`000?ooo`310?ooo`00HP3o
ool00`000000oooo0?ooo`1>0?ooo`03003o003o0000oooo03D0oooo00<00?l00?l0003oool0`P3o
ool00680oooo00<000000?ooo`3oool0C`3oool00`00o`00o`000?ooo`0d0?ooo`03003o003oool0
oooo0<80oooo001R0?ooo`030000003oool0oooo04l0oooo00<00?l00?l0003oool0<`3oool00`00
o`00o`000?ooo`330?ooo`00HP3oool00`000000oooo0?ooo`1@0?ooo`03003o003o0000oooo0380
oooo00<00?l00?ooo`3oool0``3oool00680oooo00<000000?ooo`3oool0D@3oool00`00o`00oooo
0?ooo`0`0?ooo`03003o003oool0oooo0<@0oooo001R0?ooo`800000DP3oool00`00o`00o`000?oo
o`0`0?ooo`03003o003oool0oooo0<@0oooo001R0?ooo`030000003oool0oooo0580oooo00<00?l0
0?ooo`3oool0;P3oool00`00o`00oooo0?ooo`350?ooo`00HP3oool00`000000oooo0?ooo`1C0?oo
o`03003o003oool0oooo02d0oooo00<00?l00?ooo`3oool0a@3oool00680oooo00<000000?ooo`3o
ool0D`3oool00`00o`00o`000?ooo`0/0?ooo`03003o003oool0oooo0<H0oooo001R0?ooo`030000
003oool0oooo05@0oooo00<00?l00?ooo`3oool0:P3oool00`3o00000?l00?ooo`370?ooo`00HP3o
ool00`000000oooo0?ooo`1E0?ooo`03003o003oool0oooo02T0oooo00<00?l00?ooo`3oool0a`3o
ool00680oooo00<000000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0X0?ooo`03003o003oool0
oooo0<P0oooo001R0?ooo`030000003oool0oooo05H0oooo00<00?l00?ooo`3oool09P3oool00`00
o`00oooo0?ooo`390?ooo`00HP3oool00`000000oooo0?ooo`1G0?ooo`03003o003oool0oooo02@0
oooo00<00?l00?ooo`3oool0bP3oool00680oooo00<000000?ooo`3oool0E`3oool00`00o`00o`00
0?ooo`0S0?ooo`03003o003o0000oooo0</0oooo001R0?ooo`030000003oool0oooo05P0oooo00<0
0?l00?ooo`3oool08P3oool00`00o`00oooo0?ooo`3;0?ooo`00HP3oool2000005T0oooo00<00?l0
0?l0003oool08@3oool00`00o`00oooo0?ooo`3<0?ooo`00HP3oool00`000000oooo0?ooo`1I0?oo
o`03003o003o0000oooo01l0oooo00<00?l00?l0003oool0c@3oool00680oooo00<000000?ooo`3o
ool0FP3oool00`00o`00o`000?ooo`0M0?ooo`03003o003o0000oooo0<h0oooo001R0?ooo`030000
003oool0oooo05/0oooo00<00?l00?ooo`3oool06`3oool00`00o`00o`000?ooo`3?0?ooo`00HP3o
ool00`000000oooo0?ooo`1L0?ooo`03003o003oool0oooo01T0oooo00<00?l00?l0003oool0d03o
ool00680oooo00<000000?ooo`3oool0G@3oool00`00o`00oooo0?ooo`0G0?ooo`03003o003o0000
oooo0=40oooo001R0?ooo`030000003oool0oooo05h0oooo00<00?l00?ooo`3oool05P3oool00`00
o`00oooo0?ooo`3A0?ooo`00HP3oool00`000000oooo0?ooo`1O0?ooo`03003o003o0000oooo01<0
oooo00<0o`00003o003oool0d`3oool005D0oooo1`0000060?ooo`030000003oool0oooo0600oooo
0P00o`0B0?ooo`800?l0e@3oool005P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1R0?ooo`800?l03P3oool2003o0=L0oooo001H0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0I03oool3003o00P0oooo00<0o`00003o0000o`00f@3oool005P0oooo00<000000?oo
o`3oool01`3oool3000006L0oooo2@00o`3K0?ooo`00F03oool00`000000oooo0?ooo`3o0?oooeH0
oooo001H0?ooo`030000003oool0oooo0?l0ooooEP3oool005P0oooo00<000000?ooo`3oool0o`3o
oomF0?ooo`00EP3oool300000?l0ooooF03oool005P0oooo00<000000?ooo`3oool0o`3ooomF0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00H@3oool400000?l0ooooC03oool006D0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`00I@3oool00`000000oooo0?ooo`3o0?ooodT0oooo001>0?ooo`@0
00001@3oool7000000<0oooo0`0000000`3oool000000?ooo`040?ooo`8000001@3oool6000000`0
oooo1@3o00060?ooo`@0o`00103oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo103o00040?oo
o`D0o`003@3oool00`3o0000oooo0?l000020?l000<0oooo1`3o00020?ooo`<0o`000P3oool30?l0
00<0oooo0`3o00000`3oool0o`000?l000020?ooo`D0o`001@3oool40?l000<0oooo1`3o00030?oo
o`<0o`0000<0oooo0?l0003o00003P3oool2000000D0oooo1@00000>0?ooo`@00?l01@3oool5003o
00@0oooo0`00o`000`3oool00?l0003o00020?ooo`D00?l0103oool5003o0600oooo001?0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool20000
00D0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00X0o`000?ooo`3oool0o`000?ooo`3o
0000oooo0?l0003oool0o`000`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool03P3oool20?l000<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000030?oo
o`80o`000`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000103oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo0P3o
000?0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<0
0?l00?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool0
0P3oool01000o`00oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3oool00P3oool01@00o`00
oooo0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3oool0G@3oool004l0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool00P3oool02P3o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00030?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`060?ooo`050?l0003oool0oooo0?oo
o`3o0000103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`00o`000`3o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01P3o
ool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo05d0oooo001?0?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool03P3oool50?l000@0oooo00<0o`000?ooo`3oool00P3o
ool02P3o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00030?ooo`H0o`00103oool0
0`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?oo
o`020?ooo`@0o`00103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00@0
00000?ooo`3oool000001@3oool4000000`0oooo00<00?l00?ooo`3oool01@00o`030?ooo`@00?l0
103oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo1000o`050?ooo`@00?l0
H03oool004l0oooo100000070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo
0P00000?0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0o`0000@0oooo00@0o`000?ooo`3oool0o`000P3oool0103o0000oooo0?ooo`3o0003
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l00100oooo103o0006
0?ooo`030?l0003oool0oooo00@0oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000103o
ool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`3oool20?l0
00d0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`070?ooo`05003o003oool0oooo0?ooo`00o`00103o
ool00`00o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`00103oool01@00o`00oooo
0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3oool0G@3oool004l0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`<000001P3oool3000000030?ooo`000000000000l0oooo00<000000?oo
o`3oool0303oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo103o00020?oo
o`<0o`000`3oool30?l000<0oooo103o00040?ooo`80o`0000@0oooo0?l0003o0000o`00303oool0
0`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`<0o`001@3oool20?l000040?ooo`3o
0000o`000?l000<0oooo0P3o00030?ooo`80o`00103oool50?l000@0oooo103o00040?ooo`<0o`00
1P3oool30?l000030?ooo`3o0000oooo00/0oooo0`0000020?ooo`<000000`3oool5000000/0oooo
00<00?l00?ooo`3oool0203oool3003o00@0oooo0P00o`030?ooo`800?l0103oool5003o00@0oooo
1@00o`1O0?ooo`00C`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0;P3oool0103o0000oooo0?ooo`3oool20?l003d0oooo00<0o`000?ooo`3oool0
9P3oool01000o`00oooo0?ooo`3oool2003o08<0oooo001>0?ooo`L000007@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo1P3o000b0?ooo`<0o`0000<0oooo0?l0003oool0
?03oool00`3o0000oooo0?ooo`0W0?ooo`<00?l000<0oooo003o003oool0PP3oool005X0oooo00<0
00000?ooo`3oool05P3oool4000004l0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`070?ooo`80o`00/@3oool005X0oooo00<000000?ooo`3oool0J@3oool00`3o0000oooo0?ooo`0Z
0?ooo`030?l0003oool0oooo0;X0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0.0488663, -0.0803532, \
0.000780313, 0.00668029}}]
}, Open  ]],

Cell[TextData[{
  "\tThe power-sinusoid travelling pulse ",
  StyleBox["V=(a Sin[",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)],
    FontSlant->"Italic"],
  StyleBox["kx*(x+xi-jx*t)]",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`)\^p\)],
    FontSlant->"Italic"],
  " is a solution of the non-linear TXY.. differential equation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&\[DoubleDot]\)]],
  StyleBox["=(1-1/p) ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`V\& . \^2\)],
    FontSlant->"Italic"],
  StyleBox["/V + pV",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)],
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\((jx\ kx)\)\^2\)],
    FontSlant->"Italic"],
  ", which reduces to the TX fixed power sinusoid ",
  Cell[BoxData[
      \(TraditionalForm\`V\&\[DoubleDot]\)]],
  " = ",
  StyleBox["(1-1/p)",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(V\& . \^2\)\)\)]],
  "/",
  StyleBox["V",
    FontSlant->"Italic"],
  " +",
  Cell[BoxData[
      \(TraditionalForm\`p\ \[Omega]\^2\)]],
  StyleBox["V",
    FontSlant->"Italic"],
  ". Example E4 compares the integration (red) with the 12th. power sinusoid, \
which has been shifted up slightly for clarity (green). As the function and \
derivatives become zero when t\[RightArrow]\[Pi], the integration blows up \
beyond this point. An integration procedure that set very small values to \
zero would generate a single pulse resembling a wavelet."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Example E4. Power-sinusoid ",
  StyleBox["Differential Equation solution",
    FontColor->RGBColor[1, 0, 0]],
  " & ",
  StyleBox["Sin[x]^12+.05",
    FontColor->RGBColor[0, 1, 0]],
  "."
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(pp = 12\), ";", \(kk = 1\), 
      ";", \(startvals = {Sin[kk\ t]^pp, D[Sin[kk\ t]^pp, t]}\), 
      ";", \(sv = startvals /. t \[Rule] \[Pi]/4\), ";", 
      RowBox[{"solution", "=", 
        RowBox[{"NDSolve", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    SuperscriptBox["y", "\[DoublePrime]",
                      MultilineFunction->None], "[", "x", "]"}], "\[Equal]", 
                  RowBox[{
                    RowBox[{\((1 - 1/12)\), 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{
                            SuperscriptBox["y", "\[Prime]",
                              MultilineFunction->None], "[", "x", "]"}], "2"],
                         "/", \(y[x]\)}]}], "-", \(12  y[x]\)}]}], 
                ",", \(y[\[Pi]/4] == sv[\([1]\)]\), ",", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", \(\[Pi]/4\), "]"}], 
                  "\[Equal]", \(sv[\([2]\)]\)}]}], "}"}], ",", "y", 
            ",", \({x, \[Pi]/4, 5}\)}], "]"}]}], 
      ";", \(Plot[{Evaluate[y[x] /. solution], Sin[x]^12 +  .05}, {x,  .8, 
          5}, PlotRange \[Rule] {\(- .02\), 1.05}, 
        PlotStyle \[Rule] {{RGBColor[1, 0, 0]}, {RGBColor[0, 1, 0]}}, 
        PlotLabel \[Rule] "\<Fig.3 Power-Sinusoid Integration\>"]\), 
      ";"}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.011552 0.577602 [
[.21429 -0.00095 -3 -9 ]
[.21429 -0.00095 3 0 ]
[.40476 -0.00095 -3 -9 ]
[.40476 -0.00095 3 0 ]
[.59524 -0.00095 -3 -9 ]
[.59524 -0.00095 3 0 ]
[.78571 -0.00095 -3 -9 ]
[.78571 -0.00095 3 0 ]
[.97619 -0.00095 -3 -9 ]
[.97619 -0.00095 3 0 ]
[.01131 .12707 -18 -4.5 ]
[.01131 .12707 0 4.5 ]
[.01131 .24259 -18 -4.5 ]
[.01131 .24259 0 4.5 ]
[.01131 .35811 -18 -4.5 ]
[.01131 .35811 0 4.5 ]
[.01131 .47363 -18 -4.5 ]
[.01131 .47363 0 4.5 ]
[.01131 .58915 -6 -4.5 ]
[.01131 .58915 0 4.5 ]
[.5 .63053 -98 0 ]
[.5 .63053 98 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01155 m
.21429 .0178 L
s
[(1)] .21429 -0.00095 0 1 Mshowa
.40476 .01155 m
.40476 .0178 L
s
[(2)] .40476 -0.00095 0 1 Mshowa
.59524 .01155 m
.59524 .0178 L
s
[(3)] .59524 -0.00095 0 1 Mshowa
.78571 .01155 m
.78571 .0178 L
s
[(4)] .78571 -0.00095 0 1 Mshowa
.97619 .01155 m
.97619 .0178 L
s
[(5)] .97619 -0.00095 0 1 Mshowa
.125 Mabswid
.0619 .01155 m
.0619 .0153 L
s
.1 .01155 m
.1 .0153 L
s
.1381 .01155 m
.1381 .0153 L
s
.17619 .01155 m
.17619 .0153 L
s
.25238 .01155 m
.25238 .0153 L
s
.29048 .01155 m
.29048 .0153 L
s
.32857 .01155 m
.32857 .0153 L
s
.36667 .01155 m
.36667 .0153 L
s
.44286 .01155 m
.44286 .0153 L
s
.48095 .01155 m
.48095 .0153 L
s
.51905 .01155 m
.51905 .0153 L
s
.55714 .01155 m
.55714 .0153 L
s
.63333 .01155 m
.63333 .0153 L
s
.67143 .01155 m
.67143 .0153 L
s
.70952 .01155 m
.70952 .0153 L
s
.74762 .01155 m
.74762 .0153 L
s
.82381 .01155 m
.82381 .0153 L
s
.8619 .01155 m
.8619 .0153 L
s
.9 .01155 m
.9 .0153 L
s
.9381 .01155 m
.9381 .0153 L
s
.25 Mabswid
0 .01155 m
1 .01155 L
s
.02381 .12707 m
.03006 .12707 L
s
[(0.2)] .01131 .12707 1 0 Mshowa
.02381 .24259 m
.03006 .24259 L
s
[(0.4)] .01131 .24259 1 0 Mshowa
.02381 .35811 m
.03006 .35811 L
s
[(0.6)] .01131 .35811 1 0 Mshowa
.02381 .47363 m
.03006 .47363 L
s
[(0.8)] .01131 .47363 1 0 Mshowa
.02381 .58915 m
.03006 .58915 L
s
[(1)] .01131 .58915 1 0 Mshowa
.125 Mabswid
.02381 .04043 m
.02756 .04043 L
s
.02381 .06931 m
.02756 .06931 L
s
.02381 .09819 m
.02756 .09819 L
s
.02381 .15595 m
.02756 .15595 L
s
.02381 .18483 m
.02756 .18483 L
s
.02381 .21371 m
.02756 .21371 L
s
.02381 .27147 m
.02756 .27147 L
s
.02381 .30035 m
.02756 .30035 L
s
.02381 .32923 m
.02756 .32923 L
s
.02381 .38699 m
.02756 .38699 L
s
.02381 .41587 m
.02756 .41587 L
s
.02381 .44475 m
.02756 .44475 L
s
.02381 .50251 m
.02756 .50251 L
s
.02381 .53139 m
.02756 .53139 L
s
.02381 .56027 m
.02756 .56027 L
s
.02381 .61803 m
.02756 .61803 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -159 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.3) show
99.000 12.750 moveto
(Power) show
129.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sinusoid) show
189.000 12.750 moveto
(Integration) show
255.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.17619 .02228 m
.18009 .02511 L
.18373 .02827 L
.19199 .03768 L
.20004 .0505 L
.20864 .06906 L
.21817 .09644 L
.22718 .12963 L
.24404 .2112 L
.27631 .41277 L
.29264 .50713 L
.29712 .52836 L
.30193 .54816 L
.30644 .5635 L
.31063 .5747 L
.31285 .57938 L
.31486 .58285 L
.3171 .58583 L
.31833 .58706 L
.31948 .58797 L
.32051 .58856 L
.32159 .58896 L
.32251 .58913 L
.32352 .58913 L
.32461 .58891 L
.32523 .58868 L
.32578 .58842 L
.32687 .58773 L
.32789 .58688 L
.3298 .58476 L
.33182 .58178 L
.33546 .57453 L
.33937 .56411 L
.34369 .54964 L
.35217 .51312 L
.35994 .47187 L
.37746 .36289 L
.3947 .25333 L
.41074 .16575 L
.42622 .10189 L
.43488 .07549 L
.44275 .05682 L
.45114 .04183 L
.45887 .03176 L
.46291 .02769 L
.46735 .02401 L
.47196 .02095 L
.47634 .01865 L
.48042 .01695 L
.48488 .01551 L
Mistroke
.48892 .01449 L
.49267 .01376 L
.49714 .0131 L
.50117 .01266 L
.50342 .01246 L
.50584 .01229 L
.50796 .01216 L
.51022 .01204 L
.51437 .01188 L
.51823 .01177 L
.52059 .01172 L
.52282 .01169 L
.52701 .01164 L
.52915 .01162 L
.53142 .0116 L
.53338 .01159 L
.53549 .01158 L
.53775 .01157 L
.53988 .01157 L
.5424 .01156 L
.54471 .01156 L
.54681 .01156 L
.54871 .01156 L
.5509 .01156 L
.55297 .01155 L
.55489 .01155 L
.55665 .01155 L
.55859 .01155 L
.56064 .01155 L
.56172 .01155 L
.56271 .01155 L
.56377 .01155 L
.56493 .01155 L
.56599 .01155 L
.56698 .01155 L
.56893 .01155 L
.57001 .01155 L
.57103 .01155 L
.57224 .01155 L
.57335 .01155 L
.57444 .01155 L
.5756 .01155 L
.57677 .01155 L
.57804 .01155 L
.57914 .01155 L
.58016 .01155 L
.58128 .01155 L
.58247 .01155 L
.5835 .01155 L
.58446 .01155 L
Mistroke
.58552 .01155 L
.58611 .01155 L
.58666 .01155 L
.58766 .01155 L
.58875 .01155 L
.58972 .01155 L
.59075 .01155 L
.59176 .01155 L
.59271 .01155 L
.59357 .01155 L
.59449 .01155 L
.59559 .01155 L
.59662 .01155 L
.59721 .01155 L
.59774 .01155 L
.59836 .01155 L
.59895 .01155 L
.59952 .01155 L
.60012 .01155 L
.6012 .01155 L
.60181 .01155 L
.60237 .01155 L
.60298 .01155 L
.60366 .01155 L
.60469 .01155 L
.60577 .01155 L
.60678 .01155 L
.60771 .01155 L
.60882 .01155 L
.60983 .01155 L
.61099 .01155 L
.61208 .01155 L
.61305 .01155 L
.6141 .01155 L
.61508 .01155 L
.61598 .01155 L
.61703 .01155 L
.61817 .01155 L
.61925 .01155 L
.62026 .01156 L
.62139 .01156 L
.62246 .01156 L
.62445 .01156 L
.62557 .01156 L
.62659 .01157 L
.62771 .01157 L
.62891 .01158 L
.63077 .01159 L
.63251 .0116 L
.63457 .01162 L
Mistroke
.63645 .01165 L
.63841 .01169 L
.64054 .01175 L
.64255 .01183 L
.64441 .01192 L
.64645 .01206 L
.64832 .01222 L
.65048 .01247 L
.65253 .01277 L
.65441 .01313 L
.65616 .01355 L
.66013 .01489 L
.6624 .01597 L
.66453 .01726 L
.66852 .02062 L
.67075 .02318 L
.67281 .02609 L
.67524 .03034 L
.67746 .03515 L
.6814 .04644 L
.68563 .0636 L
.68955 .08572 L
.69326 .11385 L
.69758 .15784 L
.70157 .2123 L
.70596 .29136 L
.71061 .40322 L
.71472 .53121 L
Mfstroke
.71472 .53121 m
.71694 .61803 L
s
0 1 0 r
.17619 .05116 m
.18009 .05399 L
.18373 .05715 L
.19199 .06656 L
.20004 .07938 L
.20864 .09794 L
.21817 .12532 L
.22718 .15851 L
.24404 .24008 L
.27631 .44165 L
.29264 .53601 L
.29712 .55724 L
.30193 .57704 L
.30644 .59238 L
.31063 .60358 L
.31285 .60826 L
.31486 .61173 L
.3171 .61471 L
.31833 .61594 L
.31948 .61685 L
.32051 .61744 L
.32159 .61784 L
.32251 .61801 L
.32352 .61801 L
.32461 .61779 L
.32523 .61756 L
.32578 .6173 L
.32687 .61661 L
.32789 .61576 L
.3298 .61364 L
.33182 .61066 L
.33546 .6034 L
.33937 .59299 L
.34369 .57852 L
.35217 .542 L
.35994 .50075 L
.37746 .39177 L
.3947 .28221 L
.41074 .19463 L
.42622 .13077 L
.43488 .10437 L
.44275 .0857 L
.45114 .07071 L
.45887 .06064 L
.46291 .05657 L
.46735 .05289 L
.47196 .04983 L
.47634 .04753 L
.48042 .04583 L
.48488 .04439 L
Mistroke
.48892 .04337 L
.49267 .04264 L
.49714 .04198 L
.50117 .04154 L
.50342 .04134 L
.50584 .04117 L
.50796 .04104 L
.51022 .04092 L
.51437 .04076 L
.51823 .04065 L
.52059 .0406 L
.52282 .04057 L
.52701 .04052 L
.52915 .0405 L
.53142 .04048 L
.53338 .04047 L
.53549 .04046 L
.53775 .04045 L
.53988 .04045 L
.5424 .04044 L
.54471 .04044 L
.54681 .04044 L
.54871 .04044 L
.5509 .04044 L
.55297 .04043 L
.55489 .04043 L
.55665 .04043 L
.55859 .04043 L
.56064 .04043 L
.56172 .04043 L
.56271 .04043 L
.56377 .04043 L
.56493 .04043 L
.56599 .04043 L
.56698 .04043 L
.56893 .04043 L
.57001 .04043 L
.57103 .04043 L
.57224 .04043 L
.57335 .04043 L
.57444 .04043 L
.5756 .04043 L
.57677 .04043 L
.57804 .04043 L
.57914 .04043 L
.58016 .04043 L
.58128 .04043 L
.58247 .04043 L
.5835 .04043 L
.58446 .04043 L
Mistroke
.58552 .04043 L
.58666 .04043 L
.58766 .04043 L
.58875 .04043 L
.58979 .04043 L
.59075 .04043 L
.5917 .04043 L
.59256 .04043 L
.59356 .04043 L
.59449 .04043 L
.59551 .04043 L
.59609 .04043 L
.59663 .04043 L
.59773 .04043 L
.59834 .04043 L
.5989 .04043 L
.59989 .04043 L
.60098 .04043 L
.602 .04043 L
.60294 .04043 L
.60403 .04043 L
.60505 .04043 L
.60564 .04043 L
.60617 .04043 L
.60676 .04043 L
.60738 .04043 L
.60794 .04043 L
.60854 .04043 L
.60962 .04043 L
.61029 .04043 L
.61091 .04043 L
.61147 .04043 L
.61208 .04043 L
.61312 .04043 L
.61407 .04043 L
.61516 .04043 L
.6162 .04043 L
.62004 .04043 L
.62458 .04043 L
.62679 .04043 L
.62783 .04043 L
.62879 .04043 L
.62981 .04043 L
.6309 .04043 L
.63187 .04043 L
.63289 .04043 L
.63397 .04043 L
.63497 .04043 L
.63607 .04043 L
.63669 .04043 L
Mistroke
.63725 .04043 L
.63783 .04043 L
.63843 .04043 L
.63952 .04043 L
.64013 .04043 L
.6407 .04043 L
.64132 .04043 L
.64199 .04043 L
.64256 .04043 L
.64319 .04043 L
.64378 .04043 L
.64433 .04043 L
.64537 .04043 L
.64647 .04043 L
.64751 .04043 L
.64811 .04043 L
.64866 .04043 L
.64977 .04043 L
.6504 .04043 L
.65097 .04043 L
.65199 .04043 L
.65309 .04043 L
.65414 .04043 L
.65511 .04043 L
.65622 .04043 L
.65726 .04043 L
.6584 .04043 L
.65905 .04043 L
.65964 .04043 L
.66076 .04043 L
.66198 .04043 L
.66326 .04043 L
.66445 .04043 L
.66551 .04043 L
.66666 .04043 L
.66774 .04043 L
.66874 .04043 L
.67063 .04043 L
.67159 .04043 L
.67264 .04043 L
.67482 .04043 L
.67604 .04043 L
.67716 .04043 L
.6782 .04043 L
.67933 .04043 L
.68139 .04043 L
.68251 .04043 L
.68354 .04043 L
.68465 .04043 L
.68586 .04043 L
Mistroke
.68791 .04043 L
.69007 .04043 L
.69204 .04043 L
.69414 .04044 L
.69613 .04044 L
.69794 .04044 L
.7002 .04044 L
.70228 .04044 L
.70457 .04045 L
.707 .04046 L
.7091 .04046 L
.71107 .04047 L
.71324 .04048 L
.71557 .0405 L
.71759 .04052 L
.71974 .04054 L
.72362 .0406 L
.726 .04065 L
.72824 .04071 L
.73243 .04085 L
.73458 .04094 L
.73686 .04106 L
.74094 .04134 L
.74533 .04175 L
.75016 .04238 L
.75455 .04317 L
.75871 .04416 L
.76245 .04529 L
.76652 .04684 L
.77093 .04897 L
.77563 .05186 L
.78004 .05526 L
.78408 .05907 L
.79193 .06871 L
.8004 .08315 L
.80787 .10003 L
.81575 .12265 L
.8323 .18811 L
.84772 .27034 L
.88048 .47736 L
.88907 .52589 L
.89838 .56945 L
.90266 .58535 L
.90718 .59901 L
.91105 .60787 L
.91325 .6117 L
.9153 .61449 L
.91635 .6156 L
.91747 .61655 L
.91852 .61724 L
Mistroke
.91947 .61768 L
.92006 .61786 L
.9206 .61797 L
.92119 .61803 L
.92182 .61802 L
.92287 .61783 L
.92347 .61763 L
.92403 .61738 L
.9251 .61673 L
.92612 .61592 L
.92803 .61386 L
.93008 .61089 L
.93232 .60677 L
.93624 .59739 L
.9404 .58453 L
.94788 .55464 L
.96248 .47645 L
.97619 .38961 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00M@3oool700000400oooo1P0000110?ooo`@00000A03oool400000440oooo1000000L0?oo
o`00N03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo001h0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool06@3oool007P0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03l0oooo1P0000150?ooo`030000003o
ool0oooo01T0oooo001h0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool2
000004<0oooo00@000000?ooo`3oool00000AP3oool00`000000oooo0?ooo`0I0?ooo`00N03oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0@03oool0
10000000oooo0?ooo`0000120?ooo`@00000703oool007P0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo000000120?ooo`030000003oool0oooo01d0oooo001f0?ooo`<00000@`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool000000480oooo00<000000?ooo`3oool07@3oool007P0
oooo00<000000?ooo`3oool0@P3oool400000480oooo100000150?ooo`800000@P3oool5000001/0
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo000b0?ooo`030000003oool0oooo
0?l0ooooO03oool00380oooo00<000000?ooo`3oool0o`3oooml0?ooo`00<P3oool00`000000oooo
0?ooo`3o0?ooog`0oooo000b0?ooo`030000003oool0oooo0?l0ooooO03oool00380oooo00<00000
0?ooo`3oool0o`3oooml0?ooo`00:@3ooonh000003`0o`00O`00000D0?ooo`00<P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?l000030?l000P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool20?l000<0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0H0?ooo`<0o`00
:@3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`2S0?ooo`80o`00AP3o
ool20?l008h0oooo000b0?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool0J03oool2
0?l004X0oooo00<0o`000?ooo`3oool0R`3oool00380oooo00<000000?ooo`3oool0=`3oool00`3o
0000oooo0?ooo`1V0?ooo`030?l0003oool0oooo04X0oooo00<0o`000?ooo`3oool0R`3oool00380
oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`1U0?ooo`030?l0003oool0oooo04X0
oooo00<0o`000?ooo`3oool0R`3oool00380oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo
0?ooo`1R0?ooo`80o`00CP3oool00`3o0000oooo0?ooo`2:0?ooo`00<P3oool00`000000oooo0?oo
o`0j0?ooo`030?l0003oool0oooo0600oooo00<0o`000?ooo`3oool0C`3oool00`3o0000oooo0?oo
o`290?ooo`00<P3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo05h0oooo00<0o`00
0?ooo`3oool0D03oool00`3o0000oooo0?ooo`290?ooo`00<P3oool3000003`0oooo00<0o`000?oo
o`3oool0G@3oool00`3o0000oooo0?ooo`0F0?oood`00?l0NP3oool00380oooo00<000000?ooo`3o
ool0?03oool00`3o0000oooo0?ooo`1L0?ooo`030?l0003oool0oooo00d0oooo2P00o`0k0?ooo`03
0?l0003oool0oooo00h0oooo3000o`1^0?ooo`00<P3oool00`000000oooo0?ooo`0m0?ooo`030?l0
003oool0oooo05X0oooo00<0o`000?ooo`3oool02@3oool5003o04H0oooo00<0o`000?ooo`3oool0
6@3oool3003o06/0oooo000b0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0FP3o
ool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo04T0oooo00<0o`000?ooo`3oool0703o
ool00`00o`00oooo0?ooo`1X0?ooo`00<P3oool00`000000oooo0?ooo`0f0?ooo`03003o003oool0
oooo00D0oooo00<0o`000?ooo`3oool0F03oool00`3o0000oooo0?ooo`070?ooo`800?l0C03oool0
0`3o0000oooo0?ooo`0M0?ooo`800?l0J03oool00380oooo00<000000?ooo`3oool0=`3oool00`00
o`00oooo0?ooo`050?ooo`030?l0003oool0oooo05L0oooo00<0o`000?ooo`3oool01@3oool2003o
04h0oooo00<0o`000?ooo`3oool07`3oool00`00o`00oooo0?ooo`1U0?ooo`00<P3oool00`000000
oooo0?ooo`0g0?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool0EP3oool00`3o0000
oooo0?ooo`050?ooo`03003o003oool0oooo04h0oooo00<0o`000?ooo`3oool0803oool2003o06D0
oooo000b0?ooo`030000003oool0oooo03P0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo
0?ooo`1E0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0D03oool00`3o0000oooo
0?ooo`0Q0?ooo`800?l0H`3oool00380oooo00<000000?ooo`3oool0>@3oool00`00o`00oooo0?oo
o`040?ooo`030?l0003oool0oooo05@0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?oo
o`1A0?ooo`030?l0003oool0oooo0280oooo00<00?l00?ooo`3oool0H@3oool00380oooo00<00000
0?ooo`3oool0>P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo05<0oooo00<0o`00
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`1B0?ooo`030?l0003oool0oooo02<0oooo00<00?l0
0?ooo`3oool0H03oool00380oooo00<000000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`030?oo
o`030?l0003oool0oooo0580oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`1C0?oo
o`030?l0003oool0oooo02<0oooo00<00?l00?ooo`3oool0H03oool00380oooo0`00000l0?ooo`03
003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`030?ooo`03
003o003oool0oooo05<0oooo00<0o`000?ooo`3oool0903oool00`00o`00oooo0?ooo`1O0?ooo`00
<P3oool00`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0
D03oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo05D0oooo00<0o`000?ooo`3oool0
903oool00`00o`00oooo0?ooo`1N0?ooo`00<P3oool00`000000oooo0?ooo`0m0?ooo`03003o003o
ool0oooo00<0oooo00<0o`000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`020?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool09@3oool00`00o`00oooo0?ooo`1M0?ooo`00<P3oool0
0`000000oooo0?ooo`0m0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0C`3oool0
0`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool09@3oool0
0`00o`00oooo0?ooo`1M0?ooo`00<P3oool00`000000oooo0?ooo`0n0?ooo`03003o003oool0oooo
0080oooo00<0o`000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo
05L0oooo00<0o`000?ooo`3oool09P3oool00`00o`00oooo0?ooo`1L0?ooo`00<P3oool00`000000
oooo0?ooo`0o0?ooo`05003o003oool0oooo0?ooo`3o0000D03oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool0oooo05P0oooo00<0o`000?ooo`3oool09P3oool00`00o`00oooo0?ooo`1K0?oo
o`00<P3oool00`000000oooo0?ooo`0o0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o
ool0C@3oool01@3o0000oooo0?ooo`3oool00?l005/0oooo00<0o`000?ooo`3oool09P3oool00`00
o`00oooo0?ooo`1K0?ooo`00<P3oool00`000000oooo0?ooo`100?ooo`05003o003oool0oooo0?oo
o`3o0000CP3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo05T0oooo00<0o`000?oo
o`3oool09`3oool00`00o`00oooo0?ooo`1J0?ooo`00<P3oool00`000000oooo0?ooo`100?ooo`05
003o003oool0oooo0?ooo`3o0000CP3oool01@3o0000oooo0?ooo`3oool00?l005`0oooo00<0o`00
0?ooo`3oool09`3oool00`00o`00oooo0?ooo`1J0?ooo`00<P3oool00`000000oooo0?ooo`110?oo
o`05003o003oool0oooo0?ooo`3o0000C@3oool01@3o0000oooo0?ooo`3oool00?l005`0oooo00<0
o`000?ooo`3oool09`3oool00`00o`00oooo0?ooo`1J0?ooo`00<P3oool00`000000oooo0?ooo`11
0?ooo`05003o003oool0oooo0?ooo`3o0000C@3oool0103o0000oooo0?ooo`00o`1M0?ooo`030?l0
003oool0oooo02P0oooo00<00?l00?ooo`3oool0F@3oool00380oooo0`0000120?ooo`04003o003o
ool0oooo0?l004`0oooo00D0o`000?ooo`3oool0oooo003o001M0?ooo`030?l0003oool0oooo02P0
oooo00<00?l00?ooo`3oool0F@3oool00380oooo00<000000?ooo`3oool0@P3oool01000o`00oooo
0?ooo`3o001<0?ooo`040?l0003oool0oooo003o05l0oooo00<0o`000?ooo`3oool09`3oool00`00
o`00oooo0?ooo`1I0?ooo`00<P3oool00`000000oooo0?ooo`130?ooo`04003o003oool0oooo0?l0
04/0oooo00@0o`000?ooo`3oool00?l0G`3oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0
oooo05P0oooo000b0?ooo`030000003oool0oooo04<0oooo00@00?l00?ooo`3oool0o`00BP3oool0
1@3o0000oooo0?ooo`3oool00?l005l0oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?oo
o`1H0?ooo`00<P3oool00`000000oooo0?ooo`130?ooo`04003o003oool0oooo0?l004X0oooo00@0
o`000?ooo`3oool00?l0H03oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo05P0oooo
000b0?ooo`030000003oool0oooo04<0oooo00@00?l00?ooo`3oool0o`00BP3oool0103o0000oooo
0?ooo`00o`1P0?ooo`030?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool0E`3oool00380oooo
00<000000?ooo`3oool0A03oool01000o`00oooo0?ooo`3o00190?ooo`040?l0003oool0oooo003o
0600oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`1G0?ooo`005@3oool4000000H0
oooo0P0000050?ooo`H000001P3oool00`000000oooo0?ooo`140?ooo`04003o003oool0oooo0?l0
04P0oooo00@0o`000?ooo`3oool00?l0H@3oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0
oooo05L0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
04@0oooo00@00?l00?ooo`3oool0o`00B03oool0103o0000oooo0?ooo`00o`1Q0?ooo`030?l0003o
ool0oooo02X0oooo00<00?l00?ooo`3oool0EP3oool001@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A@3oool0
0`00o`00oooo0?l000180?ooo`040?l0003oool0oooo003o0640oooo00<0o`000?ooo`3oool0:P3o
ool00`00o`00oooo0?ooo`1F0?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01`3oool4000004@0oooo00@00?l00?ooo`3oool0o`00A`3o
ool0103o0000oooo0?ooo`00o`1Q0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?ooo`3oool0
EP3oool001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0A@3oool01000o`00oooo0?ooo`3o00160?ooo`040?l0
003oool0oooo003o06<0oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`1F0?ooo`00
503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`150?ooo`04003o003oool0oooo0?l004H0oooo00@0o`000?ooo`3o
ool00?l0H`3oool00`3o0000oooo0?ooo`0Z0?ooo`03003o003oool0oooo05D0oooo000D0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0AP3oool00`00o`00oooo0?l000160?ooo`04
0?l0003oool0oooo003o06<0oooo00<0o`000?ooo`3oool0:P3oool00`00o`00oooo0?ooo`1E0?oo
o`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo00@00?l00?ooo`3o
ool0o`00A@3oool00`3o0000oooo003o001T0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?oo
o`3oool0E@3oool001D0oooo1000000>0?ooo`@000001`3oool00`000000oooo0?ooo`160?ooo`04
003o003oool0oooo0?l004@0oooo00@0o`000?ooo`3oool00?l0I03oool00`3o0000oooo0?ooo`0Z
0?ooo`03003o003oool0oooo05D0oooo000b0?ooo`030000003oool0oooo04H0oooo00@00?l00?oo
o`3oool0o`00A03oool0103o0000oooo0?ooo`00o`1T0?ooo`030?l0003oool0oooo02/0oooo00<0
0?l00?ooo`3oool0E03oool00380oooo00<000000?ooo`3oool0A`3oool00`00o`00oooo0?l00014
0?ooo`040?l0003oool0oooo003o06@0oooo00<0o`000?ooo`3oool0:`3oool00`00o`00oooo0?oo
o`1D0?ooo`00<P3oool00`000000oooo0?ooo`170?ooo`04003o003oool0oooo0?l004<0oooo00<0
o`000?ooo`00o`00I@3oool00`3o0000oooo0?ooo`0[0?ooo`03003o003oool0oooo05@0oooo000b
0?ooo`030000003oool0oooo04L0oooo00@00?l00?ooo`3oool0o`00@P3oool0103o0000oooo0?oo
o`00o`1V0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?ooo`3oool0E03oool00380oooo00<0
00000?ooo`3oool0A`3oool01000o`00oooo0?ooo`3o00120?ooo`040?l0003oool0oooo003o06H0
oooo00<0o`000?ooo`3oool0:`3oool00`00o`00oooo0?ooo`1C0?ooo`00<P3oool3000004P0oooo
00<00?l00?ooo`3o0000@P3oool0103o0000oooo0?ooo`00o`1V0?ooo`030?l0003oool0oooo02/0
oooo00<00?l00?ooo`3oool0D`3oool00380oooo00<000000?ooo`3oool0B03oool00`00o`00oooo
0?l000120?ooo`030?l0003oool00?l006L0oooo00<0o`000?ooo`3oool0:`3oool00`00o`00oooo
0?ooo`1C0?ooo`00<P3oool00`000000oooo0?ooo`180?ooo`04003o003oool0oooo0?l00400oooo
00@0o`000?ooo`3oool00?l0I`3oool00`3o0000oooo0?ooo`0[0?ooo`03003o003oool0oooo05<0
oooo000b0?ooo`030000003oool0oooo04P0oooo00@00?l00?ooo`3oool0o`00@03oool0103o0000
oooo0?ooo`00o`1W0?ooo`030?l0003oool0oooo02`0oooo00<00?l00?ooo`3oool0DP3oool00380
oooo00<000000?ooo`3oool0B@3oool00`00o`00oooo0?l000100?ooo`040?l0003oool0oooo003o
06L0oooo00<0o`000?ooo`3oool0;03oool00`00o`00oooo0?ooo`1B0?ooo`00<P3oool00`000000
oooo0?ooo`190?ooo`03003o003oool0o`000400oooo00<0o`000?ooo`00o`00J03oool00`3o0000
oooo0?ooo`0/0?ooo`03003o003oool0oooo0580oooo000b0?ooo`030000003oool0oooo04T0oooo
00@00?l00?ooo`3oool0o`00?`3oool00`3o0000oooo003o001X0?ooo`030?l0003oool0oooo02`0
oooo00<00?l00?ooo`3oool0DP3oool00380oooo00<000000?ooo`3oool0B@3oool01000o`00oooo
0?ooo`3o000n0?ooo`040?l0003oool0oooo003o06P0oooo00<0o`000?ooo`3oool0;@3oool00`00
o`00oooo0?ooo`1A0?ooo`00<P3oool00`000000oooo0?ooo`1:0?ooo`03003o003oool0o`0003h0
oooo00@0o`000?ooo`3oool00?l0J03oool00`3o0000oooo0?ooo`0]0?ooo`03003o003oool0oooo
0540oooo000b0?ooo`030000003oool0oooo04X0oooo00<00?l00?ooo`3o0000?P3oool00`3o0000
oooo003o001Y0?ooo`030?l0003oool0oooo02d0oooo00<00?l00?ooo`3oool0D@3oool00380oooo
00<000000?ooo`3oool0BP3oool01000o`00oooo0?ooo`3o000m0?ooo`030?l0003oool00?l006T0
oooo00<0o`000?ooo`3oool0;@3oool00`00o`00oooo0?ooo`1A0?ooo`00<P3oool3000004X0oooo
00@00?l00?ooo`3oool0o`00?@3oool00`3o0000oooo003o001Y0?ooo`030?l0003oool0oooo02h0
oooo00<00?l00?ooo`3oool0D03oool00380oooo00<000000?ooo`3oool0B`3oool00`00o`00oooo
0?l0000l0?ooo`040?l0003oool0oooo003o06X0oooo00<0o`000?ooo`3oool0;@3oool00`00o`00
oooo0?ooo`1@0?ooo`00<P3oool00`000000oooo0?ooo`1;0?ooo`03003o003oool0o`0003`0oooo
00<0o`000?ooo`00o`00J`3oool00`3o0000oooo0?ooo`0]0?ooo`03003o003oool0oooo0500oooo
000b0?ooo`030000003oool0oooo04/0oooo00<00?l00?ooo`3o0000?03oool00`3o0000oooo003o
001[0?ooo`030?l0003oool0oooo02d0oooo00<00?l00?ooo`3oool0D03oool00380oooo00<00000
0?ooo`3oool0B`3oool01000o`00oooo0?ooo`3o000k0?ooo`030?l0003oool00?l006/0oooo00<0
o`000?ooo`3oool0;P3oool00`00o`00oooo0?ooo`1?0?ooo`00<P3oool00`000000oooo0?ooo`1;
0?ooo`04003o003oool0oooo0?l003/0oooo00<0o`000?ooo`00o`00J`3oool00`3o0000oooo0?oo
o`0^0?ooo`03003o003oool0oooo04l0oooo000b0?ooo`030000003oool0oooo04`0oooo00<00?l0
0?ooo`3o0000>`3oool00`3o00000?l00?ooo`1[0?ooo`030?l0003oool0oooo02h0oooo00<00?l0
0?ooo`3oool0C`3oool00380oooo00<000000?ooo`3oool0C03oool00`00o`00oooo0?l0000j0?oo
o`030?l0003oool00?l006`0oooo00<0o`000?ooo`3oool0;P3oool00`00o`00oooo0?ooo`1?0?oo
o`00<P3oool00`000000oooo0?ooo`1<0?ooo`04003o003oool0oooo0?l003T0oooo00<0o`000?oo
o`00o`00K03oool00`3o0000oooo0?ooo`0^0?ooo`03003o003oool0oooo04l0oooo000b0?ooo`03
0000003oool0oooo04`0oooo00@00?l00?ooo`3oool0o`00>@3oool00`3o0000oooo003o001/0?oo
o`030?l0003oool0oooo02l0oooo00<00?l00?ooo`3oool0CP3oool00380oooo00<000000?ooo`3o
ool0C@3oool00`00o`00oooo0?l0000i0?ooo`030?l0003oool00?l006`0oooo00<0o`000?ooo`3o
ool0;`3oool00`00o`00oooo0?ooo`1>0?ooo`00<P3oool3000004d0oooo00<00?l00?ooo`3o0000
>@3oool00`3o0000oooo003o001/0?ooo`030?l0003oool0oooo02l0oooo00<00?l00?ooo`3oool0
CP3oool00380oooo00<000000?ooo`3oool0C@3oool00`00o`00oooo0?l0000h0?ooo`030?l0003o
ool00?l006d0oooo00<0o`000?ooo`3oool0;`3oool00`00o`00oooo0?ooo`1>0?ooo`00<P3oool0
0`000000oooo0?ooo`1=0?ooo`03003o003oool0o`0003P0oooo00<0o`000?ooo`00o`00K@3oool0
0`3o0000oooo0?ooo`0_0?ooo`03003o003oool0oooo04h0oooo000b0?ooo`030000003oool0oooo
04h0oooo00<00?l00?ooo`3o0000=`3oool00`3o0000oooo003o001]0?ooo`030?l0003oool0oooo
0300oooo00<00?l00?ooo`3oool0C@3oool00380oooo00<000000?ooo`3oool0CP3oool00`00o`00
oooo0?l0000g0?ooo`030?l0003oool00?l006d0oooo00<0o`000?ooo`3oool0<03oool00`00o`00
oooo0?ooo`1=0?ooo`00<P3oool00`000000oooo0?ooo`1>0?ooo`03003o003oool0o`0003L0oooo
00<0o`000?ooo`00o`00K@3oool00`3o0000oooo0?ooo`0`0?ooo`03003o003oool0oooo04d0oooo
000b0?ooo`030000003oool0oooo04h0oooo00<00?l00?ooo`3o0000=P3oool00`3o0000oooo003o
001^0?ooo`030?l0003oool0oooo0300oooo00<00?l00?ooo`3oool0C@3oool001D0oooo10000006
0?ooo`8000001`3oool4000000H0oooo00<000000?ooo`3oool0C`3oool00`00o`00o`000?ooo`0e
0?ooo`030?l0003oool00?l006l0oooo00<0o`000?ooo`3oool0;`3oool00`00o`00oooo0?ooo`1=
0?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0C`3oool00`00o`00o`000?ooo`0e0?oo
o`030?l0003oool00?l006l0oooo00<0o`000?ooo`3oool0<03oool00`00o`00oooo0?ooo`1<0?oo
o`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1?0?ooo`03003o003oool0o`0003D0oooo00<0o`000?ooo`00
o`00K`3oool00`3o0000oooo0?ooo`0`0?ooo`03003o003oool0oooo04`0oooo000D0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool6000000H0oooo1000001>0?ooo`03003o
003oool0o`0003D0oooo00<0o`000?ooo`00o`00K`3oool00`3o0000oooo0?ooo`0`0?ooo`03003o
003oool0oooo04`0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo04l0oooo00<00?l00?ooo`3o0000
=@3oool00`3o0000oooo003o001_0?ooo`030?l0003oool0oooo0300oooo00<00?l00?ooo`3oool0
C03oool001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool0C`3oool00`00o`00oooo0?l0000d0?ooo`030?l0
003oool00?l00700oooo00<0o`000?ooo`3oool0<03oool00`00o`00oooo0?ooo`1<0?ooo`00503o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`1@0?ooo`03003o003o0000oooo03<0oooo00<0o`000?ooo`00o`00L03o
ool00`3o0000oooo0?ooo`0a0?ooo`03003o003oool0oooo04/0oooo000D0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo000000070?ooo`030000003oool0
oooo0500oooo00<00?l00?l0003oool0<`3oool00`3o0000oooo003o001`0?ooo`030?l0003oool0
oooo0340oooo00<00?l00?ooo`3oool0B`3oool001D0oooo1000000@0?ooo`8000001`3oool00`00
0000oooo0?ooo`1@0?ooo`03003o003oool0o`0003<0oooo00<0o`000?ooo`00o`00L03oool00`3o
0000oooo0?ooo`0a0?ooo`03003o003oool0oooo04/0oooo000b0?ooo`030000003oool0oooo0500
oooo00<00?l00?ooo`3o0000<`3oool00`3o0000oooo003o001`0?ooo`030?l0003oool0oooo0340
oooo00<00?l00?ooo`3oool0B`3oool00380oooo00<000000?ooo`3oool0D03oool00`00o`00oooo
0?l0000c0?ooo`030?l00000o`00oooo0700oooo00<0o`000?ooo`3oool0<@3oool00`00o`00oooo
0?ooo`1;0?ooo`00<P3oool00`000000oooo0?ooo`1@0?ooo`03003o003oool0o`000380oooo00<0
o`000?ooo`00o`00L@3oool00`3o0000oooo0?ooo`0b0?ooo`03003o003oool0oooo04X0oooo000b
0?ooo`030000003oool0oooo0540oooo00<00?l00?l0003oool0<@3oool00`3o0000oooo003o001a
0?ooo`030?l0003oool0oooo0380oooo00<00?l00?ooo`3oool0BP3oool00380oooo00<000000?oo
o`3oool0D@3oool00`00o`00o`000?ooo`0a0?ooo`030?l0003oool00?l00740oooo00<0o`000?oo
o`3oool0<P3oool00`00o`00oooo0?ooo`1:0?ooo`00<P3oool300000540oooo00<00?l00?ooo`3o
0000<@3oool00`3o0000oooo003o001b0?ooo`030?l0003oool0oooo0340oooo00<00?l00?ooo`3o
ool0BP3oool00380oooo00<000000?ooo`3oool0D@3oool00`00o`00oooo0?l0000a0?ooo`030?l0
003oool00?l00780oooo00<0o`000?ooo`3oool0<@3oool00`00o`00oooo0?ooo`1:0?ooo`00<P3o
ool00`000000oooo0?ooo`1A0?ooo`03003o003oool0o`000340oooo00<0o`00003o003oool0LP3o
ool00`3o0000oooo0?ooo`0a0?ooo`03003o003oool0oooo04X0oooo000b0?ooo`030000003oool0
oooo0540oooo00<00?l00?ooo`3o0000<@3oool00`3o00000?l00?ooo`1b0?ooo`030?l0003oool0
oooo0380oooo00<00?l00?ooo`3oool0B@3oool00380oooo00<000000?ooo`3oool0DP3oool00`00
o`00o`000?ooo`0_0?ooo`030?l0003oool00?l007<0oooo00<0o`000?ooo`3oool0<P3oool00`00
o`00oooo0?ooo`190?ooo`00<P3oool00`000000oooo0?ooo`1B0?ooo`03003o003o0000oooo02l0
oooo00<0o`000?ooo`00o`00L`3oool00`3o0000oooo0?ooo`0b0?ooo`03003o003oool0oooo04T0
oooo000b0?ooo`030000003oool0oooo0580oooo00<00?l00?ooo`3o0000;`3oool00`3o0000oooo
003o001c0?ooo`030?l0003oool0oooo0380oooo00<00?l00?ooo`3oool0B@3oool00380oooo00<0
00000?ooo`3oool0DP3oool00`00o`00oooo0?l0000_0?ooo`030?l0003oool00?l007<0oooo00<0
o`000?ooo`3oool0<P3oool00`00o`00oooo0?ooo`190?ooo`00<P3oool00`000000oooo0?ooo`1B
0?ooo`03003o003oool0o`0002l0oooo00<0o`00003o003oool0L`3oool00`3o0000oooo0?ooo`0b
0?ooo`03003o003oool0oooo04T0oooo000b0?ooo`030000003oool0oooo0580oooo00<00?l00?oo
o`3o0000;`3oool00`3o00000?l00?ooo`1c0?ooo`030?l0003oool0oooo03<0oooo00<00?l00?oo
o`3oool0B03oool00380oooo00<000000?ooo`3oool0D`3oool00`00o`00o`000?ooo`0^0?ooo`03
0?l00000o`00oooo07<0oooo00<0o`000?ooo`3oool0<`3oool00`00o`00oooo0?ooo`180?ooo`00
<P3oool3000005<0oooo00<00?l00?l0003oool0;@3oool00`3o0000oooo003o001d0?ooo`030?l0
003oool0oooo03<0oooo00<00?l00?ooo`3oool0B03oool00380oooo00<000000?ooo`3oool0D`3o
ool00`00o`00oooo0?l0000]0?ooo`030?l0003oool00?l007@0oooo00<0o`000?ooo`3oool0<`3o
ool00`00o`00oooo0?ooo`180?ooo`00<P3oool00`000000oooo0?ooo`1C0?ooo`03003o003oool0
o`0002d0oooo00<0o`000?ooo`00o`00M03oool00`3o0000oooo0?ooo`0c0?ooo`03003o003oool0
oooo04P0oooo000b0?ooo`030000003oool0oooo05<0oooo00<00?l00?ooo`3o0000;@3oool00`3o
00000?l00?ooo`1d0?ooo`030?l0003oool0oooo03<0oooo00<00?l00?ooo`3oool0B03oool00380
oooo00<000000?ooo`3oool0D`3oool00`00o`00oooo0?l0000]0?ooo`030?l00000o`00oooo07@0
oooo00<0o`000?ooo`3oool0<`3oool00`00o`00oooo0?ooo`180?ooo`00<P3oool00`000000oooo
0?ooo`1C0?ooo`03003o003oool0o`0002d0oooo00<0o`00003o003oool0M03oool00`3o0000oooo
0?ooo`0d0?ooo`03003o003oool0oooo04L0oooo000b0?ooo`030000003oool0oooo05@0oooo00<0
0?l00?l0003oool0:`3oool00`3o0000oooo003o001e0?ooo`030?l0003oool0oooo03@0oooo00<0
0?l00?ooo`3oool0A`3oool00380oooo00<000000?ooo`3oool0E03oool00`00o`00o`000?ooo`0[
0?ooo`030?l0003oool00?l007D0oooo00<0o`000?ooo`3oool0=03oool00`00o`00oooo0?ooo`17
0?ooo`00<P3oool00`000000oooo0?ooo`1D0?ooo`03003o003oool0o`0002/0oooo00<0o`000?oo
o`00o`00M@3oool00`3o0000oooo0?ooo`0d0?ooo`03003o003oool0oooo04L0oooo000b0?ooo`03
0000003oool0oooo05@0oooo00<00?l00?ooo`3o0000:`3oool00`3o0000oooo003o001e0?ooo`03
0?l0003oool0oooo03@0oooo00<00?l00?ooo`3oool0A`3oool00380oooo0`00001D0?ooo`03003o
003oool0o`0002/0oooo00<0o`00003o003oool0M@3oool00`3o0000oooo0?ooo`0d0?ooo`03003o
003oool0oooo04L0oooo000b0?ooo`030000003oool0oooo05@0oooo00<00?l00?ooo`3o0000:`3o
ool00`3o00000?l00?ooo`1e0?ooo`030?l0003oool0oooo03D0oooo00<00?l00?ooo`3oool0AP3o
ool00380oooo00<000000?ooo`3oool0E@3oool00`00o`00o`000?ooo`0Z0?ooo`030?l00000o`00
oooo07D0oooo00<0o`000?ooo`3oool0=@3oool00`00o`00oooo0?ooo`160?ooo`00<P3oool00`00
0000oooo0?ooo`1E0?ooo`03003o003o0000oooo02T0oooo00<0o`000?ooo`00o`00MP3oool00`3o
0000oooo0?ooo`0e0?ooo`03003o003oool0oooo04H0oooo000b0?ooo`030000003oool0oooo05D0
oooo00<00?l00?ooo`3o0000:@3oool00`3o0000oooo003o001f0?ooo`030?l0003oool0oooo03D0
oooo00<00?l00?ooo`3oool0AP3oool00380oooo00<000000?ooo`3oool0E@3oool00`00o`00oooo
0?l0000Y0?ooo`030?l0003oool00?l007H0oooo00<0o`000?ooo`3oool0=@3oool00`00o`00oooo
0?ooo`160?ooo`00<P3oool00`000000oooo0?ooo`1E0?ooo`03003o003oool0o`0002T0oooo00<0
o`000?ooo`00o`00MP3oool00`3o0000oooo0?ooo`0e0?ooo`03003o003oool0oooo04H0oooo000E
0?ooo`@000001P3oool2000000L0oooo100000060?ooo`030000003oool0oooo05D0oooo00<00?l0
0?ooo`3o0000:@3oool00`3o00000?l00?ooo`1f0?ooo`030?l0003oool0oooo03H0oooo00<00?l0
0?ooo`3oool0A@3oool001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0EP3oool00`00o`00o`000?ooo`0X0?ooo`030?l00000o`00oooo07L0oooo00<0o`000?oo
o`3oool0=@3oool00`00o`00oooo0?ooo`150?ooo`00503oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo05H0oooo00<00?l00?l0003oool0:03oool00`3o00000?l00?ooo`1g0?ooo`03
0?l0003oool0oooo03D0oooo00<00?l00?ooo`3oool0A@3oool001@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo05H0oooo00<00?l00?ooo`3o00009`3oool00`3o0000oooo003o001h0?ooo`030?l0
003oool0oooo03D0oooo00<00?l00?ooo`3oool0A@3oool001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool00000008000001P3oool4000005D0oooo00<0
0?l00?ooo`3o00009`3oool00`3o0000oooo003o001h0?ooo`030?l0003oool0oooo03D0oooo00<0
0?l00?ooo`3oool0A@3oool001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0EP3oool00`00o`00oooo0?l0000W
0?ooo`030?l0003oool00?l007P0oooo00<0o`000?ooo`3oool0=@3oool00`00o`00oooo0?ooo`15
0?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1F0?ooo`03003o003oool0o`0002L0oooo00<0o`00003o
003oool0N03oool00`3o0000oooo0?ooo`0e0?ooo`03003o003oool0oooo04D0oooo000D0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo05L0oooo00<00?l00?l0003oool09P3oool00`3o00000?l00?ooo`1h0?ooo`03
0?l0003oool0oooo03H0oooo00<00?l00?ooo`3oool0A03oool001D0oooo1000000A0?ooo`<00000
1@3oool00`000000oooo0?ooo`1G0?ooo`03003o003o0000oooo02H0oooo00<0o`00003o003oool0
N03oool00`3o0000oooo0?ooo`0f0?ooo`03003o003oool0oooo04@0oooo000b0?ooo`030000003o
ool0oooo05L0oooo00<00?l00?ooo`3o00009P3oool00`3o00000?l00?ooo`1h0?ooo`030?l0003o
ool0oooo03H0oooo00<00?l00?ooo`3oool0A03oool00380oooo00<000000?ooo`3oool0E`3oool0
0`00o`00oooo0?l0000U0?ooo`030?l0003oool00?l007T0oooo00<0o`000?ooo`3oool0=P3oool0
0`00o`00oooo0?ooo`140?ooo`00<P3oool00`000000oooo0?ooo`1G0?ooo`03003o003oool0o`00
02D0oooo00<0o`000?ooo`00o`00N@3oool00`3o0000oooo0?ooo`0f0?ooo`03003o003oool0oooo
04@0oooo000b0?ooo`030000003oool0oooo05L0oooo00<00?l00?ooo`3o00009@3oool00`3o0000
oooo003o001i0?ooo`030?l0003oool0oooo03H0oooo00<00?l00?ooo`3oool0A03oool00380oooo
00<000000?ooo`3oool0E`3oool00`00o`00oooo0?l0000U0?ooo`030?l00000o`00oooo07T0oooo
00<0o`000?ooo`3oool0=`3oool00`00o`00oooo0?ooo`130?ooo`00<P3oool00`000000oooo0?oo
o`1H0?ooo`03003o003o0000oooo02@0oooo00<0o`00003o003oool0N@3oool00`3o0000oooo0?oo
o`0g0?ooo`03003o003oool0oooo04<0oooo000b0?ooo`<00000F03oool00`00o`00oooo0?l0000T
0?ooo`030?l00000o`00oooo07T0oooo00<0o`000?ooo`3oool0=`3oool00`00o`00oooo0?ooo`13
0?ooo`00<P3oool00`000000oooo0?ooo`1H0?ooo`03003o003oool0o`0002<0oooo00<0o`000?oo
o`00o`00NP3oool00`3o0000oooo0?ooo`0g0?ooo`03003o003oool0oooo02H0oooo00<00?l00?oo
o`3oool06P3oool00380oooo00<000000?ooo`3oool0F03oool00`00o`00oooo0?l0000S0?ooo`03
0?l0003oool00?l007X0oooo00<0o`000?ooo`3oool0=`3oool00`00o`00oooo0?ooo`0V0?ooo`03
003o003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo05P0oooo00<00?l00?ooo`3o0000
8`3oool00`3o0000oooo003o001j0?ooo`030?l0003oool0oooo03L0oooo00<00?l00?ooo`3oool0
9P3oool00`00o`00oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`1H0?ooo`03003o003o
ool0o`0002<0oooo00<0o`000?ooo`00o`00NP3oool00`3o0000oooo0?ooo`0g0?ooo`03003o003o
ool0oooo02H0oooo00<00?l00?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0F@3oool0
0`00o`00o`000?ooo`0R0?ooo`030?l00000o`00oooo07X0oooo00<0o`000?ooo`3oool0>03oool0
0`00o`00oooo0?ooo`0T0?ooo`03003o003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo
05T0oooo00<00?l00?ooo`3o00008P3oool00`3o00000?l00?ooo`1j0?ooo`030?l0003oool0oooo
03P0oooo00<00?l00?ooo`3oool0903oool00`00o`00oooo0?ooo`0K0?ooo`00<P3oool00`000000
oooo0?ooo`1I0?ooo`03003o003oool0o`000280oooo00<0o`00003o003oool0NP3oool00`3o0000
oooo0?ooo`0h0?ooo`03003o003oool0oooo02@0oooo00<00?l00?ooo`3oool06`3oool00380oooo
00<000000?ooo`3oool0F@3oool00`00o`00oooo0?l0000Q0?ooo`030?l0003oool00?l007/0oooo
00<0o`000?ooo`3oool0>03oool00`00o`00oooo0?ooo`0T0?ooo`03003o003oool0oooo01/0oooo
000b0?ooo`030000003oool0oooo05T0oooo00<00?l00?ooo`3o00008@3oool00`3o0000oooo003o
001k0?ooo`030?l0003oool0oooo03P0oooo00<00?l00?ooo`3oool0903oool00`00o`00oooo0?oo
o`0K0?ooo`00<P3oool3000005T0oooo00<00?l00?ooo`3o00008@3oool00`3o0000oooo003o001k
0?ooo`030?l0003oool0oooo03P0oooo00<00?l00?ooo`3oool0903oool00`00o`00oooo0?ooo`0K
0?ooo`00<P3oool00`000000oooo0?ooo`1J0?ooo`03003o003o0000oooo0200oooo00<0o`000?oo
o`00o`00N`3oool00`3o0000oooo0?ooo`0i0?ooo`03003o003oool0oooo0280oooo00<00?l00?oo
o`3oool0703oool00380oooo00<000000?ooo`3oool0FP3oool00`00o`00oooo0?l0000P0?ooo`03
0?l00000o`00oooo07/0oooo00<0o`000?ooo`3oool0>@3oool00`00o`00oooo0?ooo`0R0?ooo`03
003o003oool0oooo01`0oooo000b0?ooo`030000003oool0oooo05X0oooo00<00?l00?ooo`3o0000
803oool00`3o00000?l00?ooo`1k0?ooo`030?l0003oool0oooo03T0oooo00<00?l00?ooo`3oool0
8P3oool00`00o`00oooo0?ooo`0L0?ooo`00<P3oool00`000000oooo0?ooo`1J0?ooo`03003o003o
ool0o`000200oooo00<0o`00003o003oool0N`3oool00`3o0000oooo0?ooo`0i0?ooo`03003o003o
ool0oooo0280oooo00<00?l00?ooo`3oool0703oool00380oooo00<000000?ooo`3oool0FP3oool0
0`00o`00oooo0?l0000O0?ooo`030?l0003oool00?l007`0oooo00<0o`000?ooo`3oool0>@3oool0
0`00o`00oooo0?ooo`0R0?ooo`03003o003oool0oooo01`0oooo000b0?ooo`030000003oool0oooo
05X0oooo00<00?l00?ooo`3o00007`3oool00`3o0000oooo003o001l0?ooo`030?l0003oool0oooo
03T0oooo00<00?l00?ooo`3oool08P3oool00`00o`00oooo0?ooo`0L0?ooo`00<P3oool00`000000
oooo0?ooo`1K0?ooo`03003o003o0000oooo01h0oooo00<0o`000?ooo`00o`00O03oool00`3o0000
oooo0?ooo`0j0?ooo`03003o003oool0oooo0200oooo00<00?l00?ooo`3oool07@3oool00380oooo
00<000000?ooo`3oool0F`3oool00`00o`00oooo0?l0000N0?ooo`030?l0003oool00?l007d0oooo
00<0o`000?ooo`3oool0>@3oool00`00o`00oooo0?ooo`0P0?ooo`03003o003oool0oooo01d0oooo
000b0?ooo`030000003oool0oooo05/0oooo00<00?l00?ooo`3o00007P3oool00`3o00000?l00?oo
o`1m0?ooo`030?l0003oool0oooo03T0oooo00<00?l00?ooo`3oool0803oool00`00o`00oooo0?oo
o`0M0?ooo`00<P3oool00`000000oooo0?ooo`1K0?ooo`03003o003oool0o`0001h0oooo00<0o`00
003o003oool0O@3oool00`3o0000oooo0?ooo`0i0?ooo`03003o003oool0oooo0200oooo00<00?l0
0?ooo`3oool07@3oool00380oooo0`00001K0?ooo`03003o003oool0o`0001d0oooo00<0o`000?oo
o`00o`00OP3oool00`3o0000oooo0?ooo`0i0?ooo`03003o003oool0oooo0200oooo00<00?l00?oo
o`3oool07@3oool00380oooo00<000000?ooo`3oool0F`3oool00`00o`00oooo0?l0000M0?ooo`03
0?l0003oool00?l007h0oooo00<0o`000?ooo`3oool0>@3oool00`00o`00oooo0?ooo`0P0?ooo`03
003o003oool0oooo01d0oooo000b0?ooo`030000003oool0oooo05`0oooo00<00?l00?l0003oool0
703oool00`3o0000oooo003o001n0?ooo`030?l0003oool0oooo03T0oooo00<00?l00?ooo`3oool0
803oool00`00o`00oooo0?ooo`0M0?ooo`00<P3oool00`000000oooo0?ooo`1L0?ooo`03003o003o
ool0o`0001`0oooo00<0o`000?ooo`00o`00OP3oool00`3o0000oooo0?ooo`0j0?ooo`03003o003o
ool0oooo01h0oooo00<00?l00?ooo`3oool07P3oool00380oooo00<000000?ooo`3oool0G03oool0
0`00o`00oooo0?l0000L0?ooo`030?l00000o`00oooo07h0oooo00<0o`000?ooo`3oool0>P3oool0
0`00o`00oooo0?ooo`0N0?ooo`03003o003oool0oooo01h0oooo000b0?ooo`030000003oool0oooo
05`0oooo00<00?l00?ooo`3o0000703oool00`3o00000?l00?ooo`1n0?ooo`030?l0003oool0oooo
03X0oooo00<00?l00?ooo`3oool07P3oool00`00o`00oooo0?ooo`0N0?ooo`00<P3oool00`000000
oooo0?ooo`1L0?ooo`03003o003oool0o`0001`0oooo00<0o`00003o003oool0OP3oool00`3o0000
oooo0?ooo`0j0?ooo`03003o003oool0oooo01h0oooo00<00?l00?ooo`3oool07P3oool001D0oooo
100000060?ooo`8000001P3oool4000000L0oooo00<000000?ooo`3oool0G03oool00`00o`00oooo
0?l0000K0?ooo`030?l0003oool00?l007l0oooo00<0o`000?ooo`3oool0>P3oool00`00o`00oooo
0?ooo`0N0?ooo`03003o003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo05d0oooo00<00?l00?l0003oool06P3oool00`3o0000oooo003o
001o0?ooo`030?l0003oool0oooo03X0oooo00<00?l00?ooo`3oool07P3oool00`00o`00oooo0?oo
o`0N0?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05d0oooo00<00?l0
0?ooo`3o00006P3oool00`3o0000oooo003o001o0?ooo`030?l0003oool0oooo03/0oooo00<00?l0
0?ooo`3oool0703oool00`00o`00oooo0?ooo`0O0?ooo`00503oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo05d0oooo00<00?l00?ooo`3o00006P3oool00`3o0000oooo003o001o0?oo
o`030?l0003oool0oooo03/0oooo00<00?l00?ooo`3oool0703oool00`00o`00oooo0?ooo`0O0?oo
o`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo100000070?ooo`@0
0000G03oool00`00o`00oooo0?l0000J0?ooo`030?l00000o`00oooo07l0oooo00<0o`000?ooo`3o
ool0>`3oool00`00o`00oooo0?ooo`0L0?ooo`03003o003oool0oooo01l0oooo000D0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0G@3oool00`00o`00oooo0?l0000J0?ooo`030?l0
0000o`00oooo07l0oooo00<0o`000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0L0?ooo`03003o
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0G@3o
ool00`00o`00oooo0?l0000I0?ooo`030?l0003oool00?l00800oooo00<0o`000?ooo`3oool0>`3o
ool00`00o`00oooo0?ooo`0L0?ooo`03003o003oool0oooo01l0oooo000D0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0GP3oool00`00o`00o`000?ooo`0H0?ooo`030?l0003oool0
0?l00800oooo00<0o`000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0L0?ooo`03003o003oool0
oooo01l0oooo000E0?ooo`@000003P3oool4000000L0oooo00<000000?ooo`3oool0GP3oool00`00
o`00oooo0?l0000H0?ooo`030?l0003oool00?l00800oooo00<0o`000?ooo`3oool0>`3oool00`00
o`00oooo0?ooo`0K0?ooo`03003o003oool0oooo0200oooo000b0?ooo`030000003oool0oooo05h0
oooo00<00?l00?ooo`3o0000603oool00`3o0000oooo003o00200?ooo`030?l0003oool0oooo03`0
oooo00<00?l00?ooo`3oool06P3oool00`00o`00oooo0?ooo`0P0?ooo`00<P3oool00`000000oooo
0?ooo`1N0?ooo`03003o003oool0o`0001P0oooo00<0o`000?ooo`00o`00P03oool00`3o0000oooo
0?ooo`0l0?ooo`03003o003oool0oooo01X0oooo00<00?l00?ooo`3oool0803oool00380oooo00<0
00000?ooo`3oool0GP3oool00`00o`00oooo0?l0000G0?ooo`030?l0003oool00?l00840oooo00<0
o`000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0J0?ooo`03003o003oool0oooo0200oooo000b
0?ooo`030000003oool0oooo05h0oooo00<00?l00?ooo`3o00005`3oool00`3o0000oooo003o0021
0?ooo`030?l0003oool0oooo03`0oooo00<00?l00?ooo`3oool06P3oool00`00o`00oooo0?ooo`0P
0?ooo`00<P3oool00`000000oooo0?ooo`1O0?ooo`03003o003o0000oooo01H0oooo00<0o`000?oo
o`00o`00P@3oool00`3o0000oooo0?ooo`0l0?ooo`03003o003oool0oooo01T0oooo00<00?l00?oo
o`3oool08@3oool00380oooo0`00001O0?ooo`03003o003oool0o`0001H0oooo00<0o`000?ooo`00
o`00PP3oool00`3o0000oooo0?ooo`0k0?ooo`03003o003oool0oooo01T0oooo00<00?l00?ooo`3o
ool08@3oool00380oooo00<000000?ooo`3oool0G`3oool00`00o`00oooo0?l0000F0?ooo`030?l0
003oool00?l00880oooo00<0o`000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0H0?ooo`03003o
003oool0oooo0240oooo000b0?ooo`030000003oool0oooo05l0oooo00<00?l00?ooo`3o00005@3o
ool0103o0000oooo0?ooo`00o`220?ooo`030?l0003oool0oooo03`0oooo00<00?l00?ooo`3oool0
603oool00`00o`00oooo0?ooo`0Q0?ooo`00<P3oool00`000000oooo0?ooo`1O0?ooo`03003o003o
ool0o`0001D0oooo00<0o`000?ooo`00o`00P`3oool00`3o0000oooo0?ooo`0l0?ooo`03003o003o
ool0oooo01P0oooo00<00?l00?ooo`3oool08@3oool00380oooo00<000000?ooo`3oool0G`3oool0
0`00o`00oooo0?l0000E0?ooo`030?l0003oool00?l008<0oooo00<0o`000?ooo`3oool0?03oool0
0`00o`00oooo0?ooo`0G0?ooo`03003o003oool0oooo0280oooo000b0?ooo`030000003oool0oooo
0600oooo00<00?l00?l0003oool0503oool00`3o0000oooo003o00230?ooo`030?l0003oool0oooo
03`0oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo0?ooo`0R0?ooo`00<P3oool00`000000
oooo0?ooo`1P0?ooo`03003o003o0000oooo01@0oooo00<0o`000?ooo`00o`00P`3oool00`3o0000
oooo0?ooo`0l0?ooo`03003o003oool0oooo01L0oooo00<00?l00?ooo`3oool08P3oool00380oooo
00<000000?ooo`3oool0H03oool00`00o`00oooo0?l0000C0?ooo`040?l0003oool0oooo003o08<0
oooo00<0o`000?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo0280
oooo000b0?ooo`030000003oool0oooo0600oooo00<00?l00?ooo`3o00004`3oool00`3o0000oooo
003o00240?ooo`030?l0003oool0oooo03d0oooo00<00?l00?ooo`3oool05@3oool00`00o`00oooo
0?ooo`0S0?ooo`00<P3oool00`000000oooo0?ooo`1P0?ooo`03003o003oool0o`0001<0oooo00<0
o`000?ooo`00o`00Q03oool00`3o0000oooo0?ooo`0m0?ooo`03003o003oool0oooo01D0oooo00<0
0?l00?ooo`3oool08`3oool00380oooo00<000000?ooo`3oool0H03oool00`00o`00oooo0?l0000C
0?ooo`030?l0003oool00?l008@0oooo00<0o`000?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0E
0?ooo`03003o003oool0oooo02<0oooo000b0?ooo`<00000H@3oool00`00o`00o`000?ooo`0A0?oo
o`040?l0003oool0oooo003o08@0oooo00<0o`000?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0E
0?ooo`03003o003oool0oooo02<0oooo000b0?ooo`030000003oool0oooo0640oooo00<00?l00?oo
o`3o00004@3oool0103o0000oooo0?ooo`00o`240?ooo`030?l0003oool0oooo03h0oooo00<00?l0
0?ooo`3oool0503oool00`00o`00oooo0?ooo`0S0?ooo`00<P3oool00`000000oooo0?ooo`1Q0?oo
o`03003o003oool0o`000140oooo00<0o`000?ooo`00o`00Q@3oool00`3o0000oooo0?ooo`0n0?oo
o`03003o003oool0oooo01<0oooo00<00?l00?ooo`3oool0903oool00380oooo00<000000?ooo`3o
ool0H@3oool00`00o`00oooo0?l0000A0?ooo`030?l0003oool00?l008D0oooo00<0o`000?ooo`3o
ool0?P3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo02@0oooo000b0?ooo`030000
003oool0oooo0640oooo00<00?l00?ooo`3o00004@3oool00`3o0000oooo003o00250?ooo`030?l0
003oool0oooo03h0oooo00<00?l00?ooo`3oool04`3oool00`00o`00oooo0?ooo`0T0?ooo`00<P3o
ool00`000000oooo0?ooo`1Q0?ooo`04003o003oool0oooo0?l000l0oooo00@0o`000?ooo`3oool0
0?l0Q@3oool00`3o0000oooo0?ooo`0o0?ooo`03003o003oool0oooo0180oooo00<00?l00?ooo`3o
ool0903oool00380oooo00<000000?ooo`3oool0H@3oool01000o`00oooo0?ooo`3o000?0?ooo`04
0?l0003oool0oooo003o08D0oooo00<0o`000?ooo`3oool0?`3oool00`00o`00oooo0?ooo`0B0?oo
o`03003o003oool0oooo02@0oooo000b0?ooo`030000003oool0oooo0680oooo00<00?l00?ooo`3o
00003`3oool00`3o0000oooo003o00260?ooo`030?l0003oool0oooo03l0oooo00<00?l00?ooo`3o
ool04@3oool00`00o`00oooo0?ooo`0U0?ooo`00<P3oool00`000000oooo0?ooo`1R0?ooo`04003o
003oool0oooo0?l000h0oooo00<0o`000?ooo`00o`00QP3oool00`3o0000oooo0?ooo`0o0?ooo`03
003o003oool0oooo0140oooo00<00?l00?ooo`3oool09@3oool00380oooo00<000000?ooo`3oool0
HP3oool01000o`00oooo0?ooo`3o000=0?ooo`040?l0003oool0oooo003o08H0oooo00<0o`000?oo
o`3oool0@03oool00`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo02D0oooo000b0?ooo`03
0000003oool0oooo0680oooo00@00?l00?ooo`3oool0o`003@3oool0103o0000oooo0?ooo`00o`26
0?ooo`030?l0003oool0oooo0400oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`0U
0?ooo`00<P3oool300000680oooo00D00?l00?ooo`3oool0oooo0?l0000;0?ooo`040?l0003oool0
oooo003o08L0oooo00<0o`000?ooo`3oool0@03oool00`00o`00oooo0?ooo`0?0?ooo`03003o003o
ool0oooo02H0oooo000b0?ooo`030000003oool0oooo06<0oooo00@00?l00?ooo`3oool0o`002`3o
ool0103o0000oooo0?ooo`00o`270?ooo`030?l0003oool0oooo0400oooo00<00?l00?ooo`3oool0
3`3oool00`00o`00oooo0?ooo`0V0?ooo`00<P3oool00`000000oooo0?ooo`1S0?ooo`04003o003o
ool0oooo0?l000/0oooo00@0o`000?ooo`3oool00?l0Q`3oool00`3o0000oooo0?ooo`110?ooo`03
003o003oool0oooo00h0oooo00<00?l00?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
H`3oool01000o`00oooo0?ooo`3o000:0?ooo`050?l0003oool0oooo0?ooo`00o`00Q`3oool00`3o
0000oooo0?ooo`110?ooo`03003o003oool0oooo00h0oooo00<00?l00?ooo`3oool09P3oool00380
oooo00<000000?ooo`3oool0H`3oool01@00o`00oooo0?ooo`3oool0o`0000T0oooo00D0o`000?oo
o`3oool0oooo003o00270?ooo`030?l0003oool0oooo0440oooo00<00?l00?ooo`3oool03@3oool0
0`00o`00oooo0?ooo`0W0?ooo`00<P3oool00`000000oooo0?ooo`1T0?ooo`04003o003oool0oooo
0?l000T0oooo00@0o`000?ooo`3oool00?l0R03oool00`3o0000oooo0?ooo`110?ooo`03003o003o
ool0oooo00d0oooo00<00?l00?ooo`3oool09`3oool00380oooo00<000000?ooo`3oool0I03oool0
1000o`00oooo0?ooo`3o00080?ooo`050?l0003oool0oooo0?ooo`00o`00R@3oool00`3o0000oooo
0?ooo`100?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3oool09`3oool002H0oooo1`00
00050?ooo`030000003oool0oooo06@0oooo00D00?l00?ooo`3oool0oooo0?l000070?ooo`050?l0
003oool0oooo0?ooo`00o`00R@3oool00`3o0000oooo0?ooo`110?ooo`03003o003oool0oooo00`0
oooo00<00?l00?ooo`3oool09`3oool002T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1U0?ooo`05003o003oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`020?ooo`03
003o003oool0oooo08L0oooo00<0o`000?ooo`3oool0@@3oool00`00o`00oooo0?ooo`0;0?ooo`03
003o003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
I@3oool00`00o`00oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`00o`00
oooo0?ooo`280?ooo`030?l0003oool0oooo0440oooo00<00?l00?ooo`3oool02`3oool00`00o`00
oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`060?ooo`@00000I03oool00`00o`00oooo
0?ooo`020?ooo`D0o`00103oool00`00o`00oooo0?ooo`280?ooo`030?l0003oool0oooo0440oooo
00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo06H0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?oo
o`290?ooo`030?l0003oool0oooo0480oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?oo
o`0Y0?ooo`00:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06H0oooo00<00?l0
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`290?ooo`030?l0003oool0oooo0480oooo00<00?l0
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`0Y0?ooo`00:@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo06H0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`290?oo
o`030?l0003oool0oooo04<0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0Y0?oo
o`009`3oool3000000P0oooo00<000000?ooo`3oool0IP3oool00`00o`00oooo0?ooo`080?ooo`03
003o003oool0oooo08X0oooo00<0o`000?ooo`3oool0@`3oool00`00o`00oooo0?ooo`070?ooo`03
003o003oool0oooo02X0oooo000Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
I`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo08X0oooo00<0o`000?ooo`3oool0
@`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo02X0oooo000b0?ooo`030000003o
ool0oooo06L0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`2:0?ooo`030?l0003o
ool0oooo04@0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0[0?ooo`00<P3oool0
0`000000oooo0?ooo`1W0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0R`3oool0
0`3o0000oooo0?ooo`140?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0:`3oool0
0380oooo00<000000?ooo`3oool0J03oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo
08`0oooo00<0o`000?ooo`3oool0A03oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo
02/0oooo000b0?ooo`030000003oool0oooo06T0oooo00<00?l00?ooo`3oool00P3oool00`00o`00
oooo0?ooo`2=0?ooo`030?l0003oool0oooo04D0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`0/0?ooo`00<P3oool00`000000oooo0?ooo`1Z0?ooo`05003o003oool0oooo0?ooo`00
o`00S`3oool00`3o0000oooo0?ooo`160?ooo`04003o003oool0oooo0?ooo`800?l0;P3oool00380
oooo0`00001[0?ooo`<00?l0T03oool00`3o0000oooo0?ooo`170?ooo`@00?l0;`3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool006H0oooo1000003;0?ooo`@00000M`3oool006X0oooo00<000000?oo
o`3oool0c03oool00`000000oooo0?ooo`1d0?ooo`00JP3oool00`000000oooo0?ooo`3<0?ooo`03
0000003oool0oooo07@0oooo001C0?ooo`@000001@3oool7000000<0oooo0`0000000`3oool00000
0?ooo`040?ooo`8000001P3oool4000000d0oooo1@0000060?ooo`@00000103oool01@000000oooo
0?ooo`3oool0000000D0oooo100000040?ooo`D000003@3oool00`000000oooo00000002000000<0
oooo1`0000020?ooo`<000000P3oool3000000<0oooo0`0000000`3oool00000000000020?ooo`D0
00001@3oool4000000<0oooo1`0000030?ooo`<0000000<0oooo0000000000002`3oool700000080
oooo0`0000020?ooo`<00000103oool4000000@0oooo100000040?ooo`<0000000<0oooo0000003o
ool00`3oool5000000D0oooo1@0000050?ooo`@000000P3oool7000000@0oooo100000030?ooo`<0
00000P3oool3000003h0oooo001D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`3oool2000000D0oooo0P0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool2000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool0oooo0P00000?0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0m0?ooo`00E03oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0?@3oool005@0oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0;0?ooo`D00000103oool00`000000oooo0?ooo`020?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo000000<0oooo1P0000040?ooo`030000003oool0
oooo00D0oooo1P0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool600000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo100000050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0m0?ooo`00E03oool4000000L0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`3oool2000000l0oooo0P00000>0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00000@
0?ooo`@000001P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool0oooo0P00000?0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000<0oooo0P0000050?ooo`8000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo03d0oooo001D0?ooo`060000003o
ool0oooo0000003oool000000`3oool3000000H0oooo0`0000000`3oool000000000000@0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`@0
00000P3oool3000000<0oooo0`0000030?ooo`@00000103oool2000000040?ooo`00000000000000
00`0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000D0oooo0P000000
103oool000000000000000030?ooo`8000000`3oool2000000@0oooo1@0000040?ooo`@00000103o
ool3000000H0oooo0`0000000`3oool000000?ooo`0>0?ooo`030000003oool0oooo00<0oooo0P00
0000103oool000000000000000030?ooo`L00000103oool4000000@0oooo0`0000000`3oool00000
000000030?ooo`80000000@0oooo0000000000000000103oool3000000@0oooo1`0000030?ooo`<0
00001`3oool4000000<0oooo0P000000103oool000000000000000100?ooo`00E03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool0oooo0P00000m0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo05`0oooo001C0?ooo`L000007@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo1P00000b0?ooo`<0000000<0oooo0000003oool0?03oool00`000000
oooo0?ooo`0:0?ooo`L000003@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05`0
oooo001O0?ooo`030000003oool0oooo01H0oooo1000001?0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool01`3oool2000005L0oooo00<000000?ooo`3oool0DP3oool005l0oooo00<0
00000?ooo`3oool0J@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0DP3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 430.875}, {265.875, 0}} -> {-0.719983, -0.0848258, \
0.0212861, 0.00701952}}]
}, Open  ]],

Cell[TextData[{
  "\tThe non-linearity disappears if ",
  StyleBox["p",
    FontSlant->"Italic"],
  "=1, simplifying to the standard sinusoid equation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&\[DoubleDot]\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\)]],
  StyleBox["V",
    FontSlant->"Italic"],
  ". "
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["18. Appendix F. Plex-conjugation.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Summary.",
    FontSlant->"Plain"],
  " Loops with sizes that are the signed sum of squared elements have \
conjugates, pairs of vectors whose product is the vector size followed by \
zeroes. The complex conjugate is the archetype: (a+\[ImaginaryI] b)(a-\
\[ImaginaryI] b)= (",
  Cell[BoxData[
      \(a\^2 + b\^2\)]],
  "+\[ImaginaryI] 0). Some other loops have \"plex-conjugates\" that give \
hoop products (usually with many zeroes) that are related to the sizes. A \
number of compact sizes have been found via such conjugates. \"Polymorphic\" \
conjugates & shape formulations have been obtained for some hoops. Ternary \
conjugates have inverted element pairs,\[DoubleStruckCapitalJ]\
\[LeftRightArrow]",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^2\)]],
  " instead of negated elements \[ImaginaryI]\[LeftRightArrow]",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^3\)]],
  ". Useless discovery - sums of quasi-group product elements factorize into \
the multiplicands."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["18.1. Complex Conjugates.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tComplex, Quaternion, & Octonion numbers have \"complex conjugates\"; a \
squared \"length\" is obtained on multiplying a vector by its complex \
conjugate. This actually gives the ",
  StyleBox["size",
    FontSlant->"Italic"],
  " of the vector, which also appears as the first element of the (hoop) \
product of the vector and its conjugate; the other elements become zero. The \
same is true for P4, CL2, & higher Cayley-Dickson non-associative algebras \
such as Sed, as well as \[DoubleStruckCapitalC], \[DoubleStruckCapitalH], & \
\[DoubleStruckCapitalO], as can be seen in Example F1. These are all the \
loops known to me with shapes that are signed sums of squared elements. \
Louenesto [3, p15] calls the CL2 conjugate the Clifford-conjugate."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example F1. Multiplication by complex conjugates that give sizes.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopTimes[{a, 
        b}, {a, \(-b\), \(-c\), \(-d\)}, "\<C4c\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 + b\^2, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopTimes[{a, b, c, 
        d}, {a, \(-b\), \(-c\), \(-d\)}, "\<Qr\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 + b\^2 + c\^2 + d\^2, 0, 0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopTimes[{a, b, c, 
        d}, {a, \(-b\), \(-c\), \(-d\)}, "\<P4\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 - b\^2 - c\^2 - d\^2, 0, 0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopTimes[{a, b, c, 
        d}, {a, \(-b\), \(-c\), \(-d\)}, "\<CL2\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 - b\^2 + c\^2 - d\^2, 0, 0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopTimes[{a, b, c, d, e, f, g, 
        h}, {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), \(-h\)}, \
"\<Octc\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2, 0, 0, 0, 0, 0, 
      0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l, m, n, 
        o, p}, {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), \(-h\), \
\(-i\), \(-j\), \(-k\), \(-l\), \(-m\), \(-n\), \(-o\), \(-p\)}, \
"\<Sed\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2 + i\^2 + j\^2 + 
        k\^2 + l\^2 + m\^2 + n\^2 + o\^2 + p\^2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.2. Plex-conjugates.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tOther loops have \"plex-conjugates\" that may give a number of zeroes in \
the hoop product. The non-zero products are related to the sizes. Sizes can \
sometimes be identified, if they are not already known, with the aid of \
plex-conjugates and knowledge of the number and order of the factors in the \
shape (provided by ",
  StyleBox["fa",
    FontSlant->"Italic"],
  " or ",
  StyleBox["fp",
    FontSlant->"Italic"],
  "). Example F2 demonstrates this. The pattern of signs of the conjugate \
have to be discovered in each case. For CL3 the plex-conjugate that gives two \
non-zero terms gives the shape directly, as the sum of the squares of the two \
non-zero elements in the product:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example F2.  Plex-conjugate defining shape. CL3.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
        "\"\<CL3 {a,b,c,d,e,f,g,h}\[Times]{a,-b,-c,-d,-e,-f,-g,h}=\>\"", 
          ",", \(hoopTimes[{a, b, c, d, e, f, g, 
              h}, {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), h}, 
            tst = "\<CL3\>"]\), ",", "\[IndentingNewLine]", 
          "\"\<\\nFactors after \!\(\*
StyleBox[\"Alph\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"substitution\",\nFontSlant->\"Plain\"]\)\>\"", 
          ",", \(fp[mp[tst]]\), ",", "\[IndentingNewLine]", 
          "\"\<\\nShape\>\"", ",", \(sh[tst]\), ",", 
          "\"\<\\nShape found from \!\(\*
StyleBox[\"plex\",\nFontSlant->\"Italic\"]\) gives the correct factor\\n\>\"",
           ",", \(Expand[sh[tst]] /. fromAlph[Take[pow2, 8]]\)}], "}"}], 
      TraditionalForm]], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"CL3 {a,b,c,d,e,f,g,h}\[Times]{a,-b,-c,-d,-e,-f,-g,h}=\"\>",
         ",", \({a\^2 - b\^2 - c\^2 + d\^2 - e\^2 + f\^2 + g\^2 - h\^2, 0, 0, 
          0, 0, 0, 0, \(-2\)\ d\ e + 2\ c\ f - 2\ b\ g + 2\ a\ h}\), 
        ",", "\<\"\\nFactors after \\!\\(\\* \
StyleBox[\\\"Alph\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"substitution\\\",\\nFontSlant->\\\"Plain\\\"]\\)\"\>", 
        ",", \(\((8235257 - 16384\ a + 10646\ a\^2 + a\^4)\)\^2\), 
        ",", "\<\"\\nShape\"\>", 
        ",", \({4\ \((\(-d\)\ e + c\ f - b\ g + a\ h)\)\^2 + \((a\^2 - b\^2 - \
c\^2 + d\^2 - e\^2 + f\^2 + g\^2 - h\^2)\)\^2}\), 
        ",", "\<\"\\nShape found from \\!\\(\\* \
StyleBox[\\\"plex\\\",\\nFontSlant->\\\"Italic\\\"]\\) gives the correct \
factor\\n\"\>", ",", \({8235257 - 16384\ a + 10646\ a\^2 + a\^4}\)}], 
      "}"}]], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tPlex-conjugate products for CL4, CL13 & CL04 have six non-zero terms \
that give the shapes directly - as the squared sum of the squared elements \
minus the squares of the other non-zero products. (As ",
  StyleBox["pow2",
    FontSlant->"Italic"],
  " gives anomalous results with some Clifford algebras a different \
substitution is used.) Only CL4 is shown:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example F3.  Plex-conjugate defining shape. CL4.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`subs = {a, 1, 3, 2, 7, 5, 41, 11, 13, 29, 17, 19, 31, 
        61, 37, 43}; 
    sbs = fromAlph[
        subs]; {"\<{a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p}\[Times]{a,b,c,-d,e,-f,-g,\
-h,i,-j,-k,-l,-m,-n,-o,p} using CL4 is\>", 
      fcl4 = hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p}, {a, 
            b, c, \(-d\), e, \(-f\), \(-g\), \(-h\), 
            i, \(-j\), \(-k\), \(-l\), \(-m\), \(-n\), \(-o\), p}, 
          tst = "\<CL4\>"], \[IndentingNewLine]"\<\nFactors after a \
substitution\>", 
      fp[mp[tst], 
        subs], \[IndentingNewLine]"\<\nThe shape is the first factor squared, \
minus the other factors squared, giving, after the same substitution \>", 
      Expand[\((fcl4[\([1]\)]^2 - fcl4[\([2]\)]^2 - fcl4[\([3]\)]^2 - 
              fcl4[\([5]\)]^2 - fcl4[\([9]\)]^2 - fcl4[\([16]\)]^2)\) /. 
          sbs]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"{a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p}\[Times]{a,b,c,-d,e,-f,-g,-h,i,-j,-k,\
-l,-m,-n,-o,p} using CL4 is", {a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + 
          g\^2 + h\^2 + i\^2 + j\^2 + k\^2 + l\^2 + m\^2 + n\^2 + o\^2 + 
          p\^2, 2\ a\ b + 2\ c\ d + 2\ e\ f + 2\ g\ h + 2\ i\ j + 2\ k\ l + 
          2\ m\ n + 2\ o\ p, 
        2\ a\ c - 2\ b\ d + 2\ e\ g - 2\ f\ h + 2\ i\ k - 2\ j\ l + 2\ m\ o - 
          2\ n\ p, 0, 
        2\ a\ e - 2\ b\ f - 2\ c\ g + 2\ d\ h + 2\ i\ m - 2\ j\ n - 2\ k\ o + 
          2\ l\ p, 0, 0, 0, 
        2\ a\ i - 2\ b\ j - 2\ c\ k + 2\ d\ l - 2\ e\ m + 2\ f\ n + 2\ g\ o - 
          2\ h\ p, 0, 0, 0, 0, 0, 0, 
        2\ h\ i - 2\ g\ j + 2\ f\ k - 2\ e\ l - 2\ d\ m + 2\ c\ n - 2\ b\ o + 
          2\ a\ p}, 
      "\nFactors after a substitution", \((18354868 + 306416\ a + 14592\ a\^2 \
+ a\^4)\)\^4, 
      "\nThe Shape is the first factor squared, minus the other factors \
squared, giving, after the same substitution ", 
      18354868 + 306416\ a + 14592\ a\^2 + a\^4}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The relation between plex-conjugate products is often less \
obvious",
    FontSize->12,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  ":"
}], "Subsubsection",
  PageWidth->WindowWidth],

Cell["Example F5.  Plex-conjugate and related sizes.  O4.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell["\<\
\tHere each of the four sizes can be expressed as the sum of two squares, \
which are equal to the scalar term res[[1]], combined with signed sums of the \
remaining terms.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{"\<{a,b,c,d,e,f,g,h}\[Times]{a,b,c,d,-e,-f,-g,-h}, \
using O4 is\>", 
      res = hoopTimes[{a, b, c, d, e, f, g, h}, {a, b, c, 
            d, \(-e\), \(-f\), \(-g\), \(-h\)}, 
          tst = "\<O4\>"], \[IndentingNewLine]"\<\nFactors\>", 
      fp[mp[tst]], \[IndentingNewLine]"\<\nShape\>", sh[tst]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"{a,b,c,d,e,f,g,h}\[Times]{a,b,c,d,-e,-f,-g,-h}, using O4", {a\^2 + 
          b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2, 
        2\ a\ b + 2\ c\ d + 2\ e\ f + 2\ g\ h, 
        2\ a\ c + 2\ b\ d + 2\ e\ g + 2\ f\ h, 
        2\ b\ c + 2\ a\ d + 2\ f\ g + 2\ e\ h, 0, 0, 0, 0}, 
      "\nFactors", \((5209 - 10\ a + a\^2)\)\ \((1609 - 6\ a + 
            a\^2)\)\ \((577 + 2\ a + a\^2)\)\ \((14449 + 14\ a + a\^2)\), 
      "\nShape", {\((a - b - c + d)\)\^2 + \((e - f - g + h)\)\^2, \((a - b + \
c - d)\)\^2 + \((e - f + g - h)\)\^2, \((a + b - c - d)\)\^2 + \((e + f - g - \
h)\)\^2, \((a + b + c + d)\)\^2 + \((e + f + g + h)\)\^2}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[{\((a - b - c + d)\)\^2 + \((e - f - g + h)\)\^2 - 
          res[\([1]\)] + res[\([2]\)] + res[\([3]\)] - 
          res[\([4]\)], \[IndentingNewLine]\((a - b + c - d)\)\^2 + \((e - f \
+ g - h)\)\^2 - res[\([1]\)] + res[\([2]\)] - res[\([3]\)] + 
          res[\([4]\)], \[IndentingNewLine]\((a + b - c - d)\)\^2 + \((e + f \
- g - h)\)\^2 - res[\([1]\)] - res[\([2]\)] + res[\([3]\)] + 
          res[\([4]\)], \[IndentingNewLine]\((a + b + c + d)\)\^2 + \((e + f \
+ g + h)\)\^2 - res[\([1]\)] - res[\([2]\)] - res[\([3]\)] - 
          res[\([4]\)]}]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({0, 0, 0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["Example F6.  Plex-conjugate and related sizes.  CL03. ", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell["\<\
\tHere there are two sizes and two non-zero terms (the scalar and trivector \
parts). The sizes are their sum and difference. The same is true for CL21.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{"\<{a,b,c,d,e,f,g,h}\[Times]{a,-b,-c,-d,-e,-f,-g,h}, \
using CL03 is\>", 
      hoopTimes[{a, b, c, d, e, f, g, 
          h}, {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), h}, 
        tst = "\<CL03\>"], \[IndentingNewLine]"\<\nShape\>", 
      sh[tst]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"{a,b,c,d,e,f,g,h}\[Times]{a,-b,-c,-d,-e,-f,-g,h}, using CL03 is", \
{a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2, 0, 0, 0, 0, 0, 
        0, \(-2\)\ d\ e + 2\ c\ f - 2\ b\ g + 2\ a\ h}, 
      "\nShape", {\((d + e)\)\^2 + \((c - f)\)\^2 + \((b + g)\)\^2 + \((a - \
h)\)\^2, \((d - e)\)\^2 + \((c + f)\)\^2 + \((b - g)\)\^2 + \((a + \
h)\)\^2}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["Example F7.  Plex-conjugate and related sizes.  CL21.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{"\<{a,b,c,d,e,f,g,h},{a,-b,-c,-d,-e,-f,-g,h}, using \
CL21 is\>", 
      hoopTimes[{a, b, c, d, e, f, g, 
          h}, {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), h}, 
        tst = "\<CL21\>"], \[IndentingNewLine]"\<\nShape\>", 
      sh[tst]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"{a,b,c,d,e,f,g,h},{a,-b,-c,-d,-e,-f,-g,h}, using CL21 is", {a\^2 + 
          b\^2 - c\^2 - d\^2 - e\^2 - f\^2 + g\^2 + h\^2, 0, 0, 0, 0, 0, 
        0, \(-2\)\ d\ e + 2\ c\ f - 2\ b\ g + 2\ a\ h}, 
      "\nShape", {\(-\((d - e)\)\^2\) - \((c + f)\)\^2 + \((b + g)\)\^2 + \
\((a - h)\)\^2, \(-\((d + e)\)\^2\) - \((c - f)\)\^2 + \((b - g)\)\^2 + \((a \
+ h)\)\^2}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "Some ternary algebras have plex-conjugates with reversed pairs of \
elements",
  ", \[DoubleStruckCapitalJ]\[LeftRightArrow]",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^2\)]],
  ", and the product has repeated, instead of zero, elements."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example F8.  Ternary Plex-conjugate and related sizes.  C3.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{"\<{a,b,c},{a,c,b}, using C3 is\>", 
      hoopTimes[{a, b, c}, {a, c, b}, 
        tst = "\<C3\>"], \[IndentingNewLine]"\<\nShape\>", 
      Expand[sh[tst]]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"{a,b,c},{a,c,b}, using C3 is", {a\^2 + b\^2 + c\^2, 
        a\ b + a\ c + b\ c, a\ b + a\ c + b\ c}, 
      "\nShape", {a + b + c, 
        a\^2 - a\ b + b\^2 - a\ c - b\ c + c\^2}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
Example F9.  Conjugate Plex-conjugate and related sizes. g2401c.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \({id[tst = mp[6, 9]], tst // tf, "\<Shape \>", sh[gmn], "\<\nPlex \>", 
      plex}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"g2401c\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "6", "4", "5"},
                  {"3", "1", "2", "5", "6", "4"},
                  {"4", "5", "6", 
                    "\[ImaginaryI]", \(2\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\
\)},
                  {"5", "6", "4", \(3\ \[ImaginaryI]\), 
                    "\[ImaginaryI]", \(2\ \[ImaginaryI]\)},
                  {"6", "4", "5", \(2\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\), 
                    "\[ImaginaryI]"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"Shape \"\>", 
        ",", \({1\/2\ \((\((a - b)\)\^2 + \((a - c)\)\^2 + \((b - c)\)\^2 - \
\[ImaginaryI]\ \((\((d - e)\)\^2 + \((d - f)\)\^2 + \((e - f)\)\^2)\))\), \
\((a + b + c)\)\^2 - \[ImaginaryI]\ \((d + e + f)\)\^2}\), 
        ",", "\<\"\\nPlex \"\>", ",", \({a, c, b, \(-d\), \(-e\), \(-f\)}\)}],
       "}"}]], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff = fa[tst]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\[ImaginaryI]\ \((a\^2 - a\ b + b\^2 - a\ c - b\ c + c\^2 + \
\[ImaginaryI]\ d\^2 - \[ImaginaryI]\ d\ e + \[ImaginaryI]\ e\^2 - \
\[ImaginaryI]\ d\ f - \[ImaginaryI]\ e\ f + \[ImaginaryI]\ f\^2)\)\^2\ \
\((a\^2 + 2\ a\ b + b\^2 + 2\ a\ c + 2\ b\ c + c\^2 + \[ImaginaryI]\ d\^2 + 
          2\ \[ImaginaryI]\ d\ e + \[ImaginaryI]\ e\^2 + 
          2\ \[ImaginaryI]\ d\ f + 
          2\ \[ImaginaryI]\ e\ f + \[ImaginaryI]\ f\^2)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(res = hoopTimes[{a, b, c, d, e, f}, plex, gmn]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 + b\^2 + 
        c\^2 - \[ImaginaryI]\ d\^2 - \[ImaginaryI]\ e\^2 - \[ImaginaryI]\ \
f\^2, a\ b + a\ c + 
        b\ c - \[ImaginaryI]\ d\ e - \[ImaginaryI]\ d\ f - \[ImaginaryI]\ e\ \
f, a\ b + a\ c + 
        b\ c - \[ImaginaryI]\ d\ e - \[ImaginaryI]\ d\ f - \[ImaginaryI]\ e\ \
f, 0, 0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
The conjugate of the repeated factor is the difference between the first two \
elements of the product:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[
      a\^2 - a\ b + b\^2 - a\ c - b\ c + 
        c\^2 - \[ImaginaryI]\ d\^2 + \[ImaginaryI]\ d\ e - \[ImaginaryI]\ \
e\^2 + \[ImaginaryI]\ d\ f + \[ImaginaryI]\ e\ f - \[ImaginaryI]\ f\^2 - 
        res[\([1]\)] + res[\([3]\)]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(0\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
The conjugate of the other factor is the sum of the elements of the product:-\
\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[
      a\^2 + 2\ a\ b + b\^2 + 2\ a\ c + 2\ b\ c + 
        c\^2 - \[ImaginaryI]\ d\^2 - 
        2\ \[ImaginaryI]\ d\ e - \[ImaginaryI]\ e\^2 - 
        2\ \[ImaginaryI]\ d\ f - 
        2\ \[ImaginaryI]\ e\ f - \[ImaginaryI]\ f\^2 - \((res[\([1]\)] + 
            res[\([2]\)] + res[\([3]\)])\)]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(0\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.3. Polymorphs.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tSome quartic shapes are polymorphic, with different plex-conjugates \
leading to different fragmented formulations of the shape. These correspond \
to the different involutions. Louenesto p86 mentions grade involution, \
reversion, and Clifford conjugation.\n\tExample F1 showed that CL3 has a \
shape consisting of the sum of two squares. Example F9 shows three \
polymorphs, each being the signed sum of 4 squares. In these case, four \
zeroes occur in the sizes of a plex-conjugate. The appropriately signed sums \
of squares of the sizes is then shown to match the determinant of the CL3 \
table, as found by ",
  StyleBox["fp",
    FontSlant->"Italic"],
  ".  (CL4 and CL04 dimorphs have also been found.)"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example F9.  Plex-conjugate Polymorphs. CL3.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{"\<Conjugate {a,b,c,-d,e,-f,-g,-h}\>", 
      hoopTimes[{a, b, c, d, e, f, g, h}, {a, b, c, \(-d\), 
          e, \(-f\), \(-g\), \(-h\)}, tst = "\<CL3\>"], "\<\n Det    \>", 
      fp[mp[tst]], \*"\"\<1st Shape is \
(\!\(a\^2\)+\!\(b\^2\)+\!\(c\^2\)+\!\(d\^2\)+\!\(e\^2\)+\!\(f\^2\)+\!\(g\^2\)+\
\!\(h\^2\))^2-(2 a b+2 c d+2 e f+2 g h)^2-(2 a c-2 b d+2 e g-2 f h)^2-(2 a \
e-2 b f-2 c g+2 d h)^2\>\"", \[IndentingNewLine]"\<\nFactor OK\>", 
      Expand[\((a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + 
                  h\^2)\)^2 - \((2\ a\ b + 2\ c\ d + 2\ e\ f + 
                  2\ g\ h)\)^2 - \((2\ a\ c - 2\ b\ d + 2\ e\ g - 
                  2\ f\ h)\)^2 - \((2\ a\ e - 2\ b\ f - 2\ c\ g + 
                  2\ d\ h)\)^2] /. 
        fromAlph[
          Take[pow2, 
            8]], \[IndentingNewLine]"\<\n\nConjugate \
{a,-b,-c,-d,e,f,g,-h}\>", 
      hoopTimes[{a, b, c, d, e, f, g, h}, {a, \(-b\), \(-c\), \(-d\), e, f, 
          g, \(-h\)}], \*"\"\<2nd Shape is (\!\(a\^2\)-\!\(b\^2\)-\!\(c\^2\)+\
\!\(d\^2\)+\!\(e\^2\)-\!\(f\^2\)-\!\(g\^2\)+\!\(h\^2\))^2-(2 a e+2 b f+2 c \
g+2 d h)^2+(2 b e+2 a f+2 d g+2 c h)^2+(2 c e-2 d f+2 a g-2 b h)^2\>\"", \
\[IndentingNewLine]"\<\nFactor OK\>", 
      Expand[\((a\^2 - b\^2 - c\^2 + d\^2 + e\^2 - f\^2 - g\^2 + 
                  h\^2)\)^2 - \((2\ a\ e + 2\ b\ f + 2\ c\ g + 
                  2\ d\ h)\)^2 + \((2\ b\ e + 2\ a\ f + 2\ d\ g + 
                  2\ c\ h)\)^2 + \((2\ c\ e - 2\ d\ f + 2\ a\ g - 
                  2\ b\ h)\)^2] /. 
        fromAlph[Take[pow2, 8]], "\<\n\nConjugate {a,-b,-c,-d,e,f,g,-h}\>", 
      hoopTimes[{a, b, c, d, e, f, g, h}, {a, \(-b\), \(-c\), \(-d\), e, f, 
          g, \(-h\)}], \*"\"\<3rd Shape \
is(\!\(a\^2\)-\!\(b\^2\)-\!\(c\^2\)+\!\(d\^2\)+\!\(e\^2\)-\!\(f\^2\)-\!\(g\^2\
\)+\!\(h\^2\))^2-(2 a e+2 b f+2 c g+2 d h)^2+(2 b e+2 a f+2 d g+2 c h)^2+(2 c \
e-2 d f+2 a g-2 b h)^2\>\"", \[IndentingNewLine]"\<\nFactor OK\>", 
      Expand[\((a\^2 - b\^2 - c\^2 + d\^2 + e\^2 - f\^2 - g\^2 + 
                  h\^2)\)^2 - \((2\ a\ e + 2\ b\ f + 2\ c\ g + 
                  2\ d\ h)\)^2 + \((2\ b\ e + 2\ a\ f + 2\ d\ g + 
                  2\ c\ h)\)^2 + \((2\ c\ e - 2\ d\ f + 2\ a\ g - 
                  2\ b\ h)\)^2] /. 
        fromAlph[Take[pow2, 8]], "\<\n\nConjugate {a,-b,c,d,-e,-f,g,-h}\>", 
      hoopTimes[{a, b, c, d, e, f, g, h}, {a, \(-b\), c, d, \(-e\), \(-f\), 
          g, \(-h\)}], \*"\"\<4th Shape is (\!\(a\^2\)-\!\(b\^2\)+\!\(c\^2\)-\
\!\(d\^2\)-\!\(e\^2\)+\!\(f\^2\)-\!\(g\^2\)+\!\(h\^2\))^2-(2 a c+2 b d-2 e \
g-2 f h)^2+(2 b c+2 a d-2 f g-2 e h)^2+(2 c e-2 d f-2 a g+2 b h)^2\>\"", \
\[IndentingNewLine]"\<\nFactor OK\>", 
      Expand[\((a\^2 - b\^2 + c\^2 - d\^2 - e\^2 + f\^2 - g\^2 + 
                  h\^2)\)^2 - \((2\ a\ c + 2\ b\ d - 2\ e\ g - 
                  2\ f\ h)\)^2 + \((2\ b\ c + 2\ a\ d - 2\ f\ g - 
                  2\ e\ h)\)^2 + \((2\ c\ e - 2\ d\ f - 2\ a\ g + 
                  2\ b\ h)\)^2] /. fromAlph[Take[pow2, 8]]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"Conjugate {a,b,c,-d,e,-f,-g,-h}", {a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + 
          f\^2 + g\^2 + h\^2, 2\ a\ b + 2\ c\ d + 2\ e\ f + 2\ g\ h, 
        2\ a\ c - 2\ b\ d + 2\ e\ g - 2\ f\ h, 0, 
        2\ a\ e - 2\ b\ f - 2\ c\ g + 2\ d\ h, 0, 0, 0}, 
      "\n Det    ", \((8235257 - 16384\ a + 10646\ a\^2 + a\^4)\)\^2, 
      "1st Shape is \
(\!\(a\^2\)+\!\(b\^2\)+\!\(c\^2\)+\!\(d\^2\)+\!\(e\^2\)+\!\(f\^2\)+\!\(g\^2\)+\
\!\(h\^2\))^2-(2 a b+2 c d+2 e f+2 g h)^2-(2 a c-2 b d+2 e g-2 f h)^2-(2 a \
e-2 b f-2 c g+2 d h)^2", "\nFactor OK", 
      8235257 - 16384\ a + 10646\ a\^2 + a\^4, 
      "\n\nConjugate {a,-b,-c,-d,e,f,g,-h}", {a\^2 - b\^2 - c\^2 + d\^2 + 
          e\^2 - f\^2 - g\^2 + h\^2, 0, 0, 0, 
        2\ a\ e + 2\ b\ f + 2\ c\ g + 2\ d\ h, 
        2\ b\ e + 2\ a\ f + 2\ d\ g + 2\ c\ h, 
        2\ c\ e - 2\ d\ f + 2\ a\ g - 2\ b\ h, 0}, 
      "2nd Shape is \
(\!\(a\^2\)-\!\(b\^2\)-\!\(c\^2\)+\!\(d\^2\)+\!\(e\^2\)-\!\(f\^2\)-\!\(g\^2\)+\
\!\(h\^2\))^2-(2 a e+2 b f+2 c g+2 d h)^2+(2 b e+2 a f+2 d g+2 c h)^2+(2 c \
e-2 d f+2 a g-2 b h)^2", "\nFactor OK", 
      8235257 - 16384\ a + 10646\ a\^2 + a\^4, 
      "\n\nConjugate {a,-b,-c,-d,e,f,g,-h}", {a\^2 - b\^2 - c\^2 + d\^2 + 
          e\^2 - f\^2 - g\^2 + h\^2, 0, 0, 0, 
        2\ a\ e + 2\ b\ f + 2\ c\ g + 2\ d\ h, 
        2\ b\ e + 2\ a\ f + 2\ d\ g + 2\ c\ h, 
        2\ c\ e - 2\ d\ f + 2\ a\ g - 2\ b\ h, 0}, 
      "3rd Shape is(\!\(a\^2\)-\!\(b\^2\)-\!\(c\^2\)+\!\(d\^2\)+\!\(e\^2\)-\!\
\(f\^2\)-\!\(g\^2\)+\!\(h\^2\))^2-(2 a e+2 b f+2 c g+2 d h)^2+(2 b e+2 a f+2 \
d g+2 c h)^2+(2 c e-2 d f+2 a g-2 b h)^2", "\nFactor OK", 
      8235257 - 16384\ a + 10646\ a\^2 + a\^4, 
      "\n\nConjugate {a,-b,c,d,-e,-f,g,-h}", {a\^2 - b\^2 + c\^2 - d\^2 - 
          e\^2 + f\^2 - g\^2 + h\^2, 0, 
        2\ a\ c + 2\ b\ d - 2\ e\ g - 2\ f\ h, 
        2\ b\ c + 2\ a\ d - 2\ f\ g - 2\ e\ h, 0, 
        0, \(-2\)\ c\ e + 2\ d\ f + 2\ a\ g - 2\ b\ h, 0}, 
      "4th Shape is \
(\!\(a\^2\)-\!\(b\^2\)+\!\(c\^2\)-\!\(d\^2\)-\!\(e\^2\)+\!\(f\^2\)-\!\(g\^2\)+\
\!\(h\^2\))^2-(2 a c+2 b d-2 e g-2 f h)^2+(2 b c+2 a d-2 f g-2 e h)^2+(2 c \
e-2 d f-2 a g+2 b h)^2", "\nFactor OK", 
      8235257 - 16384\ a + 10646\ a\^2 + a\^4}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"Conjugate {a,b,c,-d,e,-f,-g,-h}", {a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + 
          f\^2 + g\^2 + h\^2, 2\ a\ b + 2\ c\ d + 2\ e\ f + 2\ g\ h, 
        2\ a\ c - 2\ b\ d + 2\ e\ g - 2\ f\ h, 0, 
        2\ a\ e - 2\ b\ f - 2\ c\ g + 2\ d\ h, 0, 0, 0}, 
      "\n Det    ", \((8235257 - 16384\ a + 10646\ a\^2 + a\^4)\)\^2, 
      "1st Shape is \
(\!\(a\^2\)+\!\(b\^2\)+\!\(c\^2\)+\!\(d\^2\)+\!\(e\^2\)+\!\(f\^2\)+\!\(g\^2\)+\
\!\(h\^2\))^2-(2 a b+2 c d+2 e f+2 g h)^2-(2 a c-2 b d+2 e g-2 f h)^2-(2 a \
e-2 b f-2 c g+2 d h)^2", "\nFactor OK", 
      8235257 - 16384\ a + 10646\ a\^2 + a\^4, 
      "\n\nConjugate {a,-b,-c,-d,e,f,g,-h}", {a\^2 - b\^2 - c\^2 + d\^2 + 
          e\^2 - f\^2 - g\^2 + h\^2, 0, 0, 0, 
        2\ a\ e + 2\ b\ f + 2\ c\ g + 2\ d\ h, 
        2\ b\ e + 2\ a\ f + 2\ d\ g + 2\ c\ h, 
        2\ c\ e - 2\ d\ f + 2\ a\ g - 2\ b\ h, 0}, 
      "2nd Shape is \
(\!\(a\^2\)-\!\(b\^2\)-\!\(c\^2\)+\!\(d\^2\)+\!\(e\^2\)-\!\(f\^2\)-\!\(g\^2\)+\
\!\(h\^2\))^2-(2 a e+2 b f+2 c g+2 d h)^2+(2 b e+2 a f+2 d g+2 c h)^2+(2 c \
e-2 d f+2 a g-2 b h)^2", "\nFactor OK", 
      8235257 - 16384\ a + 10646\ a\^2 + a\^4, 
      "\n\nConjugate {a,-b,c,d,-e,-f,g,-h}", {a\^2 - b\^2 + c\^2 - d\^2 - 
          e\^2 + f\^2 - g\^2 + h\^2, 0, 
        2\ a\ c + 2\ b\ d - 2\ e\ g - 2\ f\ h, 
        2\ b\ c + 2\ a\ d - 2\ f\ g - 2\ e\ h, 0, 
        0, \(-2\)\ c\ e + 2\ d\ f + 2\ a\ g - 2\ b\ h, 0}, 
      "4th Shape is \
(\!\(a\^2\)-\!\(b\^2\)+\!\(c\^2\)-\!\(d\^2\)-\!\(e\^2\)+\!\(f\^2\)-\!\(g\^2\)+\
\!\(h\^2\))^2-(2 a c+2 b d-2 e g-2 f h)^2+(2 b c+2 a d-2 f g-2 e h)^2+(2 c \
e-2 d f-2 a g+2 b h)^2", "\nFactor OK", 
      8235257 - 16384\ a + 10646\ a\^2 + a\^4}\)], "Output",
  PageWidth->WindowWidth,
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.4. Database Plexes, chirality.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tA number of plex vecs (involutions) have been included in the shapes in \
the database. Some only give one of several sizes as functions of plex \
products, others give a different formulation of the shape, which is included \
as a comment in the ",
  StyleBox["sh",
    FontSlant->"Italic"],
  " definition. More work is needed. The following plex conjugate was \
discovered on 8/12/3, and reverses ",
  StyleBox["bc",
    FontSlant->"Italic"],
  " to ",
  StyleBox["cb",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ef",
    FontSlant->"Italic"],
  " to ",
  StyleBox["fe",
    FontSlant->"Italic"],
  "; it gives the two quadratic shapes for C3C2. Other ternary conjugates \
were then found; pairs of elements are interchanged instead of being \
negated."
}], "Text",
  PageWidth->WindowWidth],

Cell["Example F10.  Chiral Plex-conjugate. C3C2.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pr = 
      hoopTimes[{a, b, c, d, e, f}, {a, c, b, d, f, 
          e}, "\<C3C2\>"]\), "\[IndentingNewLine]", 
    \(shh = sh["\<C3C2\>"]; 
    Expand[{pr[\([1]\)] - pr[\([2]\)] + pr[\([4]\)] - pr[\([5]\)] - 
          shh[\([3]\)], 
        pr[\([1]\)] - pr[\([2]\)] - pr[\([4]\)] + pr[\([5]\)] - 
          shh[\([4]\)]}]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2, 
      a\ b + a\ c + b\ c + d\ e + d\ f + e\ f, 
      a\ b + a\ c + b\ c + d\ e + d\ f + e\ f, 2\ a\ d + 2\ b\ e + 2\ c\ f, 
      b\ d + c\ d + a\ e + c\ e + a\ f + b\ f, 
      b\ d + c\ d + a\ e + c\ e + a\ f + b\ f}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["D3 still not sorted:-", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pr = 
      hoopTimes[{a, b, c, d, e, f}, {a, \(-f\), e, \(-d\), 
          c, \(-b\)\ }, "\<D3\>"]\), "\[IndentingNewLine]", 
    \(shh = Expand[sh["\<D3\>"]]\), "\[IndentingNewLine]", 
    \(Factor[{pr[\([1]\)] + pr[\([2]\)] + pr[\([3]\)] + pr[\([4]\)] + 
          pr[\([5]\)] + pr[\([6]\)] - shh[\([3]\)]}]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 + c\^2 - d\^2 + e\^2 - 2\ b\ f, 
      a\ b - b\ c - a\ f + c\ f, \(-b\^2\) + a\ c + a\ e + c\ e - 2\ d\ f, 
      b\ c - b\ e - c\ f + e\ f, 
      a\ c - 2\ b\ d + a\ e + c\ e - f\^2, \(-a\)\ b + b\ e + a\ f - 
        e\ f}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c + d + e + f, a - b + c - d + e - f, 
      a\^2 - b\^2 - a\ c + c\^2 + b\ d - d\^2 - a\ e - c\ e + e\^2 + b\ f + 
        d\ f - f\^2}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({3\ \((a\ c - b\ d + a\ e + c\ e - b\ f - d\ f)\)}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pr = 
      hoopTimes[{a, b, c, d, e, f}, {a, \(-b\), e, \(-f\), 
          c, \(-d\)\ }, "\<D3\>"]\), "\[IndentingNewLine]", 
    \(shh = Expand[sh["\<D3\>"]]\), "\[IndentingNewLine]", 
    \(Factor[{pr[\([1]\)] + pr[\([2]\)] + pr[\([3]\)] + pr[\([4]\)] + 
          pr[\([5]\)] + pr[\([6]\)] - shh[\([3]\)]}]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a\^2 - b\^2 + c\^2 + e\^2 - 2\ d\ f, \(-c\)\ d + d\ e + c\ f - e\ f, 
      a\ c - 2\ b\ d + a\ e + c\ e - f\^2, a\ d - d\ e - a\ f + e\ f, 
      a\ c - d\^2 + a\ e + c\ e - 2\ b\ f, \(-a\)\ d + c\ d + a\ f - 
        c\ f}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c + d + e + f, a - b + c - d + e - f, 
      a\^2 - b\^2 - a\ c + c\^2 + b\ d - d\^2 - a\ e - c\ e + e\^2 + b\ f + 
        d\ f - f\^2}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({3\ \((a\ c - b\ d + a\ e + c\ e - b\ f - d\ f)\)}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sh["\<D3\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c + d + e + f, a - b + c - d + e - f, 
      1\/2\ \((\((a - c)\)\^2 + \((c - e)\)\^2 + \((\(-a\) + e)\)\^2)\) + 
        1\/2\ \((\(-\((b - d)\)\^2\) - \((d - f)\)\^2 - \((\(-b\) + \
f)\)\^2)\)}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.3. Factorization of sums of quasi-group product elements.", \
"Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
Any pair of vectors are factors of the sums of their quasi-group Cayley Table \
product elements:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell["Example F11.  Product factorisation.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f}, {m, \(-n\), o, p, 
            q, \(-r\)}, "\<C3C2\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f)\)\ \((m - n + o + p + q - r)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f}, {m, \(-n\), o, p, 
            q, \(-r\)}, "\<D3\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f)\)\ \((m - n + o + p + q - r)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f}, {m, \(-n\), o, p, 
            q, \(-r\)}, "\<C6an\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f)\)\ \((m - n + o + p + q - r)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e}, {m, \(-n\), o, 
            p - q}, "\<C5n\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e)\)\ \((m - n + o + p - q)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l}, {m, \(-n\), o, 
            p, q, \(-r\), s, t, u, \(-v\), w, x}, "\<C3C4\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f + g + h + i + j + k + l)\)\ \((m - n + o + p + 
          q - r + s + t + u - v + w + x)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l}, {m, \(-n\), o, 
            p, q, \(-r\), s, t, u, \(-v\), w, x}, "\<C3K\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f + g + h + i + j + k + l)\)\ \((m - n + o + p + 
          q - r + s + t + u - v + w + x)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l}, {m, \(-n\), o, 
            p, q, \(-r\), s, t, u, \(-v\), w, x}, "\<Q12\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f + g + h + i + j + k + l)\)\ \((m - n + o + p + 
          q - r + s + t + u - v + w + x)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l}, {m, \(-n\), o, 
            p, q, \(-r\), s, t, u, \(-v\), w, x}, "\<D3C2\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f + g + h + i + j + k + l)\)\ \((m - n + o + p + 
          q - r + s + t + u - v + w + x)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l}, {m, \(-n\), o, 
            p, q, \(-r\), s, t, u, \(-v\), w, x}, "\<A4\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f + g + h + i + j + k + l)\)\ \((m - n + o + p + 
          q - r + s + t + u - v + w + x)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l}, {m, \(-n\), o, 
            p, q, \(-r\), s, t, u, \(-v\), w, x}, "\<Alt12n\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f + g + h + i + j + k + l)\)\ \((m - n + o + p + 
          q - r + s + t + u - v + w + x)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, 
            p}, {a, \(-b\), c, c, e, \(-f\), g, h, i, \(-j\), k, l, q, r, s, 
            t}, "\<Oct\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f + g + h + i + j + k + l + m + n + o + 
          p)\)\ \((a - b + 2\ c + e - f + g + h + i - j + k + l + q + r + s + 
          t)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f}, {m, \(-n\), o, p, 
            q, \(-r\)}, "\<C6n\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a + b + c + d + e + f)\)\ \((m - n + o + p + q - r)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["This is not true for signed tables", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h}, {m, \(-n\), o, p, 
            q, \(-r\), s, t}, "\<O4\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(a\ m + b\ m + c\ m + d\ m + e\ m + f\ m + g\ m + h\ m - a\ n - b\ n - 
      c\ n - d\ n - e\ n - f\ n - g\ n - h\ n + a\ o + b\ o + c\ o + d\ o + 
      e\ o + f\ o + g\ o + h\ o + a\ p + b\ p + c\ p + d\ p + e\ p + f\ p + 
      g\ p + h\ p + a\ q + b\ q + c\ q + d\ q - e\ q - f\ q - g\ q - h\ q - 
      a\ r - b\ r - c\ r - d\ r + e\ r + f\ r + g\ r + h\ r + a\ s + b\ s + 
      c\ s + d\ s - e\ s - f\ s - g\ s - h\ s + a\ t + b\ t + c\ t + d\ t - 
      e\ t - f\ t - g\ t - h\ t\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h}, {m, \(-n\), o, p, 
            q, \(-r\), s, t}, "\<P8\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(a\ m + b\ m + c\ m + d\ m + e\ m + f\ m + g\ m + h\ m - a\ n - 
      b\ n - \[ImaginaryI]\ c\ n + \[ImaginaryI]\ d\ n - e\ n - 
      f\ n - \[ImaginaryI]\ g\ n + \[ImaginaryI]\ h\ n + 
      a\ o - \[ImaginaryI]\ b\ o + c\ o + \[ImaginaryI]\ d\ o + 
      e\ o - \[ImaginaryI]\ f\ o + g\ o + \[ImaginaryI]\ h\ o + 
      a\ p + \[ImaginaryI]\ b\ p - \[ImaginaryI]\ c\ p + d\ p + 
      e\ p + \[ImaginaryI]\ f\ p - \[ImaginaryI]\ g\ p + h\ p + a\ q + b\ q + 
      c\ q + d\ q + e\ q + f\ q + g\ q + h\ q - a\ r - 
      b\ r - \[ImaginaryI]\ c\ r + \[ImaginaryI]\ d\ r - e\ r - 
      f\ r - \[ImaginaryI]\ g\ r + \[ImaginaryI]\ h\ r + 
      a\ s - \[ImaginaryI]\ b\ s + c\ s + \[ImaginaryI]\ d\ s + 
      e\ s - \[ImaginaryI]\ f\ s + g\ s + \[ImaginaryI]\ h\ s + 
      a\ t + \[ImaginaryI]\ b\ t - \[ImaginaryI]\ c\ t + d\ t + 
      e\ t + \[ImaginaryI]\ f\ t - \[ImaginaryI]\ g\ t + h\ t\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      Plus @@ hoopTimes[{a, b, c, d, e, f, g, h, i, j, k, l}, {a, \(-b\), c, 
            c, e, \(-f\), g, h, i, \(-j\), k, l}, "\<C3Qr\>"]]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(a\^2 - b\^2 + 3\ a\ c + b\ c + 2\ c\^2 + a\ d - b\ d + 2\ a\ e + c\ e - 
      d\ e - e\^2 - 2\ b\ f - c\ f + d\ f + f\^2 + 2\ a\ g + 3\ c\ g - d\ g - 
      2\ f\ g - g\^2 + 2\ a\ h + 3\ c\ h - d\ h - 2\ f\ h - 2\ g\ h - h\^2 + 
      2\ a\ i + 3\ c\ i - d\ i - 2\ f\ i - 2\ g\ i - 2\ h\ i - i\^2 - 
      2\ b\ j - c\ j - d\ j - 2\ e\ j + 2\ g\ j + 2\ h\ j + 2\ i\ j + j\^2 + 
      2\ a\ k + c\ k + d\ k + 2\ f\ k - k\^2 + 2\ a\ l + c\ l + d\ l + 
      2\ f\ l - 2\ k\ l - l\^2\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["19. Appendix G. Rotations in various dimensions.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tClassical (Euler) \"rigid rotation\" only occurs in the complex plane \
for 2D, in the imaginary quaternions for 3D, and the imaginary octonions for \
7D. It is implemented (for real or complex vector lists, axes of rotation, \
and angles) by ",
  StyleBox["rotateQOP",
    FontSlant->"Italic"],
  " for the quaternion, octonion, and Pauli-\[Sigma] algebra; the Pauli \
algebra gives the same result as the quaternion algebra, with the direction \
of rotation reversed. Example G1 rotates sets of arbitrary vectors about \
arbitrary axes in each of these algebras, and checks that the effect of \
rotation is additive. (As expected, testing an extension of the procedure to \
the 16-element non-conservative Sedenion algebra did not give additive \
15-dimension rotation.)"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example G1. Rigid rotations in 3 & 7 dimensions.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{"\<Rotation of vec\>", 
      v4\  = {{4. , 6. , 7, \(-1\)}}, "\<\nabout axis  ax =\>", 
      ax = {\(-1. \), 
          9. , \(-3\)}, "\<by \[Pi]/4 using Qr or -\[Pi]/4 using P4 gives the \
same result\>", 
      q1 = rotateQOP[v4, ax = {\(-1. \), 9. , \(-3\)}, \[Pi]/4. , "\<Qr\>"], 
      q1 = rotateQOP[v4, 
          ax = {\(-1. \), 9. , \(-3\)}, \(-\[Pi]\)/
            4. , "\<P4\>"], \[IndentingNewLine]"\<Qr Rotates back \
correctly\>", 
      rotateQOP[q1, ax, \(-\[Pi]\)/4. , "\<Qr\>"] \[Equal] 
        v4, \[IndentingNewLine]"\<\n P4 reverses Qr           \>", 
      rotateQOP[q1, ax, \[Pi]/4. , "\<P4\>"] \[Equal] 
        v4, \[IndentingNewLine]"\<\n A further rotation by .4 gives \>", 
      rotateQOP[q1, 
        ax,  .4, "\<Qr\>"], "\<\nthe same as rotating by \[Pi]/4+.4\>", 
      rotateQOP[v4, 
        ax = {\(-1. \), 9. , \(-3\)}, \[Pi]/4 +  .4, "\<Qr\>"]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"Rotation of vec", {{4.`, 6.`, 7, \(-1\)}}, 
      "\nabout axis  ax =", {\(-1.`\), 9.`, \(-3\)}, 
      "by \[Pi]/4 using Qr or -\[Pi]/4 using P4 gives the same result", \
{{4.000000000000001`, 3.160025099117093`, 8.096168842041752`, 
          3.235164826419561`}}, {{4.`, 4.939023459103737`, 
          5.279421438729568`, \(-5.808076836845873`\)}}, 
      "Qr Rotates back correctly", False, "\n P4 reverses Qr           ", 
      True, "\n A further rotation by .4 gives ", {{4.`, 5.984425242712861`, 
          6.17306095479756`, \(-3.4756255498449393`\)}}, 
      "\nthe same as rotating by \[Pi]/4+.4", {{3.9999999999999996`, 
          0.6784224879601769`, 8.180425161798041`, 
          4.315134656074065`}}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tMany hoops have polar forms that describe rotations, with angles adding on \
multiplication. The simplest is \"Terplex\", based on the C3 group. This \
rotates about the {1,1,1} axis. Example G2 converts {1,2,4} to the C3 polar \
form {7,7,2.42787}. Subtracting \[Pi]/4 and reverting to vector form gives \
the same effect as quaternion rotation of {1,1,2,4} by \[Pi]/4 about {1,1,1}.
\tNote that the Euler procedure is to pre- and post-multiply by a \
half-rotation and its conjugate. Hoop rotation is a single multiplication \
using the full angle.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example G2. Rotations in C3 match Quaternion rotations about {1,1,1}.\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{"\<C3 Polar form of {1,2,4} is\>", 
      toPolar[{1. , 2. , 
          4}, "\<C3\>"], \[IndentingNewLine]"\<\n Rotate by -\[Pi]/4        \
\>", toVector[{7. , 7. , 
          2.42787 - \[Pi]/
              4}, "\<C3\>"], \[IndentingNewLine]"\<\n Qr rotation by \
\[Pi]/4\>", 
      rotateQOP[{{1. , 1. , 2. , 4. }}, {1. , 1. , 1. }, \[Pi]/
          4. , "\<Qr\>"]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"C3 Polar form of {1,2,4} is", {7.`, 7.`, 2.4278682746450277`}, 
      "\n Rotate by -\[Pi]/4        ", {2.2070178372524802`, 
        0.8728879079979885`, 3.920094254749531`}, 
      "\n Qr rotation by \[Pi]/4", {{1.`, 0.5740277108235441`, 
          3.3223759443294067`, 3.103596344847049`}}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tThe hoops O4, Octi, C4C4r, C2D4r, QC2cO8, KiC4r, CL21, CL03 define \
different rotations in 4D; O8, O8a, C4KC2r & C8Kr define different rotations \
in  8D. (Of these, only O4, Octi, C2D4r, CL21, CL03 have ",
  StyleBox["toPol",
    FontSlant->"Italic"],
  " & ",
  StyleBox["toVec",
    FontSlant->"Italic"],
  " in the database.)"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example G3. O4 Rotations.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`A = {2. , 1, 3, 3, 5, 4, 6, 2. }; {"\<A= \>", 
      A, "\<\nPolar A \>", 
      pA = toPolar[
          A, "\<O4\>"], "\<\n Rotated by angles 1,-.1,.2,.3 gives vector\>", 
      vA1 = toVec[
          pA + {0, 1, 0, \(- .1\), 0,  .2, 
              0,  .3}, "\<O4\>"], "\<\n The Rotated Polar is\>", 
      rA = toPolar[
          vA1, "\<O4\>"], "\<\n Radii unchanged, Angles altered correctly\>", 
      Chop[pA - rA]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A= ", {2.`, 1, 3, 3, 5, 4, 6, 2.`}, 
      "\nPolar A ", {10.`, \(-1.2490457723982544`\), 26.`, 
        1.373400766945016`, 10.`, 2.819842099193151`, 370.`, 
        1.0838970949836275`}, 
      "\n Rotated by angles 1,-.1,.2,.3 gives vector", {1.2485505833432229`, \
\(-1.030892671058775`\), 1.2856274853567013`, 2.070899491246533`, 
        5.845053059372548`, 3.7971773208991593`, 6.042741733042781`, 
        3.215430061772869`}, 
      "\n The Rotated Polar is", {10.000000000000004`, \(-0.2490457723982545`\
\), 25.999999999999982`, 1.2734007669450158`, 10.000000000000002`, 
        3.019842099193151`, 370.`, 1.3838970949836276`}, 
      "\n Radii unchanged, Angles altered correctly", {0, \
\(-0.9999999999999999`\), 0, 0.10000000000000009`, 
        0, \(-0.20000000000000018`\), 
        0, \(-0.30000000000000004`\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tThe above are all \"central rotations\" without offsets; all the sizes are \
quadratic. Many loops have \"offset rotations\" in which the shapes include \
linear sizes that displace the centre of rotation from the origin.
\tMixed polar-hypolar rotations can be defined for various hoops; the \
database contains those for C4, P4, C4C2r, C3C2, D3, D4, & Q8. Example 40 \
shows rotation in D3 & C3C2, with two offsets (o & O here) and two related \
angles.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["Example G4. D3, C3C2 Rotations.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{\*"\"\<D3 vector form of {o,O,\!\(p\^2\),\[Phi],\!\(q\
\^2\),\[Psi]} is\>\"", 
      toVec[{o, O, p\^2, \[Phi], 
            q\^2, \[Psi]}, "\<D3\>"] /. \@any_\^2 \[Rule] 
          any, \[IndentingNewLine]"\<\nC3C2 vector form is\n\>", \
\[IndentingNewLine]toVec[{o, O, p\^2, \[Phi], 
            q\^2, \[Psi]}, "\<C3C2\>"] /. \@any_\^2 \[Rule] any}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"D3 vector form of {o,O,\!\(p\^2\),\[Phi],\!\(q\^2\),\[Psi]} is", \
{1\/6\ \((o + O + 4\ p\ Cos[\[Phi]])\), 
        1\/6\ \((\(-o\) + O + 4\ q\ Cos[\[Phi] + \[Psi]])\), 
        1\/6\ \((o + O + 4\ p\ Cos[\(2\ \[Pi]\)\/3 + \[Phi]])\), 
        1\/6\ \((\(-o\) + O + 
              4\ q\ Cos[\(2\ \[Pi]\)\/3 + \[Phi] + \[Psi]])\), 
        1\/6\ \((o + O + 4\ p\ Cos[\(4\ \[Pi]\)\/3 + \[Phi]])\), 
        1\/6\ \((\(-o\) + O + 
              4\ q\ Cos[\(4\ \[Pi]\)\/3 + \[Phi] + \[Psi]])\)}, 
      "\nC3C2 vector form is\n", {1\/6\ \((o + O + 2\ p\ Cos[\[Phi]] + 
              2\ q\ Cos[\[Psi]])\), 
        1\/6\ \((o + O + 2\ p\ Cos[\(2\ \[Pi]\)\/3 + \[Phi]] + 
              2\ q\ Cos[\(2\ \[Pi]\)\/3 + \[Psi]])\), 
        1\/6\ \((o + O + 2\ p\ Cos[\(4\ \[Pi]\)\/3 + \[Phi]] + 
              2\ q\ Cos[\(4\ \[Pi]\)\/3 + \[Psi]])\), 
        1\/6\ \((o - O + 2\ p\ Cos[\[Phi]] - 2\ q\ Cos[\[Psi]])\), 
        1\/6\ \((o - O + 2\ p\ Cos[\(2\ \[Pi]\)\/3 + \[Phi]] - 
              2\ q\ Cos[\(2\ \[Pi]\)\/3 + \[Psi]])\), 
        1\/6\ \((o - O + 2\ p\ Cos[\(4\ \[Pi]\)\/3 + \[Phi]] - 
              2\ q\ Cos[\(4\ \[Pi]\)\/3 + \[Psi]])\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["20. Appendix H. Noncommutative algebras.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\tOctonions are the best-known non-associative algebra; they are \"square \
associative\" or alternative. Their compositions with cyclic groups are also \
alternative and conservative. Because I knew of no other non-associative \
Moufang loops, I conjectured that conservation resulted from the Moufang \
property. On 4/5/6 I obtained the \"Loops\" package (in [6]) and found a list \
of Noncommutative Moufang loops. The database now contains all 12 with fewer \
than 28 elements. Only two (Oct and D4M2, related to split octonions Octi) \
are conservative:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({conservativeQ[D3Mn], conservativeQ[D4M1n], conservativeQ[Oct], 
      conservativeQ[D4M2], conservativeQ[D4M4n], conservativeQ[D4M5n], 
      conservativeQ[D5Mn], conservativeQ[D3C2Mn], conservativeQ[A4Mn], 
      conservativeQ[Q12M3n], conservativeQ[Q12M4n], 
      conservativeQ[Q12M5n]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({False, False, True, True, False, False, False, False, False, False, 
      False, False}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tNoncommutative group determinants such as D3 have repeated factors, \
which are conserved but which only appear once in the inverse denominators. \
In April 2006, I conjectured that a different, noncommutative (NC), \
formulation might yield a new conserved angle. NC versions of ",
  StyleBox["ge & det",
    FontSlant->"Italic"],
  " were developed. No progress has been made with NC powers.\n\tThe next \
example has vectors selected to give prime sizes; as no extra conserved \
values appear, the search for new radius/conserved angle does not look \
promising:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<If A & B are\>", 
      A = {3, 5, 0, 4, 3, 2}, \[IndentingNewLine]B = {7, 5, 1, 5, 3, 
          2}, "\<\n In D3, AB is\>", 
      AB = hoopTimes[A, 
          B, "\<D3\>"], \[IndentingNewLine]"\<\n the factors of Det[A] \
are\>", FactorInteger[
        Det[gmap[D3, 
            A]]], \[IndentingNewLine]"\<\n the factors of Det[B] are\>", \
\[IndentingNewLine]FactorInteger[
        Det[gmap[D3, 
            B]]], \[IndentingNewLine]"\<\n the factors of Det[AB] are\>", \
\[IndentingNewLine]FactorInteger[\(-Det[
            gmap[D3, 
              AB]]\)], \[IndentingNewLine]"\<\nThe shapes of A & B are\>", 
      shape[A], \[IndentingNewLine]shape[
        B], "\<\nand the shape of AB has factors\>", \ \
\[IndentingNewLine]FactorInteger[shape[AB]]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"If A & B are", {3, 5, 0, 4, 3, 2}, {7, 5, 1, 5, 3, 2}, 
      "\n In D3, AB is", {73, 75, 52, 66, 73, 52}, 
      "\n the factors of Det[A] are", {{2, 2}, {5, 1}, {17, 1}}, 
      "\n the factors of Det[B] are", {{19, 2}, {23, 1}}, 
      "\n the factors of Det[AB] are", {{2, 2}, {5, 1}, {17, 1}, {19, 
          2}, {23, 1}}, 
      "\nThe shapes of A & B are", {17, \(-5\), 2}, {23, \(-1\), 19}, 
      "\nand the shape of AB has factors", {{{17, 1}, {23, 1}}, {{5, 
            1}}, {{2, 1}, {19, 1}}}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "The quadratic is squared, giving repeated factors (2,2) in A, (19,2) in B. \
The inverse only involves the unsquared quadratic, with the divisor being \
23*1*19, not 23*1*",
  Cell[BoxData[
      \(TraditionalForm\`19\^2\)]],
  ". It does not use the ordinary partial-fraction formulation for repeated \
factors, but confirms the generality of the specific partial fraction \
formulation used in ",
  StyleBox["hoopIn",
    FontSlant->"Italic"],
  StyleBox["verse",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(hoopInverse[B]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({7\/437, 53\/437, \(-\(85\/437\)\), 53\/437, \(-\(131\/437\)\), 
      122\/437}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
As the quadratic is a repeated factor that involves three positive and three \
negative squared fragments, the pseudo-polar form is expressed as:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(toPolar[{a, b, c, d, e, f}]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c + d + e + f, 
      a - b + c - d + e - 
        f, \(1\/2\) \((\((a - c)\)\^2 + \((a - e)\)\^2 + \((c - e)\)\^2)\) + \
\(1\/2\) \((\(\(-\)\(\ \)\) \((b - d)\)\^2 - \((b - f)\)\^2 - \((d - f)\)\^2)\
\), ArcTan[
        2  a - c - 
          e, \(3\^\(1\/2\)\) \((\(\(-\)\(\ \)\) c + 
              e)\)], \(1\/2\) \((\((a - c)\)\^2 + \((a - e)\)\^2 + \((c - \
e)\)\^2)\), 
      ArcTan[2  b - d - 
          f, \(3\^\(1\/2\)\) \((\(\(-\)\(\ \)\) d + f)\)]}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
with two three-phase systems. The conserved size has to be split into two \
components, neither of which are conserved. \
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({toPolar[A], toPolar[B], toPolar[AB]} // N\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{17.`, \(-5.`\), 2.`, 1.0471975511965976`, 
        9.`, \(-0.7137243789447656`\)}, {23.`, \(-1.`\), 19.`, 
        0.3334731722518321`, 28.`, \(-1.0471975511965976`\)}, {391.`, 5.`, 
        38.`, 1.0471975511965976`, 
        441.`, \(-0.6484568061226152`\)}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
Curiosity - angles of \[Pi]/3?? Specific to the chosen vectors; others give \
general angles:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(AB = 
      hoopTimes[\((A = {1, \(-2\), 4, 3, 7, 0})\), \((B = {\(-3\), 9, 1, 5, 
              3, 4})\), "\<D3\>"]\), "\[IndentingNewLine]", 
    \(FactorInteger[Det[gmap[D3, A]]]\), "\[IndentingNewLine]", 
    \(FactorInteger[Det[gmap[D3, B]]]\), "\[IndentingNewLine]", 
    \(FactorInteger[Det[gmap[D3, AB]]]\), "\[IndentingNewLine]", 
    \(shape[A]\), "\[IndentingNewLine]", 
    \(shape[B]\), "\[IndentingNewLine]", 
    \(shape[AB]\), "\[IndentingNewLine]", 
    \(FactorInteger[%]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({13, 69, 29, 54, \(-12\), 94}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{\(-1\), 1}, {2, 6}, {11, 1}, {13, 1}}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{7, 2}, {17, 1}, {19, 1}}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{2, 6}, {7, 2}, {11, 1}, {13, 1}, {17, 1}, {19, 1}}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({13, 11, 8}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({19, \(-17\), 7}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({247, \(-187\), 56}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{{13, 1}, {19, 1}}, {{\(-1\), 1}, {11, 1}, {17, 1}}, {{2, 3}, {7, 
          1}}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({toPolar[A], toPolar[B], toPolar[AB]} // N\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{13.`, 11.`, 8.`, 2.6179938779914944`, 
        27.`, \(-2.5030329574907877`\)}, {19.`, \(-17.`\), 7.`, 
        2.808119481337961`, 
        28.`, \(-0.19012560334646675`\)}, {247.`, \(-187.`\), 
        56.`, \(-1.444732972701484`\), 1281.`, 
        1.714143895700262`}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["21. References.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "1. S Wolfram, The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Book, CUP, 1999."
}], "EndNote",
  PageWidth->WindowWidth,
  CellTags->"MT2"],

Cell["\<\
2. J.D.H. Smith, A.B. Romanowska, Post-Modern Algebra, Wiley Interscience \
1999.\
\>", "EndNote",
  PageWidth->WindowWidth,
  CellTags->"MT2"],

Cell["\<\
3. P. Lounesto, Clifford Algebras & Spinors 2nd ed., Cambridge University \
Press 2001.\
\>", "EndNote",
  PageWidth->WindowWidth,
  CellTags->"MT2"],

Cell[TextData[{
  "4. G. ",
  StyleBox["Frobenius, Uber die Primfactoren der Gruppendeterminante, \
Sitzungsber.Preuss. Akad. Wiss. Berlin Phys. Math,KL. 1896,(985-1021) (not \
seen, but quoted from Ref[10 p236].)", "RefAuthorFN"]
}], "EndNote",
  PageWidth->WindowWidth,
  CellTags->"MT2"],

Cell[TextData[{
  StyleBox["5. ", "RefAuthorFN"],
  "http://library.wolfram.com/infocenter/MathSource/4894 R.H.Beresford \
2003-5."
}], "EndNote",
  PageWidth->WindowWidth,
  CellTags->"CT"],

Cell["\<\
6. [GAP99] The Gap Group. GAP --- Groups, Algorithms, and Programming, \
Version 4.4.7;  St Andrews, 2006. (http://www.gap-system.org) \
\>", "EndNote",
  PageWidth->WindowWidth,
  CellTags->"FV"],

Cell["\<\
7. C. M. Davenport 2000, http://home.usit.net/~cmdaven/hyprcplex.htm\
\>", "EndNote",
  PageWidth->WindowWidth,
  CellTags->"MT2"],

Cell[TextData[{
  "8. H.-D. Ebbinghaus et al, Numbers, Springer-Verlag N.Y. ",
  StyleBox["1991.", "RefAuthorFN"]
}], "EndNote",
  PageWidth->WindowWidth,
  CellTags->"MT2"],

Cell[TextData[{
  StyleBox["9.", "RefAuthorFN"],
  " J.J.Hamilton, Hypercomplex numbers and the description of spin states, \
J.Math.Phys. ",
  StyleBox["38",
    FontWeight->"Bold"],
  "(10) Oct. 1997. pp4914-4928"
}], "EndNote",
  PageWidth->WindowWidth,
  CellTags->"MT2"],

Cell["\<\
10. B. L. van der Waerden, A History of Algebra, Chapter 12. Springer 1985\
\>", "EndNote",
  PageWidth->WindowWidth,
  CellTags->"MT2"],

Cell["11. John McKay, Sci.Math.Symbolic, 2/2/2002", "EndNote",
  PageWidth->WindowWidth,
  CellTags->"MT2"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{766, 543},
WindowMargins->{{57, Automatic}, {Automatic, 34}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "5/7/2006"]], Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}},
PageHeaderLines->{Inherited, False},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3368012412-9805623"->{
    Cell[145464, 3700, 1182, 16, 392, "Print",
      CellTags->"Info3368012412-9805623"]},
  "Info3368012496-7335081"->{
    Cell[147480, 3749, 402, 6, 137, "Print",
      CellTags->"Info3368012496-7335081"]},
  "Info3368012496-1829508"->{
    Cell[147885, 3757, 590, 9, 188, "Print",
      CellTags->"Info3368012496-1829508"]},
  "Info3368012554-3458326"->{
    Cell[149830, 3821, 378, 6, 111, "Print",
      CellTags->"Info3368012554-3458326"]},
  "Info3368026555-3164607"->{
    Cell[246749, 6159, 255, 4, 86, "Print",
      CellTags->"Info3368026555-3164607"]},
  "Info3362457282-3716175"->{
    Cell[317347, 7776, 275, 5, 86, "Print",
      CellTags->"Info3362457282-3716175"]},
  "Info3362457286-9933190"->{
    Cell[317732, 7790, 271, 5, 86, "Print",
      CellTags->"Info3362457286-9933190"]},
  "Info3308460589-1429071"->{
    Cell[742398, 17366, 354, 6, 69, "Print",
      CellTags->"Info3308460589-1429071"],
    Cell[742755, 17374, 859, 22, 69, "Print",
      CellTags->"Info3308460589-1429071"]},
  "Info3368192290-2639046"->{
    Cell[931906, 20747, 568, 8, 188, "Print",
      CellTags->"Info3368192290-2639046"]},
  "MT2"->{
    Cell[1242237, 28409, 173, 7, 34, "EndNote",
      CellTags->"MT2"],
    Cell[1242413, 28418, 153, 5, 34, "EndNote",
      CellTags->"MT2"],
    Cell[1242569, 28425, 159, 5, 34, "EndNote",
      CellTags->"MT2"],
    Cell[1242731, 28432, 290, 7, 56, "EndNote",
      CellTags->"MT2"],
    Cell[1243426, 28456, 140, 4, 34, "EndNote",
      CellTags->"MT2"],
    Cell[1243569, 28462, 173, 5, 34, "EndNote",
      CellTags->"MT2"],
    Cell[1243745, 28469, 275, 9, 56, "EndNote",
      CellTags->"MT2"],
    Cell[1244023, 28480, 146, 4, 34, "EndNote",
      CellTags->"MT2"],
    Cell[1244172, 28486, 107, 2, 34, "EndNote",
      CellTags->"MT2"]},
  "CT"->{
    Cell[1243024, 28441, 190, 6, 34, "EndNote",
      CellTags->"CT"]},
  "FV"->{
    Cell[1243217, 28449, 206, 5, 56, "EndNote",
      CellTags->"FV"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3368012412-9805623", 1245408, 28520},
  {"Info3368012496-7335081", 1245529, 28523},
  {"Info3368012496-1829508", 1245648, 28526},
  {"Info3368012554-3458326", 1245767, 28529},
  {"Info3368026555-3164607", 1245886, 28532},
  {"Info3362457282-3716175", 1246004, 28535},
  {"Info3362457286-9933190", 1246122, 28538},
  {"Info3308460589-1429071", 1246240, 28541},
  {"Info3368192290-2639046", 1246448, 28546},
  {"MT2", 1246549, 28549},
  {"CT", 1247208, 28568},
  {"FV", 1247290, 28571}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 251, 8, 330, "Title"],
Cell[2030, 63, 194, 6, 138, "Subtitle"],
Cell[2227, 71, 129, 2, 77, "Subsubtitle"],
Cell[2359, 75, 163, 5, 47, "Text"],
Cell[2525, 82, 726, 11, 203, "Text"],
Cell[3254, 95, 1028, 26, 177, "Text"],
Cell[4285, 123, 4876, 93, 1139, "Text"],

Cell[CellGroupData[{
Cell[9186, 220, 186, 6, 86, "Section"],

Cell[CellGroupData[{
Cell[9397, 230, 94, 2, 67, "Subsection"],
Cell[9494, 234, 3348, 59, 664, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12879, 298, 211, 5, 67, "Subsection"],
Cell[13093, 305, 3727, 106, 516, "Text"],
Cell[16823, 413, 7570, 185, 1086, "Text"],
Cell[24396, 600, 256, 9, 70, "Text"],
Cell[24655, 611, 81914, 2072, 356, "Text"],
Cell[106572, 2685, 3314, 72, 590, "Text"],
Cell[109889, 2759, 2442, 48, 392, "Text"],
Cell[112334, 2809, 3149, 72, 540, "Text"],
Cell[115486, 2883, 882, 20, 144, "Text"],
Cell[116371, 2905, 837, 18, 170, "Text"],
Cell[117211, 2925, 1082, 28, 170, "Text"],
Cell[118296, 2955, 1197, 32, 195, "Text"],
Cell[119496, 2989, 2406, 48, 417, "Text"],
Cell[121905, 3039, 649, 10, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122591, 3054, 106, 2, 67, "Subsection"],
Cell[122700, 3058, 4472, 140, 541, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[127221, 3204, 196, 4, 85, "Section"],
Cell[127420, 3210, 707, 15, 144, "Text"],
Cell[128130, 3227, 483, 14, 95, "Text"],
Cell[128616, 3243, 56, 1, 40, "Input"],
Cell[128675, 3246, 76, 2, 41, "Input"],
Cell[128754, 3250, 1553, 32, 293, "Text"],
Cell[130310, 3284, 1245, 20, 268, "Text"],
Cell[131558, 3306, 1640, 39, 293, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133235, 3350, 127, 2, 85, "Section"],
Cell[133365, 3354, 641, 12, 144, "Text"],

Cell[CellGroupData[{
Cell[134031, 3370, 138, 2, 67, "Subsection"],
Cell[134172, 3374, 5118, 138, 739, "Text"],
Cell[139293, 3514, 89, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[139407, 3520, 467, 11, 28, "Input",
  CellOpen->False],
Cell[139877, 3533, 2327, 60, 454, "Output"]
}, Open  ]],
Cell[142219, 3596, 462, 15, 70, "Text"],
Cell[142684, 3613, 115, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[142824, 3619, 385, 9, 28, "Input",
  CellOpen->False],
Cell[143212, 3630, 1277, 32, 243, "Output"]
}, Open  ]],
Cell[144504, 3665, 757, 23, 120, "Text"],
Cell[145264, 3690, 126, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[145415, 3697, 46, 1, 39, "Input"],
Cell[145464, 3700, 1182, 16, 392, "Print",
  CellTags->"Info3368012412-9805623"]
}, Open  ]],
Cell[146661, 3719, 391, 9, 95, "Text"],
Cell[147055, 3730, 136, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[147216, 3737, 191, 7, 28, "Input",
  CellOpen->False],
Cell[147410, 3746, 67, 1, 41, "Output"],
Cell[147480, 3749, 402, 6, 137, "Print",
  CellTags->"Info3368012496-7335081"],
Cell[147885, 3757, 590, 9, 188, "Print",
  CellTags->"Info3368012496-1829508"]
}, Open  ]],
Cell[148490, 3769, 245, 10, 45, "Text"],
Cell[148738, 3781, 397, 9, 95, "Text"],
Cell[149138, 3792, 206, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[149369, 3802, 105, 5, 28, "Input",
  CellOpen->False],
Cell[149477, 3809, 305, 7, 35, "Print"],
Cell[149785, 3818, 42, 1, 41, "Output"],
Cell[149830, 3821, 378, 6, 111, "Print",
  CellTags->"Info3368012554-3458326"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[150257, 3833, 109, 2, 67, "Subsection"],
Cell[150369, 3837, 447, 8, 120, "Text"],

Cell[CellGroupData[{
Cell[150841, 3849, 185, 7, 61, "Subsubsection"],
Cell[151029, 3858, 809, 24, 120, "Text"],
Cell[151841, 3884, 414, 10, 92, "Input",
  Evaluatable->False],
Cell[152258, 3896, 188, 7, 46, "Text"],

Cell[CellGroupData[{
Cell[152471, 3907, 381, 8, 28, "Input",
  CellOpen->False],
Cell[152855, 3917, 1430, 34, 152, "Output"]
}, Open  ]],
Cell[154300, 3954, 384, 12, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[154721, 3971, 186, 7, 61, "Subsubsection"],
Cell[154910, 3980, 658, 18, 95, "Text"],
Cell[155571, 4000, 1900, 38, 423, "Input",
  Evaluatable->False],
Cell[157474, 4040, 544, 19, 95, "Text"],
Cell[158021, 4061, 189, 7, 46, "Text"],

Cell[CellGroupData[{
Cell[158235, 4072, 2369, 48, 28, "Input",
  CellOpen->False],
Cell[160607, 4122, 6096, 116, 817, "Output"]
}, Open  ]],
Cell[166718, 4241, 168, 4, 45, "Text"],
Cell[166889, 4247, 189, 7, 46, "Text"],

Cell[CellGroupData[{
Cell[167103, 4258, 2545, 50, 28, "Input",
  CellOpen->False],
Cell[169651, 4310, 3786, 63, 270, "Output"]
}, Open  ]],
Cell[173452, 4376, 715, 15, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174204, 4396, 192, 7, 61, "Subsubsection"],
Cell[174399, 4405, 715, 15, 144, "Text"],
Cell[175117, 4422, 2024, 42, 272, "Input",
  Evaluatable->False],
Cell[177144, 4466, 485, 11, 95, "Text"],
Cell[177632, 4479, 183, 7, 46, "Text"],

Cell[CellGroupData[{
Cell[177840, 4490, 945, 20, 28, "Input",
  CellOpen->False],
Cell[178788, 4512, 9761, 238, 672, "Output"]
}, Open  ]],
Cell[188564, 4753, 145, 3, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[188746, 4761, 187, 7, 61, "Subsubsection"],
Cell[188936, 4770, 2178, 65, 268, "Text"],
Cell[191117, 4837, 2740, 50, 678, "Input",
  Evaluatable->False],
Cell[193860, 4889, 1408, 41, 194, "Text"],
Cell[195271, 4932, 178, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[195474, 4941, 1359, 30, 28, "Input",
  CellOpen->False],
Cell[196836, 4973, 2963, 56, 402, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[199848, 5035, 187, 7, 61, "Subsubsection"],
Cell[200038, 5044, 905, 17, 194, "Text"],
Cell[200946, 5063, 116, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[201087, 5069, 3838, 73, 28, "Input",
  CellOpen->False],
Cell[204928, 5144, 2588, 46, 296, "Output"]
}, Open  ]],
Cell[207531, 5193, 286, 6, 43, "Text"],

Cell[CellGroupData[{
Cell[207842, 5203, 2558, 59, 28, "Input",
  CellOpen->False],
Cell[210403, 5264, 1289, 23, 143, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[211741, 5293, 184, 6, 61, "Subsubsection"],
Cell[211928, 5301, 708, 11, 169, "Text"],
Cell[212639, 5314, 706, 16, 144, "Text"],
Cell[213348, 5332, 120, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[213493, 5338, 312, 7, 28, "Input",
  CellOpen->False],
Cell[213808, 5347, 3052, 81, 242, "Output"]
}, Open  ]],
Cell[216875, 5431, 948, 26, 144, "Text"],
Cell[217826, 5459, 140, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[217991, 5467, 317, 6, 117, "Input"],
Cell[218311, 5475, 1669, 35, 392, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[220029, 5516, 166, 4, 60, "Subsubsection"],
Cell[220198, 5522, 928, 22, 169, "Text"],
Cell[221129, 5546, 108, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[221262, 5552, 480, 10, 28, "Input",
  CellOpen->False],
Cell[221745, 5564, 2076, 38, 595, "Output"]
}, Open  ]],
Cell[223836, 5605, 829, 17, 169, "Text"],
Cell[224668, 5624, 109, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[224802, 5630, 1503, 27, 28, "Input",
  CellOpen->False],
Cell[226308, 5659, 863, 16, 474, "Output"]
}, Open  ]],
Cell[227186, 5678, 233, 5, 70, "Text"],
Cell[227422, 5685, 958, 17, 219, "Text"],
Cell[228383, 5704, 101, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[228509, 5710, 1433, 28, 28, "Input",
  CellOpen->False],
Cell[229945, 5740, 784, 14, 372, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[230790, 5761, 119, 2, 67, "Subsection"],
Cell[230912, 5765, 1722, 49, 244, "Text"],
Cell[232637, 5816, 111, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[232773, 5822, 654, 14, 28, "Input",
  CellOpen->False],
Cell[233430, 5838, 684, 13, 270, "Output"]
}, Open  ]],
Cell[234129, 5854, 1045, 26, 194, "Text"],
Cell[235177, 5882, 123, 3, 45, "Text",
  Evaluatable->False],
Cell[235303, 5887, 6836, 143, 997, "Input",
  Evaluatable->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[242188, 6036, 131, 2, 85, "Section"],
Cell[242322, 6040, 782, 14, 169, "Text"],

Cell[CellGroupData[{
Cell[243129, 6058, 111, 2, 67, "Subsection"],
Cell[243243, 6062, 929, 20, 169, "Text"],
Cell[244175, 6084, 727, 19, 120, "Text"],
Cell[244905, 6105, 115, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[245045, 6111, 411, 9, 28, "Input",
  CellOpen->False],
Cell[245459, 6122, 1198, 29, 257, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[246694, 6156, 52, 1, 39, "Input"],
Cell[246749, 6159, 255, 4, 86, "Print",
  CellTags->"Info3368026555-3164607"]
}, Open  ]],
Cell[247019, 6166, 1286, 30, 243, "Text"],
Cell[248308, 6198, 112, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[248445, 6204, 157, 5, 83, "Input"],
Cell[248605, 6211, 1388, 21, 234, "Output"],
Cell[249996, 6234, 884, 14, 183, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[250917, 6253, 135, 4, 61, "Input"],
Cell[251055, 6259, 292, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[251384, 6269, 137, 4, 61, "Input"],
Cell[251524, 6275, 292, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[251853, 6285, 139, 4, 61, "Input"],
Cell[251995, 6291, 288, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[252320, 6301, 175, 5, 83, "Input"],
Cell[252498, 6308, 1199, 17, 199, "Output"],
Cell[253700, 6327, 670, 10, 201, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254407, 6342, 206, 5, 83, "Input"],
Cell[254616, 6349, 630, 10, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[255283, 6364, 206, 5, 83, "Input"],
Cell[255492, 6371, 757, 13, 106, "Output"]
}, Open  ]],
Cell[256264, 6387, 631, 15, 120, "Text"],
Cell[256898, 6404, 109, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[257032, 6410, 357, 8, 28, "Input",
  CellOpen->False],
Cell[257392, 6420, 471, 9, 168, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[257912, 6435, 104, 2, 67, "Subsection"],
Cell[258019, 6439, 2011, 30, 441, "Text"],
Cell[260033, 6471, 107, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[260165, 6477, 4315, 116, 28, "Input",
  CellOpen->False],
Cell[264483, 6595, 6665, 115, 1762, "Output"]
}, Open  ]],
Cell[271163, 6713, 345, 6, 95, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271545, 6724, 250, 10, 67, "Subsection"],
Cell[271798, 6736, 775, 13, 169, "Text"],
Cell[272576, 6751, 442, 10, 95, "Text"],
Cell[273021, 6763, 524, 9, 120, "Text"],
Cell[273548, 6774, 533, 9, 120, "Text"],
Cell[274084, 6785, 929, 15, 194, "Text"],
Cell[275016, 6802, 702, 16, 144, "Text"],
Cell[275721, 6820, 710, 15, 169, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[276468, 6840, 130, 2, 67, "Subsection"],
Cell[276601, 6844, 803, 20, 144, "Text"],
Cell[277407, 6866, 99, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[277531, 6872, 3547, 80, 28, "Input",
  CellOpen->False],
Cell[281081, 6954, 4363, 77, 359, "Output"]
}, Open  ]],
Cell[285459, 7034, 1314, 26, 243, "Text"],
Cell[286776, 7062, 112, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[286913, 7068, 387, 12, 28, "Input",
  CellOpen->False],
Cell[287303, 7082, 2108, 41, 474, "Output"]
}, Open  ]],
Cell[289426, 7126, 389, 7, 95, "Text"],
Cell[289818, 7135, 319, 6, 95, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[290186, 7147, 99, 2, 85, "Section"],
Cell[290288, 7151, 1554, 37, 169, "Text"],

Cell[CellGroupData[{
Cell[291867, 7192, 127, 2, 67, "Subsection"],
Cell[291997, 7196, 2582, 46, 417, "Text"],
Cell[294582, 7244, 94, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[294701, 7250, 1506, 27, 168, "Input"],
Cell[296210, 7279, 2707, 44, 480, "Output"]
}, Open  ]],
Cell[298932, 7326, 623, 15, 95, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[299592, 7346, 122, 2, 67, "Subsection"],
Cell[299717, 7350, 1014, 30, 144, "Text"],
Cell[300734, 7382, 413, 11, 95, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[301184, 7398, 133, 2, 67, "Subsection"],
Cell[301320, 7402, 356, 7, 95, "Text"],
Cell[301679, 7411, 123, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[301827, 7417, 2093, 43, 28, "Input",
  CellOpen->False],
Cell[303923, 7462, 5183, 96, 303, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[309155, 7564, 121, 2, 67, "Subsection"],
Cell[309279, 7568, 892, 20, 169, "Text"],

Cell[CellGroupData[{
Cell[310196, 7592, 129, 3, 60, "Subsubsection"],

Cell[CellGroupData[{
Cell[310350, 7599, 1047, 17, 28, "Input",
  CellOpen->False],
Cell[311400, 7618, 2843, 61, 555, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[314304, 7686, 136, 2, 67, "Subsection"],
Cell[314443, 7690, 2710, 74, 300, "Text"],
Cell[317156, 7766, 93, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[317274, 7772, 70, 2, 41, "Input"],
Cell[317347, 7776, 275, 5, 86, "Print",
  CellTags->"Info3362457282-3716175"]
}, Open  ]],

Cell[CellGroupData[{
Cell[317659, 7786, 70, 2, 41, "Input"],
Cell[317732, 7790, 271, 5, 86, "Print",
  CellTags->"Info3362457286-9933190"]
}, Open  ]],
Cell[318018, 7798, 376, 13, 70, "Text"],
Cell[318397, 7813, 96, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[318518, 7819, 251, 6, 28, "Input",
  CellOpen->False],
Cell[318772, 7827, 65033, 1302, 279, 10657, 625, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[383820, 9132, 106, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[383951, 9138, 256, 6, 28, "Input",
  CellOpen->False],
Cell[384210, 9146, 87907, 1554, 279, 10241, 590, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[472132, 10703, 1096, 35, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[473265, 10743, 127, 2, 67, "Subsection"],
Cell[473395, 10747, 2396, 81, 248, "Text"],
Cell[475794, 10830, 1656, 31, 318, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[477499, 10867, 95, 2, 85, "Section"],
Cell[477597, 10871, 712, 13, 144, "Text"],

Cell[CellGroupData[{
Cell[478334, 10888, 191, 7, 67, "Subsection"],
Cell[478528, 10897, 410, 7, 95, "Text"],
Cell[478941, 10906, 523, 9, 120, "Text"],
Cell[479467, 10917, 141, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[479633, 10925, 1184, 26, 28, "Input",
  CellOpen->False],
Cell[480820, 10953, 1830, 33, 111, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[482687, 10991, 1384, 27, 28, "Input",
  CellOpen->False],
Cell[484074, 11020, 1499, 28, 170, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[485622, 11054, 196, 7, 67, "Subsection"],
Cell[485821, 11063, 2542, 75, 318, "Text"],

Cell[CellGroupData[{
Cell[488388, 11142, 115, 2, 60, "Subsubsection"],
Cell[488506, 11146, 150, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[488681, 11155, 427, 8, 28, "Input",
  CellOpen->False],
Cell[489111, 11165, 517, 9, 178, "Output"]
}, Open  ]],
Cell[489643, 11177, 340, 6, 95, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[490020, 11188, 115, 2, 60, "Subsubsection"],
Cell[490138, 11192, 2305, 61, 318, "Text"],
Cell[492446, 11255, 138, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[492609, 11263, 924, 18, 28, "Input",
  Evaluatable->False,
  CellOpen->False],
Cell[493536, 11283, 380, 7, 125, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[493953, 11295, 2233, 43, 207, "Input",
  Evaluatable->False],
Cell[496189, 11340, 91, 2, 41, "Output"]
}, Open  ]],
Cell[496295, 11345, 2009, 40, 207, "Input",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[498341, 11390, 145, 3, 60, "Subsubsection"],
Cell[498489, 11395, 2177, 57, 272, "Text"],
Cell[500669, 11454, 89, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[500783, 11459, 684, 13, 28, "Input",
  CellOpen->False],
Cell[501470, 11474, 1256, 23, 300, "Output"]
}, Open  ]],
Cell[502741, 11500, 119, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[502885, 11507, 719, 15, 28, "Input",
  CellOpen->False],
Cell[503607, 11524, 1280, 23, 274, "Output"]
}, Open  ]],
Cell[504902, 11550, 990, 25, 144, "Text"],
Cell[505895, 11577, 91, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[506011, 11582, 997, 20, 28, "Input",
  CellOpen->False],
Cell[507011, 11604, 2728, 48, 321, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[509788, 11658, 155, 4, 60, "Subsubsection"],
Cell[509946, 11664, 1155, 23, 268, "Text"],
Cell[511104, 11689, 133, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[511262, 11697, 215, 5, 28, "Input",
  CellOpen->False],
Cell[511480, 11704, 209, 4, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[511726, 11713, 1022, 23, 28, "Input",
  CellOpen->False],
Cell[512751, 11738, 1091, 21, 215, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[513903, 11766, 132, 2, 67, "Subsection"],
Cell[514038, 11770, 1858, 41, 318, "Text"],
Cell[515899, 11813, 161, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[516085, 11822, 595, 12, 28, "Input",
  CellOpen->False],
Cell[516683, 11836, 1629, 30, 442, "Output"]
}, Open  ]],
Cell[518327, 11869, 341, 6, 95, "Text"],
Cell[518671, 11877, 119, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[518815, 11883, 1364, 29, 28, "Input",
  CellOpen->False],
Cell[520182, 11914, 5233, 105, 960, "Output"]
}, Open  ]],
Cell[525430, 12022, 165, 4, 45, "Text"],
Cell[525598, 12028, 108, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[525731, 12034, 1337, 30, 28, "Input",
  CellOpen->False],
Cell[527071, 12066, 3775, 81, 1024, "Output"]
}, Open  ]],
Cell[530861, 12150, 584, 11, 120, "Text"],
Cell[531448, 12163, 2461, 57, 417, "Text"],
Cell[533912, 12222, 214, 9, 46, "Text"],

Cell[CellGroupData[{
Cell[534151, 12235, 1439, 28, 28, "Input",
  CellOpen->False],
Cell[535593, 12265, 2706, 42, 827, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[538348, 12313, 269, 10, 67, "Subsection"],
Cell[538620, 12325, 504, 9, 120, "Text"],
Cell[539127, 12336, 114, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[539266, 12342, 595, 11, 28, "Input",
  CellOpen->False],
Cell[539864, 12355, 534, 9, 270, "Output"]
}, Open  ]],
Cell[540413, 12367, 2056, 40, 367, "Text"],

Cell[CellGroupData[{
Cell[542494, 12411, 3248, 65, 28, "Input",
  CellOpen->False],
Cell[545745, 12478, 3468, 60, 429, "Output"]
}, Open  ]],
Cell[549228, 12541, 1219, 28, 219, "Text"],
Cell[550450, 12571, 542, 13, 120, "Text"],
Cell[550995, 12586, 185, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[551205, 12596, 8101, 160, 28, "Input",
  CellOpen->False],
Cell[559309, 12758, 11964, 197, 602, "Output"]
}, Open  ]],
Cell[571288, 12958, 481, 8, 120, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[571806, 12971, 116, 2, 67, "Subsection"],
Cell[571925, 12975, 1204, 23, 219, "Text"],
Cell[573132, 13000, 156, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[573313, 13010, 1962, 36, 28, "Input",
  CellOpen->False],
Cell[575278, 13048, 2681, 49, 381, "Output"]
}, Open  ]],
Cell[577974, 13100, 116, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[578115, 13108, 496, 11, 28, "Input",
  CellOpen->False],
Cell[578614, 13121, 1033, 18, 91, "Output"]
}, Open  ]],
Cell[579662, 13142, 960, 17, 194, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[580671, 13165, 105, 2, 85, "Section"],
Cell[580779, 13169, 224, 7, 45, "Text"],

Cell[CellGroupData[{
Cell[581028, 13180, 131, 2, 67, "Subsection"],
Cell[581162, 13184, 899, 14, 194, "Text"],
Cell[582064, 13200, 1256, 19, 169, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[583357, 13224, 114, 2, 67, "Subsection"],
Cell[583474, 13228, 370, 7, 95, "Text"],
Cell[583847, 13237, 169, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[584041, 13247, 144, 3, 40, "Input"],
Cell[584188, 13252, 107, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[584332, 13259, 176, 3, 40, "Input"],
Cell[584511, 13264, 200, 4, 41, "Output"]
}, Open  ]],
Cell[584726, 13271, 1173, 32, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[585936, 13308, 151, 4, 67, "Subsection"],
Cell[586090, 13314, 153, 4, 45, "Text"],
Cell[586246, 13320, 1097, 30, 169, "Text"],
Cell[587346, 13352, 178, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[587549, 13362, 297, 5, 65, "Input"],
Cell[587849, 13369, 107, 2, 41, "Output"],
Cell[587959, 13373, 200, 4, 41, "Output"]
}, Open  ]],
Cell[588174, 13380, 177, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[588376, 13390, 297, 5, 65, "Input"],
Cell[588676, 13397, 102, 2, 41, "Output"],
Cell[588781, 13401, 195, 4, 41, "Output"]
}, Open  ]],
Cell[588991, 13408, 689, 14, 144, "Text"],
Cell[589683, 13424, 175, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[589883, 13434, 677, 14, 92, "Input"],
Cell[590563, 13450, 312, 5, 66, "Output"],
Cell[590878, 13457, 324, 5, 66, "Output"],
Cell[591205, 13464, 324, 5, 66, "Output"]
}, Open  ]],
Cell[591544, 13472, 374, 7, 95, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[591955, 13484, 103, 2, 67, "Subsection"],
Cell[592061, 13488, 267, 5, 70, "Text"],
Cell[592331, 13495, 436, 9, 95, "Text"],

Cell[CellGroupData[{
Cell[592792, 13508, 398, 8, 28, "Input",
  CellOpen->False],
Cell[593193, 13518, 1011, 17, 302, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[594243, 13540, 105, 2, 85, "Section"],

Cell[CellGroupData[{
Cell[594373, 13546, 88, 2, 85, "Section"],
Cell[594464, 13550, 432, 9, 95, "Text"],

Cell[CellGroupData[{
Cell[594921, 13563, 126, 2, 67, "Subsection"],
Cell[595050, 13567, 1713, 34, 318, "Text"],
Cell[596766, 13603, 162, 6, 45, "Text"],
Cell[596931, 13611, 51, 1, 40, "Input"],

Cell[CellGroupData[{
Cell[597007, 13616, 1467, 30, 299, "Input"],
Cell[598477, 13648, 1470, 24, 713, "Output"]
}, Open  ]],
Cell[599962, 13675, 155, 6, 45, "Text"],
Cell[600120, 13683, 282, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[600427, 13694, 310, 6, 28, "Input",
  CellOpen->False],
Cell[600740, 13702, 324, 5, 129, "Output"]
}, Open  ]],
Cell[601079, 13710, 652, 15, 120, "Text"],
Cell[601734, 13727, 120, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[601879, 13733, 793, 15, 28, "Input",
  CellOpen->False],
Cell[602675, 13750, 1425, 24, 520, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[604149, 13780, 130, 2, 67, "Subsection"],
Cell[604282, 13784, 1112, 22, 219, "Text"],
Cell[605397, 13808, 154, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[605576, 13818, 253, 9, 28, "Input",
  CellOpen->False],
Cell[605832, 13829, 383, 6, 127, "Output"]
}, Open  ]],
Cell[606230, 13838, 154, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[606409, 13848, 439, 13, 28, "Input",
  CellOpen->False],
Cell[606851, 13863, 503, 8, 141, "Output"]
}, Open  ]],
Cell[607369, 13874, 154, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[607548, 13884, 469, 14, 28, "Input",
  CellOpen->False],
Cell[608020, 13900, 491, 9, 141, "Output"]
}, Open  ]],
Cell[608526, 13912, 655, 10, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[609218, 13927, 126, 2, 67, "Subsection"],
Cell[609347, 13931, 487, 8, 120, "Text"],
Cell[609837, 13941, 143, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[610005, 13951, 94, 2, 41, "Input"],
Cell[610102, 13955, 409, 6, 156, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[610548, 13966, 305, 6, 48, "Input"],
Cell[610856, 13974, 466, 7, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[611359, 13986, 957, 20, 28, "Input",
  CellOpen->False],
Cell[612319, 14008, 727, 11, 153, "Output"],
Cell[613049, 14021, 691, 13, 131, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[613777, 14039, 570, 13, 28, "Input",
  CellOpen->False],
Cell[614350, 14054, 885, 17, 161, "Output"]
}, Open  ]],
Cell[615250, 14074, 131, 4, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[615418, 14083, 117, 2, 67, "Subsection"],
Cell[615538, 14087, 524, 8, 144, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[616111, 14101, 133, 2, 85, "Section"],
Cell[616247, 14105, 678, 12, 144, "Text"],

Cell[CellGroupData[{
Cell[616950, 14121, 105, 2, 67, "Subsection"],
Cell[617058, 14125, 663, 10, 144, "Text"],
Cell[617724, 14137, 2203, 53, 318, "Text"],
Cell[619930, 14192, 202, 7, 45, "Text"],
Cell[620135, 14201, 986, 21, 234, "Input",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[621146, 14226, 1098, 23, 28, "Input",
  CellOpen->False],
Cell[622247, 14251, 895, 18, 198, "Output"]
}, Open  ]],
Cell[623157, 14272, 1211, 34, 169, "Text"],
Cell[624371, 14308, 177, 6, 45, "Text"],
Cell[624551, 14316, 182, 5, 40, "Input"],

Cell[CellGroupData[{
Cell[624758, 14325, 8525, 244, 291, "Input"],
Cell[633286, 14571, 53, 1, 41, "Output"]
}, Open  ]],
Cell[633354, 14575, 1114, 37, 144, "Text"],
Cell[634471, 14614, 970, 16, 169, "Text"],
Cell[635444, 14632, 148, 6, 45, "Text"],
Cell[635595, 14640, 130, 3, 36, "Input"],
Cell[635728, 14645, 1819, 28, 258, "Input"],
Cell[637550, 14675, 176, 6, 45, "Text"],
Cell[637729, 14683, 514, 10, 62, "Input"],
Cell[638246, 14695, 3109, 52, 251, "Input"],
Cell[641358, 14749, 586, 18, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[641981, 14772, 160, 6, 70, "Subsection"],
Cell[642144, 14780, 1089, 21, 219, "Text"],
Cell[643236, 14803, 403, 13, 40, "Input"],
Cell[643642, 14818, 1824, 34, 315, "Input",
  Evaluatable->False],
Cell[645469, 14854, 3409, 58, 333, "Input"],
Cell[648881, 14914, 192, 4, 70, "Text"],
Cell[649076, 14920, 177, 6, 45, "Text"],
Cell[649256, 14928, 140, 4, 36, "Input"],
Cell[649399, 14934, 1289, 23, 301, "Input"],
Cell[650691, 14959, 2407, 40, 270, "Input"],
Cell[653101, 15001, 152, 6, 45, "Text"],
Cell[653256, 15009, 144, 4, 36, "Input"],
Cell[653403, 15015, 1106, 22, 162, "Input"],
Cell[654512, 15039, 2276, 38, 270, "Input"],
Cell[656791, 15079, 1306, 30, 219, "Text"],
Cell[658100, 15111, 940, 30, 689, "Text"],
Cell[659043, 15143, 387, 8, 95, "Text"],

Cell[CellGroupData[{
Cell[659455, 15155, 80, 1, 60, "Subsubsection"],
Cell[659538, 15158, 158, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[659721, 15166, 783, 15, 28, "Input",
  CellOpen->False],
Cell[660507, 15183, 183, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[660727, 15191, 626, 12, 28, "Input",
  CellOpen->False],
Cell[661356, 15205, 119, 2, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[661512, 15212, 592, 12, 28, "Input",
  CellOpen->False],
Cell[662107, 15226, 213, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[662357, 15234, 628, 12, 28, "Input",
  CellOpen->False],
Cell[662988, 15248, 139, 2, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[663164, 15255, 624, 12, 28, "Input",
  CellOpen->False],
Cell[663791, 15269, 81, 1, 66, "Output"]
}, Open  ]],
Cell[663887, 15273, 50, 1, 45, "Text"],
Cell[663940, 15276, 459, 10, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[664436, 15291, 94, 1, 60, "Subsubsection"],
Cell[664533, 15294, 156, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[664714, 15302, 932, 18, 28, "Input",
  CellOpen->False],
Cell[665649, 15322, 193, 3, 66, "Output"]
}, Open  ]],
Cell[665857, 15328, 23, 0, 45, "Text"],
Cell[665883, 15330, 563, 10, 168, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[666483, 15345, 96, 1, 60, "Subsubsection"],
Cell[666582, 15348, 56, 1, 45, "Text"],
Cell[666641, 15351, 596, 11, 245, "Input"],
Cell[667240, 15364, 23, 0, 45, "Text"],
Cell[667266, 15366, 514, 10, 117, "Output"],
Cell[667783, 15378, 72, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[667880, 15383, 591, 11, 219, "Input"],
Cell[668474, 15396, 197, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[668708, 15404, 590, 11, 219, "Input"],
Cell[669301, 15417, 105, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[669443, 15424, 587, 11, 219, "Input"],
Cell[670033, 15437, 221, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[670291, 15445, 588, 11, 219, "Input"],
Cell[670882, 15458, 117, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[671036, 15465, 868, 18, 28, "Input",
  CellOpen->False],
Cell[671907, 15485, 182, 3, 66, "Output"]
}, Open  ]],
Cell[672104, 15491, 55, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[672184, 15496, 609, 12, 28, "Input",
  CellOpen->False],
Cell[672796, 15510, 196, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[673029, 15518, 608, 12, 28, "Input",
  CellOpen->False],
Cell[673640, 15532, 104, 2, 41, "Output"]
}, Open  ]],
Cell[673759, 15537, 23, 0, 45, "Text"],
Cell[673785, 15539, 196, 3, 66, "Output"],
Cell[673984, 15544, 104, 2, 41, "Output"],
Cell[674091, 15548, 147, 3, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[674287, 15557, 131, 2, 67, "Subsection"],
Cell[674421, 15561, 1005, 15, 219, "Text"],
Cell[675429, 15578, 155, 6, 45, "Text"],
Cell[675587, 15586, 324, 6, 65, "Input"],
Cell[675914, 15594, 1793, 30, 242, "Input"],
Cell[677710, 15626, 776, 19, 144, "Text"],
Cell[678489, 15647, 170, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[678684, 15657, 132, 3, 41, "Input"],
Cell[678819, 15662, 462, 8, 141, "Output"]
}, Closed]],
Cell[679296, 15673, 441, 8, 110, "Input"],
Cell[679740, 15683, 1201, 23, 219, "Text"],
Cell[680944, 15708, 192, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[681161, 15718, 307, 6, 73, "Input"],
Cell[681471, 15726, 1025, 16, 69, "Output"]
}, Closed]],
Cell[682511, 15745, 1758, 32, 234, "Input",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[684306, 15782, 132, 2, 67, "Subsection"],
Cell[684441, 15786, 664, 16, 120, "Text"],
Cell[685108, 15804, 407, 16, 45, "Text"],

Cell[CellGroupData[{
Cell[685540, 15824, 671, 11, 219, "Input"],
Cell[686214, 15837, 2894, 72, 668, "Output"]
}, Open  ]],
Cell[689123, 15912, 360, 8, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[689520, 15925, 121, 2, 67, "Subsection"],
Cell[689644, 15929, 1131, 32, 169, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[690812, 15966, 105, 2, 67, "Subsection"],
Cell[690920, 15970, 902, 15, 194, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[691859, 15990, 105, 2, 67, "Subsection"],
Cell[691967, 15994, 233, 5, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[692249, 16005, 116, 2, 85, "Section"],
Cell[692368, 16009, 10573, 291, 615, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[702978, 16305, 93, 2, 85, "Section"],
Cell[703074, 16309, 556, 9, 144, "Text"],
Cell[703633, 16320, 1204, 25, 219, "Text"],
Cell[704840, 16347, 1334, 33, 225, "Text"],
Cell[706177, 16382, 964, 14, 219, "Text"],
Cell[707144, 16398, 187, 4, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[707368, 16407, 110, 2, 85, "Section"],
Cell[707481, 16411, 298, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[707804, 16423, 102, 2, 67, "Subsection"],
Cell[707909, 16427, 611, 12, 144, "Text"],

Cell[CellGroupData[{
Cell[708545, 16443, 2209, 39, 28, "Input",
  CellOpen->False],
Cell[710757, 16484, 1601, 24, 1188, "Output"]
}, Open  ]],
Cell[712373, 16511, 773, 20, 144, "Text"],

Cell[CellGroupData[{
Cell[713171, 16535, 1289, 24, 28, "Input",
  CellOpen->False],
Cell[714463, 16561, 2445, 44, 357, "Output"]
}, Open  ]],
Cell[716923, 16608, 120, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[717068, 16615, 1325, 26, 28, "Input",
  CellOpen->False],
Cell[718396, 16643, 2504, 45, 357, "Output"]
}, Open  ]],
Cell[720915, 16691, 896, 31, 144, "Text"],
Cell[721814, 16724, 144, 3, 41, "Input"],

Cell[CellGroupData[{
Cell[721983, 16731, 832, 16, 28, "Input",
  CellOpen->False],
Cell[722818, 16749, 672, 10, 449, "Output"]
}, Open  ]],
Cell[723505, 16762, 441, 8, 120, "Text"],

Cell[CellGroupData[{
Cell[723971, 16774, 638, 14, 194, "Input"],
Cell[724612, 16790, 64, 2, 69, "Output"],
Cell[724679, 16794, 66, 2, 69, "Output"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[724794, 16802, 154, 6, 70, "Subsection"],
Cell[724951, 16810, 701, 15, 169, "Text"],
Cell[725655, 16827, 122, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[725802, 16833, 984, 23, 194, "Input"],
Cell[726789, 16858, 571, 12, 69, "Output"]
}, Closed]],
Cell[727375, 16873, 2145, 74, 285, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[729569, 16953, 154, 5, 85, "Section"],
Cell[729726, 16960, 556, 19, 95, "Text"],

Cell[CellGroupData[{
Cell[730307, 16983, 170, 4, 92, "Input"],
Cell[730480, 16989, 67, 2, 41, "Output"],
Cell[730550, 16993, 198, 5, 66, "Output"]
}, Open  ]],
Cell[730763, 17001, 319, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[731107, 17012, 154, 5, 41, "Input"],
Cell[731264, 17019, 186, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[731487, 17027, 220, 4, 92, "Input"],
Cell[731710, 17033, 740, 16, 111, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[732487, 17054, 405, 8, 117, "Input"],
Cell[732895, 17064, 447, 10, 62, "Output"],
Cell[733345, 17076, 186, 3, 66, "Output"]
}, Open  ]],
Cell[733546, 17082, 88, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[733659, 17087, 335, 8, 143, "Input"],
Cell[733997, 17097, 66, 2, 41, "Output"],
Cell[734066, 17101, 191, 5, 66, "Output"],
Cell[734260, 17108, 186, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[734483, 17116, 254, 5, 92, "Input"],
Cell[734740, 17123, 447, 10, 62, "Output"],
Cell[735190, 17135, 186, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[735413, 17143, 564, 12, 219, "Input"],
Cell[735980, 17157, 68, 2, 41, "Output"],
Cell[736051, 17161, 199, 5, 92, "Output"],
Cell[736253, 17168, 186, 3, 66, "Output"],
Cell[736442, 17173, 447, 10, 62, "Output"],
Cell[736892, 17185, 186, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[737115, 17193, 563, 12, 219, "Input"],
Cell[737681, 17207, 67, 2, 41, "Output"],
Cell[737751, 17211, 149, 4, 41, "Output"],
Cell[737903, 17217, 186, 3, 66, "Output"],
Cell[738092, 17222, 447, 10, 62, "Output"],
Cell[738542, 17234, 186, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[738765, 17242, 561, 12, 219, "Input"],
Cell[739329, 17256, 65, 2, 41, "Output"],
Cell[739397, 17260, 157, 4, 41, "Output"],
Cell[739557, 17266, 186, 3, 66, "Output"],
Cell[739746, 17271, 447, 10, 62, "Output"],
Cell[740196, 17283, 186, 3, 66, "Output"]
}, Open  ]],
Cell[740397, 17289, 70, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[740492, 17294, 136, 3, 66, "Input"],
Cell[740631, 17299, 59, 1, 35, "Print"],
Cell[740693, 17302, 41, 1, 41, "Output"],
Cell[740737, 17305, 328, 9, 130, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[741114, 17320, 202, 8, 85, "Section"],
Cell[741319, 17330, 654, 19, 120, "Text"],
Cell[741976, 17351, 304, 7, 75, "Input",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[742305, 17362, 90, 2, 40, "Input"],
Cell[742398, 17366, 354, 6, 69, "Print",
  CellTags->"Info3308460589-1429071"],
Cell[742755, 17374, 859, 22, 69, "Print",
  CellTags->"Info3308460589-1429071"]
}, Closed]],
Cell[743629, 17399, 524, 15, 87, "Text"],
Cell[744156, 17416, 84, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[744265, 17422, 652, 13, 28, "Input",
  CellOpen->False],
Cell[744920, 17437, 974, 19, 245, "Output"]
}, Open  ]],
Cell[745909, 17459, 94, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[746028, 17465, 3395, 75, 28, "Input",
  CellOpen->False],
Cell[749426, 17542, 157526, 2567, 444, 9487, 734, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[907001, 20115, 122, 2, 85, "Section"],
Cell[907126, 20119, 245, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[907396, 20130, 185, 6, 70, "Subsection"],
Cell[907584, 20138, 1149, 25, 194, "Text"],
Cell[908736, 20165, 94, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[908855, 20171, 569, 12, 114, "Input"],
Cell[909427, 20185, 8503, 191, 372, "Output"]
}, Open  ]],
Cell[917945, 20379, 94, 1, 45, "Text"],
Cell[918042, 20382, 10567, 266, 347, "Output"],
Cell[928612, 20650, 3054, 83, 93, "Input",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[931703, 20738, 111, 2, 67, "Subsection"],

Cell[CellGroupData[{
Cell[931839, 20744, 64, 1, 40, "Input"],
Cell[931906, 20747, 568, 8, 188, "Print",
  CellTags->"Info3368192290-2639046"]
}, Open  ]],
Cell[932489, 20758, 2400, 74, 268, "Text"],

Cell[CellGroupData[{
Cell[934914, 20836, 86, 1, 60, "Subsubsection"],

Cell[CellGroupData[{
Cell[935025, 20841, 235, 5, 66, "Input"],
Cell[935263, 20848, 1082, 22, 247, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[936382, 20875, 79, 2, 41, "Input"],
Cell[936464, 20879, 125, 3, 36, "Print"],
Cell[936592, 20884, 175, 4, 36, "Print"],
Cell[936770, 20890, 159, 3, 36, "Print"],
Cell[936932, 20895, 159, 3, 36, "Print"],
Cell[937094, 20900, 67, 1, 35, "Print"],
Cell[937164, 20903, 42, 1, 41, "Output"]
}, Open  ]],
Cell[937221, 20907, 118, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[937364, 20914, 309, 5, 66, "Input"],
Cell[937676, 20921, 35, 1, 41, "Output"]
}, Open  ]],
Cell[937726, 20925, 527, 12, 120, "Text"],
Cell[938256, 20939, 423, 9, 95, "Input",
  Evaluatable->False],
Cell[938682, 20950, 407, 12, 95, "Text"],
Cell[939092, 20964, 1584, 34, 366, "Input",
  Evaluatable->False],
Cell[940679, 21000, 269, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[940973, 21009, 96, 2, 40, "Input"],
Cell[941072, 21013, 118, 2, 66, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[941251, 21022, 182, 5, 67, "Subsection"],
Cell[941436, 21029, 448, 9, 95, "Text"],
Cell[941887, 21040, 80, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[941992, 21046, 81, 1, 39, "Input"],
Cell[942076, 21049, 658, 16, 84, "Output"]
}, Open  ]],
Cell[942749, 21068, 284, 10, 45, "Text"],
Cell[943036, 21080, 167, 5, 61, "Input",
  Evaluatable->False],
Cell[943206, 21087, 71, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[943302, 21092, 117, 4, 61, "Input"],
Cell[943422, 21098, 1342, 28, 224, "Output"]
}, Open  ]],
Cell[944779, 21129, 322, 7, 70, "Text"],
Cell[945104, 21138, 241, 6, 83, "Input",
  Evaluatable->False],
Cell[945348, 21146, 467, 11, 70, "Text"],

Cell[CellGroupData[{
Cell[945840, 21161, 154, 4, 61, "Input"],
Cell[945997, 21167, 418, 6, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[946452, 21178, 151, 4, 61, "Input"],
Cell[946606, 21184, 504, 8, 114, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[947147, 21197, 151, 4, 61, "Input"],
Cell[947301, 21203, 556, 9, 114, "Output"]
}, Open  ]],
Cell[947872, 21215, 85, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[947982, 21220, 155, 4, 61, "Input"],
Cell[948140, 21226, 399, 7, 114, "Output"]
}, Open  ]],
Cell[948554, 21236, 188, 4, 61, "Input"],
Cell[948745, 21242, 225, 5, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[949007, 21252, 164, 6, 70, "Subsection"],
Cell[949174, 21260, 612, 15, 120, "Text"],
Cell[949789, 21277, 683, 14, 144, "Text"],
Cell[950475, 21293, 1327, 35, 194, "Text"],
Cell[951805, 21330, 707, 19, 120, "Text"],
Cell[952515, 21351, 83, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[952623, 21356, 65, 1, 39, "Input"],
Cell[952691, 21359, 294, 5, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[953022, 21369, 97, 1, 39, "Input"],
Cell[953122, 21372, 161, 3, 41, "Output"]
}, Open  ]],
Cell[953298, 21378, 207, 6, 45, "Text"],
Cell[953508, 21386, 107, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[953640, 21392, 57, 1, 39, "Input"],
Cell[953700, 21395, 591, 10, 213, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[954328, 21410, 75, 1, 39, "Input"],
Cell[954406, 21413, 229, 4, 68, "Output"]
}, Open  ]],
Cell[954650, 21420, 368, 7, 95, "Text"],

Cell[CellGroupData[{
Cell[955043, 21431, 75, 2, 41, "Input"],
Cell[955121, 21435, 163, 4, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[955321, 21444, 117, 3, 39, "Input"],
Cell[955441, 21449, 327, 5, 94, "Output"]
}, Open  ]],
Cell[955783, 21457, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[955992, 21465, 104, 4, 61, "Input"],
Cell[956099, 21471, 188, 3, 42, "Output"],
Cell[956290, 21476, 102, 2, 42, "Output"]
}, Open  ]],
Cell[956407, 21481, 221, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[956653, 21491, 104, 4, 61, "Input"],
Cell[956760, 21497, 188, 3, 42, "Output"],
Cell[956951, 21502, 102, 2, 42, "Output"]
}, Open  ]],
Cell[957068, 21507, 260, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[957353, 21516, 94, 1, 60, "Subsubsection"],

Cell[CellGroupData[{
Cell[957472, 21521, 146, 4, 61, "Input"],
Cell[957621, 21527, 400, 7, 93, "Output"]
}, Open  ]],
Cell[958036, 21537, 183, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[958244, 21547, 212, 5, 61, "Input"],
Cell[958459, 21554, 125, 2, 42, "Output"]
}, Open  ]],
Cell[958599, 21559, 138, 4, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[958774, 21568, 125, 2, 60, "Subsubsection"],

Cell[CellGroupData[{
Cell[958924, 21574, 280, 6, 105, "Input"],
Cell[959207, 21582, 904, 13, 255, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[960148, 21600, 281, 6, 105, "Input"],
Cell[960432, 21608, 903, 13, 255, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[961372, 21626, 113, 3, 39, "Input"],
Cell[961488, 21631, 158, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[961683, 21638, 239, 6, 83, "Input"],
Cell[961925, 21646, 1288, 20, 360, "Output"]
}, Open  ]],
Cell[963228, 21669, 398, 11, 95, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[963663, 21685, 74, 1, 60, "Subsubsection"],
Cell[963740, 21688, 544, 9, 144, "Text"],

Cell[CellGroupData[{
Cell[964309, 21701, 84, 4, 61, "Input"],
Cell[964396, 21707, 717, 10, 191, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[965186, 21725, 124, 2, 85, "Section"],
Cell[965313, 21729, 410, 13, 70, "Text"],
Cell[965726, 21744, 2973, 93, 294, "Text"],
Cell[968702, 21839, 1041, 32, 120, "Text"],
Cell[969746, 21873, 120, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[969891, 21879, 747, 17, 28, "Input",
  CellOpen->False],
Cell[970641, 21898, 285, 5, 117, "Output"]
}, Open  ]],
Cell[970941, 21906, 2098, 57, 268, "Text"],
Cell[973042, 21965, 140, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[973207, 21973, 479, 9, 120, "Input"],
Cell[973689, 21984, 101765, 2421, 279, 22665, 1439, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1075469, 24408, 920, 22, 149, "Text"],
Cell[1076392, 24432, 267, 10, 45, "Text"],

Cell[CellGroupData[{
Cell[1076684, 24446, 804, 15, 28, "Input",
  CellOpen->False],
Cell[1077491, 24463, 45296, 940, 279, 7515, 468, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1122802, 25406, 1633, 50, 205, "Text"],
Cell[1124438, 25458, 266, 10, 47, "Text"],

Cell[CellGroupData[{
Cell[1124729, 25472, 1578, 34, 28, "Input",
  CellOpen->False],
Cell[1126310, 25508, 59458, 1338, 279, 12126, 749, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1185783, 26849, 369, 14, 73, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1186189, 26868, 111, 2, 86, "Section"],
Cell[1186303, 26872, 1099, 24, 229, "Text"],

Cell[CellGroupData[{
Cell[1187427, 26900, 106, 2, 68, "Subsection"],
Cell[1187536, 26904, 812, 14, 203, "Text"],
Cell[1188351, 26920, 137, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[1188513, 26928, 142, 3, 40, "Input"],
Cell[1188658, 26933, 76, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1188771, 26940, 147, 3, 40, "Input"],
Cell[1188921, 26945, 96, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1189054, 26952, 147, 3, 40, "Input"],
Cell[1189204, 26957, 96, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1189337, 26964, 148, 3, 40, "Input"],
Cell[1189488, 26969, 96, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1189621, 26976, 195, 4, 40, "Input"],
Cell[1189819, 26982, 143, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1189999, 26990, 284, 5, 65, "Input"],
Cell[1190286, 26997, 232, 4, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1190567, 27007, 103, 2, 67, "Subsection"],
Cell[1190673, 27011, 753, 16, 144, "Text"],
Cell[1191429, 27029, 112, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[1191566, 27035, 889, 18, 139, "Input"],
Cell[1192458, 27055, 982, 17, 180, "Output"]
}, Open  ]],
Cell[1193455, 27075, 422, 9, 95, "Text"],
Cell[1193880, 27086, 112, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[1194017, 27092, 919, 17, 213, "Input"],
Cell[1194939, 27111, 1082, 19, 303, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1196058, 27135, 241, 8, 60, "Subsubsection"],
Cell[1196302, 27145, 115, 2, 45, "Text"],
Cell[1196420, 27149, 222, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[1196667, 27158, 380, 7, 114, "Input"],
Cell[1197050, 27167, 703, 11, 171, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1197790, 27183, 621, 10, 123, "Input"],
Cell[1198414, 27195, 72, 2, 41, "Output"]
}, Open  ]],
Cell[1198501, 27200, 118, 2, 45, "Text"],
Cell[1198622, 27204, 202, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[1198849, 27212, 337, 7, 90, "Input"],
Cell[1199189, 27221, 415, 7, 93, "Output"]
}, Open  ]],
Cell[1199619, 27231, 117, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[1199761, 27237, 330, 7, 90, "Input"],
Cell[1200094, 27246, 427, 7, 93, "Output"]
}, Open  ]],
Cell[1200536, 27256, 319, 8, 70, "Text"],
Cell[1200858, 27266, 123, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[1201006, 27272, 235, 5, 65, "Input"],
Cell[1201244, 27279, 244, 5, 68, "Output"]
}, Open  ]],
Cell[1201503, 27287, 136, 4, 47, "Text"],

Cell[CellGroupData[{
Cell[1201664, 27295, 141, 3, 41, "Input"],
Cell[1201808, 27300, 1197, 26, 290, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1203042, 27331, 71, 2, 42, "Input"],
Cell[1203116, 27335, 491, 8, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1203644, 27348, 105, 2, 42, "Input"],
Cell[1203752, 27352, 360, 8, 68, "Output"]
}, Open  ]],
Cell[1204127, 27363, 154, 4, 73, "Text"],

Cell[CellGroupData[{
Cell[1204306, 27371, 295, 6, 69, "Input"],
Cell[1204604, 27379, 61, 2, 41, "Output"]
}, Open  ]],
Cell[1204680, 27384, 129, 4, 47, "Text"],

Cell[CellGroupData[{
Cell[1204834, 27392, 363, 8, 69, "Input"],
Cell[1205200, 27402, 61, 2, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1205322, 27411, 98, 2, 68, "Subsection"],
Cell[1205423, 27415, 770, 14, 229, "Text"],
Cell[1206196, 27431, 108, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[1206329, 27437, 3058, 49, 838, "Input"],
Cell[1209390, 27488, 2265, 40, 914, "Output"],
Cell[1211658, 27530, 1810, 34, 686, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1213517, 27570, 114, 2, 68, "Subsection"],
Cell[1213634, 27574, 818, 24, 177, "Text"],
Cell[1214455, 27600, 106, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[1214586, 27606, 385, 9, 120, "Input"],
Cell[1214974, 27617, 322, 6, 93, "Output"],
Cell[1215299, 27625, 66, 2, 41, "Output"]
}, Open  ]],
Cell[1215380, 27630, 63, 1, 47, "Text"],

Cell[CellGroupData[{
Cell[1215468, 27635, 371, 7, 146, "Input"],
Cell[1215842, 27644, 292, 6, 95, "Output"],
Cell[1216137, 27652, 205, 4, 67, "Output"],
Cell[1216345, 27658, 110, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1216492, 27665, 371, 7, 146, "Input"],
Cell[1216866, 27674, 285, 5, 95, "Output"],
Cell[1217154, 27681, 205, 4, 67, "Output"],
Cell[1217362, 27687, 110, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1217509, 27694, 71, 2, 42, "Input"],
Cell[1217583, 27698, 264, 5, 131, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1217896, 27709, 143, 3, 68, "Subsection"],
Cell[1218042, 27714, 148, 4, 73, "Text"],
Cell[1218193, 27720, 100, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[1218318, 27726, 166, 4, 94, "Input"],
Cell[1218487, 27732, 116, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1218640, 27739, 164, 4, 94, "Input"],
Cell[1218807, 27745, 116, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1218960, 27752, 166, 4, 94, "Input"],
Cell[1219129, 27758, 116, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1219282, 27765, 155, 4, 68, "Input"],
Cell[1219440, 27771, 108, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1219585, 27778, 207, 4, 94, "Input"],
Cell[1219795, 27784, 175, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1220007, 27792, 206, 4, 94, "Input"],
Cell[1220216, 27798, 175, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1220428, 27806, 206, 4, 94, "Input"],
Cell[1220637, 27812, 175, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1220849, 27820, 207, 4, 94, "Input"],
Cell[1221059, 27826, 175, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1221271, 27834, 205, 4, 94, "Input"],
Cell[1221479, 27840, 175, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1221691, 27848, 209, 4, 94, "Input"],
Cell[1221903, 27854, 175, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1222115, 27862, 243, 5, 120, "Input"],
Cell[1222361, 27869, 217, 4, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1222615, 27878, 165, 4, 94, "Input"],
Cell[1222783, 27884, 116, 2, 41, "Output"]
}, Open  ]],
Cell[1222914, 27889, 76, 1, 47, "Text"],

Cell[CellGroupData[{
Cell[1223015, 27894, 176, 4, 94, "Input"],
Cell[1223194, 27900, 547, 8, 141, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1223778, 27913, 176, 4, 94, "Input"],
Cell[1223957, 27919, 956, 15, 166, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1224950, 27939, 207, 4, 94, "Input"],
Cell[1225160, 27945, 541, 8, 147, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1225762, 27960, 126, 2, 86, "Section"],
Cell[1225891, 27964, 832, 15, 229, "Text"],
Cell[1226726, 27981, 112, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[1226863, 27987, 960, 19, 241, "Input"],
Cell[1227826, 28008, 779, 13, 291, "Output"]
}, Open  ]],
Cell[1228620, 28024, 602, 10, 203, "Text"],
Cell[1229225, 28036, 141, 4, 47, "Text"],

Cell[CellGroupData[{
Cell[1229391, 28044, 462, 11, 28, "Input",
  CellOpen->False],
Cell[1229856, 28057, 355, 6, 91, "Output"]
}, Open  ]],
Cell[1230226, 28066, 390, 11, 99, "Text"],
Cell[1230619, 28079, 89, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[1230733, 28085, 516, 12, 28, "Input",
  CellOpen->False],
Cell[1231252, 28099, 892, 16, 266, "Output"]
}, Open  ]],
Cell[1232159, 28118, 506, 9, 177, "Text"],
Cell[1232668, 28129, 95, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[1232788, 28135, 446, 9, 28, "Input",
  CellOpen->False],
Cell[1233237, 28146, 1207, 21, 510, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1234493, 28173, 118, 2, 86, "Section"],
Cell[1234614, 28177, 609, 10, 177, "Text"],

Cell[CellGroupData[{
Cell[1235248, 28191, 349, 6, 172, "Input"],
Cell[1235600, 28199, 149, 3, 66, "Output"]
}, Open  ]],
Cell[1235764, 28205, 626, 12, 177, "Text"],

Cell[CellGroupData[{
Cell[1236415, 28221, 821, 18, 328, "Input"],
Cell[1237239, 28241, 568, 10, 241, "Output"]
}, Open  ]],
Cell[1237822, 28254, 554, 15, 125, "Text"],

Cell[CellGroupData[{
Cell[1238401, 28273, 73, 2, 42, "Input"],
Cell[1238477, 28277, 140, 3, 57, "Output"]
}, Open  ]],
Cell[1238632, 28283, 196, 4, 73, "Text"],

Cell[CellGroupData[{
Cell[1238853, 28291, 86, 2, 42, "Input"],
Cell[1238942, 28295, 527, 12, 255, "Output"]
}, Open  ]],
Cell[1239484, 28310, 170, 4, 73, "Text"],

Cell[CellGroupData[{
Cell[1239679, 28318, 101, 2, 42, "Input"],
Cell[1239783, 28322, 322, 6, 91, "Output"]
}, Open  ]],
Cell[1240120, 28331, 144, 4, 47, "Text"],

Cell[CellGroupData[{
Cell[1240289, 28339, 550, 11, 250, "Input"],
Cell[1240842, 28352, 89, 2, 41, "Output"],
Cell[1240934, 28356, 99, 2, 41, "Output"],
Cell[1241036, 28360, 86, 2, 41, "Output"],
Cell[1241125, 28364, 112, 2, 41, "Output"],
Cell[1241240, 28368, 71, 2, 41, "Output"],
Cell[1241314, 28372, 76, 2, 41, "Output"],
Cell[1241393, 28376, 79, 2, 41, "Output"],
Cell[1241475, 28380, 142, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1241654, 28388, 101, 2, 42, "Input"],
Cell[1241758, 28392, 334, 7, 91, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1242141, 28405, 93, 2, 86, "Section"],
Cell[1242237, 28409, 173, 7, 34, "EndNote",
  CellTags->"MT2"],
Cell[1242413, 28418, 153, 5, 34, "EndNote",
  CellTags->"MT2"],
Cell[1242569, 28425, 159, 5, 34, "EndNote",
  CellTags->"MT2"],
Cell[1242731, 28432, 290, 7, 56, "EndNote",
  CellTags->"MT2"],
Cell[1243024, 28441, 190, 6, 34, "EndNote",
  CellTags->"CT"],
Cell[1243217, 28449, 206, 5, 56, "EndNote",
  CellTags->"FV"],
Cell[1243426, 28456, 140, 4, 34, "EndNote",
  CellTags->"MT2"],
Cell[1243569, 28462, 173, 5, 34, "EndNote",
  CellTags->"MT2"],
Cell[1243745, 28469, 275, 9, 56, "EndNote",
  CellTags->"MT2"],
Cell[1244023, 28480, 146, 4, 34, "EndNote",
  CellTags->"MT2"],
Cell[1244172, 28486, 107, 2, 34, "EndNote",
  CellTags->"MT2"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

