(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    665506,      12947]*)
(*NotebookOutlinePosition[    666605,      12981]*)
(*  CellTagsIndexPosition[    666561,      12977]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["GroupLoopHoop' Package.", "Title",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
  TextJustification->0.25,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Symmetry-conserving partial-fraction-division \"hoop algebras\" are \
closely related to Groups and Moufang Loops. They multiply, divide, add and \
split vectors with generalized signs and employ many new or neglected \
mathematical concepts to re-define physical mathematics.\nTo activate the \
package for use with ",
  StyleBox["GroupLoopDemo.nb ",
    FontSlant->"Italic"],
  "& ",
  StyleBox["HoopDemo.nb",
    FontSlant->"Italic"],
  ", either save it as a package in ",
  StyleBox["Addons/ExtraPackages",
    FontSlant->"Italic"],
  " and use ",
  StyleBox["<<GroupLoopHoop`",
    FontSlant->"Italic"],
  " or initialise the following cell and answer Yes to the query. ",
  StyleBox["GroupLoopTest.nb",
    FontSlant->"Italic"],
  " can then be used to validate the package. A shorter and simpler account \
of Hoop Algebras (using a much smaller package) is available as ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  "/6198; it should be studied first if your interest is only Hoops."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(\(Off[General::"\<spell\>", General::"\<spell1\>", Part::"\<partd\>", 
      Syntax::"\<com\>", 
      Less::"\<nord\>"]\)\( (*That\ allows\ similar\ names\ and\ nulls\ to\ \
be\ used*) \)\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0.25],

Cell[BoxData[
    \(\(\(Quit[]\)\( (*use\ this\ after\ any\ edits, \ 
      before\ using\ the\ previous\ cell*) \)\)\)], "Input",
  PageWidth->WindowWidth],

Cell["\<\
This package includes:
 (1) A database containing all finite groups with up to 73 elements and a few \
larger groups, together with many loops and hoop algebras, in an extension of \
the GAP Atlas, as \"protoloops\" - preferred isomorph Cayley index tables. 
 (2) An identification procedure that will identify any isomorph of a group \
or hoop in the database, and provisionally identify isomorphs of the other \
loops.
 (3) Procedures to create, manipulate, and analyse groups, loops and hoops.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["1. Version, Copyright notice.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Version 3b. dated 11/10/6. Packaged as GroupLoopHoop`, without extraneous \
bits, validation. \netc. \"Collapse\" converted to \"Fold\". More \
non-associative Moufang Loops included.\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 compatible. ",
  StyleBox["genTimes",
    FontSlant->"Italic"],
  " etc replaced by ",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  ". \nComments to ",
  StyleBox["rhberesford@btinternet.com ",
    FontSlant->"Italic"],
  "please."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}}],

Cell[TextData[{
  "\[Copyright] Copyright 2003, 2004, 2005, 2006",
  StyleBox[" Roger Herbert Beresford, 30, Brook Rd., Woodhouse Eaves, \
Loughborough, Leics, LE12 8RS, England",
    FontSlant->"Italic"],
  ". \nConsiderable effort has gone into checking this work, but some errors \
probably persist. No responsibility will be accepted for any problems arising \
from its use. Permission is granted to distribute this file for any purpose \
except for inclusion in commercial software or program collections. This \
copyright notice must remain intact."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{808, Inherited}]
}, Closed]],

Cell[CellGroupData[{

Cell["2. Revisions.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Based on and replacing ",
  StyleBox["GroupMLHoops.nb & HoopsDemo",
    FontSlant->"Italic"],
  " originally published as [5], May 2003 and revised up to 13th Sept. 2003.\n\
Version 1. 4th Dec. 2003. Demonstrations re-designed for non-",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "users.",
  StyleBox["\n",
    FontSlant->"Italic"],
  "Version 1a.",
  StyleBox[" ",
    FontSlant->"Italic"],
  "9th Dec. 2003. Database expanded. Appendices included. \nVersion 1b. 11th \
Jan. 2004  C4c from u4[[16]]. genCos & genSin[x,m,j] not genCos[x,m,i] for \
clarity. Duplicate ms removed. Pr changed to P4, msi creates P4, P16c. \
Plex-conjugate appendix enlarged. Extra signed tables added.\nVersion 1c. \
July - November 2004. Quadratic sizes (up to 6 elements) put first for use \
with JuliaSets. Introduced remainders on division by zero-vecs. Minor \
clarifications. hoopTest revised, Q12r corrected, rational units for \
\[DoubleStruckCapitalH] & \[DoubleStruckCapitalO], 3/11/4.\nVersion 1d. C8cn \
in place of QC2n. More u2 matrices and related groups. More 64 element \
incantations. Rl & Rr calculated on multiplication, tested in section 2.11.6. \
Q12 toPol corrected. Qr transposition removed to match standard quaternion \
package, 6/1/05\nVersion 2. 20/2/5 Stand-alone package extracted from \
HoopAlgebras1d. Renamed ",
  StyleBox["GroupLoopHoop",
    FontFamily->"Times New Roman"],
  ".m. Added reductiveQ, quasigroupQ corrected to loopQ, all tests include \
gpd test; 5/7/5. \nVersion 2a. 6/12/5 Octonion compositions added. ",
  StyleBox["alph",
    FontSlant->"Italic"],
  " lengthened to 260. alternativeQ ",
  StyleBox["l",
    FontSlant->"Italic"],
  " error removed. Skeleton routines (algorithm demos, stripped of all \
extraneous bells and whistles) added:- ",
  StyleBox[" ca[m,k,s], co[g,h,k,s], collapse[g,r], hoopInverse[A,s], ",
    FontSlant->"Italic"],
  "hoopTi",
  StyleBox["mes[A,B,G,1], groupFromRelators[gp_,post_:{}], ma[t1,t2,max,s]. ",
    
    FontSlant->"Italic"],
  "These test neither input nor output, so they only give correct results if \
the arguments are valid.\nC3C4c & C3C4 shapes, D3 & P4 toPol revised, C9j \
&C9J distinguished. Many minor edits.\nVersion 3. Packaged as ",
  StyleBox["GroupLoopHoop.m.",
    FontSlant->"Italic"],
  " 21/4/2006 without tests or Visualizations.\n(Previous versions did not \
create a package.)\ngi corrected for CL22. C3C3j factors, but no pol/vec. ",
  StyleBox["as",
    FontSlant->"Italic"],
  " copied from ",
  StyleBox["HoopData",
    FontSlant->"Italic"],
  ". non-Abelian remainders corrected. Sign removed from hoopPo",
  StyleBox["wer",
    FontSlant->"Italic"],
  ". ",
  StyleBox["cscale",
    FontSlant->"Italic"],
  " deleted. C3C4c  & C3C4 L4a, L4b factors used to give correct ",
  StyleBox["toPol, toVec",
    FontSlant->"Italic"],
  ". QPower included. sh12 extended to all functions conserved in at least \
one case. Noncommutative extensions to ",
  StyleBox["ge, det",
    FontSlant->"Italic"],
  ".\nVersion 3a, 6/6/6. Octr, not Octc. Alt12n second incantation. ",
  StyleBox["cd",
    FontSlant->"Italic"],
  " write-up, accepts incantations. O4k added. Some colour-coding.\nVersion \
3b, 11/10/6 Non-conservative non-associative Moufang Loops D3Mn, D4M1n, ... \
Q12M5n added; Q8M2 and 5 (Q8C2M, P16M, C8pC2M, KiC4M, C4iC4M) conservative \
non-associative 32 element loops added. OctC2 was already known. Moufang \
doubling partially implemented as ",
  StyleBox["md",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Rest, Mod",
    FontSlant->"Italic"],
  " altered to be M4.2 compatible. ",
  StyleBox["genTimes",
    FontSlant->"Italic"],
  " etc changed to ",
  StyleBox["hoopTimes ",
    FontSlant->"Italic"],
  "etc. shape[C3P4] restored. \"Collapse\" converted to \"Fold\". \n\
(Non-commutative OPScalar' (Mathsource/4291) investigations abandoned as it \
screws up Sqrt[b-a])"
}], "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["3. Keywords.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell["\<\
\tAlgebras, Cayley-Dickson, Cayley-tables, Clifford, Clifford-like, \
conservative loops & algebras, continuous orbits, determinants, directors, \
Frobenius-conservation, Fold, generalized signs, groups, hoops, Hoop shapes, \
Hoop sizes, isomers, isomorphs, isotopes, loops, Moufang Loops, m-vecs, \
non-associative algebras, plex-conjugate, Primal numbers, partial-fraction \
division-by-zero, quasigroups, renormalization, remainders, Roger algebras, \
roots of unity, signed-tables, vecs, univectors, zero-vectors.\
\>", "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  CellSize->{490, Inherited}]
}, Closed]],

Cell[CellGroupData[{

Cell["4. Warnings.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Many of the new concepts transcend and revise those current mathematical \
beliefs that are solely based on real and complex numbers.\nGlobal effects \
-",
  StyleBox[" genel,  globa, matel, mm, nn, gi, gp, R1, Rr, sg, smax, strep ",
    FontSlant->"Italic"],
  "are Global names that are altered by various routines."
}], "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["5. Limitations.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tOnly a few loops with over 73 elements are included in the database; \
they will not be uniquely identified by ",
  StyleBox["id",
    FontSlant->"Italic"],
  ". All 267 64-element groups are present, but many lack unique \
identification and generation. g4828 cannot be generated by ",
  StyleBox["makeProtoloop.",
    FontSlant->"Italic"],
  " Associativity is (deliberately, for speed) not tested by ",
  StyleBox["id",
    FontSlant->"Italic"],
  ", so non-associative tables may be wrongly identified as groups (",
  StyleBox["idc",
    FontSlant->"Italic"],
  " tests for conservation, but not associativity, before attempting an \
identification). Clifford hoops and named signed-tables may be isotopes. \
(Isomorphs correspond to renaming elements; isotopes involve changing some \
element signs so that the structure, but not the details, of the shape is \
conserved.)\n\tThe creation of groups and signed tables from unitary monomial \
matrices, using ",
  StyleBox["ma, mg & ms",
    FontSlant->"Italic"],
  ", has only been cursorily investigated. Extra matrices, especially \
traceless matrices, could be included, and systematic search procedures \
(supplied) could be used with more generating matrices.\n\tSigned table & \
generalised plex-conjugate investigations, generalised quadratic and \
simultaneous equation solution procedures are all rudimentary."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -2.375}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["6. Note on Implementation.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tA standard methodology has been aimed for. Top-level procedures should \
accept any format for loop arguments:- an indexTable or signed-table (in list \
or traditional matrix form), the name of a predefined table, a mnemonic that \
matches the first element of an entry in the ",
  StyleBox["loop",
    FontSlant->"Italic"],
  " database, the table size and position e.g. {12,1} as in the (extended) \
GAP atlas, or an instruction that creates an index table, such as ",
  StyleBox["ca[12,1],  co[C3,C4,2],  ge[{3,4},{ba\[Rule]a2b}],  mp[{12,1}],  \
ma[{u2[[10]], u2[[13]]}]].",
    FontSlant->"Italic"],
  " These examples all create \"",
  StyleBox["Q12",
    FontSlant->"Italic"],
  "\" - from a formula, as a non-abelian composition, from relators, as a \
protoloop, and from 2\[Times]2 matrices. Deeper procedures (that are likely \
to be called many times by a top-level procedure) only accept tables as \
lists, for speed. Two global tables, ",
  StyleBox["globa & glo",
    FontSlant->"Italic"],
  ", are set up when a \"target loop\" is established, to eliminate the need \
to copy large tables as far as possible; a global mnemonic ",
  StyleBox["gmn,",
    FontSlant->"Italic"],
  " and two global variables ",
  StyleBox["mm, nn",
    FontSlant->"Italic"],
  " are also set up. Some procedures (e.g. ",
  "hoopFactor",
  StyleBox["[f]",
    FontSlant->"Italic"],
  ") use ",
  StyleBox["glo",
    FontSlant->"Italic"],
  " implicitly, whilst others (e.g. ",
  StyleBox["sh[]",
    FontSlant->"Italic"],
  ") use ",
  StyleBox["gmn",
    FontSlant->"Italic"],
  " explicitly. Many procedures have a final \"Options\" argument, ",
  StyleBox["o_:0",
    FontSlant->"Italic"],
  ", that modifies the operation; if it is negative the output properties \
will (in many cases) be tested and failures reported. Two-letter \
abbreviations are supplied for frequently used procedures, to reduces clutter \
in the ",
  StyleBox["loop",
    FontSlant->"Italic"],
  " data file. Tests that yield True or False follow the \"trailing Q\" ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " nomenclature; the reason for falsity is output if ",
  StyleBox["o\[NotEqual]0",
    FontSlant->"Italic"],
  ".\n\tSkeleton routines have been supplied for key routines, for expository \
purposes. These omit all tests and frills, so they only work for carefully \
prepared data."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["\tTWO LETTER ABBREVIATIONS.\n",
    FontWeight->"Bold"],
  "as[v,w] maps v with u.,\t\tbf=Bold form,\t\nca=Create Cayley Table from \
formula,\ncd=Create Cayley Table by doubling,\ncl=Create Clifford Table,\n\
co=Compose Cayley Tables,\tds=Formalae in Dozalcons,\nfa=Find alpha \
determinant,\nfp=Find Powers-of-2 determinant,\ngd=Loop data,\t\t\tge=create \
loop from relators,\ngi=inverse data,\t\tgp=multiplicity data,\nid=Table \
identity,\t\tma=make loop from matrices,\nmd=Moufang Doubling,\tmg=Make loop  \
from matrix list,\nmp=Make Protoloop,\nms=make signed table from matrices,\n\
mm=No. of elements in target loop,\nnn=position of target loop in loop[[mm]],\
\npe=Create Cayley Table from permutations,\nRl Rr=Left and right remainders,\
\ns3 s4 s5 are permutations defining S3 to S5,\nsg=subgroup indices,\t\
sh=shape of target loop,\ntf=TraditionalForm,\t\tts=ToSignedLoop,\nu2 u3 \
u4=unitary monomial matrices used by ma mg ms"
}], "Input",
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["7. Set up the ",
    FontFamily->"Times New Roman"],
  StyleBox["GroupLoopHoop.m",
    FontFamily->"Times New Roman"],
  StyleBox[" package, usage",
    FontFamily->"Times New Roman"],
  "."
}], "Subsection",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[{
  "7.1 Begin, ",
  StyleBox["GroupLoopHoop",
    FontFamily->"Times New Roman"],
  " Usage."
}], "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "BeginPackage[",
  StyleBox["\"",
    FontFamily->"Courier New"],
  StyleBox["GroupLoopHoop",
    FontFamily->"Times New Roman"],
  StyleBox["`\"",
    FontFamily->"Courier New"],
  "];"
}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[TextData[{
  StyleBox["GroupLoopHoop",
    FontFamily->"Courier New"],
  "::usage = \"",
  StyleBox["GroupLoopHoop",
    FontFamily->"Courier New"],
  " is a package that creates a database of over 800 loops, including all \
groups with up to 73 elements. It generalizes signs & creates & manipulates \
Groups & 'Moufang Loops' (ordered division quasigroups) as index-Tables \
(Cayley tables with indices as elements) and signed tables (e.g. the \
Quaternion multiplication table). It also sets up conservative \
partial-fraction division algebras (Hoops) based on them, and provides \
procedures & tests for division, powers, roots, polar-dual formulations & \
loop properties.\";"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 Alphabetic list of Usage for functions and procedures.", \
"Subsubsection",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(a::usage = "\<Symbol in HoopTbl etc.\>"; b::usage = "\<\>"; 
    c::usage = "\<\>"; d::usage = "\<\>"; e::usage = "\<\>"; 
    f::usage = "\<\>"; g::usage = "\<\>"; h::usage = "\<\>"; 
    i::usage = "\<\>"; j::usage = "\<\>"; k::usage = "\<\>"; 
    l::usage = "\<\>"; m::usage = "\<\>"; n::usage = "\<\>"; 
    o::usage = "\<\>"; p::usage = "\<\>"; q::usage = "\<\>"; 
    r::usage = "\<\>"; s::usage = "\<\>"; t::usage = "\<\>"; 
    u::usage = "\<\>"; v::usage = "\<\>"; w::usage = "\<\>"; 
    x::usage = "\<\>"; y::usage = "\<\>"; 
    z::usage = "\<\>"; \[Alpha]::usage = "\<\>"; \[Beta]::usage = "\<\>"; \
\[Gamma]::usage = "\<\>"; \[Delta]::usage = "\<\>"; \[Epsilon]::usage = \
"\<\>"; \[CurlyEpsilon]::usage = "\<\>"; \[Zeta]::usage = "\<\>"; \
\[Eta]::usage = "\<\>"; \[Theta]::usage = "\<\>"; \[CapitalTheta]::usage = \
"\<\>"; \[Iota]::usage = "\<\>"; \[Kappa]::usage = "\<\>"; \[Lambda]::usage = \
"\<\>"; \[Mu]::usage = "\<\>"; \[Nu]::usage = "\<\>"; \[Xi]::usage = "\<\>"; \
\[CapitalXi]::usage = "\<\>"; \[CurlyPi]::usage = "\<\>"; \[CapitalPi]::usage \
= "\<\>"; \[Rho]::usage = "\<\>"; \[CurlyRho]::usage = "\<\>"; \
\[Sigma]::usage = "\<\>"; \[CapitalSigma]::usage = "\<\>"; \[Tau]::usage = \
"\<\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(TraditionalForm\`abbr::usage = \*"\"\<abbr[t_,o_:1] is used by 'dico' & \
'trico' to create an abbreviation such as {12,\!\(4\_5\),15} in which \
subscripts indicate numbers of appearances of elements in a table diagonal, \
with the first element real for abelian and negated for signed tables. 'dico' \
has another discriminant appended in cases with many tables of the same size. \
In the example, dico[makeProtoloop['g3207']], there are 12 occurences of the \
unit; 5 other elements occur 4 times (total=32), and there are 15 subgroups \
of 4 elements.\>\""; 
    abbrFactors::usage = \*"\"\<abbrFactors[g_indexTableQ:glo,p_:pow2] \
creates an abbreviation such as {\!\(1\_2\),2,\!\(2\_2\%2\),\!\(6\_2\%2\)} \
for the factor structure of the indexTable determinant. In this (Q36) example \
there are two different linear factors, a single quadratic and two repeated \
quadratic factors, and two repeated sixth powers. Note that abelian groups \
(only) have no repeated factors. Uses power2 as pow2 sometimes errs.\>\""; 
    abelGrassmanQ::usage = "\<Tests whether (ab)c=(cb)a for all a,b,c in \
'G'\>"; abelianQ::usage = "\<Tests whether Transpose[g]==g.\>";\), "\n", 
    \(TraditionalForm\`allFactorGroups::usage = \
"\<allFactorGroups[gg_:glo,o_:0,i1_:2,i2_:49,p_:{}] finds the  Factor groups \
(quotient groups) for all normal subgroups in the size range {i1,i2} of 'gg'. \
If the global variable 'sg' contains the selected subgroups (i.e. after \
calling subgroups) set 'o' to 1 to avoid recalculation as sg already contains \
the relevant subgroups. A list may be appended; the first matching subgroup \
{i1,p[[_]]} is then reported and the search ends.\>"; 
    alph::usage = "\<A list of 260 symbols, {a,b,...\[Alpha],\[Beta]..,a} \
(the first 72 are repeated later) used as symbolic elements of Cayley Tables.\
\>"; alpha::usage = "\<Same as alph, with letters in place of symbols\>"; 
    alternativeQ::usage = "\<alternativeQ[g_:glo,o_:0] tests whether \
xx.y=x.xy for all x,y.z in 'g'. It reports the first error if \
'o'\[NotEqual]0. See PMA p94, numbers p226.\>"; 
    amQ::usage = "\<Tests if x(yx.zx)=(xy.xz)x\>"; 
    any::usage = "\<Dummy used in various tests\>"; 
    arcTanh::usage = "\<arcTanh[adj_,opp_] or arcTanh[{adj_,opp_}] calculates \
an angle that takes account of the octant of the arguments; the angle has an \
imaginary part for three non-standard hyperbolae. Note that opp,adj is the \
argument order used by many mathematicians.\>"; 
    as::usage = "\</.as[v_,w_] replaces elements of v by elements of \
w.\>";\), "\[IndentingNewLine]", 
    \(TraditionalForm\`associator::usage = "\<associator[g_:glo,i_,j_,k_] is \
the standard groupoid function, (ij)k-i(jk) \>"; 
    AssociativeQ::usage = "\<AssociativeQ([gg_:glo,o_] tests whether (x(y \
z))==((x y) z) for all x,y,z in 'gg' and reports the first error if 'o'\
\[NotEqual]0.\>"; 
    associativeQ::usage = "\<associativeQ([gg_:glo,o_] tests whether (x(y \
z))==((x y) z) (up to a sign) for all x,y,z in 'gg' and reports the first \
error if 'o'\[NotEqual]0. Some non-associative signed tables (including Qr, \
Octr, Sed) are associative 'up to a sign'\>";\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    \(bolQ::usage = "\<bolQ([gg_:glo,o_] tests the left & right Bol \
identities (PMA p97-8) (z.yz)x ==z(y.zx) & x(zy.z) ==(xz.y)z for all x,y,z in \
'gg' and reports the error type if 'o'\[NotEqual]0.\>"; 
    c2simeq::usage = "\<c2simeq[{a_,b_,c_]solves simultaneous linear \
equations Ax+B=C in the C2 algebra. Wherever the solution is indeterminate, \
it includes a free x$ variable\>"; 
    ca::usage = "\<ca[m_Integer?Positive,a_Integer] or
   ca[{m_,a_:1}] checks that GCD[m,k=Abs[a]] is 1 before creating an \
m\[Times]m quasigroup indexTable with first row and first column containing \
the 'unity' {1,2,...,m}, and with every element occurring once in each row \
and column (i.e. it is a sorted quasigroup or Latin Square). The result is \
the Cyclic group 'Cm' if 'a' is 0 or absent, the Dihedral group 'D[m/2]' if \
'k'='m'-1 and the generalised Quaternion group 'Q[m]' if 'k'='m'/2-1; some \
other values of 'k' give compound Dihedral or Quaternion groups. Some other \
cases give Hamiltonian quasigroups. If 'a' is negative, non-associativity is \
reported. The indexTable is output. A skeleton version is supplied.\>"; 
    caylindex::usage\  = \ "\<caylindex[gg_] converts a square symbolic table \
'gg' to an indexTable on the assumption that the first row is the \
unity.\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(cd::usage = "\<cd[{gamma__:IntegerQ}] (generalized Cayley-Dickson) \
takes a list of none or more \[PlusMinus]1's and recursively builds \
signed-tables (including P,R,C,H,O,sedenions) by the generalized \
Cayley-Dickson doubling procedure. See Lounesto, Clifford Algebras & Spinors, \
2nd. ed., p285.
    'm' is the table (of size q\[Times]q) obtained by dropping the last \
\[PlusMinus]1; the starting case (with no \[PlusMinus]1's) is the primal \
multiplication table {{1}}. The top-left quarter of the new table repeats \
'm'; the top right quarter is 'm' transposed and shifted by 'q' (using \
'modqr' to give a signed index); the bottom left quarter is 'm' shifted by \
'q', with all but the first column multiplied by the current \[PlusMinus]1. \
The bottom right quarter is 'm' transposed with all but the first row & \
column multiplied by the current \[PlusMinus]1. An extension takes any of {2, \
-2, 3, 3., -3,  4, 4. -4, -4.,'incantation'} in place of the first \
\[PlusMinus]1, and also allows '\[PlusMinus]1.' (i.e. real) elsewhere. This \
generates more signed hoop algebras and lots of rubbish. ('incantation' is \
any string that creates a hoop.) If the last gamma is {list}, e.g. {2} or \
{3}, the last stage is the composition of the penultimate result with the \
group ca[list].
    md is a related Moufang Doubling operation.\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(centralizer::usage = "\<standard group function\>"; 
    center::usage = "\<standard group function\>"; 
    centre::usage = "\<standard group function\>";\), "\[IndentingNewLine]", 
    \(cl::usage = "\<cl[p,q:0] creates Clifford[p,q]; cl[p,list] creates \
Clifford-like algebras with p binary generators, those in list having \
negative squares. See Lounesto[13] ch21.
  cl[p_,q_,gr_:{}] creates a Grassmann-like algebra by creating a \
Clifford-like algebra
   (using cl[p,q]) and then zeroing the squares of elements listed in 'gr'. \
As the result is not a groupoid, most hoop operations fail.\>"; 
    cliff::usage = "\<cliff is a substitution list for Clifford-like \
algebras. 'e' is the unit, 'a', 'b', 'c', 'd', 'f' the generators \
(univectors), 'ab' etc are bivectors, 'abc' is a trivector, etc\>"; 
    co::usage = "\<co[gg_?indexTableQ,hh_?indexTableQ,a_:0] outputs the \
direct composition of 'g' & 'h' if 'a' is 0 or absent; some values of 'a' \
create quasigroups or groups. If 'a' is 1 or negative, non-groupoid & \
non-associative tables will be reported. 'gg' (but not hh) may be a signed \
table. co[g_,h_,gg_,hh_,a_,o_:0,p_:0] and co[g_,gg_,hh_,a_,o_:0] (NB first \
parameter 'a' can be 0, but must be supplied) generate the multiple \
compositions by iteratively composing the inner tables using the leading \
parameters. co[g_,h_,a_,c_] is a skeleton, omitting all tests.\>";\)}], \
"Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(collect::usage\  = \ "\<collect[%], collect[sg], or collect[] is used \
to count the numbers of each type of subgroup identified by subgroupTypes and \
stored in 'sg'\>"; 
    conservativeQ::usage = "\<conservativeQ[gg_:glo] tests whether \
Det[A]Det[B]=\[PlusMinus]Det[AB], for the (possibly signed) groupoid 'gg'. \
Frobenius showed that associativity is a sufficient condition; a few \
non-associative Moufang tables are conservative. Random integer values of the \
elements of A & B are tested if 'gg' is signed or not associative. 
   conservativeQ[gg_,t_:Complex,r_:{-1-\[ImaginaryI],1+\[ImaginaryI]}/2] uses \
random A & B of type 't' in range 'r'. As round-off errors could wrongly give \
False, the test uses the ratio of the minimum to the maximum of the \
\[PlusMinus] cases. Fails with \[DoubleStruckCapitalJ] algebras\>"; 
    cosorbit::usage = \
"\<cosorbit[\[Theta]_,phaselist_:{0,1,2,3,4,5},scale_:1,meanlist_:Table[0,{24}\
]] creates an orbit with angle parameter \[Theta]; phaselist defines the \
phase of each element (with null values permitted) and the number of \
elements; scale is a factor that can be adjusted to obtain a unitary result; \
meanlist is an optional offset from zero.\>"; 
    cQ::usage = "\<Tests if (xy.y)z=x(yy.z)\>"; 
    det::usage = \*"\"\<det[a_?MatrixQ] calculates a generalized determinant, \
as a list of 'Abs[m]' components, for a (not necessarily square) \
matrix.Putting 'm' ={\[PlusMinus]1,\[PlusMinus]2,\[PlusMinus]3,\[PlusMinus]4} \
gives the {permanent, ditermanent, tritermanent,4terminant}; the ordinary \
determinant is the signed sum of the two ditermanent terms. In effect, each \
element of 'a' is multiplied by a power of the sign 'J', with \
\!\(J\^\(\(|\)\(m\)\(|\)\)\)=1; the final result comprises the signed sums of \
all the determinant-like terms with a given power of 'J'. The calculation is \
recursive via a stripped down version, 'det1', a signed row or column matrix \
being the basis. If necessary, 'short' matrices are transposed to become \
'long', i.e. with more columns than rows. 'det' sums all the square det's, as \
in the Moore-Penrose inverse\>\""; det1::usage = "\<See det\>"; 
    dico::usage = "\<dico[g_:glo] is the 'diagonal count' i.e. the count of \
elements of 'g' in the table diagonal, compressed via 'abbr' (q.v.). The \
first entry is the number of square roots of unity, and is signed if 'g' is \
signed, and is real if 'g' is abelian.  An extra diagnostic integer is added \
for tables with m = 32, 48, 54, 64 or 72\>";\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(dozalcons::usage = "\<dozalcons[12vec] calculates 39 functions that \
are conserved in some Dozal operations. Their names are given in ds\>";\)\), \
"\n", 
    \(dozaltest::usage = "\<dozaltest[A0_,B0_,n_:5] multiplies A0 by B0 using \
the first n 12 element loops and tabulates  the conservation of the dozalcons \
functions. If 5<n<0 the polar forms are calculated from A0 & B0\>"; 
    ds::usage = "\<The list of functions in dozalcons\>";\), "\
\[IndentingNewLine]", 
    \(\(entropicQ::usage\  = \ "\<Test whether wx.yz= wy.xz.\>";\)\), "\n", 
    \(fa::usage\  = \ "\<fa[g_?indexTableQ] maps the list of symbols 'alph' \
onto the indexTable 'g' unless 'g' is too large (more than 11\[Times]11); it \
returns the determinant factors, dropping any -1. Use 'fp' for larger groups; \
'fp' with 12\[Times]12 (or larger) is very slow without a lot of zero \
elements.\>"; 
    factorGroup::usage\  = \ "\<factorGroup[n_,gg_:glo] first tests whether \
the subgroup 'n' of 'g' is normal; 'g' must be an indexTable (default \
'globa') and 'n' a subgroup list (as output by 'lcoset' or 'subgroups'). The \
factorGroup g/n (also called the quotient group) is identified\>"; 
    fenyvesQ::Usage = "\<fenyvesQ[gg_:glo,o_:0] tests whether \
(xy.z)x=x.(y.zx) for all x,y,z in 'gg'. See Kinyon,Sci.Math.Res,19/8/3\>"; 
    flexQ::usage = "\<flexQ[gg_:glo] tests whether xy.x=x.yx for all x,y,z in \
'gg'. See Smith & Romanskowa, PMA p92.\>"; 
    flexibleQ::usage = "\<flexibleQ[gg_:glo] tests whether \
\[LeftAngleBracket]x,y,z\[RightAngleBracket]=-\[LeftAngleBracket]z,y,x\
\[RightAngleBracket] for all x,y,z in 'gg'. ?ref lost?\>"; 
    fp::usage = "\<fp[g_?indexTableQ,list_pow2] maps 'list' onto 'g' and \
factorises the determinant. If necessary, 'list' is right padded with zeroes.\
\>";\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(frag::usage = "\<frag[g_,o_:0] where 'g' may be a hoop or its \
determinant factors, creates (as far as possible) the fragmented form, using \
known shapes where available. The root multiplicity is reported if >1.\>"; 
    frag2::usage = "\<frag2[Polynomial_,o_:0] attempts to convert quadratic \
factors of a quasigroup determinant to sums and/or differences of squares. It \
is Listable, and returns non-quadratics unchanged, so it can be applied to \
'hoopFactor' & 'fa' output. The 'polsort' table is printed if o>0. The \
current version is wrong with factors of a few signed tables; use 'o'=1 to \
test for failure in new cases (the unfragmented result is returned if 'o'=0). \
The correct fragmentation can often be deduced from the diagnostic output\>"; 
    fromAlph::usage = "\</.fromAlph[vec_] replaces 'alph' symbols by those in \
'vec'.\>"; fromCycles::usage = "\<converts a cycle list to permutation\>"; 
    fromZtoCliff::usage = "\<fromZtoCliff[a_,B_:cliff,Z_:Range[32]] replaces \
items in 'Z' (default: 1 to 32) by items in 'B' (default: the elements of a \
Clifford algebra) preserving negation, in the expression 'a'.\>";\)], "Input",\

  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(gd::usage = "\<gd[] returns {mm,nn,{loop entry}} for the last loop to \
be identified.
   gd[Mnemonic_],gd[m_,n_] or gd[{m_,n_}] returns the requested 'loop' \
data\>"; ge::usage\  = \ "\<ge[gp_,pre_,o_:0] creates quasigroups via \
Relators and re-write rules. If 'gp' is {na, nb,...}, 'ge' sets up a vector \
of ordered string elements starting with the empty string followed by up to \
'na'-1 repetitions of 'a', followed by 'nb'-1 repetitions of 'b', etc but not \
beyond 'g'. 'pre' contains any re-write rules for out-of-order or squared \
(quaternion-style) letters. These are preferably strings, but symbols can be \
used and will be converted to strings. Bad rules (with overlong character \
repeats, etc) are rejected if 'o'>=0. A full set of re-write rules is created \
from 'pre' by adding any unspecified Abelian rules such as \
'ba\[RightArrow]ab'. A preliminary array is created by concatenating the \
elements. The re-write rules are then applied to reduce concatenations to \
elements. If Abs[o]=1, non-quasigroups are rejected, non-conservativity is \
reported, the table is put into global list 'matel', and the elements are put \
into global list 'genel'. The reduced array is converted to an indexTable g. \
If the last element of gp is a real number r, g will be collapsed to a signed \
table by g=ts[g,r].  Finally,g is output. groupFromRelators is a skeleton \
version.\>"; 
    genel::usage = "\<Global. The string elements of the last generator group \
to have been created with 'o'=1\>";\), "\[IndentingNewLine]", 
    \(\(genCos::usage = "\<genCos[x_,m_:4,j_:0] creates the j'th phase of the \
generalized antisymmetric sinusoid or helix with m phases; generalised Cosh \
and Sinh functions are generated if m=0 or 2.\>";\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(genQuadratic::usage = \
\*"\"\<genQuadratic[A_?VectorQ,B_?VectorQ,C_?VectorQ,g_:gmn] solves the \
quadratic equation \!\(Ax\^2\)+Bx+C=0 in the algebra 'g', provided that \
'hoopPower' exists for 'g'. Still has PROBLEMS.\>\"";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(hoopShape::usage\  = \ "\<hoopShape[X_,o_:0] accepts either a valid \
Protoloop identifier ({mm,nn} or mnemonic) or a loop table. If the loop is \
symbolic, it creates a rule that will apply the symbols to the final result. \
If the specific shape[X] is not available, the indexTable (up to \
11\[Cross]11) is found, put into 'glo' and used to set 'gi' for use by \
'hoopInverse' and to find the generalised shape. The output is converted to \
the loop symbols if necessary. Non-conservative loops are rejected unless o<0\
\>"; genSin::usage = "\<genSin[x_,m_:4,j_:0] creates the j'th phase of the \
generalized symmetric sinusoid or helix with m phases; generalised Cosh and \
Sinh functions are generated if m=0 or 2.\>";\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(gi::usage = "\<Data required by hoopInverse & set up by sh, shape or \
hoopFactor, consisting of the location of the signed 1's in the indexTable \
rows, multiplied by the inverse sign if the 1 is signed, & followed by the \
multiplicity of the factors (which is zero for factored quartics).\>"; 
    gInverse::usage = "\<finds the element inverses\>"; 
    glo::usage = "\<Set by 'ge', 'ma', 'pe', 'hoopTest', 'hoopTimes', & \
'makeProtoloop' as the (global) indexTable of the loop being created or \
investigated; the default argument in many operations. See 'globa', \
'gmn'.\>"; 
    globa::usage = "\<Set by 'subgroups'. The (global) indexTable of the loop \
being analyzed. See 'glo', gmn'\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(gmap::usage\  = \ "\<gmap[gg_,v_] maps the elements of the list 'v' \
onto the indexTable 'g', which may include signed elements.\>"; 
    gmn::usage\  = \ "\<Set by 'id' & 'makeProtoloop'; the (global) mnemonic \
of the current loop,used widely as a default argument. See 'globa', glo'\>"; 
    gp::usage = "\<Size multiplicity data needed by 'hoopPower', set up for \
the target loop by 'sh', 'hoopFactor' & 'toPolar'\>"; 
    gpd::usage = "\<gpd[gg_] is used on function arguments that should be \
groupoids (i.e. magmas, loops, quasigroups). It removes any TraditionalForm \
wrapper and rejects non-groupoids by 'Abort[]'. The first row must contain \
the elements, which may be matrices; signed elements are permitted in the \
body of the table.\>";\), "\[IndentingNewLine]", 
    \(grayinv::usage = "\<grayinv[a_] calculates the inverse Graycode \
function of 'a', which must be an IntegerDigits list. Used in 'cl'\>"; 
    groupFromRelators::usage = "\<groupFromRelators[gp_,post_:{}] is a \
skeleton version of ge, which only handles pre-checked relators and only \
creates Cayley tables for groups.\>";\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{\(hamiltonianQ::usage = "\<hamiltonianQ[g_:glo] is true if 'g' \
is not abelian but all subgroups are normal\>"; 
    hmin::usage = "\<hmin is arbitrarily set at 4$MachineEpsilon as the \
criterion for 'hoopInverse' to ignore (renormalize) partial fractions with \
near-zero denominators.\>"; 
    hoopFactor::usage = "\<hoopFactor[f_:fp] is called by 'hoopShape' & \
'hoopTest' to create 'gi' from the indexTable 'glo', for use by \
'hoopInverse'; and returns the short or (if the first argument is 'fa') the \
symbolic factor list.\>"; 
    hoopInverse::usage = "\<hoopInverse[vec_?VectorQ] finds the \
multiplicative left inverse of 'vec' (right-padded with zeroes if necessary) \
in the algebra specified by 'glo'. It is effective provided that the algebra \
is conservative - i.e. the determinant of the product is the product of the \
multiplicand determinants (up to a sign). The procedure is related to \
Cramer's method. If the determinant factorises, the inverse splits into \
partial fractions with determinant factors as denominators and their \
derivations as numerators. The sequence of derivation variables is fixed by \
the location of 1's in the IndexTable, and is given in 'gi'.
   'Partial-fraction division-by-zero' (renormalisation) is implemented by \
omitting partial-fractions with denominators (sizes) that are within \
\[PlusMinus]'hmin' of zero. 'hmin' has been arbitrarily set at \
4$MachineEpsilon (=2.^-50 on my machine). Renormalisation is related to the \
Moore-Penrose pseudo-inverse (which gives minimised root-mean-square \
solutions to inconsistent sets of equations), and corresponds to projecting \
any vec onto a constrained sub-algebra whilst 'ejecting' remainders Rl, Rr to \
maintain conservation if needed. hoopInverse[vec_,loop_,gi_,gshape_]is a \
skelton algorithm, omting all tests\>";\), "\[IndentingNewLine]", 
    RowBox[{\(hoopList::usage = "\<List of hoop names\>"\), ";", 
      StyleBox[\(hoopPower::usage = \*"\"\<hoopPower[A_, r_:1/2] calculates \
\!\(A\^r\) if the target loop has a polar form.\>\""\),
        ShowStringCharacters->True,
        NumberMarks->True], 
      StyleBox[";",
        ShowStringCharacters->True,
        NumberMarks->True], 
      StyleBox[\(hoopRoot::usage = "\<hoopRoot[A_?VectorQ] calculates the \
square root of A in the target algebra if it has a polar form. It is faster \
than using hoopPower.\>"\),
        ShowStringCharacters->True,
        NumberMarks->True], 
      StyleBox[";",
        ShowStringCharacters->True,
        NumberMarks->
          True], \(hoopTimes::usage\  = \ "\<hoopTimes[a,b] or \
hoopTimes[a_,b_,gg_] multiplies the vectors 'a' & 'b' to give a product 'p' \
according to the indexTable 'gg' (default 'glo'). This may include signs. \
Remainders Rl & Rr are created, so that a=p/b+Rl, b=p/a+Rr, maintaining \
conservation. hoopTimes[a_,b_,loop_,c_] is a skeleton, omitting all tests, \
defaults and remainders. c is a dummy argument. \>"\), 
      ";", \(hoopTest::usage = "\<hoopTest[X_:{mm,nn},t_:Real,r_:{-1.,1.}] \
accepts either a valid Protoloop identifier ({mm,nn} or mnemonic) or a \
groupoid indexTable. It sets 'glo' to the indexTable and creates two suitable \
random vectors in the field 't' with range 'r'. If the shape is known or \
calculable it is tested for conservation and division. If the Polar and \
Vector forms are known, reversion, powers and (if abelian) quadratic equation \
solutions are tested; if the hyPolar and hyVector forms are known, their \
reversion is tested. Successful tests are reported.\>"\), 
      ";", \(id::usage\  = \ "\<id[G_,L_:{}] uses a range of tests to \
identify 'G', which may be a name, or {mm,nn}, or an indexTable; if an \
index-list 'L' is specified, the corresponding subgroup of 'G' is identified. \
Associativity is not tested (for speed of execution) so unknown groupoids may \
be wrongly identified. Names: Cn, Dn/2, & Qn are cyclic or generalised \
Dihedral and Quaternion groups with n elements. An & Sn have n generators. \
Alt12n, Oct, D4Mn etc  are 'Square associative' or 'alternative aa.b=a.ab' \
groupoids. XY, XiY,XpY are the direct or indirect compositions of X & Y. Xa \
is a second isomorph of X. Xr & Xc are conservative signed tables obtained \
from X that also provide conservative algebras on expanding with C2 or (C2 & \
C4). Loops with names ending in n are not conservative. Loops with M in the \
name are non-associative Moufang loops. gnnmm is GAP SmallGroups(mm,nn). If \
the name contains ? identification is provisional because all groups of that \
size have not been distinguished. The global variables glo, gmn,mm,& nn are \
set by id. gmn is returned and gd[] will provide more details.\>"\), 
      ";", \(idc::usage\  = \ "\<idc[G_?MatrixQ,L_:{}] checks that 'G' is \
conservative before attempting identification via 'id'\>"\), ";"}]}], "Input",\

  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(indexTableQ::usage = "\<indexTableQ[gg_:glo]] checks that the first row \
and column are Range[Length[gg]] and that every row and column contains each \
of these (possibly signed) integers once\>"; 
    jacobiQ::usage = "\<jacobiQ[gg_:glo,o_:0] tests whether xy=-yx & \
x.yz+y.zx+z.xy=0 for all x,y,z in glo\>"; 
    jordanQ::usage = "\<jordanQ[gg_:glo,o_:0] tests whether (xy).xx=x(y.xx) \
up to a sign\>"; 
    lcoset::usage\  = \ "\<lcoset[h_,g_:glo] finds the left coset for the \
subgrouplist 'h' in the indexTable 'g' or in 'glo'\>"; 
    linearFactor::usage = "\<linearFactor[f_,l_] finds the symbolic 'alph' \
form of a linear factor 'f' generated by 'fp' for a group of length 'l'\>"; 
    lmatrix::usage\  = \ "\<lmatrix[gg_?indexTableQ] converts 'gg' into the \
corresponding matrix with 1's on the diagonal and {1,2,3..,m} in the first \
column. If an ordered set of symbols or numbers is mapped onto an lmatrix, \
the groupoid product is given by the left matrix dot product of this matrix \
and any other ordered set. Cf rmatrix.\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(KS::"\<usage\>" = "\<KS[l_List,k_Integer?Positive,gap_:{},lef_:{}] is \
an adaptation of k-subsets in Skiena p44, to create subsets, of length 'k' of \
group indices that give groupoids from 'globa'. It creates a list 'gap' of \
rejected indices and a list 'lef' of elements left in, adding to 'lef' those \
new elements that do not have any products in 'gap'.\>"; 
    loop::"\<usage\>" = "\<loop[[mm,nn]] is the data file. 'mm' is the number \
of elements, and 'nn' is the position in the extended GAP Atlas entry. For \
each loop, the first entry is the mnemonic, the second is 'dico', the third \
specifies a test (0 if 'dico' is unique), the fourth is a prescription, the \
5th & 6th define the generators. If matrix formulations are known they are \
supplied as indices for 2\[Cross]2, 3\[Cross]3, & 4\[Cross]4 standard \
matrices u2, u3, u4. In a few cases, extra table creation procedures are \
appended.\>";\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(loopQ::usage = "\<loopQ[gg_?MatrixQ,o_:0] tests whether the first row \
and first column are the same set of different elements (i.e. are the unit) \
and every row and column contain every element once (up to a sign). If 'o' \
\[NotEqual] 0 the reason for rejection will be output.\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(ma::"\<usage\>" = "\<ma[{mm__},maxel_:72,o_:0] takes a list of one or \
more unitary monomial signed square matrices (all of the same size) and \
prepends the unit matrix. It then creates the dot products of these matrices \
and appends any that are not already present, until the size exceeds 'maxel' \
or a group has been completed. The group is then created as (global) element \
list 'matel' which is output if o\[NotEqual]0; the indexTable is put into \
'glo' and is output.\>"; 
    matel::usage = "\<Global. The elements of the latest matrix (ma or ms) or \
relator (ge) group. (The last relator acts as a sign in a signed table.)\>"; 
    makeProtoloop::usage\  = "\<makeProtoloop[g_:{mm,nn},o_:0] is the full \
name for 'mp', q.v.\>"; "\<makeProtoloop[] or makeProtoloop[mm,nn] uses the \
first available prescription in gd[mm,nn] to create the protoloop.
   makeProtoloop[G_:MatrixQ,o_:0] recognises three formats for G - a string \
(mnemonic) as a name, indices {mm,nn} in 'loop' (i.e. the extended GAP Atlas \
identifiers), or a matrix. It then attempts to make the protoloop, returning \
'Unknown' or 'No protoloop' and clearing matel as appropriate. If 'o'=0 it \
uses the first available formulation. If 'o' is 1, 'ge' is used.  If 'o' is \
2, 3, or 4, the corresponding matrix formulation is used in mg. ms is used \
for signed tables
   If 'o' is 5 or 6, different protoloops may be generated (only P16a, P16i, \
g2003, Alt12n so far). The indexTable is output.\>";\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(matstrep::usage\  = \ "\<matstrep[l_,rul_,sm_:smax] performs up to 'sm' \
string replace repetitions on the matrix.\>"; 
    md::usage = "\<md[g_,l_:{}] (Moufang doubling) creates a non-associative \
Moufang loop from a non-abelian group. l={} uses gInverse to implement Chein \
doubling; 3 cases use l as a reordering.\>"; 
    mg::usage = "\<mg[v_?VectorQ,u_] (Matrix Group) creates a matrix by \
sending the u matrices given in 'v' to 'ma'.u may be u2,u3, or u4. The size \
is limited to 'mm'+1\>"; 
    minsign::usage = "\<minsign[g_] finds any signed elements of 'g' and sets \
up the appropriate simplification list from 'unitSigns'\>"; 
    mm::usage = "\<Global. mm is the table size of entries in 'loop', set by \
'id' & 'gd', used as {mm,nn} in many procedures\>"; 
    modqr::usage = "\<The 'modqr' function shifts a signed index 'r' by 'q' \
whilst keeping in the range \[PlusMinus]{1,2q}. e.g. modqr[3,-2] = -5. Used \
in 'cd'.\>"; 
    MoufangQ::usage = "\<MoufangQ tests if zx.yz=(z.xy)z, the 3rd Moufang \
Identity. See PMA p92. As this fails for many conservative signed tables such \
as Qr, unsigned tests can be performed by moufangQ.\>"; 
    moufangQ::usage = "\<Tests if |zx.yz|=|(z.xy)z|, the (unsigned) 3rd \
Moufang Identity. See PMA p92\>"; 
    moufangLQ::usage = "\<Tests if |(zy.z)x|=|z(y.zx)|, the (unsigned) Left \
Moufang Identity. See PMA p93\>"; 
    moufangRQ::usage = "\<Tests if |x(z.yz)|=|(xz.y)z|, the (unsigned) Right \
Moufang Identity. See PMA p93\>"; 
    mp::usage = "\<mp[] or mp[mm,nn] uses the first available prescription in \
gd[mm,nn] to create the protoloop.
   mp[G_:MatrixQ,o_:0] recognises three formats for G - a string (mnemonic) \
as a name, indices {mm,nn} in 'loop' (i.e. the extended GAP Atlas \
identifiers), or a matrix. It then attempts to make the protoloop, returning \
'Unknown' or 'No protoloop' and clearing matel as appropriate. If 'o'=0 it \
uses the first available formulation. If 'o' is 1, 'ge' is used.  If 'o' is \
2, 3, or 4, the corresponding matrix formulation is used in mg. ms is used \
for signed tables.
   If 'o' is 5 or 6, different protoloops may be generated (only P16a, P16i, \
g2003, Alt12n so far). The indexTable is output.\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(ms::usage = "\<ms[v__?ListQ,l_:u2,maxel_:33] makes signed tables that \
may be hoops, from the specified unitary monomial matrices. It puts the unit \
matrix and either the matrices in v (or if v is a list of indices, possibly \
signed, the listed matrices from l, where l is u2,u3 or u4), into matel. It \
then creates a table from their dot products, adding any that do not match \
signed existing ones, up to a limit maxel. ms is used in place of mg in mp \
for signed tables\>"; 
    msi::usage = \
"\<msi[v__?ListQ,l_:u2,si={1,-1,\[ImaginaryI],-\[ImaginaryI]},maxel_:64] is a \
variation on ms that handles P4 and P16c\>"; 
    mstst::usage = "\<mstst[m_,s_] tests whether matel contains a version of \
the matrix m, multiplied by the signs in s, returning 0 or the corresponding \
sign for use in ms.\>"; 
    ncm::usage = "\<ncm performs some simplifications on NonCommutative \
polynomials of up to 3 variables. Should be replaced by instructions from \
NCAlgebra@math.ucsd.edu.\>"; 
    negatableQ::usage = "\<negatableQ[gg_:glo,f_:2] tests whether the table \
'gg' has the same elements in each 1/f \[Times] 1/f fraction with elements \
shifted by 'm/f' (allowing for signs). If so, the top left fraction may \
describe a signedTable.\>";\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(nn::usage = "\<Global. 'nn' is set by 'id', 'hoopTest', 'hoopTimes & \
'gd', and used in {mm,nn} to identify the position of an entry (of length mm) \
in 'loop'\>"; 
    normalSubgroup::usage\  = \ \*"\"\<normalSubgroup[h,g] tests whether 'h' \
is a normal subgroup of 'G', i.e. gh\!\(g\&_\)\[Epsilon]H, all g,h.\>\""; 
    orderCount::usage = "\<gives the order of each element in 'g'\>"; 
    pe::usage = "\<Generates a loop from a list of permutations such as \
s4\>"; period::usage = "\<standard group function\>"; 
    permute::usage = "\<If 'p' is a valid sub-permutation, \
permute[P_List,p_List] returns the sublist of 'P'\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(pick::usage = "\<pick[g_,m_List,n_List] picks out the rows 'm' & \
columns 'n' from 'g'\>"; 
    plex::usage = "\<The vec used to give a plex-conjugate to {a,b,...}; set \
up by some shapes. If it does not give the standard shape in an obvious way, \
the plex form of the shape is supplied as a comment. Conjugates are a \
meta-mathematical trick that provide a quadratic size in some algebras; the \
more general approach is via the explicit 'shape' functions that give all the \
conserved sizes.\>"; 
    polsort::usage = "\<creates a sorted list of elements in the polynomial \
P, for use in 'frag'\>"; 
    pos::usage = "\<pos[a_] negates 'a' if the first term is negated, so that \
'frag2' squared terms match.\>"; 
    pow2::usage = "\<A list {a,1,2,4,8..} used as elements of Cayley Tables \
to allow fast determinant evaluation via fp & 'linearFactor'. (May have \
problems with some Clifford algebras - use fp[G,power2 or power3].)\>"; 
    power2::usage = "\<A list {a,3,7,1,2,4,8..} used as elements of Cayley \
Tables to allow fast determinant evaluation via 'fp'\>"; 
    power3::usage = "\<A list {a,1,2,3,9,27,81..} used as elements of Cayley \
Tables to allow fast determinant evaluation via 'fp'.\>";\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(QPower::usage = "\<QPower[{a,b,c,d},r]  raises the quaternion (or \
biquaternion, as the coefficients can be complex) to the power or root r, \
giving the square root if r is omitted\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(rcoset::usage\  = \ "\<rcoset[h_,g_] finds the right coset for the \
subgrouplist 'h' in the indexTable'g' or in 'glo'\>"; 
    reductiveQ::usage = "\<tests xy.xx=x(y.xx)\>"; 
    reim::usage\  = \ "\<Replaces Derivative[Re] by Re, etc\>"; 
    reorder::usage\  = \ "\<reorder[gg_?indexTableQ,p_] generates the \
indexTable of 'gg' as reordered by the permutation 'p'; short permutations \
give sub-tables.\>"; riffQ::usage = "\<Tests if xy(z.xy)=((x.yz).x)y\>"; 
    r3::usage = "\<1/Sqrt[3]\>"; 
    Rl::usage = "\<The left remainder from the last P=hoopTimes[A,B], \
containing the sizes of A that are zero in P\>"; 
    Rr::usage = "\<The right remainder from the last P=hoopTimes[A,B], \
containing the sizes of B that are zero in P\>"; 
    rmatrix::usage\  = \ "\<rmatrix[gg_?indexTableQ] converts 'gg' into the \
corresponding matrix with 1's on the diagonal and {1,2,3..,m) in the first \
row. If an ordered set of symbols or numbers is mapped onto an rmatrix, the \
groupoid product is given by the right matrix dot product of this matrix and \
any other ordered set. Cf lmatrix\>"; 
    rotateQOP::usage = "\<rotateQOP[{vecs},axis,angle,hoop:gmn] rotates the \
vecs (truncated or padded with zeroes if necessary) through angle about axis \
(which is also truncated or padded) The hoop must be Qr,Octr, or P4. gmn is \
set for further use. The classic Euler defnition is used, multiplying twice \
by half angles.\>"; 
    ruleExpand::usage\  = \ "\<ruleExpand[a] applies 'stringExpand' to a list \
of compressed rules e.g a4b2\[ShortRightArrow]aaaabb.\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(select::usage = "\<select[l_] finds all elements appearing as products \
in the subarray 'l' of 'globa'\>"; 
    s3::usage = "\<s3 is the list of permutations that define S3\>"; 
    s4::usage = "\<s4 is the list of permutations that define S4\>"; 
    s5::usage = "\<s5 is the list of permutations that define S5\>"; 
    sg::usage = "\<sg is the (global) list of subgroup indices created by \
'subgroups'; used by 'subgroupTypes'\>"; 
    sh::usage = "\<sh[hoop] is the list of factors of the symbolic hoop \
determinant.\>"; 
    shape::usage = "\<shape[vec_,mnemonic_] obtains specific shape data \
(where known) from sh for the current or specified loop. The real determinant \
factors (i.e. those that are conserved) are supplied, and the lists gi & gp \
are set up for use by hoopInverse & toPolar. Plex conjugates are also \
supplied (where known) for completeness.\>"; 
    sgroup::usage\  = \ "\<sgroup[m_?IntegerQ] is adapted from Skiena p17. It \
creates the indexTable for S[n]\>"; 
    sh12::usage = "\<sh12[{12vec}] is the standard shape data for Dozal, the \
12-element groups C3C4, C3K, Q12, D3C2, A4. It includes functions that are \
conserved on general multiplication but are not determinant factors, and \
others that are only conserved in some multiplications of orbits\>";\)], \
"Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(signlist::usage = "\<signlist={\[DoubleStruckD],\[DoubleStruckO],\
\[DoubleStruckG],\[DoubleStruckH],\[DoubleStruckP],\[DoubleStruckCapitalI],\
\[DoubleStruckCapitalY],\[DoubleStruckCapitalJ],\[DoubleStruckM],\
\[DoubleStruckN],\[DoubleStruckS]} is the list of extended signs. These are \
different 12th, 8th, 7th, 6th, 5th, 4th, 3rd, 3rd, 2nd, 2nd & 9th roots of +1 \
respectively. \[DoubleStruckS] is the general sign or \[DoubleStruckR]'th \
root of +1. See also 'unitSigns'.\>"; \[DoubleStruckD]::usage = \
\*"\"\<Extended Sign. \!\(\[DoubleStruckD]\^12\)=1\>\""; \
\[DoubleStruckG]::usage = \*"\"\<Extended Sign. \!\(\[DoubleStruckG]\^7\)=1\>\
\""; \[DoubleStruckH]::usage = \*"\"\<Extended Sign. \
\!\(\[DoubleStruckH]\^6\)=1\>\""; \[DoubleStruckCapitalI]::usage = \
\*"\"\<Extended Sign. \!\(\[DoubleStruckCapitalI]\^4\)=1\>\""; \
\[DoubleStruckCapitalJ]::usage = \*"\"\<Extended Sign. \!\(\
\[DoubleStruckCapitalJ]\^3\)=1\>\""; \[DoubleStruckK]::usage = \
\*"\"\<Extended Sign. \!\(\[DoubleStruckK]\^2\)=1\>\""; \
\[DoubleStruckL]::usage = \*"\"\<Extended Sign. \!\(\[DoubleStruckL]\^2\)=1\>\
\""; \[DoubleStruckM]::usage = \*"\"\<Extended Sign. \
\!\(\[DoubleStruckM]\^2\)=1\>\""; \[DoubleStruckN]::usage = \*"\"\<Extended \
Sign. \!\(\[DoubleStruckN]\^9\)=1\>\""; \[DoubleStruckO]::usage = \
\*"\"\<Extended Sign. \!\(\[DoubleStruckO]\^8\)=1\>\""; \
\[DoubleStruckP]::usage = \*"\"\<Extended Sign. \!\(\[DoubleStruckP]\^5\)=1\>\
\""; \[DoubleStruckS]::usage = \*"\"\<Generalised Extended Sign, the \
\[DoubleStruckR]'th root of unity. \!\(\[DoubleStruckS]\^\[DoubleStruckR]\)=1\
\>\"";\), "\n", 
    \(\(\(\[DoubleStruckCapitalY]::usage = \*"\"\<Extended Sign. \!\(\
\[DoubleStruckCapitalY]\^3\)=1\>\"";\);\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(signedTableQ::usage = "\<tests whether the group is an indexTable with \
signed elements\>"; 
    simC2::usage = "\<simc2[a_,b_,o_:0] solves a set of simultaneous \
equations ax+b=0 for x in the C2 algebra. The determinant factorises into p \
and n (i.e. \[PlusMinus]); if either is zero, the indeterminate solution has \
a degree of freedom $x. If o\[NotEqual]0 the solution is collapsed to real \
numbers\>"; 
    strep::usage\  = \ "\<created by ge[...,\[PlusMinus]1] as string \
replacement rules.\>"; 
    streprpt::usage\  = \ "\<streprpt[str_,rul_,imax_] performs up to 'imax' \
string replace repetitions using the list 'rul'.\>"; 
    stringExpand::usage\  = \ "\<stringExpand[t] replaces 'letter integer' by \
'integer' repetitions of 'letter' in the string 't'.\>";\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(subgroupTypes::usage\  = \ "\<subgroupTypes[] or subgroupTypes[%] may \
be used after subgroups[g] to identify them in order.\>"; \ 
    subgrpPerm::usage = "\<subgrpPerm[G_,a_:0] & subgrpPerm[G_,a_,b_,c_] are \
implementations of RandomPermutation from Skiena p7. They permute the group \
to increase the chance of pruning, and usually speed up the determination of \
subgroups for groups with 'm'>47. a, b, & c are arguments that are passed \
through.\>"; 
    subgroups::usage\  = \ "\<subgroups[g_,o_,i1_,i2_,p_:associativeQ] finds \
all the subloops, in the IndexTable 'g' that pass the 'p' test, so the \
default finds subgroups, within the optional length range {i1,i2}, as \
sublists of indices. 'globa' is set to 'g'. If 'o'=0, the number of subloops \
is output; if 'o'=1 the sublist is put into 'sg', for use by 'id' and is \
output; o=2 gives both.
  subgroups[g_,-n,i1_] or subgroups[g_,any,i1_,any,{n__}] test whether the \
subgroup identified as {i1,n} or {i1,n__} is a subgroup of 'g', returning 0 \
or the first matching n__ found. Used by 'id'\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(tf::usage = "\<TraditionalForm\>";\)\), "\n", 
    \(\(tidy::usage\  = \ "\<tidy[g_:globa,n_:-1,o_:1,p_:{}] uses the list \
'n' (or the n'th subgroup if 'n' is an integer; the default is the last found \
subgroup) in the top-left corner of a reordering of 'g'; 'o' is the \
(optional) element at the beginning  of the next column. 'p' is the \
(optional) starting  element (or list) for the remainder. The reorder list \
and the new table are output. The default group is 'globa', as set up by \
'subgroups'. It is faster to specify a subgroup as an element-list than to \
specify a position in the subgroup list, as the latter has to proceed via \
'subgroups', which is slow for large groups\>";\)\), "\n", 
    \(toCycles::"\<usage\>" = "\<toCycles[perm_?VectorQ] generates the cycles \
from the permutation.\>"; 
    toIndexTable::usage\  = \ "\<toIndexTable[g_?MatrixQ] rearranges a \
shuffled indexTable to make the first row and column into {1,2,...m}\>"; 
    tohyPol::usage = "\<tohyPol[{radius,angle}__,mnemonic_] contains the \
hyperbolic forms\>"; 
    tohyPolar::usage = "\<tohyPolar[vec_,mnemonic_] obtains the hyperbolic \
form for the current groupoid\>"; 
    tohyVec::usage = "\<tohyVec[{ulna,angle}__,mnemonic_] contains the \
hyperbolic forms\>"; 
    tohyVector::usage = "\<tohyVector[hpf_,mnemonic_] reverts the hyperbolic \
form for the current groupoid\>";\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(toPol::usage = "\<toPol[vec_,mnemonic_] gives the polar form of vec in \
the specified hoop.\>"; 
    toPolar::usage = "\<toPolar[vec_,mnemonic_] obtains the polar form from \
the vector form for the current groupoid\>"; 
    toSignedTable::usage\  = \ "\<toSignedTable[g_?MatrixQ,r_:2,reo_:{},o_:0] \
(abbreviation ts) attempts to collapse 'g' to a signed table of length m/|r|, \
after reordering if 'reo' is provided. Non-conservative tables are rejected \
unless 'r'<0. Collapse is a skeleton,omitting reordering and all tests.\>"; 
    toVec::usage = "\<toVec[mnemonic_] gives the vector form, using 'alph' \
variables.\>"; 
    toVector::usage = "\<toVector[pf_,mnemonic_] reverts the polar form to \
the vector form for the current groupoid\>";\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(trico::usage = "\<trico[g_] is the count of elements of 'g' having cube \
roots, with the unit roots first \>"; 
    ts::usage\  = \ "\<ts[a___] is an abbreviation, used in data, for \
toSignedTable[g_?MatrixQ,r_:2,reo_:{},o_:0]. It attempts to collapse 'g' to a \
signed table of length m/|r|, after reordering if 'reo' is provided. \
Non-conservative tables are rejected unless 'r'<0.\>"; 
    u2::usage = "\<u2, u3, & u4 are lists of 2\[Times]2, 3\[Times]3, & 4\
\[Cross]4 monomial unit matrices that include the Pauli Sigma and Dirac Gamma \
and Tau matrices. These allow development of matrix groups with different \
symmetries. Only some root matrices are included; dot multiplying them \
together generates many more. In combination with 'loop' & 'makeProtoloop', \
they allow the generation of many small groups with sets of matrices as \
elements. Further work is needed to increase the number of groups \
handled.\>"; u3::usage = "\<See u2\>"; u4::usage = "\<See u2\>"; 
    union::usage = "\<Finds the unsorted union. Same as UnionNoSort of \
EAAM\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(unitSigns::usage\), "=", 
        "\"\<\[DoubleStruckD], \[DoubleStruckG], \[DoubleStruckH], \
\[DoubleStruckCapitalI], \[DoubleStruckCapitalJ], \[DoubleStruckL], \
\[DoubleStruckK], \[DoubleStruckM], \[DoubleStruckN], \[DoubleStruckO], \
\[DoubleStruckP], \[DoubleStruckS] and \[DoubleStruckCapitalY] are set up to \
act as unit signs related to \[ImaginaryI], with \
\[DoubleStruckD]=\!\(\@\(+1\)\%12\), \[DoubleStruckG]=\!\(\@\(+1\)\%7\), \
\[DoubleStruckCapitalI]=\!\(\@\(+1\)\%4\) (and distinct from \[ImaginaryI] \
and I), \[DoubleStruckCapitalJ]=\!\(\@\(+1\)\%3\) and \
\[DoubleStruckCapitalY]=\!\(\@\(+1\)\%3\)(both distinct from \
\!\(TraditionalForm\`\[ImaginaryJ]\)  which is synonymous with \[ImaginaryI] \
and I in Mathematica), \[DoubleStruckH]=\!\(\@\(+1\)\), \[DoubleStruckK]=\!\(\
\@\(+1\)\), \[DoubleStruckM]=\!\(\@\(+1\)\) (all being extra negations), \
\[DoubleStruckN]=\!\(\@\(+1\)\%9\), \[DoubleStruckO]=\!\(\@\(+1\)\%8\), \
\[DoubleStruckP]=\!\(\@\(+1\)\%5\), \[DoubleStruckS]=\!\(\@\(+1\)\%\
\[DoubleStruckR]\). They are all non-Positive, with NumberQ=True, Abs=1, \
Re=0, Im=0 and equal their own Sign, so that 'gmap' treats them correctly. \
'unitSigns' reduces their powers to their primary range, whilst minsign \
creates a specific reduction rule. \[DoubleStruckS] is general \
\[DoubleStruckR]'th root of unity.\>\""}], 
      ";", \(unsign::usage = "\<unsign[g] replaces negated or complex signed \
elements in 'g' by the indices of the expanded table.\>"\), 
      ";", \(walsh::usage = "\<walsh[a_] calculates the Walsh function, \
\[PlusMinus]1, for 'a', which must be an IntegerDigits list;
  walsh[a_,list_] calculates the modified Walsh function with 'n' defining \
`negative-square` elements of 'a'. Used in 'cl'\>"\), 
      ";"}], "\n", \(\[Omega]::usage = "\<\[Omega]=2\[Pi]/3 used in many \
orbits\>";\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3 Usage for Predefined Index & Signed Tables.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(\( (*2, 
      3\ elements\ *) \)\(\[IndentingNewLine]\)\(C2::usage = "\<indexTable \
for C2\>"; C3::usage = "\<indexTable for C3\>"; 
    C3n::usage = "\<non-Moufang 3-element table\>"; 
    C3C3j::usage = "\<conservative \[DoubleStruckCapitalJ]-signedTable from \
C3C3, though conservativeQ and idc fail to simplify and so fail\>"; 
    C9J::usage = "\<conservative \[DoubleStruckCapitalJ]-signedTable from C9, \
though conservativeQ and idc fail to simplify and so fail\>"; 
    C9j::usage = "\<conservative \[DoubleStruckCapitalJ]-signedTable from a \
C9 isomorph, though conservativeQ and idc fail to simplify and so fail\>"; 
    C4C3c::usage = "\<conservative \[ImaginaryI]-signedTable\>"; 
    C3i::usage = "\<conservative \[ImaginaryI]-signedTable\>"; 
    C12c::usage = "\<conservative \[ImaginaryI]-signedTable\>";\
\[IndentingNewLine] (*\ 4\ elements\ *) \[IndentingNewLine]
    C4::usage = "\<indexTable for C4\>"; 
    K::usage = "\<indexTable for K \[Congruent] C2C2\>"; 
    P4::usage = "\<complexTable from P16 \[Congruent] Pauli algebra\>"; 
    P16c::usage = "\<complexTable from P16\>"; 
    C4C3c::usage = "\<signedTable from C4C3\>"; 
    Q4n::usage = "\<non-conservative signedTable related to Q4 & P4\>";  (*\ 
      5  elements\ *) \[IndentingNewLine]C5::usage = "\<indexTable for C5\>"; 
    C5n::usage = "\<The smallest non-associative Jacobi-identity loop \
(arXiv:hep-th/0111292 v1)\>";\[IndentingNewLine] (*6\ elements\ \
*) \[IndentingNewLine]
    C3C2::usage = "\<indexTable for C3C2\>"; 
    D3::usage = "\<indexTable for D3 \[Congruent] S3\>"; 
    D3C2c::usage = "\<signed indexTable from D3C2\>"; 
    C6n::usage = "\<A table with the repeated quadratic size of D3 replaced \
by two signed sums of 6 squares. Passes the hamiltonian test \
(only)\>";\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(\( (*\ 8, \ 
      9\ elements\ *) \)\(\[IndentingNewLine]\)\(C4C2::usage = "\<indexTable \
for C4C2\>"; C8::usage = "\<indexTable for C8\>"; 
    KC2::usage = \*"\"\<indexTable for KC2 \[Congruent]\!\(C2\^3\)\>\""; 
    D4::usage = "\<indexTable for D4\>"; 
    Q8::usage = "\<indexTable for quaternion group\>"; 
    CL12::usage = "\<signedTable Clifford(1,2)\>"; 
    P8::usage = "\<signedTable from KK\>";\[IndentingNewLine]
    Octi::usage = "\<'isoOctonion' signedTable from M(16,2)\>"; 
    Octr::usage = "\<signedTable from Oct or M(16,3)\>"; 
    O4::usage = "\<signedTable from C4K; O4a & O4b are isomorphs.\>"; 
    O4k::usage = "\<A signedTable from C4K with 4 linear and two quadratic \
sizes.\>"; Q8C2r::usage = "\<signedTable from Q8C2\>"; 
    Q8n::usage = "\<non-conservative Table related to Q8 & P8\>"; 
    C8an::usage = "\<signedTable cd[{2,-1.,-1}] that passes associativeQ & \
moufangQ but does not conserve its single factor\>";\[IndentingNewLine] (*\ 
      9\ elements\ *) \[IndentingNewLine]
    \(C3C3::usage = "\<indexTable for C3C3\>";\)\)\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(\( (*\ 
      12\ elements\ *) \)\(\[IndentingNewLine]\)\(C3C4::usage = "\<indexTable \
for C3C4\>"; C3K::usage = "\<indexTable for C3K \[Congruent] C3C2C2\>"; 
    Q12::usage = "\<indexTable for Q12\>"; 
    A4::usage = "\<indexTable for A4\>"; 
    A4a::usage = "\<second indexTable for A4\>"; 
    D3C2::usage = "\<indexTable for D3C2\>"; 
    C3P4::usage = "\<conservative 12-element complexTable\>"; 
    D3Mn::usage = "\<indexTable for M1201, 12-element non-associative Moufang \
Loop from D3\>"; 
    Alt12n::usage = "\<non-conservative alternative 12-element indexTable\>";\
\)\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(\( (*\ 
      16\ elements\ *) \)\(\[IndentingNewLine]\)\(Q16::usage = "\<indexTable \
for Q16\>"; D4C2::usage = "\<indexTable for D4C2\>"; 
    C4C4::usage = "\<indexTable for C4C4\>"; 
    Q8C2::usage = "\<indexTable for Q8C2\>"; 
    C8pC2::usage = "\<indexTable for C8pC2\>"; 
    KK::usage = \*"\"\<indexTable for KK \[Congruent] \!\(C2\^4\)\>\""; 
    C4K::usage = "\<indexTable for C4K\>"; 
    KiC4::usage = "\<indexTable for KiC4\>"; 
    C4iC4::usage = "\<indexTable for C4iC4\>"; 
    P16::usage = "\<indexTable for Pauli group P16\>"; 
    P16a::usage = "\<second indexTable for Pauli group P16\>"; 
    P16i::usage = "\<third indexTable for Pauli group P16\>"; 
    Oct::usage = "\<conservative alternative 16-element indexTable\>"; 
    r31r::usage = "\<16 element signedTable from g3249\>"; 
    CL4::usage = "\<16 element signedTable from g3250\>"; 
    D4M1n::usage = "\<indexTable for 16-element non-associative Moufang Loop \
from D4, GAP M1601\>"; 
    Q8M2::usage = "\<indexTable for 16-element associative Moufang Loop from \
Q8, GAP M1602\>"; 
    D4M4n::usage = "\<indexTable for 16-element non-associative Moufang Loop \
from D4, GAP M1604\>"; 
    D4M5n::usage = "\<indexTable for 16-element non-associative Moufang Loop \
from Q8, GAP M1605\>"; 
    Sed::usage = "\<The Sedenion (hexadecimilion) non-conservative \
non-alternative Cayley-Dickson algebra\>";\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(\( (*\ 
      20 + \ elements\ *) \)\(\[IndentingNewLine]\)\(D5Mn::usage = \
"\<indexTable for 20-element non-associative Moufang Loop from D5, GAP \
M2001\>"; 
    D3C2Mn::usage = "\<indexTable for 24-element non-associative Moufang Loop \
from D3C2, GAP M2401\>"; 
    A4Mn::usage = "\<indexTable for 24-element non-associative Moufang Loop \
from A4, GAP M402\>"; 
    Q12M3n::usage = "\<indexTable for 24-element non-associative Moufang Loop \
from Q12, GAP M2403\>"; 
    Q12M4n::usage = "\<indexTable for 24-element non-associative Moufang Loop \
from Q12, GAP M2405\>"; 
    Q12M5n::usage = "\<indexTable for 24-element non-associative Moufang Loop \
from Q12, GAP M2405\>"; 
    SL23::usage = "\<indexTable for 24-element group SL[2,3]\>"; 
    OctrC3::usage = "\<conservative alternative 24-element signedTable\>"; 
    Alt12nC2::usage = "\<non-conservative alternative 24-element \
indexTable\>"; P27::usage = "\<indexTable for group P27\>"; 
    g2704::usage = "\<indexTable for group 27-element without \
prescription\>"; 
    OctC2M::usage = "\<conservative alternative 32-element indexTable, GAP \
M3216\>"; 
    P16M::usage = "\<indexTable for 32-element non-associative Moufang Loop \
from P16, GAP M3221\>"; 
    C8pC2M::usage = "\<indexTable for 32-element non-associative Moufang Loop \
from C8pC2 GAP M3235\>"; 
    KiC4M::usage = "\<indexTable for 32-element non-associative Moufang Loop \
from KiC4, GAP M3254\>"; 
    C4iC4M::usage = "\<indexTable for 32-element non-associative Moufang Loop \
from C4iC4, GAP M4365\>"; 
    Alt12nC3::usage = "\<non-conservative alternative 36-element \
indexTable\>"; 
    OctC3::usage = "\<conservative alternative 48-element \
indexTable\>";\)\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["8. Start Private definitions.  Create Database.",
  FontFamily->"Times New Roman"]], "Subsection",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".1 Begin Private."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}}],

Cell[TextData[{
  "Begin[",
  StyleBox["\"`Private`\"",
    FontFamily->"Courier New"],
  "];\n\nprotected = Unprotect[NumberQ, Positive, Abs, Sign, Re, Im, \
Interval];(* no longer needed?*)"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".2 Miscellaneous definitions ",
  StyleBox["arcTanh, det, grayinv, pos, walsh",
    FontSlant->"Italic"],
  ", etc."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}}],

Cell["\<\
The following are general definitions that extend Mathematica without being \
specific to groups, loops, or hoops.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(arcTanh[adj_, opp_] := 
      Module[{x = Chop[adj], y = Chop[opp], b}, 
        If[\((x \[Equal] y || x \[Equal] \(-y\))\), 
          If[x \[NotEqual] 0, \[Infinity]\ Sign[y]/Sign[\ x], 0, 0], 
          b = Log[\((x + y)\)/\@\(x\^2 - y\^2\) // N]; 
          Chop[Re[b] + \[ImaginaryI]\ Chop[Im[b]]]]]; 
    arcTanh[{x_, y_}] := arcTanh[x, y];\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    StyleBox[\(Interval[{a_, a_}] := a;\),
      ShowStringCharacters->True,
      NumberMarks->True], "\[IndentingNewLine]", \(pos[a_] := 
      If[Head[a] === TraditionalForm, 
        If[Position[a[\([1, 1]\)], \(-_\)] === {{}}, \(-a[\([1]\)]\), 
          a[\([1]\)]], 
        If[Position[a[\([1]\)], \(-_\)] === {{}}, \(-a\), 
          a]];  (*used\ in\ frag*) \[IndentingNewLine]symdiff[a_Real, 
        b_Real:  0. ] := If[a < b, b - a, a - b, a - b]; 
    symdiff[a_Integer, b_Integer:  0] := 
      If[a < b, b - a, a - b, a - b]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"reim", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["Re", 
                TagBox[\((any_)\),
                  Derivative],
                MultilineFunction->None], "\[Rule]", "Re"}], ",", 
            RowBox[{
              SuperscriptBox["Im", 
                TagBox[\((any_)\),
                  Derivative],
                MultilineFunction->None], "\[Rule]", "Im"}]}], "}"}]}], 
      ";"}]}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(TraditionalForm\`\(\(det[\((a_)\)?MatrixQ, m_:  2] := 
          Module[{am = Abs[m], b = a, c, d, i, J, ln = Length[a], 
              lm = Length[a[\([1]\)]], t = Times}, 
            Which[ln \[Equal] 1, 
              d = Sum[J^\((i - 1)\)*a[\([1, i]\)], {i, lm}], lm \[Equal] 1, 
              d = Sum[J^\((i - 1)\)*a[\([i, 1]\)], {i, ln}], True, 
              If[ln > lm, b = Transpose[a]; lm = ln]; c = J*b[\([1]\)]; 
              b = Transpose[Drop[b, 1]]; 
              d = Sum[If[c[\([i]\)] === 0, 0, 
                    J^i*\ t[c[\([i]\)], det1[Drop[b, {i}], J, t]]], {i, 
                    lm}]]; CoefficientList[
                Expand[d] //. {J^any_ \[Rule] J^Mod[any, am]}, J] /. 
              J \[Rule] 
                Switch[am, 1, 1, 2, \(-1\), 3, \[DoubleStruckJ], 
                  4, \[DoubleStruckI]]];\);\)\), "\n", 
    \(TraditionalForm\`\(det1[a_, J_, t_] := 
        Module[{ln = Length[a], lm = Length[a[\([1]\)]], b, c}, 
          If[lm \[Equal] 1, Sum[J^\((i - 1)\)*a[\([i, 1]\)], {i, ln}], 
            b = Transpose[a]; c = J*b[\([1]\)]; b = Transpose[Drop[b, 1]]; 
            Sum[If[c[\([i]\)] === 0, 0, 
                J^i*t[c[\([i]\)], det1[Drop[b, {i}], J, t]]], {i, 
                ln}]]];\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  FontFamily->"Courier New",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[{
    \(walsh[a_] := If[EvenQ[Length[Position[a, 1]]], 1, \(-1\)]; 
    walsh[a_, n_] := If[EvenQ[Length[Position[a[\([n]\)], 1]]], 1, \(-1\)]; 
    grayinv[a_] := 
      Table[Mod[Plus @@ Take[a, i], 2], {i, 
          Length[a]}]\), "\[IndentingNewLine]", 
    \(Distribution[l_List] := Distribution[l, Union[l]];  (*\ 
      From\ Skiena\ p106\ *) \n
    Distribution[l_List, set_List] := Map[\((Count)\)[l, #] &, set]; 
    select[l_?ListQ]\  := 
      Union[Flatten[
          Table[globa[\([l[\([i]\)], l[\([j]\)]]\)], \ {i, \ 
              Length[l]}, \ {j, \ Length[l]}]]]; 
    union[lst_] :=  (*\ 
        Union\ No\ Sort\ as\ in\ EEAM . \ 
            Available\ as\ UnsortedUnion\ in\ \
Functions*) \[IndentingNewLine]Apply[Head[lst], 
        Fold[If[MemberQ[#1, #2], #1, Append[#1, #2]] &, {First[lst]}, 
          Drop[lst, 1]]]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(permfromQ[p_List, n_Integer] := 
      Length[Complement[p, Range[n]]] \[Equal] 0 && 
        Sort[p] \[Equal] Union[p]; 
    permute[P_List, p_List] := 
      If[permfromQ[p, Length[P]], P[\([p]\)], Print[{P, p, "\< error\>"}]]; 
    toCycles[perm_?VectorQ] := 
      Module[{c, i, m, n, p = perm}, 
        If[Sort[p] == Range[Max[p]], 
          Select[Table[
              m = \(n = p\[LeftDoubleBracket]i\[RightDoubleBracket]\); 
              c = {}; While[
                p\[LeftDoubleBracket]n\[RightDoubleBracket] \[NotEqual] 0, 
                AppendTo[c, m = n]; 
                n = p\[LeftDoubleBracket]n\[RightDoubleBracket]; 
                p\[LeftDoubleBracket]m\[RightDoubleBracket] = 0]; 
              c, {i, Length[p]}], #1 =!= {} &], "\<Not a Permutation\>"]]; 
    fromCycles[cyc_List] := 
      Module[{p = Range[Max[Flatten[cyc]]], pos}, 
        Scan[\((pos = Last[#1]; 
              Scan[Function[c, 
                  pos = \(p\[LeftDoubleBracket]pos\[RightDoubleBracket] = 
                      c\)], #1])\) &, cyc]; p]; 
    as[A_] :=  (*Relace\ alph\ dummy\ variables\ by\ the\ coefficients\ in\ A\
\ *) \[IndentingNewLine]Table[
        alph[\([ii]\)] \[Rule] A[\([ii]\)], {ii, Min[mm, Length[A]]}]; 
    tf = TraditionalForm; r3 = 1/Sqrt[3];\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".3 Extended (generalized) signs."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tExtended signs are roots of unity. They (and their low powers) are \
orthogonal to each other; several distinct r'th roots occur in many groups. \
(Projecting them onto the complex unit circle destroys these important \
properties.) A set of symbols is proposed as a standard (together with -, \
\[ImaginaryI], & -\[ImaginaryI]).  \[DoubleStruckCapitalI] and \
\[DoubleStruckCapitalJ] differ from related letters used in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", where I & \[DoubleStruckJ] are synonymous with \[ImaginaryI]. \n\t\
\[DoubleStruckS] is a generalized sign, the \[DoubleStruckR]'th root of \
unity; the others are specific extended signs. ",
  StyleBox["unitSigns",
    FontSlant->"Italic"],
  " is a simplifying function for expressions that include extended signs; ",
  StyleBox["minsign[expression] ",
    FontSlant->"Italic"],
  "creates a selective version for just those signs in ",
  StyleBox["expression",
    FontSlant->"Italic"],
  ". I suggest the convention that \"readable-ASCII-only\" documents use 'd, \
'g,...'Y (read as sign d, etc) for these double-struck letters."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}}],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(\[DoubleStruckR] =. \), ";", 
        RowBox[{"unitSigns", "=", 
          RowBox[{"{", 
            
            RowBox[{\(\[DoubleStruckD]\^12 \[ShortRightArrow] 1\), 
              ",", \(\[DoubleStruckD]\^any_ \[Rule] \
\[DoubleStruckD]\^Mod[any, 12]\), ",", \(\[DoubleStruckG]\^7 \[Rule] 1\), 
              ",", \(\[DoubleStruckG]\^any_ \[Rule] \
\[DoubleStruckG]\^Mod[any, 7]\), ",", \(\[DoubleStruckH]\^6 \[Rule] 1\), 
              ",", \(\[DoubleStruckH]\^any_ \[Rule] \
\[DoubleStruckH]\^Mod[any, 6]\), ",", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["\[DoubleStruckCapitalI]",
                    FontWeight->"Plain"], "4"], "\[Rule]", "1"}], ",", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["\[DoubleStruckCapitalI]",
                    FontWeight->"Plain"], "any_"], "\[Rule]", 
                SuperscriptBox[
                  StyleBox["\[DoubleStruckCapitalI]",
                    FontWeight->"Plain"], \(Mod[any, 4]\)]}], ",", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["\[DoubleStruckCapitalJ]",
                    FontWeight->"Plain"], "3"], "\[Rule]", "1"}], ",", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["\[DoubleStruckCapitalJ]",
                    FontWeight->"Plain"], "any_"], "\[Rule]", 
                SuperscriptBox[
                  StyleBox["\[DoubleStruckCapitalJ]",
                    FontWeight->"Plain"], \(Mod[any, 3]\)]}], 
              ",", \(\[DoubleStruckK]\^any_?OddQ \[Rule] \[DoubleStruckK]\), 
              ",", \(\[DoubleStruckK]\^any_?EvenQ \[Rule] 1\), 
              ",", \(\[DoubleStruckL]\^any_?OddQ \[Rule] \[DoubleStruckL]\), 
              ",", \(\[DoubleStruckL]\^any_?EvenQ \[Rule] 1\), ",", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["\[DoubleStruckM]",
                    FontWeight->"Plain"], \(any_?OddQ\)], "\[Rule]", 
                StyleBox["\[DoubleStruckM]",
                  FontWeight->"Plain"]}], ",", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["\[DoubleStruckM]",
                    FontWeight->"Plain"], \(any_?EvenQ\)], "\[Rule]", "1"}], 
              ",", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["\[DoubleStruckN]",
                    FontWeight->"Plain"], "9"], "\[Rule]", 
                StyleBox["1",
                  FontWeight->"Plain"]}], ",", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["\[DoubleStruckN]",
                    FontWeight->"Plain"], "any_"], "\[Rule]", 
                StyleBox[\(\[DoubleStruckN]\^Mod[any, 9]\),
                  FontWeight->"Plain"]}], 
              ",", \(\[DoubleStruckO]\^8 \[Rule] 1\), 
              ",", \(\[DoubleStruckO]\^any_ \[Rule] \
\[DoubleStruckO]\^Mod[any, 8]\), ",", \(\[DoubleStruckP]\^5 \[Rule] 1\), 
              ",", \(\[DoubleStruckP]\^any_ \[Rule] \
\[DoubleStruckP]\^Mod[any, 5]\), 
              ",", \(\[DoubleStruckS]\^\[DoubleStruckR] \[Rule] 1\), 
              ",", \(\[DoubleStruckS]\^any_ \[Rule] \
\[DoubleStruckS]\^Mod[any, \[DoubleStruckR]]\), 
              ",", \(\[DoubleStruckCapitalY]\^3 \[Rule] 1\), 
              ",", \(\[DoubleStruckCapitalY]\^any_ \[Rule] \
\[DoubleStruckCapitalY]\^Mod[any, 3]\)}], "}"}]}], ";"}], 
      "\n"}], "\[IndentingNewLine]", \(signlist = {\[DoubleStruckD], \
\[DoubleStruckG], \[DoubleStruckH], \[DoubleStruckCapitalI], \
\[DoubleStruckCapitalJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM], \[DoubleStruckN], \[DoubleStruckO], \[DoubleStruckP], \
\[DoubleStruckS], \[DoubleStruckCapitalY]};\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{\(NumberQ[\[DoubleStruckD]] = True\), 
      ";", \(NumberQ[\[DoubleStruckG]] = True\), 
      ";", \(NumberQ[\[DoubleStruckH]] = True\), 
      ";", \(NumberQ[\[DoubleStruckCapitalI]] = True\), 
      ";", \(NumberQ[\[DoubleStruckCapitalJ]] = True\), 
      ";", \(NumberQ[\[DoubleStruckK]] = True\), 
      ";", \(NumberQ[\[DoubleStruckL]] = True\), ";", 
      RowBox[{
        RowBox[{"NumberQ", "[", 
          StyleBox["\[DoubleStruckM]",
            FontWeight->"Plain"], "]"}], "=", "True"}], ";", 
      RowBox[{
        RowBox[{"NumberQ", "[", 
          StyleBox["\[DoubleStruckN]",
            FontWeight->"Plain"], "]"}], "=", "True"}], 
      ";", \(NumberQ[\[DoubleStruckO]] = True\), 
      ";", \(NumberQ[\[DoubleStruckP]] = True\), 
      ";", \(NumberQ[\[DoubleStruckS]] = True\), 
      ";", \(NumberQ[\[DoubleStruckCapitalY]] = True\), ";"}], "\n", 
    RowBox[{\(Positive[\[DoubleStruckD]] = False\), 
      ";", \(Positive[\(-\[DoubleStruckD]\)] = False\), 
      ";", \(Positive[\[DoubleStruckG]] = False\), 
      ";", \(Positive[\(-\[DoubleStruckG]\)] = False\), 
      ";", \(Positive[\[DoubleStruckH]] = False\), 
      ";", \(Positive[\(-\[DoubleStruckH]\)] = False\), 
      ";", \(Positive[\[DoubleStruckCapitalI]] = False\), 
      ";", \(Positive[\(-\[DoubleStruckCapitalI]\)] = False\), 
      ";", \(Positive[\[DoubleStruckCapitalJ]] = False\), 
      ";", \(Positive[\(-\[DoubleStruckCapitalJ]\)] = False\), 
      ";", \(Positive[\[DoubleStruckK]] = False\), 
      ";", \(Positive[\(-\[DoubleStruckK]\)] = False\), 
      ";", \(Positive[\[DoubleStruckL]] = False\), 
      ";", \(Positive[\(-\[DoubleStruckL]\)] = False\), ";", 
      RowBox[{
        RowBox[{"Positive", "[", 
          StyleBox["\[DoubleStruckM]",
            FontWeight->"Plain"], "]"}], "=", "False"}], ";", 
      RowBox[{
        RowBox[{"Positive", "[", 
          RowBox[{"-", 
            StyleBox["\[DoubleStruckM]",
              FontWeight->"Plain"]}], "]"}], "=", "False"}], ";", 
      RowBox[{
        RowBox[{"Positive", "[", 
          StyleBox["\[DoubleStruckN]",
            FontWeight->"Plain"], "]"}], "=", "False"}], ";", 
      RowBox[{
        RowBox[{"Positive", "[", 
          RowBox[{"-", 
            StyleBox["\[DoubleStruckN]",
              FontWeight->"Plain"]}], "]"}], "=", "False"}], ";", 
      RowBox[{
        RowBox[{"Positive", "[", 
          StyleBox["\[DoubleStruckO]",
            FontWeight->"Plain"], "]"}], "=", "False"}], 
      ";", \(Positive[\(-\[DoubleStruckO]\)] = False\), ";", 
      RowBox[{
        RowBox[{"Positive", "[", 
          StyleBox["\[DoubleStruckP]",
            FontWeight->"Plain"], "]"}], "=", "False"}], 
      ";", \(Positive[\(-\[DoubleStruckP]\)] = False\), ";", 
      RowBox[{
        RowBox[{"Positive", "[", 
          StyleBox["\[DoubleStruckS]",
            FontWeight->"Plain"], "]"}], "=", "False"}], 
      ";", \(Positive[\(-\[DoubleStruckS]\)] = False\), 
      ";", \(Positive[\[DoubleStruckCapitalY]] = False\), 
      ";", \(Positive[\(-\[DoubleStruckCapitalY]\)] = False\), 
      ";"}]}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{\(Abs[\[DoubleStruckD]] = 1\), ";", \(Abs[\[DoubleStruckG]] = 1\),
       ";", \(Abs[\[DoubleStruckH]] = 1\), 
      ";", \(Abs[\[DoubleStruckCapitalI]] = 1\), 
      ";", \(Abs[\[DoubleStruckCapitalJ]] = 1\), 
      ";", \(Abs[\[DoubleStruckK]] = 1\), ";", \(Abs[\[DoubleStruckL]] = 1\), 
      ";", 
      RowBox[{
        RowBox[{"Abs", "[", 
          StyleBox["\[DoubleStruckM]",
            FontWeight->"Plain"], "]"}], "=", "1"}], ";", 
      RowBox[{
        RowBox[{"Abs", "[", 
          StyleBox["\[DoubleStruckN]",
            FontWeight->"Plain"], "]"}], "=", "1"}], 
      ";", \(Abs[\[DoubleStruckO]] = 1\), ";", \(Abs[\[DoubleStruckP]] = 1\), 
      ";", \(Abs[\[DoubleStruckS]] = 1\), 
      ";", \(Abs[\[DoubleStruckCapitalY]] = 1\), ";"}], "\n", 
    RowBox[{\(Sign[\[DoubleStruckD]] = \[DoubleStruckD]\), 
      ";", \(Sign[\[DoubleStruckG]] = \[DoubleStruckG]\), 
      ";", \(Sign[\[DoubleStruckH]] = \[DoubleStruckH]\), 
      ";", \(Sign[\[DoubleStruckCapitalI]] = \[DoubleStruckCapitalI]\), 
      ";", \(Sign[\[DoubleStruckCapitalJ]] = \[DoubleStruckCapitalJ]\), 
      ";", \(Sign[\[DoubleStruckK]] = \[DoubleStruckK]\), 
      ";", \(Sign[\[DoubleStruckL]] = \[DoubleStruckL]\), ";", 
      RowBox[{
        RowBox[{"Sign", "[", 
          StyleBox["\[DoubleStruckM]",
            FontWeight->"Plain"], "]"}], "=", 
        StyleBox["\[DoubleStruckM]",
          FontWeight->"Plain"]}], ";", 
      RowBox[{
        RowBox[{"Sign", "[", 
          StyleBox["\[DoubleStruckN]",
            FontWeight->"Plain"], "]"}], "=", 
        StyleBox["\[DoubleStruckN]",
          FontWeight->"Plain"]}], 
      ";", \(Sign[\[DoubleStruckO]] = \[DoubleStruckO]\), 
      ";", \(Sign[\[DoubleStruckP]] = \[DoubleStruckP]\), ";", 
      RowBox[{
        RowBox[{"Sign", "[", 
          StyleBox["\[DoubleStruckS]",
            FontWeight->"Plain"], "]"}], "=", 
        StyleBox["\[DoubleStruckS]",
          FontWeight->"Plain"]}], 
      ";", \(Sign[\[DoubleStruckCapitalY]] = \[DoubleStruckCapitalY]\), 
      ";"}], "\n", 
    RowBox[{\(Re[\[DoubleStruckD]] = 0\), ";", \(Re[\[DoubleStruckG]] = 0\), 
      ";", \(Re[\[DoubleStruckH]] = 0\), 
      ";", \(Re[\[DoubleStruckCapitalI]] = 0\), 
      ";", \(Re[\[DoubleStruckCapitalJ]] = 0\), 
      ";", \(Re[\[DoubleStruckK]] = 0\), ";", \(Re[\[DoubleStruckL]] = 0\), 
      ";", 
      RowBox[{
        RowBox[{"Re", "[", 
          StyleBox["\[DoubleStruckM]",
            FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
      RowBox[{
        RowBox[{"Re", "[", 
          StyleBox["\[DoubleStruckN]",
            FontWeight->"Plain"], "]"}], "=", "0"}], 
      ";", \(Re[\[DoubleStruckO]] = 0\), ";", \(Re[\[DoubleStruckP]] = 0\), 
      ";", 
      RowBox[{
        RowBox[{"Re", "[", 
          StyleBox["\[DoubleStruckS]",
            FontWeight->"Plain"], "]"}], "=", "0"}], 
      ";", \(Re[\[DoubleStruckCapitalY]] = 0\), 
      ";", \(Im[\[DoubleStruckD]] = 0\), ";", \(Im[\[DoubleStruckG]] = 0\), 
      ";", \(Im[\[DoubleStruckH]] = 0\), 
      ";", \(Im[\[DoubleStruckCapitalI]] = 0\), 
      ";", \(Im[\[DoubleStruckCapitalJ]] = 0\), 
      ";", \(Im[\[DoubleStruckK]] = 0\), ";", 
      RowBox[{
        RowBox[{"Im", "[", 
          StyleBox["\[DoubleStruckL]",
            FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
      RowBox[{
        RowBox[{"Im", "[", 
          StyleBox["\[DoubleStruckM]",
            FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
      RowBox[{
        RowBox[{"Im", "[", 
          StyleBox["\[DoubleStruckN]",
            FontWeight->"Plain"], "]"}], "=", "0"}], 
      ";", \(Im[\[DoubleStruckO]] = 0\), ";", \(Im[\[DoubleStruckP]] = 0\), 
      ";", 
      RowBox[{
        RowBox[{"Im", "[", 
          StyleBox["\[DoubleStruckS]",
            FontWeight->"Plain"], "]"}], "=", "0"}], 
      ";", \(Im[\[DoubleStruckCapitalY]] = 0\), 
      ";", \(Re[\ \ \ a_\ \[DoubleStruckCapitalJ]^b_] := 0\), 
      ";", \(Im[\ \ a_\ \ \[DoubleStruckCapitalJ]^b_] := 0\), 
      ";", \(Re[\ \[DoubleStruckCapitalJ]^b_] := 0\), 
      ";", \(Im[\[DoubleStruckCapitalJ]^b_] := 0\), 
      ";", \(Re[a_\ \ \[DoubleStruckCapitalJ]] = 0\), 
      ";", \(Im[a_\ \[DoubleStruckCapitalJ]] = 0\), 
      ";", \(Re[\ \ \ a_\ \[DoubleStruckCapitalY]^b_] := 0\), 
      ";", \(Im[\ \ a_\ \ \[DoubleStruckCapitalY]^b_] := 0\), 
      ";", \(Re[\ \[DoubleStruckCapitalY]^b_] := 0\), 
      ";", \(Im[\[DoubleStruckCapitalY]^b_] := 0\), 
      ";", \(Re[a_\ \ \[DoubleStruckCapitalY]] = 0\), 
      ";", \(Im[a_\ \[DoubleStruckCapitalY]] = 0\), ";"}]}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(minsign[g_] := 
      Module[{a = 
            Intersection[Variables[g], signlist], \[IndentingNewLine]s = {}}, 
        Do[Do[If[\(unitSigns[\([i]\)]\)[\([1, 1]\)] === a[\([j]\)], 
              AppendTo[s, unitSigns[\([i]\)]]], {i, Length[unitSigns]}], {j, 
            Length[a]}]; s]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".4 Predefined Index & Signed Tables."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell["\<\
hoopList names all the loops for which determinant factors have been found, \
in their order in sections 8.2 ete seq (but non-conservative loops are moved \
to the end).\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(hoopList = {"\<C2\>", "\<C4c\>", "\<C3\>", "\<C3C2c\>", "\<C12c\>", "\
\<C3i\>", "\<C4C3c\>", "\<C3C3j\>", "\<C9j\>", "\<C9J\>", "\<C4\>", "\<K\>", \
"\<Qr\>", "\<P4\>", "\<Dav\>", "\<O2\>", "\<C8r\>", "\<C3C4j\>", "\<CL2\>", "\
\<C4C2r\>", "\<P16c\>", "\<C8c\>", "\<C5\>", "\<C3C2\>", "\<D3\>", \
"\<C3C4c\>", "\<Q12c\>", "\<Q12r\>", "\<Q12r\>", "\<g2401c\>", "\<D6r\>", \
"\<D3C2c\>", "\<KC3c\>", "\<C3Kr\>", "\<Cl3r\>", "\<Clm3r\>", "\<C8\>", \
"\<KC2\>", "\<C4C2\>", "\<D4\>", "\<Q8\>", "\<Octr\>", "\<KiC4c\>", "\<O4\>", \
"\<O4a\>", "\<O4b\>", "\<C4C4c\>", "\<C4C4r\>", "\<Q8C2r\>", "\<C2D4r\>", \
"\<P8\>", "\<CL3\>", "\<C4iC4c\>", "\<QC2r\>", "\<KiC4r\>", "\<CL21\>", \
"\<CL03\>", "\<Octi\>", "\<C3C3\>", "\<C9\>", "\<C6C3c\>", "\<C3C4\>", "\<C3K\
\>", "\<Q12\>", "\<D3C2\>", "\<A4\>", "\<C3Qr\>", "\<C3P4\>", "\<C6Kr\>", \
"\<C3KC2r\>", "\<Q12C2c\>", "\<D8\>", "\<Q16\>", "\<D4C2\>", "\<C4C4\>", \
"\<Q8C2\>", "\<KK\>", "\<C4K\>", "\<KiC4\>", "\<C4iC4\>", "\<P16\>", \
"\<Oct\>", "\<Q8M2\>", "\<CL4\>", "\<CL13\>", "\<CL22\>", "\<CL31\>", "\<r31r\
\>", "\<CL04\>", "\<O8\>", "\<C3C4C2\>", "\<CL31C2\>", "\<CL4C2\>", \
"\<Q4n\>", "\<C6n\>", "\<Q8n\>", "\<D3Mn\>"};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{\(C2 = ca[2]; C3 = ca[3]; 
    C3n = {{a, b, c}, {b, c, a}, {c, \(-a\), b}};\), "\[IndentingNewLine]", 
    RowBox[{\(C3C3j = {{1, 2, 3}, {2, 
            3\ \[DoubleStruckCapitalJ]\^2, \[DoubleStruckCapitalJ]}, {3, \
\[DoubleStruckCapitalJ], 2\ \[DoubleStruckCapitalJ]\^2}}\), 
      ";", \(C9j = {{1, 2, 3}, {2, 3\ \[DoubleStruckCapitalJ]\^2, 1}, {3, 1, 
            2\ \[DoubleStruckCapitalJ]}}\), 
      ";", \(C9J = {{1, 2, 3}, {2, 
            3, \[DoubleStruckCapitalJ]}, {3, \[DoubleStruckCapitalJ], 
            2\ \[DoubleStruckCapitalJ]}}\), ";", 
      FormBox[\(C3i = {{1, 2, 3}, {2, 3, \[ImaginaryI]}, {3, \[ImaginaryI], 
              2\ \[ImaginaryI]}}\),
        "TraditionalForm"], 
      ";"}], "\[IndentingNewLine]", \(C12c = {{1, 2, 3}, {2, 
            3, \(-\[ImaginaryI]\)}, {3, \(-\[ImaginaryI]\), \(-2\)\ \
\[ImaginaryI]}};\), "\[IndentingNewLine]", \(C4 = ca[4]; K = ca[4, 3]; 
    P4 = {{1, 2, 3, 4}, {2, 1, \(-4\)\ \[ImaginaryI], 3\ \[ImaginaryI]}, {3, 
          4\ \[ImaginaryI], 
          1, \(-2\)\ \[ImaginaryI]}, {4, \(-3\)\ \[ImaginaryI], 
          2\ \[ImaginaryI], 1}}; 
    C4C3c = {{1, 2, 3}, {2, 3\ \[ImaginaryI], \(-1\)}, {3, \(-1\), 
          2\ \[ImaginaryI]}};\), "\[IndentingNewLine]", \(P16c = {{1, 2, 3, 
          4}, {2, \(-1\), \(-4\)\ \[ImaginaryI], \(-3\)\ \[ImaginaryI]}, {3, 
          4\ \[ImaginaryI], \(-1\), 2\ \[ImaginaryI]}, {4, 
          3\ \[ImaginaryI], \(-2\)\ \[ImaginaryI], 1}}; 
    Q4n = {{1, 2, 3, 4}, {2, 1, 4, \(-3\)}, {3, \(-4\), 1, 2}, {4, 3, \(-2\), 
          1}}; C5 = ca[5]; 
    C5n = {{1, 2, 3, 4, 5}, {2, 1, 4, 5, 3}, {3, 5, 1, 2, 4}, {4, 3, 5, 1, 
          2}, {5, 4, 2, 3, 1}};\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(C3C2 = co[C3, C2]; D3 = ca[6, 5];\), "\[IndentingNewLine]", 
    \(D3C2c = ms[{6, 7}, u3]; 
    C6n = {{1, 2, 3, 4, 5, 6}, {2, 3, 1, 6, 4, 5}, {3, 1, 2, 5, 6, 4}, {4, 5, 
          6, 2, 1, 3}, {5, 6, 4, 1, 3, 2}, {6, 4, 5, 3, 2, 1}};\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(\(C4C2 = co[C4, C2]; KC2 = co[K, C2]; D4 = ca[8, 7]; C8 = ca[8]; 
    Q8 = ca[8, 3]; 
    Oct = cd[{\(-1\), \(-1\), \(-1\), {2}}];\[IndentingNewLine]
    \(Q8C2r = {{1, 2, 3, 4, 5, 6, 7, 8}, {2, \(-5\), 1, 8, \(-3\), \(-4\), 
            6, \(-7\)}, {3, 1, \(-5\), \(-6\), \(-2\), 7, \(-8\), 
            4}, {4, \(-6\), 8, \(-5\), 7, \(-3\), \(-1\), 
            2}, {5, \(-3\), \(-2\), 7, 1, 8, 4, 6}, {6, 7, \(-4\), \(-2\), 
            8, \(-5\), 3, \(-1\)}, {7, \(-8\), 6, \(-1\), 4, 
            2, \(-5\), \(-3\)}, {8, 4, \(-7\), 3, 
            6, \(-1\), \(-2\), \(-5\)}};\)\[IndentingNewLine]
    \(P8 = {{1, 2, 3, 4, 5, 6, 7, 8}, {2, 1, \(-4\)\ \[ImaginaryI], 
            3\ \[ImaginaryI], 6, 5, \(-8\)\ \[ImaginaryI], 
            7\ \[ImaginaryI]}, {3, 4\ \[ImaginaryI], 
            1, \(-2\)\ \[ImaginaryI], 7, 8\ \[ImaginaryI], 
            5, \(-6\)\ \[ImaginaryI]}, {4, \(-3\)\ \[ImaginaryI], 
            2\ \[ImaginaryI], 1, 8, \(-7\)\ \[ImaginaryI], 6\ \[ImaginaryI], 
            5}, {5, 6, 7, 8, 1, 2, 3, 4}, {6, 5, \(-8\)\ \[ImaginaryI], 
            7\ \[ImaginaryI], 2, 1, \(-4\)\ \[ImaginaryI], 
            3\ \[ImaginaryI]}, {7, 8\ \[ImaginaryI], 
            5, \(-6\)\ \[ImaginaryI], 3, 4\ \[ImaginaryI], 
            1, \(-2\)\ \[ImaginaryI]}, {8, \(-7\)\ \[ImaginaryI], 
            6\ \[ImaginaryI], 5, 4, \(-3\)\ \[ImaginaryI], 2\ \[ImaginaryI], 
            1}};\)\[IndentingNewLine]
    \(Q8n = {{1, 2, 3, 4, 5, 6, 7, 8}, {2, 1, 4, 7, 6, 5, 8, 3}, {3, 8, 1, 2, 
            7, 4, 5, 6}, {4, 3, 6, 1, 8, 7, 2, 5}, {5, 6, 7, 8, 1, 2, 3, 
            4}, {6, 5, 8, 3, 2, 1, 4, 7}, {7, 4, 5, 6, 3, 8, 1, 2}, {8, 7, 2, 
            5, 4, 3, 6, 1}};\)\[IndentingNewLine]
    \(CL12 = cl[1, 2];\)\)\( (*CL3\ isomorph*) \)\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(C3C3 = co[C3, C3]; C3C4 = co[C3, C4]; C3K = co[C3, K]; 
    Q12 = co[C3, C4, 2]; D3C2 = co[C3, K, 2]; 
    A4 = ge[{3, 2, 
          2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>"}]; 
    A4a = Transpose[A4]; D3C4r = ms[{3, 15}];\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"C3P4", "=", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", 
                  "12"},
                {"2", "3", "1", "5", "6", "4", "8", "9", "7", "11", "12", 
                  "10"},
                {"3", "1", "2", "6", "4", "5", "9", "7", "8", "12", "10", 
                  "11"},
                {"4", "5", "6", "1", "2", 
                  "3", \(10\ \[ImaginaryI]\), \(11\ \[ImaginaryI]\), \(12\ \
\[ImaginaryI]\), \(\(-7\)\ \[ImaginaryI]\), \(\(-8\)\ \[ImaginaryI]\), \(\(-9\
\)\ \[ImaginaryI]\)},
                {"5", "6", "4", "2", "3", 
                  "1", \(11\ \[ImaginaryI]\), \(12\ \[ImaginaryI]\), \(10\ \
\[ImaginaryI]\), \(\(-8\)\ \[ImaginaryI]\), \(\(-9\)\ \[ImaginaryI]\), \(\(-7\
\)\ \[ImaginaryI]\)},
                {"6", "4", "5", "3", "1", 
                  "2", \(12\ \[ImaginaryI]\), \(10\ \[ImaginaryI]\), \(11\ \
\[ImaginaryI]\), \(\(-9\)\ \[ImaginaryI]\), \(\(-7\)\ \[ImaginaryI]\), \(\(-8\
\)\ \[ImaginaryI]\)},
                {"7", "8", 
                  "9", \(\(-10\)\ \[ImaginaryI]\), \(\(-11\)\ \
\[ImaginaryI]\), \(\(-12\)\ \[ImaginaryI]\), "1", "2", 
                  "3", \(4\ \[ImaginaryI]\), \(5\ \[ImaginaryI]\), \(6\ \
\[ImaginaryI]\)},
                {"8", "9", 
                  "7", \(\(-11\)\ \[ImaginaryI]\), \(\(-12\)\ \
\[ImaginaryI]\), \(\(-10\)\ \[ImaginaryI]\), "2", "3", 
                  "1", \(5\ \[ImaginaryI]\), \(6\ \[ImaginaryI]\), \(4\ \
\[ImaginaryI]\)},
                {"9", "7", 
                  "8", \(\(-12\)\ \[ImaginaryI]\), \(\(-10\)\ \
\[ImaginaryI]\), \(\(-11\)\ \[ImaginaryI]\), "3", "1", 
                  "2", \(6\ \[ImaginaryI]\), \(4\ \[ImaginaryI]\), \(5\ \
\[ImaginaryI]\)},
                {"10", "11", 
                  "12", \(7\ \[ImaginaryI]\), \(8\ \[ImaginaryI]\), \(9\ \
\[ImaginaryI]\), \(\(-4\)\ \[ImaginaryI]\), \(\(-5\)\ \[ImaginaryI]\), \(\(-6\
\)\ \[ImaginaryI]\), "1", "2", "3"},
                {"11", "12", 
                  "10", \(8\ \[ImaginaryI]\), \(9\ \[ImaginaryI]\), \(7\ \
\[ImaginaryI]\), \(\(-5\)\ \[ImaginaryI]\), \(\(-6\)\ \[ImaginaryI]\), \(\(-4\
\)\ \[ImaginaryI]\), "2", "3", "1"},
                {"12", "10", 
                  "11", \(9\ \[ImaginaryI]\), \(7\ \[ImaginaryI]\), \(8\ \
\[ImaginaryI]\), \(\(-6\)\ \[ImaginaryI]\), \(\(-4\)\ \[ImaginaryI]\), \(\(-5\
\)\ \[ImaginaryI]\), "3", "1", "2"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], ";"}], 
      TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0,
  FontFamily->"Courier New",
  FontSize->10],

Cell[BoxData[{
    \(P16i = 
      ge[{2, 2, 2, 
          2}, {"\<aa\>" \[Rule] "\<d\>", "\<cb\>" \[Rule] "\<bcd\>"}]; 
    P16a = co[Q8, C2, 4]; P16 = co[P4, C4]; C8pC2 = co[ca[8], C2, 4]; 
    g2101 = ge[{7, 3}, {"\<ba\>" \[Rule] "\<aab\>"}]; 
    OctC2 = co[Oct, C2];\), "\n", 
    \(SL23 = mg[{9, 14}, u4]; 
    P27 = ge[{3, 3, 3}, {"\<ba\>" \[Rule] "\<abc\>"}]; 
    g2704 = ge[{9, 
          3}, {"\<ba\>" \[Rule] "\<a4b\>", "\<baa\>" \[Rule] "\<ab\>"}];\)}], \
"Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    FormBox[
      RowBox[{\( (*Large\ alternative\ tables*) \), "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"Q12M5n", "=", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", 
                    "12", "13", "14", "15", "16", "17", "18", "19", "20", 
                    "21", "22", "23", "24"},
                  {"2", "3", "5", "6", "1", "7", "9", "10", "4", "11", "12", 
                    "8", "14", "15", "17", "22", "13", "23", "24", "18", "20",
                     "19", "21", "16"},
                  {"3", "5", "1", "7", "2", "9", "4", "11", "6", "12", "8", 
                    "10", "15", "17", "13", "19", "14", "21", "16", "23", 
                    "18", "24", "20", "22"},
                  {"4", "10", "7", "8", "12", "2", "11", "1", "5", "6", "3", 
                    "9", "16", "18", "19", "20", "21", "22", "23", "13", "24",
                     "14", "15", "17"},
                  {"5", "1", "2", "9", "3", "4", "6", "12", "7", "8", "10", 
                    "11", "17", "13", "14", "24", "15", "20", "22", "21", 
                    "23", "16", "18", "19"},
                  {"6", "11", "9", "10", "8", "3", "12", "2", "1", "7", "5", 
                    "4", "18", "19", "21", "14", "16", "15", "17", "22", "13",
                     "23", "24", "20"},
                  {"7", "12", "4", "11", "10", "5", "8", "3", "2", "9", "1", 
                    "6", "19", "21", "16", "23", "18", "24", "20", "15", "22",
                     "17", "13", "14"},
                  {"8", "6", "11", "1", "9", "10", "3", "4", "12", "2", "7", 
                    "5", "20", "22", "23", "13", "24", "14", "15", "16", "17",
                     "18", "19", "21"},
                  {"9", "8", "6", "12", "11", "1", "10", "5", "3", "4", "2", 
                    "7", "21", "16", "18", "17", "19", "13", "14", "24", "15",
                     "20", "22", "23"},
                  {"10", "7", "12", "2", "4", "11", "5", "6", "8", "3", "9", 
                    "1", "22", "23", "24", "18", "20", "19", "21", "14", "16",
                     "15", "17", "13"},
                  {"11", "9", "8", "3", "6", "12", "1", "7", "10", "5", "4", 
                    "2", "23", "24", "20", "15", "22", "17", "13", "19", "14",
                     "21", "16", "18"},
                  {"12", "4", "10", "5", "7", "8", "2", "9", "11", "1", "6", 
                    "3", "24", "20", "22", "21", "23", "16", "18", "17", "19",
                     "13", "14", "15"},
                  {"13", "17", "15", "20", "14", "21", "23", "16", "18", "24",
                     "19", "22", "3", "2", "1", "11", "5", "6", "8", "7", "9",
                     "10", "4", "12"},
                  {"14", "13", "17", "22", "15", "16", "24", "18", "19", "20",
                     "21", "23", "5", "3", "2", "9", "1", "11", "6", "12", 
                    "8", "7", "10", "4"},
                  {"15", "14", "13", "23", "17", "18", "20", "19", "21", "22",
                     "16", "24", "1", "5", "3", "8", "2", "9", "11", "4", "6",
                     "12", "7", "10"},
                  {"16", "24", "19", "13", "22", "17", "15", "20", "14", "21",
                     "23", "18", "7", "6", "4", "3", "9", "10", "1", "11", 
                    "12", "2", "8", "5"},
                  {"17", "15", "14", "24", "13", "19", "22", "21", "16", "23",
                     "18", "20", "2", "1", "5", "6", "3", "8", "9", "10", 
                    "11", "4", "12", "7"},
                  {"18", "20", "21", "14", "23", "13", "17", "22", "15", "16",
                     "24", "19", "9", "7", "6", "12", "4", "3", "10", "5", 
                    "1", "11", "2", "8"},
                  {"19", "22", "16", "15", "24", "14", "13", "23", "17", "18",
                     "20", "21", "4", "9", "7", "1", "6", "12", "3", "8", 
                    "10", "5", "11", "2"},
                  {"20", "21", "23", "16", "18", "24", "19", "13", "22", "17",
                     "15", "14", "11", "10", "8", "7", "12", "2", "4", "3", 
                    "5", "6", "1", "9"},
                  {"21", "23", "18", "17", "20", "15", "14", "24", "13", "19",
                     "22", "16", "6", "4", "9", "10", "7", "1", "12", "2", 
                    "3", "8", "5", "11"},
                  {"22", "16", "24", "18", "19", "20", "21", "14", "23", "13",
                     "17", "15", "12", "11", "10", "5", "8", "7", "2", "9", 
                    "4", "3", "6", "1"},
                  {"23", "18", "20", "19", "21", "22", "16", "15", "24", "14",
                     "13", "17", "8", "12", "11", "4", "10", "5", "7", "1", 
                    "2", "9", "3", "6"},
                  {"24", "19", "22", "21", "16", "23", "18", "17", "20", "15",
                     "14", "13", "10", "8", "12", "2", "11", "4", "5", "6", 
                    "7", "1", "9", "3"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
          ";", \(Alt12nC2 = co[Alt12n, C2]\), ";", \(OctrC3 = co[Oct, C3]\), 
          ";", \(Alt12nC3 = co[Alt12n, C3]\), ";", 
          FormBox[
            RowBox[{
              RowBox[{"C4iC4M", "=", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", 
                        "11", "12", "13", "14", "15", "16", "17", "18", "19", 
                        "20", "21", "22", "23", "24", "25", "26", "27", "28", 
                        "29", "30", "31", "32"},
                      {"2", "5", "6", "7", "8", "10", "11", "1", "12", "13", 
                        "14", "15", "3", "4", "16", "9", "18", "21", "28", 
                        "23", "24", "31", "27", "17", "22", "32", "30", "26", 
                        "25", "20", "29", "19"},
                      {"3", "12", "4", "9", "10", "2", "6", "16", "1", "11", 
                        "15", "7", "8", "13", "5", "14", "25", "28", "17", 
                        "19", "31", "18", "22", "32", "20", "21", "26", "23", 
                        "24", "29", "27", "30"},
                      {"4", "7", "9", "1", "11", "12", "2", "14", "3", "15", 
                        "5", "6", "16", "8", "10", "13", "20", "23", "25", 
                        "17", "27", "28", "18", "30", "19", "31", "21", "22", 
                        "32", "24", "26", "29"},
                      {"5", "8", "10", "11", "1", "13", "14", "2", "15", "3", 
                        "4", "16", "6", "7", "9", "12", "21", "24", "26", 
                        "27", "17", "29", "30", "18", "31", "19", "20", "32", 
                        "22", "23", "25", "28"},
                      {"6", "15", "7", "12", "13", "5", "10", "9", "2", "14", 
                        "16", "11", "1", "3", "8", "4", "28", "31", "23", 
                        "22", "32", "27", "26", "25", "18", "30", "29", "21", 
                        "20", "19", "24", "17"},
                      {"7", "11", "12", "2", "14", "15", "5", "4", "6", "16", 
                        "8", "10", "9", "1", "13", "3", "23", "27", "22", 
                        "18", "30", "26", "21", "20", "28", "29", "24", "31", 
                        "19", "17", "32", "25"},
                      {"8", "1", "13", "14", "2", "3", "4", "5", "16", "6", 
                        "7", "9", "10", "11", "12", "15", "24", "17", "32", 
                        "30", "18", "25", "20", "21", "29", "28", "23", "19", 
                        "31", "27", "22", "26"},
                      {"9", "6", "1", "3", "15", "7", "12", "13", "4", "5", 
                        "10", "2", "14", "16", "11", "8", "19", "22", "20", 
                        "25", "26", "23", "28", "29", "17", "27", "31", "18", 
                        "30", "32", "21", "24"},
                      {"10", "16", "11", "15", "3", "8", "13", "12", "5", "4",
                         "9", "14", "2", "6", "1", "7", "31", "32", "21", 
                        "26", "25", "24", "29", "28", "27", "17", "19", "30", 
                        "18", "22", "20", "23"},
                      {"11", "14", "15", "5", "4", "16", "8", "7", "10", "9", 
                        "1", "13", "12", "2", "3", "6", "27", "30", "31", 
                        "21", "20", "32", "24", "23", "26", "25", "17", "29", 
                        "28", "18", "19", "22"},
                      {"12", "10", "2", "6", "16", "11", "15", "3", "7", "8", 
                        "13", "5", "4", "9", "14", "1", "22", "26", "18", 
                        "28", "29", "21", "31", "19", "23", "24", "32", "27", 
                        "17", "25", "30", "20"},
                      {"13", "9", "14", "16", "6", "1", "3", "15", "8", "7", 
                        "12", "4", "5", "10", "2", "11", "32", "25", "30", 
                        "29", "28", "20", "19", "31", "24", "23", "22", "17", 
                        "27", "26", "18", "21"},
                      {"14", "4", "16", "8", "7", "9", "1", "11", "13", "12", 
                        "2", "3", "15", "5", "6", "10", "30", "20", "29", 
                        "24", "23", "19", "17", "27", "32", "22", "18", "25", 
                        "26", "21", "28", "31"},
                      {"15", "13", "5", "10", "9", "14", "16", "6", "11", "1",
                         "3", "8", "7", "12", "4", "2", "26", "29", "27", 
                        "31", "19", "30", "32", "22", "21", "20", "25", "24", 
                        "23", "28", "17", "18"},
                      {"16", "3", "8", "13", "12", "4", "9", "10", "14", "2", 
                        "6", "1", "11", "15", "7", "5", "29", "19", "24", 
                        "32", "22", "17", "25", "26", "30", "18", "28", "20", 
                        "21", "31", "23", "27"},
                      {"17", "23", "19", "20", "21", "22", "18", "30", "25", 
                        "26", "27", "28", "29", "24", "31", "32", "5", "14", 
                        "10", "11", "1", "13", "8", "7", "15", "3", "4", "16",
                         "6", "2", "9", "12"},
                      {"18", "27", "22", "23", "24", "26", "21", "20", "28", 
                        "29", "30", "31", "19", "17", "32", "25", "8", "4", 
                        "16", "14", "2", "9", "1", "11", "13", "12", "7", "3",
                         "15", "5", "6", "10"},
                      {"19", "22", "20", "25", "26", "18", "28", "29", "17", 
                        "27", "31", "23", "24", "32", "21", "30", "15", "13", 
                        "5", "10", "9", "8", "16", "6", "11", "1", "3", "14", 
                        "2", "12", "4", "7"},
                      {"20", "18", "25", "17", "27", "28", "23", "24", "19", 
                        "31", "21", "22", "32", "30", "26", "29", "11", "8", 
                        "15", "5", "4", "16", "14", "2", "10", "9", "1", "13",
                         "12", "7", "3", "6"},
                      {"21", "30", "26", "27", "17", "29", "24", "23", "31", 
                        "19", "20", "32", "22", "18", "25", "28", "1", "7", 
                        "3", "4", "5", "6", "2", "14", "9", "10", "11", "12", 
                        "13", "8", "15", "16"},
                      {"22", "26", "23", "28", "29", "21", "31", "19", "18", 
                        "30", "32", "27", "17", "25", "24", "20", "16", "3", 
                        "14", "13", "12", "4", "9", "10", "8", "7", "6", "1", 
                        "11", "15", "2", "5"},
                      {"23", "21", "28", "18", "30", "31", "27", "17", "22", 
                        "32", "24", "26", "25", "20", "29", "19", "14", "1", 
                        "13", "8", "7", "3", "4", "5", "16", "6", "2", "9", 
                        "10", "11", "12", "15"},
                      {"24", "20", "29", "30", "18", "19", "17", "27", "32", 
                        "22", "23", "25", "26", "21", "28", "31", "2", "11", 
                        "12", "7", "8", "15", "5", "4", "6", "16", "14", "10",
                         "9", "1", "13", "3"},
                      {"25", "28", "17", "19", "31", "23", "22", "32", "20", 
                        "21", "26", "18", "30", "29", "27", "24", "10", "16", 
                        "11", "15", "3", "14", "13", "12", "5", "4", "9", "8",
                         "7", "6", "1", "2"},
                      {"26", "29", "27", "31", "19", "24", "32", "22", "21", 
                        "20", "25", "30", "18", "28", "17", "23", "9", "6", 
                        "1", "3", "15", "2", "12", "13", "4", "5", "10", "7", 
                        "8", "16", "11", "14"},
                      {"27", "24", "31", "21", "20", "32", "30", "18", "26", 
                        "25", "17", "29", "28", "23", "19", "22", "4", "2", 
                        "9", "1", "11", "12", "7", "8", "3", "15", "5", "6", 
                        "16", "14", "10", "13"},
                      {"28", "31", "18", "22", "32", "27", "26", "25", "23", 
                        "24", "29", "21", "20", "19", "30", "17", "13", "9", 
                        "8", "16", "6", "1", "3", "15", "14", "2", "12", "4", 
                        "5", "10", "7", "11"},
                      {"29", "19", "30", "32", "22", "17", "25", "26", "24", 
                        "23", "28", "20", "21", "31", "18", "27", "12", "10", 
                        "7", "6", "16", "11", "15", "3", "2", "14", "13", "5",
                         "4", "9", "8", "1"},
                      {"30", "17", "32", "24", "23", "25", "20", "21", "29", 
                        "28", "18", "19", "31", "27", "22", "26", "7", "5", 
                        "6", "2", "14", "10", "11", "1", "12", "13", "8", 
                        "15", "3", "4", "16", "9"},
                      {"31", "32", "21", "26", "25", "30", "29", "28", "27", 
                        "17", "19", "24", "23", "22", "20", "18", "3", "12", 
                        "4", "9", "10", "7", "6", "16", "1", "11", "15", "2", 
                        "14", "13", "5", "8"},
                      {"32", "25", "24", "29", "28", "20", "19", "31", "30", 
                        "18", "22", "17", "27", "26", "23", "21", "6", "15", 
                        "2", "12", "13", "5", "10", "9", "7", "8", "16", "11",
                         "1", "3", "14", "4"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
              ";"}],
            "TraditionalForm"]}]}], TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".5 Main Groupoid Data File,",
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["loop[[mm,nn]]",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\(Unprotect[loop];\)\n
    \(Clear[loop];\)\)\( (*\ to\ allow\ revisions*) \)\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(loop = Table[{}, {i, 257}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([1]\)] = {{"\<C1\>", {1. }, 
            0, "\<ca[1]\>", {1}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([2]\)] = {{"\<C2\>", {2. }, 
            0, "\<ca[2]\>", {2}, {}, {1}, {1}, {1}}, \
\[IndentingNewLine]{"\<C4c\>", {\(-1. \), 1, 1}, 
            0, "\<cd[{-1}]\>", {}, {}, {12}, {44}, {30}, \
"\<cl[0,1]\>"}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([3]\)] = {{"\<C3\>", {1. , 1\_2}, 
            0, "\<ca[3]\>", {3}, {}, {10}, {8}, {8}}, {"\<C3C2c\>", {\(-1. \
\), 1\_2, 3}, 
            0, "\<cd[{3.}]\>", {}, {}, {\[DoubleStruckCapitalJ]}, {\(-8\)}, {\
\(-8\)}}, {"\<C3C2r\>", {\(-1. \), 1\_2, 2}, 
            0, "\<cd[{-3}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C4C3c\>", {\(-1. \)\ \[ImaginaryI], 1\_2, 4}, 
            0, "\<C4C3c\>", {}, {}, {}, {}, {}}, {"\<C3C3j\>", {\(-1. \)\ \
\[DoubleStruckCapitalJ], 1\_2, 8}, 
            0, "\<C3C3j\>", {}, {}, {}, {}, {}}, {"\<C9j\>", {\(-1. \) \
\[DoubleStruckCapitalJ], 1\_2, 5}, 
            0, "\<C9j\>", {}, {}, {}, {}, {}}, {"\<C9J\>", {\(-1. \)\ \
\[DoubleStruckCapitalJ], 1\_2, 4}, 
            0, "\<ts[ca[9],3]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C12c\>", {\(-1. \) \[ImaginaryI], 1\_2, 3}, 
            22, "\<C12c\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C3i\>", {\(-1. \)\ \[ImaginaryI], 1\_2, 3}, 
            22, "\<C3i\>", {}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([4]\)] = {{"\<K\>", {4. }, 
            0, "\<co[C2,C2]\>", {2, 2}, {}, {1, 2}, {1, 2}, {1, 
              2}}, \[IndentingNewLine]{"\<C4\>", {2. , 2}, 
            0, "\<ca[4]\>", {4}, {}, {12}, {13}, {12}}, \[IndentingNewLine]{"\
\<Qr\>", {\(-3\), 1, 6}, 
            0, "\<cd[{-1,-1}]\>", {}, {}, {13, 14}, {}, {30, 
              31}, "\<cl[0,2]\>"}, \[IndentingNewLine]{"\<Kr\>", {\(-4. \), 
              6}, 0, "\<cd[{4.}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<O2\>", {\(-2. \), 2, 4}, 
            7, "\<cd[{-1,1}]\>", {}, {}, {3, 12}, {3, 43}, {3, 
              30}}, {"\<Dav\>", {\(-2. \), 2, 6}, 
            2, "\<cd[{-1,-1.}]\>", {}, {}, {12, 13}, {}, {30, 
              41}}, \[IndentingNewLine]{"\<CL2\>", {\(-1\), 3, 4}, 
            0, "\<cd[{1,-1}]\>", {}, {}, {2, 4}, {}, {4, 
              5}}, \[IndentingNewLine]{"\<P4\>", {\(-4\) \[ImaginaryI], 6}, 
            0, "\<P4\>", {}, {}, {}, {}, {}, "\<msi[{2,3,4}]\>"}, \
\[IndentingNewLine]{"\<C4C2r\>", {\(-2. \), 2, 6}, 
            2, "\<cd[{-4}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C3C4j\>", {\(-2. \), 2, 4}, 
            7, "\<cd[{-2,1}]\>", {}, {}, {}, {}, {4, 
              13}}, \[IndentingNewLine]{"\<C8c\>", {\(-1. \), 1\_3, 6}, 
            0, "\<cd[{-4.}]\>", {}, {}, {29}, {}, {37}}, \
\[IndentingNewLine]{"\<C8r\>", {\(-1. \), 1\_3, 4}, 
            0, "\<ts[ca[8,5]]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<P16c\>", {\(-2\) \[ImaginaryI], 2, 8}, 
            0, "\<P16c\>", {}, {}, {}, {}, {}, "\<msi[{13,2,14}]\>"}, \
\[IndentingNewLine]{"\<Q4n\>", {\(-4\), 3}, 
            0, "\<Q4n\>", {}, {}, {}, {}, {}}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([5]\)] = {{"\<C5\>", {1. , 1\_4}, 
            0, "\<ca[5]\>", {5}, {}, {18}, {16}, {17}}, {"\<C10c\>", {\(-1. \
\), 1\_4, 10}, 
            0, "\<ts[ca[10]]\>", {}, {}, {}, {\(-16\)}, {25}}, {"\<C10r\>", {\
\(-1. \), 1\_4, 9}, 
            0, "\<ts[ca[10],2,{1,3,5,7,4,6,8,10,2,9}]\>", {}, {}, {}, {}, \
{}}, \[IndentingNewLine]{"\<C10s\>", {\(-1. \), 1\_4, 7}, 
            0, "\<ts[ca[10],2,{1,7,8,4,10,6,2,3,9,5}]\>", {}, {}, {}, {}, \
{}}, \[IndentingNewLine]{"\<C10t\>", {\(-1. \), 1\_4, 12}, 
            0, "\<ts[ca[10],2,{1,2,8,4,10,6,7,3,9,5}]\>", {}, {}, {}, {}, \
{}}, {"\<C5n\>", {5}, 0, "\<C5n\>", {}, {}, {}, {}, {}}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([6]\)] = {{"\<D3\>", {4, 1\_2}, 
            0, "\<ca[6,5]\>", {3, 2}, {"\<ba\>" \[Rule] "\<a2b\>"}, {3, 
              10}, {2, 5}, {3, 9}}, \[IndentingNewLine]{"\<C3C2\>", {2. , 
              2\_2}, 72, "\<co[C3,C2]\>", {3, 
              2}, {}, {19\ }, {17}, {18}}, \[IndentingNewLine]{"\<Q12c\>", \
{\(-3\), 1\_3, 9}, 
            0, "\<ts[Q12]\>", {}, {}, {10, 13}, {}, {8, 
              43}}, {"\<Q12r\>", {\(-1\), 1\_2, 3, 15}, 
            0, "\<ts[ca[12,5]]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<D6r\>", {\(-1\), 1, 4, 12}, 
            0, "\<ts[ca[12,11]]\>", {}, {}, {}, {}, {4, \(-8\)}}, \
\[IndentingNewLine]{"\<KC3c\>", {\(-2. \), 2\_2, 12}, 
            0, "\<cd[{3.,1}]\>", {}, {}, {\[DoubleStruckCapitalJ], \
\[DoubleStruckK]}, {3, 17}, {}}, {"\<C3Kr\>", {\(-2. \), 2\_2, 8}, 
            0, "\<cd[{-3,1}]\>", {}, {}, {}, {}, {}}, {"\<C3C4c\>", {\(-1. \
\), 1\_5, 9}, 
            0, "\<cd[{3,-1.}]\>", {}, {}, {10, 12}, {8, 
              43}, {}}, \[IndentingNewLine]{"\<D3C2c\>", {\(-1\), 1, 4, 8}, 
            0, "\<ms[{6,7},u3]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<Clm3r\>", {\(-1. \), 1\_5, 13}, 
            0, "\<cd[{-3,-1.}]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<Cl3r\>", {\(-1. \), 1\_5, 15}, 
            0, "\<cd[{3.,-1.}]\>", {}, {}, {\[DoubleStruckCapitalJ]\ 12}, \
{17, 44}, {26}}, \[IndentingNewLine]{"\<g2401c\>", {\(-3\) \[ImaginaryI], 
              1\_3, 9}, 
            0, "\<ts[mp[{24,1}],-4]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C6n\>", {2, 2\_2}, 
            0, "\<C6n\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C6an\>", {2. , 2\_2}, 
            72, "\<co[C9j,C2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<Alt6n\>", {\(-1. \)\ \[ImaginaryI], 1\_5, 15}, 
            0, "\<ts[mp[{24,2}],-4]\>", {}, {}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([7]\)] = {{"\<C7\>", {1. , 1\_6}, 
            0, "\<ca[7]\>", {7}, {}, {21}, {24}, {20}}, {"\<C14c\>", {\(-1. \
\), 1\_6, 21}, 
            0, "\<ts[ca[14]]\>", {}, {}, {}, {\(-24\)}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([8]\)] = {\ \ {"\<C8\>", {2. , 2\_3}, 
            0, "\<ca[8]\>", {8}, {}, {22}, {25}, {21}}, \[IndentingNewLine]{"\
\<C4C2\>", {4. , 4}, 
            0, "\<co[C4,C2]\>", {4, 2}, {}, {1, 16}, {1, 13}, {1, 
              16}}, \ {"\<D4\>", {6, 2}, 
            0, "\<ca[8,7]\>", {4, 2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {2, 
              3}, {2, 15}, {1, 3}}, \[IndentingNewLine]{"\<Q8\>", {2, 6}, 
            0, "\<ca[8,3]\>", {2, 2, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {13, 14}, {13, 14}, {15, 
              16}}, \[IndentingNewLine]{"\<KC2\>", {8. }, 
            0, "\<co[K,C2]\>", {2, 2, 2}, {}, {1, 2, 6}, {1, 2, 3}, {1, 2, 
              4}}, {"\<C16c\>", {\(-1. \), 1\_7, 28}, 
            0, "\<ts[ca[16]]\>", {}, {}, {}, {}, {}}, {"\<C16r\>", {\(-1. \), 
              1\_7, 24}, 
            0, "\<ts[ca[16,9]]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<C4C4c\>", {\(-2. \), 2\_3, 16}, 
            0, "\<cd[{2,1.,-1.}]\>", {}, {}, {12, 16}, {42, 
              44}, {}}, {"\<KiC4c\>", {\(-2\), 2, 4, 16}, 
            0, "\<ts[co[K,C4,2]]\>", {}, {}, {}, {}, {12, 
              16}}, {"\<C4iC4c\>", {\(-4\), 2\_2, 16}, 
            0, "\<ts[co[C4,C4,2]]\>", {}, {}, {16, 
              24}, {}, {}}, {"\<QC2r\>", {\(-6\), 2, 24}, 
            20, "\<ts[co[C2,Q8]]\>", {}, {}, {6, 13, 14}, {}, {7, 30, 
              44}}, {"\<Q8C2r\>", {\(-6\), 2, 26}, 
            0, "\<Q8C2r\>", {}, {}, {}, {}, {29, 30, 
              31}}, \[IndentingNewLine]{"\<O4\>", {\(-4. \), 4, 16}, 
            97, "\<cd[{1,1,-1.}]\>", {}, {}, {4, 6, 
              13}, {}, {}}, \[IndentingNewLine]{"\<O4a\>", {\(-4. \), 4, 24}, 
            0, "\<cd[{-1,1.,-1.}]\>", {}, {}, {3, 26, 
              27}, {}, {}}, \[IndentingNewLine]{"\<O4b\>", {\(-4. \), 4, 28}, 
            0, "\<cd[{-1,-1.,-1.}]\>", {}, {}, {12, 26, 
              27}, {}, {}}, \[IndentingNewLine]{"\<P8\>", {\(-8\) \
\[ImaginaryI], 24}, 
            0, "\<P8\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<KKr\>", \
{\(-8. \), 24}, 
            0, "\<cd[{4.,1}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C2D4r\>", {\(-2\), 6, 16}, 
            0, "\<ts[co[C2,D4]]\>", {}, {}, {2, 6, 25}, {}, {1, 4, 
              5}}, \[IndentingNewLine]{"\<CL3\>", {\(-4\), 4, 24}, 
            0, "\<cl[3]\>", {}, {}, {}, {}, {4, 29, 
              30}, "\<ts[P16i]\>"}, \[IndentingNewLine]{"\<CL12\>", {\(-4\), 
              4, 24}, 0, "\<cl[1,2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<Octr\>", {\(-7\), 1, 28}, 
            0, "\<cd[{-1,-1,-1}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<KiC4r\>", {\(-2\), 2, 4, 24}, 
            0, "\<ts[co[K,C4,2],2,{1,10,13,14,3,12,15,16,9,2,5,6,11,4,7,8}]\>\
", {}, {}, {9, 13}, {}, {3, 43}}, \[IndentingNewLine]{"\<C8pC2c\>", {\(-2\), 
              2\_3, 24}, 
            0, "\<ts[mp[{16,6}],{1,14,3,4,9,6,11,12,5,10,7,8,13,2,15,16}]\>", \
{}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<D8c\>", {\(-1\), 1\_2, 5, 24}, 
            0, "\<ts[ca[16,15]]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<Q8iC2r\>", {\(-1\), 1, 3\_2, 24}, 
            0, "\<ts[co[Q8,C2,2],{1,4,3,2,9,14,15,16,   5,8,7,6,13,10,11,12}]\
\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<Q16r\>", {\(-1\), 1\_2, 5, 
              28}, 0, "\<ts[ca[16,7]]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<CL21\>", {\(-2\), 6, 24}, 
            0, "\<cl[2,1]\>", {}, {}, {}, {}, {4, 5, 7, 
              16}}, \[IndentingNewLine]{"\<CL03\>", {\(-6\), 2, 28}, 
            0, "\<cl[0,3]\>", {}, {}, {}, {}, {16, 30, 
              44}}, {"\<C4C4r\>", {\(-2. \), 2\_3, 24}, 
            12, "\<cd[{-2,1,-1.}]\>", {}, {}, {6, 
              29}, {}, {}}, \[IndentingNewLine]{"\<Octi\>", {\(-3\), 5, 24}, 
            0, "\<cd[{1,-1,-1}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<O4k\>", {\(-4. \), 4, 16}, 
            97, "\<cd[{-2,1,1}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C8pr\>", {\(-2\), 2\_3, 26}, 
            0, "\<ts[co[ca[8],C2,4],{1,13,16,4,3,11,10,6,5,9,12,8,7,15,14,2}]\
\>", {}, {}, {2, 29}, {}, {}}, {"\<C8n\>", {\(-2\), 1, 2, 3, 24}, 
            0, "\<cd[{2,-1.,-1}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<Q8n\>", {8}, 
            0, "\<Q8n\>", {}, {}, {}, {}, {}}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([9]\)] = {{"\<C9\>", {1. , 1\_8}, 
            1, "\<ca[9]\>", {9}, {}, {23}, {28}, {23}}, {"\<C3C3\>", {1. , 
              1\_8}, 1, "\<co[C3,C3]\>", {3, 3}, {}, {10, 11}, {8, 12}, {8, 
              11}}, {"\<C6C3c\>", {\(-1. \), 1\_8, 38}, 
            0, "\<ts[mp[18,5],2,{1,15,8,5,13,9,14,7,6,4,18,11,2,16,12,17,10,3}\
]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<C3C6c\>", {\(-1. \), 1\_8, 
              27}, 0, "\<ts[co[C3,ca[6]]]\>", {}, {}, {}, {10, \(-12\)}, {}}, \
\[IndentingNewLine]{"\<C18c\>", {\(-1. \), 1\_8, 36}, 
            0, "\<ts[ca[18]]\>", {}, {}, {}, { (*\(-28\)*) }, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([10]\)] = {{"\<D5\>", {6, 1\_4}, 
            0, "\<ca[10,9]\>", {5, 2}, {"\<ba\>" \[Rule] "\<a4b\>"}, {3, 
              18}, {2, 16}, {}}, {"\<C10\>", {2. , 2\_4}, 
            0, "\<ca[10]\>", {5, 2}, {}, {1, 
              18}, {29}, {24}}, \[IndentingNewLine]{"\<Q20c\>", {\(-5\), 
              1\_5, 25}, 
            0, "\<ca[]\>", {}, {}, {13, 
              18}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([11]\)] = {{"\<C11\>", {1. , 1\_10}, 
            0, "\<ca[11]\>", {11}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([12]\)] = {{"\<Q12\>", {2, 2\_2, 6}, 
            0, "\<co[C3,C4,2]\>", {3, 4}, {"\<ba\>" \[Rule] "\<a2b\>"}, {10, 
              13}, {8, 36}, {8, 16}}, {"\<C3C4\>", {2. , 2\_5}, 
            0, "\<co[C3,C4]\>", {3, 4}, {}, {10, 12}, {8, 
              15}, {26}}, {"\<A4\>", {4, 1\_8}, 
            0, "\<ca[]\>", {3, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>"}, \
{}, {3, 9}, {1, 10}}, \[IndentingNewLine]{"\<D3C2\>", {8, 2\_2}, 
            0, "\<co[C3,K,2]\>", {3, 2, 2}, {"\<ba\>" \[Rule] "\<a2b\>"}, {3, 
              19}, {2, 6}, {2, 3\ }}, \[IndentingNewLine]{"\<C3K\>", {4. , 
              4\_2}, 0, "\<co[C3,K]\>", {3, 2, 2}, {}, {1, 19}, {1, 19}, {1, 
              19}}, {"\<Alt12n\>", {4, 4\_2}, 
            0, "\<cd[{-1,-1,{3}}]\>", {}, {}, {}, {}, {}, "\<ge[{2,2,3},{ \
ba->abc }]\>"}, {"\<C3Qr\>", {\(-3\), 1\_3, 3\_2, 54}, 
            0, "\<ts[co[C3,Q8]]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C3P4\>", {\(-4\) \[ImaginaryI], 4\_2, 54}, 
            0, "\<C3P4\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C3Dav\>", {\(-2. \), 2\_5, 54}, 
            0, "\<cd[{3,-1.,-1.}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<SL23r\>", {\(-1\), 1\_8, 3, 54}, 
            0, "\<ts[mp[{24,3},4],2,{1,2,4,3,5,6,10,9,22,20,21,7,8,12,14,13,\
15,16,19,18,24,11,23,17}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C3iC8c\>", {\(-3\), 1\_6, 3, 54}, 
            0, "\<ts[mp[{24,1},1]]\>", {}, {}, {10, 
              29}, {}, {}}, \[IndentingNewLine]{"\<D3C4c\>", {\(-1\), 1\_3, 
              4\_2, 36}, 
            0, "\<ts[mp[{24,5},1]]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D12r\>", {\(-1\), 1\_4, 7, 60}, 
            0, "\<ts[ca[24,23]]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<Q12C2c\>", {\(-6\), 2\_3, 36}, 
            0, "\<ts[mp[{24,7},1]]\>", {}, {}, {13, 
              19}, {}, {}}, \[IndentingNewLine]{"\<Q12C2r\>", {\(-2\), 2\_2, 
              6, 60}, 0, "\<ts[co[C2,ca[12,5]]]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C3iC4iC2r\>", {\(-3\), 2\_2, 5, 36}, 
            0, "\<ts[mp[{24,8},1]]\>", {}, {}, {4, 10, 
              15}, {}, {}, "\<msi[{11,2,14}]\>"}, \[IndentingNewLine]{"\<C3r8\
\>", {\(-2. \), 2\_5, 36}, 
            0, "\<cd[{3,-1.,1}]\>", {}, {}, { (*12, 
                19*) }, { (*\[ImaginaryI], 
                2  \[DoubleStruckCapitalJ]*) }, { (*\[ImaginaryI], \
\[DoubleStruckCapitalJ]*) }}, \[IndentingNewLine]{"\<C6Kc\>", {\(-4. \), 
              4\_2, 48}, 
            0, "\<cd[{3.,1,1}]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<C3KC2r\>", {\(-4. \), 4\_2, 30}, 
            0, "\<ts[co[C2,C3K],2,{1,3, 5,20,22,24,7,21,23,2,4, \
6,13,15,17,8,10,12,19,9,11,14,16,18}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C6Kr\>", {\(-4. \), 4\_2, 32}, 
            0, "\<cd[{-3,1,1}]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<C3C8c\>", {\(-1. \), 1\_11, 54}, 
            0, "\<ts[co[C3,ca[8],1]]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C24r\>", {\(-2. \), 2\_5, 52}, 
            0, "\<cd[{-3,-1.,1}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C24ra\>", {\(-2. \), 2\_5, 60}, 
            0, "\<cd[{3.,-1.,1}]\>", {}, {}, {2, \[DoubleStruckCapitalJ]\ \
12}, {19, 44}, { (*2, 
                8  \[ImaginaryI]*) }}, \[IndentingNewLine]{"\<Cm311\>", \
{\(-2. \), 2\_5, 62}, 
            0, "\<cd[{-3,-1.,-1.}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C24rb\>", {\(-2. \), 2\_5, 66}, 
            0, "\<cd[{3.,-1.,-1.}]\>", {}, {}, {13, \[DoubleStruckCapitalJ]\ \
12}, {}, {}}, \[IndentingNewLine]{"\<A4C2r\>", {\(-1\), 1\_7, 4, 46}, 
            0, "\<ca[]\>", {}, {}, {}, {4, 
              11}, {}}, \[IndentingNewLine]{"\<C12n\>", {\(-4\), 1, 3, 4, 
              52}, 0, "\<cd[{-3,1.,-1}]\>", {}, {}, {}, {}, {}}, {"\<D3Mn\>", \
{10, 1\_2}, 
            0, "\<md[D3]\>", {}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([13]\)] = {{"\<C13\>", {1. , 1\_12}, 
            0, "\<ca[13]\>", {13}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([14]\)] = {{"\<C14\>", {2. , 2\_6}, 
            0, "\<ca[14]\>", {14}, {}, {1, 21}, {30}, {1, 
              20}}, {"\<D7\>", {8, 1\_6}, 
            0, "\<ca[14,13]\>", {7, 2}, {"\<ba\>" \[Rule] "\<a6b\>"}, {3, 
              21}, {2, 24}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([15]\)] = {{"\<C15\>", {1. , 1\_14}, 
            0, "\<ca[15]\>", {15}, {}, {10, 18}, {8, 
              16}, {28}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([16]\)] = {\[IndentingNewLine]{"\<C16\>", {2. , 2\_7}, 
            0, "\<ca[16]\>", {16}, {}, {}, {}}, \ \ {"\<C4C4\>", {4. , 4\_3}, 
            3, "\<co[C4,C4]\>", {4, 4}, {}, {12, 16}, {15, 
              43}, {}}, \ \ {"\<KiC4\>", {8, 4\_2}, 
            0, "\<co[K,C4,2]\>", {4, 2, 2}, {"\<ba\>" \[Rule] "\<abc\>"}, {9, 
              13}, {3, 13}, {1, 13}}, {"\<C4iC4\>", {4, 4, 8}, 
            0, "\<co[C4,C4,2]\>", {4, 4}, {"\<ba\>" \[Rule] "\<a3b\>"}, {13, 
              16}, {}, {}}, {"\<C8C2\>", {4. , 4\_3}, 
            3, "\<co[C8,C2]\>", {8, 2}, {}, {1, 22}, {1, 25}, {1, 
              22}}, {"\<C8pC2\>", {4, 4\_3}, 
            0, "\<co[ca[8],C2,4]\>", {8, 2}, {"\<ba\>" -> "\<a5b\>"}, {29, 
              34}, {15, 26}, {1, 21}}, {"\<D8\>", {10, 2\_3}, 
            0, "\<ca[16,15]\>", {8, 2}, {"\<ba\>" \[Rule] "\<a7b\>"}, {3, 
              22}, {}, {4, 22}}, {"\<Q8iC2\>", {6, 2\_2, 6}, 
            0, "\<co[Q8,C2,2]\>", {8, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {14, 
              37}}, {"\<Q16\>", {2, 2\_2, 10}, 
            0, "\<ca[16,7]\>", {2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<dd\>" \[Rule] "\<c\>", "\<ba\>" \[Rule] "\<abc\>", "\<da\>" \[Rule] "\<abd\
\>", "\<db\>" \[Rule] "\<bcd\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<C4K\>", \
{8. , 8}, 0, "\<co[C4,K]\>", {4, 2, 2}, {}, {1, 2, 16}, {1, 3, 15}, {5, 6, 
              12}}, {"\<D4C2\>", {12, 4}, 
            0, "\<co[D4,C2]\>", {4, 2, 2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {1, 
              3, 9}, {1, 2, 15}, {1, 2, 
              5}}, \[IndentingNewLine]{"\<Q8C2\>", {4, 12}, 
            0, "\<co[Q8,C2]\>", {2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {6, 13, 14}, {1, 13, 14}, {6, 14, 
              30\ }}, \[IndentingNewLine]{"\<P16\>", {8, 8}, 
            0, "\<co[P4,C4]\>", {2, 2, 2, 
              2}, {"\<dd\>" \[Rule] "\<c\>", "\<ba\>" \[Rule] "\<abc\>"}, {2, 
              3, 4\ }, {\ }, {1, 7, 
              16}, "\<co[Q8,C2,4]\>", "\<co[cl[3],C2]\>"}, \
\[IndentingNewLine]{"\<KK\>", {16. }, 
            0, "\<co[K,K]\>", {2, 2, 2, 2}, {}, {1, 2, 6, 
              8}, {}, {}}, \[IndentingNewLine]{"\<Oct\>", {2, 14}, 
            0, "\<Oct\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<Sed\>", \
{\(-15\), 1, 120}, 
            0, "\<cd[{-1,-1,-1,-1}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<r31r\>", {\(-6\), 10, 96}, 
            16, "\<cl[4,{2}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<r31s\>", {\(-6\), 10, 96}, 
            16, "\<cl[4,{2,3}]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<r31t\>", {\(-6\), 10, 96}, 
            16, "\<cl[4,{2,4}]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<r31u\>", {\(-6\), 10, 96}, 
            16, "\<cl[4,{1,3}]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<CL4\>", {\(-10\), 6, 112}, 
            15, "\<cl[4]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<CL31\
\>", {\(-6\), 10, 112}, 
            13, "\<cl[3,1]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<CL22\>", {\(-6\), 10, 112}, 
            13, "\<cl[2,2]\>", {}, {}, {}, {}, {}}, {"\<CL13\>", {\(-10\), 6, 
              112}, 15, "\<cl[1,3]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<CL04\>", {\(-10\), 6, 120}, 
            0, "\<cl[0,4]\>", {}, {}, {}, {}, {}}, {"\<PD16\>",  (*Variation\ \
on\ CL04 ?? *) {\(-10\), 6, 118}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {1, \(-29\), \(-30\), 
              15}}, \[IndentingNewLine]{"\<O8\>", {\(-8. \), 8, 64}, 
            0, "\<cd[{1,1,1,-1.}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{\*"\"\<\!\(C2\^5\)r\>\"", {\(-16. \), 96}, 
            0, "\<cd[{4.,1,1}]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<C4KC2r\>", {\(-8. \), 8, 112}, 
            0, "\<cd[{4.,1,-1.}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C8Kr\>", {\(-4. \), 4\_3, 96}, 
            0, "\<cd[{-4.,1,1}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D4Kr\>", {\(-4\), 12, 70}, 
            0, "\<ca[]\>", {}, {}, {2, 3, 6, 
              8}, {}, {}}, \[IndentingNewLine]{"\<O8a\>", {\(-4. \), 4\_3, 
              64}, 0, "\<cd[{4,1,-1.}]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D4M1n\>", {14, 2}, 
            0, "\<md[D4]\>", {}, {}, {}, {}, {}}, {"\<Q8M2\>", {10, 6}, 
            98, "\<md[Q8]\>", {}, {}, {}, {}, {}, "\<cd[{1,-1,-1,{2}}]\>"}, \
{"\<D4M4n\>", {10, 6}, 
            98, "\<md[D4,{1,2,3,8,5,6,7,4}]\>", {}, {}, {}, {}, {}}, \
{"\<D4M5n\>", {6, 10}, 
            0, "\<md[Q8,{1,2,3,8,5,6,7,4}]\>", {}, {}, {}, {}, {}}};\)\)], \
"Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([17]\)] = {{"\<C17\>", {1. , 1\_16}, 
            0, "\<ca[17]\>", {17}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([18]\)] = {{"\<D9\>", {10, 1\_8}, 
            6, "\<ca[18,17]\>", {9, 2}, {"\<ba\>" \[Rule] "\<a8b\>"}, {3, 
              23}, {2, 28}, {}}, \[IndentingNewLine]{"\<C18\>", {2. , 2\_8}, 
            5, "\<ca[18]\>", {18}, {}, {1, 23}, {31}, {1, 
              23}}, {"\<D3C3\>", {4, 1\_6, 4\_2}, 
            0, "\<co[D3,C3]\>", {3, 6}, {"\<ba\>" \[Rule] "\<a2b\>"}, {4, 
              32}, {2, 9}, {2, 11}}, \[IndentingNewLine]{"\<E18\>", {10, 
              1\_8}, 6, "\<co[C3,ca[6,5],2]\>", {2, 3, 
              3}, {"\<ba\>" \[Rule] "\<abb\>", "\<ca\>" \[Rule] "\<acc\>"}, \
{3, 10, 11}, {2, 8, 32}, {}}, \[IndentingNewLine]{"\<C6C3\>", {2. , 2\_8}, 
            5, "\<co[C3C2,C3]\>", {6, 3}, {}, {10, 19}, {8, 17}, {8, 
              19}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([19]\)] = {{"\<C19\>", {1. , 1\_18}, 
            0, "\<ca[19]\>", {19}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([20]\)] = {{"\<Q20\>", {2, 2\_4, 10}, 
            0, "\<ca[20,9]\>", {5, 4}, {"\<ba\>" \[Rule] "\<a4b\>"}, {13, 
              18}, {}, {}}, {"\<C20\>", {2. , 2\_9}, 
            0, "\<ca[20]\>", {20}, {}, {12, 18}, {15, 16}, {12, 
              17}}, \[IndentingNewLine]{"\<g2003\>", {6, 1\_4, 2\_5}, 
            0, "\<ca[]\>", {5, 
              4}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}, \
"\<pe[{{1,6,5,4,2,3},{1,3,4,5,2,6}}]\>"}, {"\<D10\>", {12, 2\_4}, 
            0, "\<ca[20,19]\>", {10, 
              2}, {"\<ba\>" \[Rule] "\<a9b\>"}, {3, \(-18\)}, {2, 
              29}, {}}, {"\<C10C2\>", {4. , 4\_4}, 
            0, "\<co[ca[10],C2]\>", {10, 2}, {}, {2, \(-18\)}, {3, 29}, {1, 
              25}}, {"\<D5Mn\>", {16, 1\_4}, 
            0, "\<md[ca[10,9]]\>", {}, {}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([21]\)] = {{"\<g2101\>", {1, 1\_20}, 
            0, "\<co[ca[7],C3,7]\>", {7, 
              3}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, {"\<C21\>", {1. \
, 1\_20}, 0, "\<ca[21]\>", {21}, {}, {10, 21}, {8, 24}, {8, 
              20}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([22]\)] = {{"\<D11\>", {12, 1\_10}, 
            0, "\<ca[22,21]\>", {11, 
              2}, {"\<ba\>" \[Rule] "\<a10b\>"}, {}, {}, {}}, {"\<C22\>", {2. \
, 2\_10}, 
            0, "\<co[ca[11],C2]\>", {22}, {}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([23]\)] = {{"\<C23\>", {1. , 1\_22}, 
            0, "\<ca[23]\>", {23}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([24]\)] = {{"\<C3iC8\>", {2, 2\_5, 6\_2}, 
            0, "\<co[C3,C8,2]\>", {3, 8}, {"\<ba\>" \[Rule] "\<a2b\>"}, {10, 
              35}, {8, 26\ }, {}}, {"\<C24\>", {2. , 2\_11}, 
            0, "\<ca[24]\>", {24}, {}, {10, 22}, {8, 27}, {8, 
              22}}, \[IndentingNewLine]{"\<SL23\>", {2, 2\_8, 6}, 
            0, "\<ca[]\>", {3, 2, 2, 
              2}, {"\<bb\>" \[Rule] "\<c\>", "\<dd\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abcd\>", "\<da\>" \[Rule] "\<abc\>", "\<db\>" \[Rule] \
"\<bcd\>"}, {}, {}, {9, 
              14}, "\<pe[{{{3,7,5},{4,8,6}},{{1,5,2,6},{3,8,4,7}},{{1,3,2,4},{\
5,7,6,8}},{{1,2},{3,4},{5,6},{7,8}}}]\>"}, \[IndentingNewLine]{"\<Q24\>", {2, 
              2\_4, 14}, 
            0, "\<ca[24,11]\>", {3, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a2b\>", "\<bb\>" \[Rule] "\<c\>", \
"\<dd\>" \[Rule] "\<c\>", "\<db\>" \[Rule] "\<bcd\>"}, {13, 15}, {}, {14, 
              27}}, {"\<D3C4\>", {8, 2\_4, 8}, 
            0, "\<co[D3,C4]\>", {3, 2, 4}, {"\<ba\>" \[Rule] "\<a2b\>"}, {3, 
              15}, {2, 46}, {27, 29}}, {"\<D12\>", {14, 2\_5}, 
            0, "\<ca[24,23]\>", {12, 2}, {"\<ba\>" \[Rule] "\<a11b\>"}, {3, 
              5}, {2, 8, 15}, {34, 39, 40}}, {"\<Q12C2\>", {4, 4\_2, 12}, 
            0, "\<co[ca[12,5],C2]\>", {6, 
              4}, {"\<ba\>" \[Rule] "\<a5b\>"}, {13, 19}, {}, {1, 8, 
              16}}, \[IndentingNewLine]{"\<C3iC4iC2\>", {10, 4\_2, 6}, 
            0, "\<co[C3,C4,C2,2,2]\>", {6, 2, 
              2}, {"\<ba\>" \[Rule] "\<a5bc\>"}, {3, 20}, {3, 5, 7}, {3, 
              19}}, \[IndentingNewLine]{"\<C3C4C2\>", {4. , 4\_5}, 
            0, "\<co[C3C4,C2]\>", {3, 4, 2}, {}, {12, 19}, {13, 17}, {5, 
              27}}, {"\<D4C3\>", {6, 2\_3, 6\_2}, 
            0, "\<co[D4,C3]\>", {4, 2, 3}, {"\<ba\>" \[Rule] "\<a3b\>"}, {2, 
              32}, {5, 22}, {1, 27}}, {"\<Q8C3\>", {2, 2\_2, 6\_3}, 
            0, "\<co[Q8,C3]\>", {2, 2, 2, 
              3}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {}, {12, 13, 
              14}, {}}, \[IndentingNewLine]{"\<S4\>", {10, 1\_8, 2\_3}, 
            0, "\<sgroup[4]\>", {3, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>", \
"\<da\>" \[Rule] "\<a2d\>", "\<db\>" \[Rule] "\<cd\>", "\<dc\>" \[Rule] "\<bd\
\>"}, {}, {2, 11}, {2, 9}}, \[IndentingNewLine]{"\<A4C2\>", {8, 2\_8}, 
            0, "\<co[A4a,C2]\>", {3, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>"}, \
{}, {3, 20}, {1, 9}}, \[IndentingNewLine]{"\<D6C2\>", {16, 4\_2}, 
            0, "\<co[ca[12,11],C2]\>", {6, 2, 
              2}, {"\<ba\>" \[Rule] "\<a5b\>"}, {1, 3, 19}, {2, 3, 
              18}, {3, \(-9\), 18}}, \[IndentingNewLine]{"\<C3KC2\>", {8. , 
              8\_2}, 0, "\<co[C3K,C2]\>", {3, 2, 2, 2}, {}, {1, 2, 19}, {1, 
              2, 22}, {1, 5, 19}}, \[IndentingNewLine]{"\<Alt12nC2\>", {8, 
              8\_2}, 0, "\<co[cd[{-1,-1,{3}}],C2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D3C2Mn\>", {20, 2\_2}, 
            0, "\<md[D3C2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<A4Mn\>", {16, 1\_8}, 
            0, "\<md[A4]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<Q12M3n\>", {14, 2\_2, 6}, 
            0, "\<md[Q12]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<Q12M4n\>", {8, 2\_2, 12}, 
            0, "\<md[Q12,{1,3,2,4,5,6,7,9,8,10,11,12}]\>", {}, {}, {}, {}, \
{}}, \[IndentingNewLine]{"\<Q12M5n\>", {2, 2\_2, 18}, 
            0, "\<Q12M5n\>", {}, {}, {}, {}, {}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([25]\)] = {{"\<C25\>", {1. , 1\_24}, 
            9, "\<ca[25]\>", {25}, {}, {}, {}, {}}, {"\<C5C5\>", {1. , 
              1\_24}, 9, "\<co[ca[5],ca[5]]\>", {5, 
              5}, {}, {}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([26]\)] = {{"\<D13\>", {14, 1\_12}, 
            0, "\<ca[26,25]\>", {13, 
              2}, {"\<ba\>" \[Rule] "\<a12b\>"}, {}, {}, {}}, {"\<C26\>", {2. \
, 2\_12}, 
            0, "\<ca[26]\>", {26}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([27]\)] = {{"\<C27\>", {1. , 1\_26}, 
            8, "\<ca[27]\>", {27}, {}, {}, {}, {}}, {"\<C9C3\>", {1. , 
              1\_26}, 8, "\<co[ca[9],C3]\>", {9, 3}, {}, {10, 23}, {8, 
              28}, {8, 23}}, {"\<P27\>", {1, 1\_26}, 
            10, "\<ca[]\>", {3, 3, 3}, {"\<ba\>" \[Rule] "\<abc\>"}, {}, {8, 
              9\ }, {8, 10\ }}, \[IndentingNewLine]{"\<g2704\>", {1, 1\_26}, 
            10, "\<ca[]\>", {9, 
              3}, {"\<ba\>" \[Rule] "\<a4b\>"}, {}, {}, {}}, {"\<C3^3\>", {1. \
, 1\_26}, 8, "\<co[C3C3,C3]\>", {3, 3, 3}, {}, {}, {8, 12, 
              32}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([28]\)] = {{"\<Q28\>", {2, 2\_6, 14}, 
            0, "\<ca[28,13]\>", {7, 4}, {"\<ba\>" \[Rule] "\<a6b\>"}, {13, 
              21}, {}, {}}, {"\<C28\>", {2. , 2\_13}, 
            0, "\<ca[28]\>", {28}, {}, {12, 21}, {15, 24}, {12, 
              20}}, {"\<D14\>", {16, 2\_6}, 
            0, "\<ca[28,27]\>", {14, 
              2}, {"\<ba\>" \[Rule] "\<a13b\>"}, {3, \(-21\)}, {2, 
              30}, {}}, {"\<C14C2\>", {4. , 4\_6}, 
            0, "\<co[ca[14],C2]\>", {14, 2}, {}, {2, \(-21\)}, {3, 
              30}, {1, \(-20\)}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([29]\)] = {{"\<C29\>", {1. , 1\_28}, 
            0, "\<ca[29]\>", {29}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([30]\)] = {{"\<D3C5\>", {4, 1\_10, 4\_4}, 
            0, "\<ca[30,11]\>", {3, 
              10}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {3, 
              28}}, {"\<D5C3\>", {6, 1\_12, 6\_2}, 
            0, "\<ca[30,19]\>", {15, 2}, {"\<ba\>" \[Rule] "\<a4b\>"}, {18, 
              32}, {16, 19}, {}}, \[IndentingNewLine]{"\<D15\>", {16, 1\_14}, 
            0, "\<ca[30,29]\>", {15, 2}, {"\<ba\>" \[Rule] "\<a14b\>"}, {3, 
              10, 18}, {2, 8, 16}, {}}, \[IndentingNewLine]{"\<C30\>", {2. , 
              2\_14}, 0, "\<ca[30]\>", {30}, {}, {18, 19}, {8, 29}, {8, 
              25}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([31]\)] = {{"\<C31\>", {1. , 1\_30}, 
            0, "\<ca[31]\>", {31}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([32]\)] = {{"\<C32\>", {2. , 2\_15, 1}, 
            0, "\<ca[32]\>", {32}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g3202\>", {8, 8\_3, 19}, 
            11, "\<ca[]\>", {4, 4, 
              2}, {"\<ba\>" -> "\<abc\>"}, {}, {}, {}}, \[IndentingNewLine]{"\
\<C8C4\>", {4. , 4\_7, 7}, 
            0, "\<co[C8,C4]\>", {8, 4}, {}, {12, 22}, {15, 27}, {12, 
              22}}, \[IndentingNewLine]{"\<C8pC4\>", {4, 4\_7, 7}, 
            0, "\<co[C8,C4,4]\>", {8, 
              4}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<KiC8\>", {8, 4\_4, 8, 11}, 
            14, "\<co[K,C8,2]\>", {8, 2, 2}, {"\<ba\>" -> "\<abc\>"}, {2, 
              35}, {3, 25}, {}}, {"\<g3206\>", {12, 4\_5, 23}, 
            0, "\<ca[]\>", {4, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<acd\>"}, \
{}, {}, {5, 13}}, \[IndentingNewLine]{"\<g3207\>", {12, 4\_5, 15}, 
            0, "\<ca[]\>", {8, 2, 
              2}, {"\<ba\>" \[Rule] "\<a5b\>", "\<ca\>" \[Rule] "\<abc\>"}, \
{}, {}, {7, 37}}, \[IndentingNewLine]{"\<g3208\>", {4, 4\_4, 12, 7}, 
            0, "\<ca[]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" -> "\<d\>", "\<bb\>" -> "\<e\>", "\<dd\>" -> "\<e\
\>", "\<ba\>" \[Rule] "\<abc\>", "\<ca\>" -> "\<ace\>", "\<db\>" -> \
"\<bde\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<D4iC4\>", {12, 4\_3, 8, 19}, 
            0, "\<co[D4,C4,2]\>", {8, 2, 2}, {"\<ba\>" -> "\<a3bc\>"}, {3, 
              17}, {}, {}}, \[IndentingNewLine]{"\<Q8iC4\>", {4, 4\_2, 8, 12, 
              11}, 0, "\<co[Q8,C4,2]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<d\>", "\<bb\>" -> "\<e\>", "\<cc\>" \
\[Rule] "\<e\>", "\<ba\>" -> "\<abc\>", "\<ca\>" -> "\<ace\>", "\<cb\>" -> \
"\<bce\>"}, {}, {}, {}}, \[IndentingNewLine]\[IndentingNewLine]{"\<g3211\>", \
{8, 4\_4, 8, 11}, 
            14, "\<ca[]\>", {}, {}, {3, 29}, {2, 26}, {3, 
              12}}, \[IndentingNewLine]{"\<C4iC8\>", {4, 4\_3, 8\_2, 7}, 
            0, "\<co[C4,C8,2]\>", {4, 8}, {"\<ba\>" \[Rule] "\<a3b\>"}, {34, 
              35}, {}, {}}, \[IndentingNewLine]{"\<Q8pC4\>", {4, 4\_3, 8\_2, 
              11}, 0, "\<co[ca[8,5],C4,2]\>", {8, 
              4}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, {"\<C8iC4\>", \
{4, 4\_3, 16, 11}, 
            0, "\<co[C8,C4,2]\>", {8, 4}, {"\<ba\>" -> "\<a7b\>"}, {13, 
              17}, {13, 27\ }, {16, 
              22\ }}, \[IndentingNewLine]{"\<g3215\>", {4, 4\_3, 8\_2, 3}, 
            0, "\<ca[]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" -> "\<d\>", "\<bb\>" -> "\<c\>", "\<cc\>" -> "\<e\
\>", "\<dd\>" -> "\<e\>", "\<ba\>" \[Rule] "\<abc\>", "\<ca\>" -> "\<ace\>"}, \
{}, {}, {}}, \[IndentingNewLine]{"\<C16C2\>", {4. , 4\_7, 3}, 
            0, "\<co[ca[16],C2]\>", {16, 
              2}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g3217\>", {4, 4\_7, 
              3}, 0, "\<ca[]\>", {16, 
              2}, {"\<ba\>" -> "\<a9b\>"}, {}, {}, {}}, {"\<D16\>", {18, 
              2\_7, 9}, 
            0, "\<ca[32,31]\>", {16, 
              2}, {"\<ba\>" -> "\<a15b\>"}, {}, {}, {}}, {"\<Q16iC2\>", {10, 
              2\_6, 10, 9}, 
            0, "\<co[ca[16,7],C2,2]\>", {16, 
              2}, {"\<ba\>" \[Rule] "\<a7b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<Q32\>", {2, 2\_6, 18, 9}, 
            0, "\<ca[32,15]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" -> "\<e\>", "\<bb\>" -> "\<e\>", "\<cc\>" -> \
"\<de\>", "\<dd\>" -> "\<e\>", "\<ba\>" \[Rule] "\<abc\>", "\<ca\>" -> "\<acd\
\>", "\<da\>" -> "\<ade\>", "\<db\>" -> "\<bde\>", "\<cb\>" -> "\<bcd\>"}, \
{}, {}, {}}, \[IndentingNewLine]\[IndentingNewLine]{"\<C4C4C2\>", {8. , 8\_3, 
              19}, 0, "\<co[C4,C4,C2,1]\>", {4, 4, 2}, {}, {2, 12, 
              16}, {}, {}}, {"\<KiC4C2\>", {16, 8\_2, 43}, 
            0, "\<co[K,C4C2,2]\>", {4, 2, 2, 2}, {"\<ba\>" -> "\<abc\>"}, {6, 
              9, 13}, {1, 3, 13}, {2, 4, 
              12}}, \[IndentingNewLine]{"\<C4iC4C2\>", {8, 8, 16, 19}, 
            17, "\<co[C4,C4,C2,1,2]\>", {4, 4, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {6, 13, 
              16}, {}, {}}, \[IndentingNewLine]{"\<C2C4pC4\>", {8, 8\_3, 19}, 
            11, "\<co[co[C2,C4],C4,4]\>", {4, 2, 
              4}, {"\<ba\>" -> "\<abcc\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D4C4\>", {12, 4\_2, 12, 23}, 
            18, "\<co[ca[8,7],C4]\>", {4, 2, 
              4}, {"\<ba\>" \[Rule] "\<a3b\>"}, {3, 9, 12}, {}, {2, 5, 
              12}}, {"\<Q8C4\>", {4, 4, 12\_2, 15}, 
            19, "\<co[Q8,C4]\>", {2, 2, 2, 
              4}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}, {"\<P32\>", {20, 4\_3, 47}, 
            0, "\<co[K,K,C2,2,2]\>", {4, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<acd\>"}, \
{}, {3, 5, 34}, {1, 2, 7}}, \[IndentingNewLine]{"\<KiD4\>", {16, 8\_2, 27}, 
            0, "\<co[K,D4,2]\>", {4, 2, 
              4}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<ac3\>"}, \
{2, 3, 9}, {}, {4, 5, 12}}, \[IndentingNewLine]{"\<KiQ8\>", {8, 8, 16, 19}, 
            17\ , "\<co[K,Q8,2]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>", "\<da\>" \[Rule] "\<ade\>"}, {}, {3, 13, 14}, {2, 
              14, 30}}, {"\<g3230\>", {12, 4\_2, 12, 23}, 
            18, "\<ca[]\>", {2, 2, 2, 2, 
              2}, {"\<cc\>" -> "\<d\>", "\<ba\>" \[Rule] "\<abd\>", "\<ca\>" -> \
"\<ace\>"}, {}, {}, {}}, \[IndentingNewLine]\[IndentingNewLine]{"\<g3231\>", \
{12, 4\_2, 12, 23}, 
            18, "\<ca[]\>", {2, 2, 2, 2, 
              2}, {"\<bb\>" -> "\<e\>", "\<cc\>" -> "\<d\>", "\<ba\>" \[Rule] \
"\<abd\>", "\<ca\>" -> "\<ace\>"}, {9, 13, 
              14}, {}, {}}, \[IndentingNewLine]{"\<Q8C4a\>", {4, 4, 12\_2, 
              15}, 19\ , "\<ca[]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" -> "\<d\>", "\<bb\>" -> "\<e\>", "\<cc\>" -> "\<d\
\>", "\<ba\>" \[Rule] "\<abd\>", "\<ca\>" -> "\<ace\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g3233\>", {8, 8\_3, 19}, 
            11, "\<ca[]\>", {2, 2, 2, 2, 
              2}, {"\<bb\>" -> "\<de\>", "\<cc\>" -> "\<d\>", "\<ba\>" \
\[Rule] "\<abd\>", "\<ca\>" -> "\<ace\>"}, {}, {}, {}}, \[IndentingNewLine]{"\
\<C4iD4\>", {20, 4\_3, 31}, 
            0\ , "\<co[C4,D4,2]\>", {4, 4, 
              2}, {"\<cb\>" \[Rule] "\<b3c\>", "\<ca\>" \[Rule] "\<a3c\>"}, \
{3, 4, 9}, {}, {}}, \[IndentingNewLine]{"\<C4iQ8\>", {4, 4\_2, 20, 15}, 
            0, "\<co[C4,Q8,2]\>", {4, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<bb\>" \[Rule] "\<c\>", \
"\<dd\>" \[Rule] "\<c\>", "\<db\>" \[Rule] "\<bcd\>"}, {13, 14, 
              16}, {}, {}}, {"\<C8K\>", {8. , 8\_3, 11}, 
            0, "\<co[C8,K]\>", {8, 2, 2}, {}, {1, 2, 22}, {1, 3, 26}, {1, 2, 
              22}}, {"\<C2C8pC2\>", {8, 8\_3, 11}, 
            0, "\<co[C2,ca[8],C2,4]\>", {8, 2, 
              2}, {"\<ba\>" -> "\<a5b\>"}, {}, {1, 15, 26}, {1, 5, 
              21}}, \[IndentingNewLine]{"\<g3238\>", {8, 8\_3, 7}, 
            99, "\<ca[]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" -> "\<d\>", "\<dd\>" -> "\<e\>", "\<cb\>" \[Rule] \
"\<bce\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<D4iK\>", {20, 4\_3, 27}, 
            0\ , "\<co[D4,K,2]\>", {8, 2, 
              2}, {"\<ba\>" \[Rule] "\<a7b\>"}, {1, 3, 22}, {}, {1, 4, 
              22}}, \[IndentingNewLine]{"\<Q8iK\>", {12, 4\_2, 12, 19}, 
            0, "\<co[Q8,K,2]\>", {8, 2, 
              2}, {"\<ba\>" -> "\<a3b\>"}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<Q16C2\>", {4, 4\_2, 20, 11}, 
            0\ , "\<co[ca[16,7],C2]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<d\>", "\<bb\>" \[Rule] "\<d\>", \
"\<cc\>" \[Rule] "\<d\>", "\<ba\>" \[Rule] "\<abd\>", "\<ca\>" \[Rule] "\<abc\
\>", "\<cb\>" \[Rule] "\<bcd\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g3242\>", {12, 4\_2, 12, 11}, 
            0, "\<ca[]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<e\>", "\<bb\>" \[Rule] "\<e\>", \
"\<cc\>" \[Rule] "\<e\>", "\<dd\>" \[Rule] "\<e\>", "\<ba\>" \[Rule] \
"\<abe\>", "\<ca\>" \[Rule] "\<abc\>", "\<cb\>" \[Rule] "\<bce\>"}, {}, {}, \
{}}, \[IndentingNewLine]{"\<g3243\>", {16, 4\_2, 8, 19}, 
            0, "\<ca[]\>", {8, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<a5c\>"}, \
{}, {}, {}}, {"\<g3244\>", {8, 4\_2, 16, 11}, 
            0, "\<ca[]\>", {2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<e\>", "\<bb\>" \[Rule] "\<e\>", \
"\<cc\>" \[Rule] "\<e\>", "\<dd\>" \[Rule] "\<e\>", "\<ba\>" \[Rule] \
"\<abe\>", "\<ca\>" \[Rule] "\<abc\>", "\<cb\>" \[Rule] "\<bce\>", "\<dc\>" \
\[Rule] "\<cde\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<C4KC2\>", {16. , 16, 
              43}, 0, "\<co[C4,K,C2,1]\>", {4, 2, 2, 2}, {}, {1, 2, 6, 
              16}, {}, {}}, {"\<D4K\>", {24, 8, 67}, 
            0, "\<co[D4,K]\>", {4, 2, 2, 2}, {"\<ba\>" -> "\<a3b\>"}, {1, 3, 
              6, 9}, {1, 2, 3, 15}, {}}, \[IndentingNewLine]{"\<Q8K\>", {8, 
              24, 19}, 
            0, "\<co[Q8,K]\>", {2, 2, 2, 2, 
              
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {6, 8, 13, 14}, {1, 3, 4, 15, 
              36}, {}}, \[IndentingNewLine]{"\<PC2\>", {16, 16, 27}, 
            0\ , "\<co[co[Q8,C2,4],C2]\>", {2, 2, 2, 2, 
              2}, {"\<dd\>" \[Rule] "\<c\>", "\<ba\>" \[Rule] "\<abc\>"}, {2, 
              3, 4, 6}, {}, {5, 7, 29, 
              30}}, \[IndentingNewLine]{"\<CL31C2\>", {20, 12, 39}, 
            0, "\<co[cl[3,1],C2]\>", {2, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ed\>" \[Rule] "\<cde\>"}, \
{}, {}, {1, 4, 5, 7}}, \[IndentingNewLine]{"\<CL4C2\>", {12, 20, 15}, 
            0, "\<co[cl[4],C2]\>", {2, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abe\>", "\<ca\>" \[Rule] "\<ace\>", \
"\<cb\>" \[Rule] "\<bce\>", "\<da\>" \[Rule] "\<ade\>", "\<db\>" \[Rule] \
"\<bde\>", "\<dc\>" \[Rule] "\<cde\>"}, {}, {}, {1, 29, 30, 
              31}}, \[IndentingNewLine]\[IndentingNewLine]{"\<KKC2\>", {32. , 
              155}, 0, "\<co[K,co[K,C2]]\>", {2, 2, 2, 2, 
              2}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<CL5?\>", {\(-20\), 
              12, 3}, 0, "\<cl[5]\>", {}, {}, {}, {}, {}}, {"\<CL32\>", \
{\(-12\), 20, 17}, 
            0, "\<cl[3,2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<CL41?\>", {\(-16\), 16, 7}, 
            0, "\<cl[4,1]\>", {}, {}, {}, {}, {}}, {"\<OctC2\>", {{4, 28, 
                15}}, 0, "\<co[Oct,C2]\>", {}, {}, {}, {}, {}}, \
{"\<OctiC2n\>", {6, 2\_2, 4\_2, 14, 9}, 
            0, "\<co[Oct,C2,2]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<P16M\>", {16, 16, 15}, 
            0, "\<md[co[P4,C4],{1,10,11,12,5,14,15,16,9,2,3,4,13,6,7,8}]\>", \
{}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<C8pC2M\>", {8, 8\_3, 7}, 
            99, "\<md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\
\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<KiC4M\>", {12, 4, 8\_2, 23}, 
            0, "\<md[co[K,C4,2],{1,4,3,2,7,8,5,6,9,12,11,10,15,16,13,14}]\>", \
{}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<Q8C2M\>", {20, 12, 31}, 
            0, "\<md[co[Q8,C2]]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C4iC4M\>", {4, 12, 16, 15}, 
            0, "\<C4iC4M\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<O16\>", {\(-16. \), 16, 35}, 
            0, "\<cd[{-1,1,1,1,1}]\>", {}, {}, {}, {}, {}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([33]\)] = {{"\<C33\>", {1. , 1\_32}, 
            0, "\<ca[33]\>", {11, 
              3}, {}, {}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([34]\)] = {{"\<C34\>", {2. , 2\_16}, 
            0, "\<ca[34]\>", {34}, {}, {}, {}, {}}, {"\<D17\>", {18, 1\_16}, 
            0, "\<ca[34,33]\>", {17, 
              2}, {"\<ba\>" \[Rule] "\<a16b\>"}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([35]\)] = {{"\<C35\>", {1. , 1\_34}, 
            0, "\<ca[35]\>", {7, 5}, {}, {18, 21}, {16, 24}, {17, 
              20}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([36]\)] = {{"\<Q36\>", {2, 2\_8, 18}, 
            26, "\<ca[36,17]\>", {9, 4}, {"\<ba\>" \[Rule] "\<a8b\>"}, {13, 
              23}, {}, {}}, \[IndentingNewLine]{"\<C36\>", {2. , 2\_17}, 
            23, "\<ca[36]\>", {36}, {}, {12, 23}, {15, 28}, {12, 
              23}}, \[IndentingNewLine]{"\<g3603\>", {4, 1\_24, 4\_2}, 
            27, "\<ca[]\>", {3, 3, 2, 
              2}, {"\<aaa\>" \[Rule] "\<b\>", "\<ca\>" -> "\<acd\>", "\<da\>" \
\[Rule] "\<ac\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<D18\>", {20, 2\_8}, 
            25, "\<ca[36,35]\>", {18, 
              2}, {"\<ba\>" \[Rule] "\<a17b\>"}, {3, \(-23\)}, {2, 
              31}, {}}, \[IndentingNewLine]{"\<C18C2\>", {4. , 4\_8}, 
            24, "\<co[ca[18],C2]\>", {18, 2}, {}, {6, 7}, {3, 
              31}, {1, \(-23\)}}, \[IndentingNewLine]{"\<Q12C3\>", {2, 2\_8, 
              6\_3}, 0, "\<co[Q12,C3]\>", {12, 
              3}\[InvisibleSpace], {"\<ba\>" \[Rule] "\<abb\>"}, {}, {8, 
              13}, {8, 14}}, {"\<C3iQ12\>", {2, 2\_8, 18}, 
            26, "\<co[C3,ca[12,5],2]\>", {3, 4, 
              3}, {"\<ba\>" \[Rule] "\<a2b\>", "\<cb\>" \[Rule] "\<bcc\>"}, \
{10, 11, 13}, {}, {}}, \[IndentingNewLine]{"\<C12C3\>", {2. , 2\_17}, 
            23, "\<co[ca[12],C3]\>", {12, 3}, {}, {10, 11, 12}, {8, 12, 
              15}, {8, 11, 12}}, \[IndentingNewLine]{"\<g3609\>", {10, 1\_8, 
              2\_9}, 0, "\<ca[]\>", {4, 3, 
              3}, {"\<ba\>" \[Rule] "\<ac\>", "\<ca\>" \[Rule] "\<abb\>"}, \
{}, {}, {8, 13}}, \[IndentingNewLine]{"\<D3D3\>", {16, 1\_4, 4\_4}, 
            0, "\<co[D3,D3]\>", {3\ , 2\ , 3, \ 
              2}, {"\<ba\>" \[Rule] "\<a2b\>", "\<dc\>" \[Rule] "\<c2d\>"}, \
{}, {}, {32, 33}}, \[IndentingNewLine]{"\<A4C3\>", {4, 1\_24, 4\_2}, 
            27, "\<co[A4a,C3]\>", {3, 2, 2, 
              3}, {"\<ca\>" \[Rule] "\<ab\>", "\<ba\>" \[Rule] "\<abc\>"}, \
{}, {9, 22}, {1, 10, 11}}, \[IndentingNewLine]{"\<D6C3\>", {8, 2\_6, 8\_2}, 
            0, "\<co[D3C2,C3]\>", {6, 6}, {"\<ba\>" \[Rule] "\<a5b\>"}, {19, 
              32}, {2, 23}, {7, 19}}, \[IndentingNewLine]{"\<E18C2\>", {20, 
              2\_8}, 25, "\<co[ca[6],ca[6,5],2]\>", {2, 3, 3, 
              2}, {"\<ba\>" \[Rule] "\<abb\>", "\<ca\>" \[Rule] "\<acc\>"}, \
{3, 10, 19}, {2, 18, 32}, {}}, \[IndentingNewLine]{"\<C6C6\>", {4. , 4\_8}, 
            24, "\<co[ca[6],ca[6]]\>", {6, 6}, {}, {19, 20}, {18, 
              22}, {\(-8\), 19}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([37]\)] = {{"\<C37\>", {1. , 1\_36}, 
            0, "\<ca[37]\>", {37}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([38]\)] = {{"\<C38\>", {2. , 2\_18}, 
            0, "\<ca[38]\>", {38}, {}, {}, {}, {}}, {"\<D19\>", {20, 1\_18}, 
            0, "\<ca[38,37]\>", {19, 
              2}, {"\<ba\>" \[Rule] "\<a18b\>"}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([39]\)] = {{"\<C39n\>", {1, 1\_38}, 
            0, "\<ca[]\>", {13, 
              3}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, {"\<C39\>", {1. \
, 1\_38}, 0, "\<ca[39]\>", {13, 3}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([40]\)] = {{"\<C40g9\>", {2, 2\_9, 10\_2}, 
            0, "\<ca[40,9]\>", {5, 8}, {"\<ba\>" \[Rule] "\<a4b\>"}, {18, 
              35}, {16, 26}, {}}, \[IndentingNewLine]{"\<C40\>", {2. , 
              2\_19}, 0, "\<ca[40]\>", {40}, {}, {18, 22}, {16, 27}, {17, 
              22}}, \[IndentingNewLine]{"\<C40d\>", {2, 2\_14, 10}, 
            0, "\<ca[]\>", {5, 
              8}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, {"\<Q40\>", {2, 
              2\_8, 22}, 
            0, "\<ca[40,19]\>", {5, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a4b\>", "\<bb\>" \[Rule] "\<c\>", \
"\<dd\>" \[Rule] "\<c\>", "\<db\>" \[Rule] "\<bcd\>"}, {13, 14, 
              18}, {}, {}}, {"\<D5C4\>", {12, 2\_8, 12}, 
            0, "\<co[ca[10,9],C4]\>", {20, 
              2}, {"\<ba\>" \[Rule] "\<a9b\>"}, {3, 12, 
              18}, {}, {}}, \[IndentingNewLine]{"\<D20\>", {22, 2\_9}, 
            0, "\<ca[40,39]\>", {20, 2}, {"\<ba\>" \[Rule] "\<a19b\>"}, {3, 
              4, 18}, {2, 15, 16}, {}}, \[IndentingNewLine]{"\<C10iC4\>", {4, 
              4\_4, 20}, 
            0, "\<co[ca[10],C4,2]\>", {5, 4, 
              2}, {"\<ba\>" \[Rule] "\<a4b\>"}, {6, 13, 
              18}, {}, {}}, \[IndentingNewLine]{"\<KiD5\>", {14, 4\_4, 10}, 
            0, "\<co[K,ca[10,9],2]\>", {5, 4, 
              2}, {"\<ba\>" \[Rule] "\<a4b\>", "\<cb\>" \[Rule] "\<b3c\>"}, \
{2, 3, 18}, {}, {}}, \[IndentingNewLine]{"\<C20C2\>", {4. , 4\_9}, 
            0, "\<co[ca[20],C2]\>", {20, 2}, {}, {16, \(-18\)}, {15, 
              29}, {12, 25}}, \[IndentingNewLine]{"\<C40g31\>", {6, 2\_5, 
              6\_4}, 0, "\<ca[40,31]\>", {4, 
              10}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {37, 40}, {1, 
              24}}, {"\<Q8C5\>", {2, 2\_4, 6\_5}, 
            0, "\<ca[40,11]\>", {5, 2, 2, 
              2}, {"\<bb\>" \[Rule] "\<c\>", "\<dd\>" \[Rule] "\<c\>", \
"\<db\>" \[Rule] "\<bcd\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<C40b\>", \
{12, 2\_4, 4\_5}, 
            0, "\<ca[]\>", {5, 4, 
              2}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D5K\>", {24, 4\_4}, 
            0, "\<co[ca[10,9],K]\>", {5, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a4b\>"}, {3, 6, \(-18\)}, {2, 3, 
              29}, {}}, \[IndentingNewLine]{"\<C10K\>", {8. , 8\_4}, 
            0, "\<co[ca[10],K]\>", {10, 2, 2}, {}, {2, 6, \(-18\)}, {}, {1, 
              5, 25}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([41]\)] = {{"\<C41\>", {1. , 1\_40}, 
            0, "\<ca[41]\>", {41}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([42]\)] = {{"\<C42\>", {2. , 2\_20}, 
            0, "\<ca[42]\>", {42}, {}, {19, 21}, {8, 30}, {19, 
              20}}, \[IndentingNewLine]{"\<C42g13\>", {8, 1\_18, 8\_2}, 
            0, "\<ca[42,13]\>", {21, 2}, {"\<ba\>" \[Rule] "\<a13b\>"}, {21, 
              32}, {19, 24}, {}}, \[IndentingNewLine]{"\<C42g29\>", {4, 
              1\_14, 4\_6}, 
            0, "\<ca[42,29]\>", {3, 
              14}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D21\>", {22, 1\_20}, 
            0, "\<ca[42,41]\>", {21, 2}, {"\<ba\>" \[Rule] "\<a20b\>"}, {3, 
              10, 21}, {2, 8, 24}, {}}, \[IndentingNewLine]{"\<C42a\>", {8, 
              1\_6, 2\_14}, 
            0, "\<ca[]\>", {7, 
              6}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g2101C2\>", {2, 2\_20}, 
            0, "\<co[co[ca[7],C3,7],C2]\>", {7, 3, 
              2}, {"\<ba\>" \[Rule] "\<a2b\>", "\<baa\>" \[Rule] "\<ab\>"}, \
{}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([43]\)] = {{"\<C43\>", {1. , 1\_42}, 
            0, "\<ca[43]\>", {43}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([44]\)] = {{"\<Q44\>", {2, 2\_10, 22}, 
            0, "\<ca[44,21]\>", {11, 
              4}, {"\<ba\>" \[Rule] "\<a10b\>"}, {}, {}, {}}, {"\<C44\>", {2. \
, 2\_21}, 0, "\<ca[44]\>", {44}, {}, {}, {}, {}}, {"\<D22\>", {24, 2\_10}, 
            0, "\<ca[44,43]\>", {22, 
              2}, {"\<ba\>" \[Rule] "\<a21b\>"}, {}, {}, {}}, {"\<C11K\>", \
{4. , 4\_10}, 
            0, "\<co[ca[11],K]\>", {11, 2, 
              2}, {}, {}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([45]\)] = {{"\<C45\>", {1. , 1\_44}, 
            30, "\<ca[45]\>", {45}, {}, {18, 23}, {16, 28}, {17, 
              23}}, \[IndentingNewLine]{"\<C15C3\>", {1. , 1\_44}, 
            30, "\<co[ca[5],C3C3]\>", {15, 3}, {}, {10, 11, 18}, {8, 12, 
              16}, {8, 11, 17}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([46]\)] = {{"\<C46\>", {2. , 2\_22}, 
            0, "\<ca[46]\>", {46}, {}, {}, {}, {}}, {"\<D23\>", {24, 1\_22}, 
            0, "\<ca[46,45]\>", {23, 
              2}, {"\<ba\>" \[Rule] "\<a22b\>"}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([47]\)] = {{"\<C47\>", {1. , 1\_46}, 
            0, "\<ca[47]\>", {47}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([48]\)] = {{"\<C3iC16\>", {2, 2\_11, 6\_4}, 
            0, "\<ca[48,41]\>", {3, 
              16}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C48\>", {2. , 2\_23}, 
            0, "\<ca[48]\>", {48}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g4803\>", {4, 1\_32, 4\_3}, 
            0, "\<ca[]\>", {3, 2, 2, 2, 
              2}, {"\<bb\>" -> "\<de\>", "\<cc\>" -> "\<d\>", "\<ba\>" -> \
"\<abcd\>", "\<ca\>" -> "\<abe\>", "\<da\>" -> "\<ade\>", "\<ea\>" -> \
"\<ad\>"}, {}, {9, 15}, {10, 12}}, \[IndentingNewLine]{"\<C8D3\>", {8, 2\_8, 
              8\_3}, 33, "\<co[C8,D3]\>", {24, 
              2}, {"\<ba\>" \[Rule] "\<a17b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g4805\>", {8, 2\_8, 8\_3}, 
            33, "\<ca[]\>", {2, 2, 2, 2, 
              3}, {"\<bb\>" -> "\<c\>", "\<cc\>" -> "\<d\>", "\<ba\>" -> \
"\<abd\>", "\<ea\>" -> "\<aee\>"}, {}, {}, {}\ }, \
\[IndentingNewLine]{"\<C24iC2\>", {14, 2\_10, 14}, 
            0, "\<co[ca[24,13],C2,2]\>", {24, 
              2}, {"\<ba\>" \[Rule] "\<a11b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D24\>", {26, 2\_11}, 
            0, "\<ca[48,47]\>", {24, 2}, {"\<ba\>" \[Rule] "\<a23b\>"}, {3, 
              10, 22}, {}, {4, 8, 22}}, \[IndentingNewLine]{"\<Q48\>", {2, 
              2\_10, 26}, 
            0, "\<ca[48,23]\>", {2, 2, 2, 2, 
              3}, {"\<aa\>" \[Rule] "\<d\>", "\<bb\>" -> "\<cd\>", "\<cc\>" \
\[Rule] "\<d\>", "\<ba\>" -> "\<abc\>", "\<ca\>" -> "\<acd\>", "\<ea\>" -> \
"\<aee\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<C3iC8C2\>", {4, 4\_5, 12\_2}, 
            36, "\<co[ca[24,17],C2]\>", {3, 8, 
              2}, {"\<ba\>" \[Rule] "\<a2b\>"}, {\(-11\), 35}, {18, 
              26}, {}}, \[IndentingNewLine]{"\<C3C8pC2\>", {4, 4\_5, 12\_2}, 
            36, "\<co[C3,C8pC2,2]\>", {3, 8, 
              2}, {"\<ba\>" \[Rule] "\<a2b\>", "\<cb\>" \[Rule] "\<b5c\>"}, \
{}, {8, 15, 26}, {}}, \[IndentingNewLine]\[IndentingNewLine]{"\<Q12C4\>", {4, 
              4\_5, 12\_2}, 
            36, "\<co[Q12,C4]\>", {12, 
              4}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {}}, {"\<Q12iC4\>", \
{4, 4\_4, 12, 16}, 
            0, "\<co[ca[12,5],C4,2]\>", {3, 4, 
              4}, {"\<ba\>" \[Rule] "\<a2b\>", "\<cb\>" \[Rule] "\<bbbc\>"}, \
{}, {}, {}}, {"\<C4iQ12\>", {4, 4\_5, 24}, 
            0, "\<co[ca[4],ca[12,5],2]\>", {12, 
              4}, {"\<ba\>" \[Rule] "\<a11b\>"}, {10, 13, 
              16}, {}, {}}, \[IndentingNewLine]{"\<D6iC4\>", {16, 4\_5, 12}, 
            0, "\<co[ca[12,11],C4,2]\>", {12, 2, 
              2}, {"\<ba\>" \[Rule] "\<a11bc\>"}, {9, 15}, {}, {4, 8, 
              12}}, \[IndentingNewLine]{"\<C3iC8iC2\>", {18, 2\_3, 6\_4}, 
            0, "\<co[ca[24,17],C2,2]\>", {8, 3, 
              2}, {"\<ba\>" \[Rule] "\<abb\>", "\<ca\>" \[Rule] "\<a7c\>"}, \
{}, {}, {}}, {"\<C3iQ8iC2\>", {6, 2\_2, 6\_4, 14}, 
            0, "\<co[C3,co[Q8,C2,2],2]\>", {3, 8, 
              2}, {"\<ba\>" \[Rule] "\<a2b\>", "\<cb\>" \[Rule] "\<bbbc\>"}, \
{}, {}, {}}, \[IndentingNewLine]{"\<Q8iD3\>", {14, 2\_2, 6\_5}, 
            0, "\<co[Q8,ca[6,5],2]\>", {2, 2, 2, 2, 
              3}, {"\<bb\>" \[Rule] "\<d\>", "\<cc\>" -> "\<d\>", "\<ba\>" -> \
"\<abc\>", "\<ca\>" -> "\<adc\>", "\<ea\>" -> "\<aee\>", "\<cb\>" -> \
"\<bcd\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<g4818\>", {2, 2\_2, 6\_4, 
              18}, 0, "\<ca[]\>", {2, 2, 2, 2, 
              3}, {"\<aa\>" -> "\<d\>", "\<bb\>" -> "\<d\>", "\<cc\>" -> "\<d\
\>", "\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<acd\>", "\<ea\>" -> \
"\<aee\>", "\<cb\>" -> "\<bcd\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<KiQ12\>", {8, 8\_2, 12\_2}, 
            0, "\<co[K,ca[12,5],2]\>", {6, 4, 
              2}, {"\<ba\>" \[Rule] "\<a5bc\>"}, {}, {}, {14, 
              19}}, \[IndentingNewLine]{"\<C3C4C4\>", {4. , 4\_11}, 
            32\ , "\<co[C3C4,C4]\>", {3, 4, 4}, {}, {10, 12, 
              16}, {}, {}}, \
\[IndentingNewLine]\[IndentingNewLine]{"\<KiC4C3\>", {8, 4\_6, 8\_2}, 
            0, "\<co[C3,K,C4,2]\>", {6, 4, 
              2}, {"\<ba\>" \[Rule] "\<abc\>"}, {}, {3, 12, 13}, {2, 8, 
              12}}, \[IndentingNewLine]{"\<C4iC4iC3\>", {4, 4\_5, 8\_3}, 
            0, "\<co[co[C4,C4,2],C3,2]\>", {4, 
              12}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C24C2\>", {4. , 4\_11}, 
            32, "\<co[ca[24],C2]\>", {24, 2}, {}, {19, 22}, {17, 25}, {19, 
              22}}, \[IndentingNewLine]{"\<C8pC2C3\>", {4, 4\_11}, 
            0, "\<co[C8pC2,C3]\>", {8, 2, 
              3}, {"\<ba\>" \[Rule] "\<a5b\>"}, {\[DoubleStruckCapitalJ]\ 2, 
              29}, {22, 25}, {1, 11, 
              21}}, \[IndentingNewLine]{"\<D8C3\>", {10, 2\_9, 10\_2}, 
            0, "\<co[ca[16,15],C3]\>", {8, 
              6}, {"\<ba\>" \[Rule] "\<a7b\>"}, {22, 32}, {}, {22, 
              33}}, \[IndentingNewLine]{"\<Q8iC6\>", {6, 2\_6, 6\_5}, 
            0, "\<co[Q8,C3C2,2]\>", {8, 
              6}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, {"\<Q16C3\>", \
{2, 2\_8, 10\_3}, 
            0, "\<co[ca[16,7],C3]\>", {2, 2, 2, 2, 
              3}, {"\<aa\>" \[Rule] "\<d\>", "\<bb\>" \[Rule] "\<d\>", \
"\<cc\>" \[Rule] "\<d\>", "\<ba\>" \[Rule] "\<abd\>", "\<ca\>" \[Rule] "\<abc\
\>", "\<cb\>" \[Rule] "\<bcd\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g4828\>", {2, 2\_14, 18}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g4829\>", {14, 2\_14, 6}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {9, 
              37}}, \[IndentingNewLine]{"\<g4830\>", {8, 2\_8, 4\_3, 12}, 
            0, "\<ca[]\>", {2, 2, 3, 2, 
              2}, {"\<aa\>" -> "\<b\>", "\<ca\>" \[Rule] "\<acc\>", "\<da\>" -> \
"\<ae\>", "\<ea\>" \[Rule] "\<ad\>", "\<dc\>" \[Rule] "\<ce\>", "\<ec\>" \
\[Rule] "\<cde\>"}, {}, {}, {}}, \
\[IndentingNewLine]\[IndentingNewLine]{"\<A4C4\>", {8, 2\_16, 8}, 
            37, "\<co[A4a,C4]\>", {3, 2, 2, 
              4}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>"}, \
{}, {4, 46}, {1, 26}}, \[IndentingNewLine]{"\<SL23C2\>", {4, 4\_8, 12}, 
            0, "\<co[SL23,C2]\>", {3, 2, 2, 2, 
              2}, {"\<bb\>" \[Rule] "\<d\>", "\<cc\>" \[Rule] "\<d\>", \
"\<ba\>" \[Rule] "\<abcd\>", "\<ca\>" \[Rule] "\<abd\>", "\<cb\>" \[Rule] \
"\<bcd\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<g4833\>", {8, 2\_16, 8}, 
            37, "\<ca[]\>", {2, 3, 2, 2, 
              2}, {"\<aa\>" -> "\<e\>", "\<cc\>" -> "\<e\>", "\<dd\>" -> "\<e\
\>", "\<cb\>" \[Rule] "\<bcde\>", "\<db\>" \[Rule] "\<bce\>", "\<dc\>" \
\[Rule] "\<cde\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<Q24C2\>", {4, 4\_4, 
              28}, 0, "\<co[ca[24,11],C2]\>", {6, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a5b\>", "\<bb\>" \[Rule] "\<c\>", \
"\<dd\>" \[Rule] "\<c\>", "\<db\>" \[Rule] "\<bcd\>"}, {6, 13, 15}, {1, 8, 
              15, 18, 36}, {}}, {"\<C4D6\>", {16, 4\_4, 16}, 
            35, "\<co[C4,D3C2]\>", {12, 2, 
              2}, {"\<ba\>" \[Rule] "\<a5b\>"}, {3, 6, 
              15}, {}, {}}, \[IndentingNewLine]{"\<D12C2\>", {28, 4\_5}, 
            0, "\<co[ca[24,23],C2]\>", {12, 2, 
              2}, {"\<ba\>" \[Rule] "\<a11b\>"}, {1, 5, 9}, {2, 15, 
              18}, {}}, \[IndentingNewLine]{"\<P48\>", {16, 4\_4, 16}, 
            35, "\<co[C3,P16a,2]\>", {3, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a2b\>", "\<ca\>" \[Rule] "\<aac\>", \
"\<cb\>" \[Rule] "\<bce\>", "\<db\>" \[Rule] "\<bde\>", "\<dc\>" \[Rule] \
"\<cde\>"}, {2, 3, 5}, {}, {5, 14, 27}}, \[IndentingNewLine]{"\<D4D3\>", {24, 
              2\_2, 6\_2, 8}, 
            0, "\<co[D4,D3]\>", {6, 2, 
              4}, {"\<ba\>" \[Rule] "\<a5b\>", "\<ca\>" \[Rule] "\<ac3\>"}, \
{}, {}, {1, 27, 29}}, \[IndentingNewLine]{"\<C3iP16\>", {12, 2\_2, 6\_2, 20}, 
            0, "\<co[C3,P16i,2]\>", {3, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a2b\>", "\<cb\>" \[Rule] "\<bce\>", \
"\<db\>" \[Rule] "\<bde\>", "\<dc\>" \[Rule] "\<cde\>"}, {}, {}, {1, 14, 
              27}}, {"\<Q8D3\>", {8, 2\_2, 6\_2, 24}, 
            0, "\<co[Q8,D3]\>", {2, 2, 2, 3, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>", "\<abab\>" \[Rule] "\<c\>", "\<ed\>" \[Rule] \
"\<dde\>"}, {}, {}, {14, 27, 
              30}}, \[IndentingNewLine]\[IndentingNewLine]{"\<Q8pD3\>", {20, 
              2\_2, 6\_2, 12}, 
            0, "\<co[Q8,D3,4]\>", {2, 2, 2, 2, 
              3}, {"\<bb\>" -> "\<d\>", "\<cc\>" -> "\<d\>", "\<ca\>" \[Rule] \
"\<acd\>", "\<ea\>" \[Rule] "\<aee\>", "\<cb\>" \[Rule] "\<bcd\>"}, {}, {}, \
{}}, \[IndentingNewLine]{"\<Q12K\>", {8, 8\_2, 24}, 
            0, "\<co[Q12,K]\>", {6, 4, 2}, {"\<ba\>" \[Rule] "\<a5b\>"}, {6, 
              13, 19}, {1, 3, 4, 8, 36}, {}}, {"\<KpD12\>", {20, 8\_2, 12}, 
            0\ \ , "\<co[K,ca[12,11],2]\>", {6, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a5bc\>"}, {2, 3, 19}, {3, 6, 7}, {3, 
              6, 19}}, \[IndentingNewLine]{"\<C3C4K\>", {8. , 8\_5}, 
            0, "\<co[C3C4,K]\>", {3, 4, 2, 2}, {}, {1, 16, 19}, {3, 15, 
              17}, {5, 12, 19}}, \[IndentingNewLine]{"\<C4pC12\>", {12, 4\_3, 
              12\_2}, 
            0, "\<co[C4,ca[12,7],2]\>", {12, 2, 
              2}, {"\<ba\>" \[Rule] "\<a7b\>"}, {}, {1, 5, 22}, {1, 5, 
              27}}, \[IndentingNewLine]{"\<Q8C6\>", {4, 4\_2, 12\_3}, 
            0, "\<co[Q8,C3C2]\>", {2, 2, 2, 
              6}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {}, {1, 12, 13, 14}, {}}, {"\<PC3\>", {8, 8\_5}, 
            0, "\<co[P16i,C3]\>", {2, 2, 6, 
              2}, {"\<dd\>" \[Rule] "\<c\>", "\<ba\>" \[Rule] "\<abc\>"}, {}, \
{2, 12, 15, 19, 36}, {}}, \[IndentingNewLine]{"\<S4C2\>", {20, 2\_8, 4\_3}, 
            0\ , "\<co[pe[s4],C2]\>", {3, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>", \
"\<da\>" \[Rule] "\<a2d\>", "\<db\>" \[Rule] "\<cd\>", "\<dc\>" \[Rule] "\<bd\
\>"}, {}, {2, 13}, {2, 18}}, \[IndentingNewLine]{"\<A4K\>", {16, 4\_8}, 
            0, "\<co[A4a,K]\>", {3, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>"}, \
{}, {}, {1, 18}}, \[IndentingNewLine]{"\<g4850\>", {16, 1\_32}, 
            0, "\<ca[]\>", {3, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>", \
"\<da\>" \[Rule] "\<ade\>", "\<ea\>" \[Rule] "\<ad\>"}, {}, {3, 10, 
              35}, {}}, \[IndentingNewLine]{"\<D3KC2\>", {32, 8\_2}, 
            0, "\<co[D3,KC2]\>", {6, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a5b\>"}, {1, 3, 6, 
              19}, {}, {}}, \[IndentingNewLine]{"\<C6KC2\>", {16. , 16\_2}, 
            0, "\<co[ca[6],K,C2,1]\>", {6, 2, 2, 2}, {}, {1, 2, 6, 19}, {1, 
              2, 3, 22}, {1, 5, 6, 19}}, {"\<OctC3\>", {2, 2\_2, 14\_3}, 
            0, "\<co[Oct,C3]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<OctiC3n\>", {2, 2\_3, 4\_3, 14\_2}, 
            0, "\<co[Oct,C3,2]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<OctpC3n\>", {2, 2\_2, 6\_2, 30}, 
            0, "\<co[Oct,C3,3]\>", {}, {}, {}, {}, {}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([49]\)] = {{"\<C49\>", {1. , 1\_48}, 
            38, "\<ca[49]\>", {49}, {}, {}, {}, {}}, {"\<C7C7\>", {1. , 
              1\_48}, 38, "\<co[ca[7],ca[7]]\>", {7, 
              7}, {}, {}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([50]\)] = {{"\<C50\>", {2. , 2\_24}, 
            39, "\<ca[50]\>", {50}, {}, {}, {}, {}}, {"\<C10C5\>", {2. , 
              2\_24}, 39, "\<co[ca[10],ca[5]]\>", {10, 
              5}, {}, {}, {}, {}}, {"\<D25\>", {26, 1\_24}, 
            40, "\<ca[50,49]\>", {25, 
              2}, {"\<ba\>" \[Rule] "\<a24b\>"}, {}, {}, {}}, {"\<C5nD5\>", \
{26, 1\_24}, 
            40, "\<co[ca[5],ca[10,9],2]\>", {5, 5, 
              2}, {"\<cb\>" \[Rule] "\<b4c\>", "\<ca\>" \[Rule] "\<a4c\>"}, \
{}, {}, {}}, {"\<C5nC10\>", {6, 1\_20, 6\_4}, 
            0, "\<co[ca[5],ca[10],2]\>", {5, 
              10}, {"\<ba\>" \[Rule] "\<a4b\>"}, {}, {5, 16}, {2, 
              17}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([51]\)] = {{"\<C51\>", {1. , 1\_50}, 
            0, "\<ca[51]\>", {51}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([52]\)] = {{"\<C52\>", {2. , 2\_25}, 
            0, "\<ca[52]\>", {52}, {}, {}, {}, {}}, {"\<D26\>", {28, 2\_12}, 
            0, "\<ca[52,51]\>", {26, 
              2}, {"\<ba\>" \[Rule] "\<a25b\>"}, {}, {}, {}}, {"\<Q52\>", {2, 
              2\_12, 26}, 
            0, "\<ca[52,25]\>", {13, 
              4}, {"\<ba\>" \[Rule] "\<a12b\>"}, {}, {}, {}}, {"\<C26C2\>", \
{4. , 4\_12}, 
            0, "\<co[ca[26],C2]\>", {26, 
              2}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<C52a\>", {14, 
              1\_12, 2\_13}, 
            0, "\<ca[]\>", {13, 
              4}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([53]\)] = {{"\<C53\>", {1. , 1\_52}, 
            0, "\<ca[53]\>", {53}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([54]\)] = {{"\<D27\>", {28, 1\_26, 1}, 
            0, "\<ca[54,53]\>", {27, 
              2}, {"\<ba\>" \[Rule] "\<a26b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C54\>", {2. , 2\_26, 1}, 
            0, "\<ca[54]\>", {\ 
              54}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<D9C3\>", {10, 
              1\_24, 10\_2, 4}, 
            0, "\<co[ca[18,17],C3]\>", {9, 
              6}, {"\<ba\>" \[Rule] "\<a8b\>"}, {23, 32}, {19, 
              28}, {}}, \[IndentingNewLine]{"\<C9D3\>", {4, 1\_18, 4\_8, 4}, 
            0, "\<co[ca[9],D3]\>", {3, 18}, {"\<ba\>" \[Rule] "\<a2b\>"}, {7, 
              10}, {2, 33}, {3, 23}}, \[IndentingNewLine]{"\<D9C3a\>", {10, 
              1\_20, 4\_6, 4}, 
            42, "\<ca[]\>", {9, 
              6}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g5406\>", {10, 1\_20, 4\_6, 4}, 
            42, "\<ca[]\>", {2, 3, 3, 
              3}, {"\<ccc\>" -> "\<dd\>", "\<ca\>" \[Rule] "\<accd\>", \
"\<da\>" \[Rule] "\<add\>", "\<cb\>" \[Rule] "\<bcd\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D9nC3\>", {28, 1\_26, 4}, 
            0, "\<co[C3,ca[18,17],2]\>", {2, 3, 3, 
              3}, {"\<bbb\>" \[Rule] "\<dd\>", "\<ba\>" \[Rule] "\<abbd\>", "\
\<ca\>" \[Rule] "\<acc\>", "\<da\>" \[Rule] "\<add\>"}, {3, 10, 23}, {2, 8, 
              28}, {}}, \[IndentingNewLine]{"\<P54\>", {10, 1\_24, 10\_2, 
              13}, 41, "\<ca[]\>", {2, 3, 3, 
              3}, {"\<ba\>" \[Rule] "\<abb\>", "\<ca\>" \[Rule] "\<acc\>", \
"\<cb\>" \[Rule] "\<bcd\>"}, {}, {2, 5, 
              7}, {}}, \[IndentingNewLine]{"\<C18C3\>", {2. , 2\_26, 4}, 
            0, "\<co[ca[18],C3]\>", {18, 3\ }, {}, {19, 23}, {8, 31}, {19, 
              23}}, \[IndentingNewLine]{"\<Q54\>", {2, 2\_26, 13}, 
            0, "\<co[P27,C2]\>", {6, 3, 
              3}, {"\<ba\>" \[Rule] "\<abc\>"}, {}, {8, 20}, {\(-8\), 
              10}}, \[IndentingNewLine]\[IndentingNewLine]{"\<g2704C2\>", {2, 
              2\_26, 4}, 
            0, "\<ca[]\>", {9, 
              6}, {"\<ba\>" \[Rule] "\<a4b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D3C3C3\>", {4, 1\_18, 4\_8, 13}, 
            0, "\<co[D3,C3,C3,0]\>", {3, 6, 
              3}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {5, 12, 32}, {2, 8, 
              11}}, \[IndentingNewLine]{"\<E18C3\>", {10, 1\_24, 10\_2, 13}, 
            41, "\<co[co[C3,ca[6,5],2],C3]\>", {2, 3, 3, 
              3}, {"\<ba\>" \[Rule] "\<abb\>", "\<ca\>" \[Rule] "\<acc\>"}, \
{}, {5, 7, 32}, {4, 8, 11}}, \[IndentingNewLine]{"\<D27b\>", {28, 1\_26, 13}, 
            0, "\<ca[]\>", {3, 3, 3, 
              2}, {"\<da\>" \[Rule] "\<aad\>", "\<db\>" \[Rule] "\<bbd\>", \
"\<dc\>" \[Rule] "\<ccd\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<C3^3C2\>", \
{2. , 2\_26, 13}, 
            0, "\<co[C3C3,C3,C2,1]\>", {3, 3, 3, 2}, {}, {10, 11, 19}, {8, 
              17, 32}, {8, 11, 19}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([55]\)] = {{"\<C55\>", {1. , 1\_54}, 
            0, "\<ca[55]\>", {55}, {}, {}, {}, {}}, {"\<g5502\>", {1, 1\_54}, 
            0, "\<ca[]\>", {11, 
              5}, {"\<ba\>" \[Rule] "\<a9b\>"}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([56]\)] = {{"\<C7nC8\>", {2, 2\_13, 14\_2}, 
            0, "\<ca[56,13]\>", {7, 8}, {"\<ba\>" \[Rule] "\<a6b\>"}, {21, 
              35}, {24, 26}, {}}, \[IndentingNewLine]{"\<C56\>", {2. , 
              2\_27}, 0, "\<ca[56]\>", {56}, {}, {21, 22}, {24, 27}, {20, 
              22}}, \[IndentingNewLine]{"\<C7nQ8\>", {2, 2\_12, 30}, 
            0, "\<co[ca[7],Q8,2]\>", {7, 2, 2, 
              2}, {"\<bb\>" \[Rule] "\<d\>", "\<cc\>" \[Rule] "\<d\>", \
"\<cb\>" \[Rule] "\<bcd\>", "\<ba\>" \[Rule] "\<a6b\>"}, {13, 14, 
              21}, {}, {}}, \[IndentingNewLine]{"\<Q56\>", {16, 2\_12, 16}, 
            0, "\<co[ca[14,13],C4]\>", {28, 
              2}, {"\<ba\>" \[Rule] "\<a13b\>"}, {3, 12, 
              21}, {}, {}}, \[IndentingNewLine]{"\<D28\>", {30, 2\_13}, 
            0, "\<ca[56,55]\>", {28, 2}, {"\<ba\>" \[Rule] "\<a27b\>"}, {3, 
              4, 21}, {2, 15, 24}, {}}, \[IndentingNewLine]{"\<C14nC4\>", {4, 
              4\_6, 28}, 
            0, "\<co[ca[14],C4,2]\>", {14, 
              4}, {"\<ba\>" \[Rule] "\<a13b\>"}, {6, 13, 
              21}, {}, {}}, {"\<KnD7\>", {18, 4\_6, 14}, 
            0, "\<co[K,ca[14,13],2]\>", {7, 4, 
              2}, {"\<ba\>" \[Rule] "\<a6b\>", "\<cb\>" -> "\<bbbc\>"}, {2, 
              3, 21}, {}, {}}, \[IndentingNewLine]{"\<C2nC28\>", {4. , 
              4\_13}, 0, "\<co[C4,ca[14],4]\>", {2, 2, 7, 
              2}, {"\<aa\>" \[Rule] "\<d\>"}, {16, \(-21\)}, {15, 
              30}, {12, \(-20\)}}, \[IndentingNewLine]{"\<KnC14\>", {6, 2\_7, 
              6\_6}, 0, "\<ca[56,15]\>", {4, 
              14}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {2, 5, 
              20}}, {"\<Q8C7\>", {2, 2\_6, 6\_7}, 
            0, "\<ca[56,43]\>", {2, 2, 2, 
              7}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<g5611\>", \
{8, 1\_48}, 
            0, "\<ca[]\>", {7, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<adc\>", \
"\<da\>" \[Rule] "\<ab\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<C14nK\>", \
{32, 4\_6}, 
            0, "\<co[ca[14],K,2]\>", {14, 2, 
              2}, {"\<ba\>" \[Rule] "\<a13b\>"}, {3, 6, \(-21\)}, {2, 3, 
              30}, {}}, \[IndentingNewLine]{"\<C14K\>", {8. , 8\_6}, 
            0, "\<co[ca[14],K]\>", {14, 2, 2}, {}, {2, 6, \(-21\)}, {}, {1, 
              5, 6, 20}}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([57]\)] = {{"\<g5701\>", {1, 1\_56}, 
            0, "\<ca[]\>", {19, 
              3}, {"\<ba\>" \[Rule] "\<a7b\>"}, {}, {}, {}}, {"\<C57\>", {1. \
, 1\_56}, 
            0, "\<ca[57]\>", {57}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([58]\)] = {{"\<C58\>", {2. , 2\_28}, 
            0, "\<ca[58]\>", {58}, {}, {}, {}, {}}, {"\<D29\>", {30, 1\_28}, 
            0, "\<ca[58,57]\>", {29, 
              2}, {"\<ba\>" \[Rule] "\<a28b\>"}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([59]\)] = {{"\<C59\>", {1. , 1\_58}, 
            0, "\<ca[59]\>", {59}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([60]\)] = {{"\<C3iC20\>", {2, 2\_14, 6\_5}, 
            0, "\<co[C3,ca[20],2]\>", {3, 4, 
              5}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, {"\<Q20C3\>", \
{2, 2\_14, 10\_3}, 
            0, "\<ca[60,49]\>", {5, 4, 
              3}, {"\<ba\>" \[Rule] "\<a4b\>"}, {}, {}, {}}, {"\<Q60\>", {2, 
              2\_14, 30}, 
            0, "\<ca[60,29]\>", {15, 4}, {"\<ba\>" \[Rule] "\<a14b\>"}, {10, 
              13, 18}, {}, {}}, {"\<C60\>", {2. , 2\_29}, 
            0, "\<ca[60]\>", {5, 4, 3}, {}, {10, 12, 18}, {8, 15, 16}, {8, 
              12, 17}}, {"\<A5\>", {16, 1\_44}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}, \
"\<pe[{{1,4,2,6,3,5},{1,2,5,6,3,4}}]\>"}, \[IndentingNewLine]{"\<g6006\>", \
{6, 1\_12, 2\_15, 6\_2}, 
            0, "\<ca[]\>", {5, 4, 
              3}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, {"\<g6007\>", \
{6, 1\_12, 6\_7}, 
            0, "\<ca[]\>", {15, 
              4}, {"\<ba\>" \[Rule] "\<a8b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D10iC3\>", {24, 1\_8, 4\_4, 6\_2}, 
            0, "\<co[ca[30,19],C2,2]\>", {15, 2, 
              2}, {"\<ba\>" \[Rule] "\<a14b\>", "\<ca\>" \[Rule] "\<a4c\>"}, \
{}, {}, {}}, \[IndentingNewLine]{"\<A4C5\>", {4, 1\_40, 4\_4}, 
            0, "\<co[A4a,ca[5]]\>", {3, 2, 2, 
              5}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>"}, \
{}, {}, {5, 28}}, {"\<C60g19\>", {12, 2\_12, 12\_2}, 
            0, "\<ca[60,19]\>", {5, 6, 
              2}, {"\<ba\>" \[Rule] "\<a4b\>"}, {}, {19, 
              29}, {}}, {"\<C6iC10\>", {8, 2\_10, 8\_4}, 
            0, "\<co[ca[6],ca[10],2]\>", {6, 
              10}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {3, \(-28\)}}, \
{"\<D30\>", {32, 2\_14}, 
            0, "\<ca[60,59]\>", {30, 2}, {"\<ba\>" \[Rule] "\<a29b\>"}, {3, 
              18, 19}, {2, 8, 29}, {}}, {"\<C30C2\>", {4. , 4\_14}, 
            0, "\<co[ca[30],C2]\>", {5, 3, 2, 2}, {}, {\(-18\), 19}, {22, 
              29}, {19, 25}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(loop[\([61]\)] = {{"\<C61\>", {1. , 1\_60}, 
            0, "\<ca[61]\>", {61}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([62]\)] = {{"\<C62\>", {2. , 2\_30}, 
            0, "\<ca[62]\>", {62}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D31\>", {32, 1\_30}, 
            0, "\<ca[62,61]\>", {31, 
              2}, {"\<ba\>" \[Rule] "\<a30b\>"}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([63]\)] = {{"\<C63\>", {1. , 1\_62}, 
            29, "\<ca[63]\>", {63}, {}, {21, 23}, {24, 28}, {20, 
              23}}, \[IndentingNewLine]{"\<C7C3C3\>", {1. , 1\_62}, 
            29, "\<co[ca[7],C3C3]\>", {7, 3, 3}, {}, {10, 11, 21}, {8, 12, 
              24}, {8, 11, 20}}, \[IndentingNewLine]{"\<g2101C3\>", {1, 
              1\_62}, 31, "\<co[co[ca[7],C3,7],C3]\>", {7, 3, 
              3}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g6304\>", {1, 1\_62}, 
            31, "\<ca[]\>", {7, 
              9}, {"\<ba\>" \[Rule] "\<a4b\>"}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(loop[\([64]\)] = {{"\<C64\>", {2. , 2\_31, 32, 0}, 
            0, "\<ca[64]\>", {64}, {}, {}, {}, {}}, {"\<g64002\>", {4. , 
              4\_15, 48, 0}, 
            0, "\<co[C8,C8]\>", {8, 
              8}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64003\>", {4, 
              4\_15, 48, 1536}, 
            0, "\<co[C8,C8,4]\>", {8, 
              8}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {}}, {"\<g64004\>", \
{16, 4\_8, 8\_2, 32, 2688}, 
            0, "\<ca[]\>", {8, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<da\>" -> "\<adb\>"}, {}, \
{}, {}}, {"\<g64005\>", {8, 4\_8, 8, 16, 32, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64006\
\>", {12, 4\_6, 8\_2, 12, 32, 2304}, 
            0, "\<co[D4,ca[8,5],2]\>", {}, {}, {29, 
              17}, {}, {}}, {"\<Q8pC8\>", {4, 4\_5, 8\_2, 12\_2, 32, 2304}, 
            0, "\<co[Q8,C8,2]\>", {}, {}, {}, {}, {}}, {"\<g64008\>", {16, 
              4\_4, 8\_4, 32, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64009\>", {8, 4\_4, 
              8\_3, 16, 40, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64010\>", {12, 4\_10, 
              12, 32, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64011\>", {4, 4\_9, 12\_2, 32, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64012\>", {20, 4\_3, 
              8\_4, 32, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64013\>", {4, 4\_2, 
              8\_4, 20, 32, 2880}, 
            47, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64014\>", {4, 4\_2, 
              8\_4, 20, 32, 2880}, 
            47, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64015\>", {4, 4\_7, 
              8\_4, 48, 2304}, 
            0, "\<co[ca[8,5],C8,2]\>", {8, 
              8}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, {"\<g64016\>", \
{4, 4\_7, 16\_2, 48, 2304}, 
            0, "\<co[C8,C8,2]\>", {8, 8}, {"\<ba\>" \[Rule] "\<a7b\>"}, {29, 
              22}, {}, {}}, \[IndentingNewLine]{"\<g64017\>", {8, 8\_7, 32, 
              1536}, 60, "\<co[C4C2,C8,4]\>", {8, 4, 
              2}, {"\<ba\>" \[Rule] "\<abc\>"}, {1, 16, 22}, {1, 15, 27}, {5, 
              12, 22}}, {"\<g64018\>", {8, 8\_7, 40, 2688}, 
            51, "\<ca[]\>", {4, 4, 
              4}, {"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64019\>", {8, 8\_7, 48, 2688}, 
            46, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64020\>", {8, 8\_7, 40, 2304}, 
            0, "\<ca[]\>", {4, 4, 
              4}, {"\<ca\>" \[Rule] "\<bc\>", "\<cb\>" \[Rule] "\<ac\>"}, \
{24, 35}, {}, {}}, \[IndentingNewLine]\[IndentingNewLine]{"\<g64021\>", {8, 
              8\_3, 16\_2, 40, 2304}, 
            52, "\<ca[]\>", {8, 4, 
              2}, {"\<ba\>" \[Rule] "\<a3bc\>"}, {}, {}, {}}, {"\<g64022\>", \
{8, 8\_7, 48, 2304}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64023\
\>", {16, 8\_6, 48, 2688}, 
            0, "\<ca[]\>", {4, 4, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<acd\>"}, \
{}, {}, {}}, \[IndentingNewLine]{"\<g64024\>", {8, 8\_5, 16, 32, 2688}, 
            0, "\<ca[]\>", {8, 2, 
              4}, {"\<ba\>" \[Rule] "\<a5b\>", "\<ca\>" -> "\<abc\>"}, {}, \
{}, {}}, {"\<g64025\>", {8, 8\_7, 32, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64026\
\>", {4. , 4\_15, 32, 0}, 
            49, "\<co[C4,ca[16,9],4]\>", {}, {}, {}, {}, {}}, {"\<g64027\>", \
{4, 4\_15, 32, 1536}, 
            50, "\<ca[]\>", {16, 
              4}, {"\<ba\>" \[Rule] "\<a9b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64028\>", {4, 4\_15, 32, 2688}, 
            0, "\<ca[]\>", {16, 
              4}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {}}, {"\<g64029\>", \
{8, 4\_8, 8\_3, 32, 1536}, 
            0, "\<co[K,ca[16],2]\>", {16, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}, {"\<g64030\>", \
{8, 4\_8, 8\_3, 32, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64031\>", {8, 4\_8, 8\_3, 32, 2304}, 
            0, "\<ca[]\>", {8, 4, 
              2}, {"\<ca\>" \[Rule] "\<abc\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64032\>", {20, 4\_11, 28, 3264}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64033\>", {12, 4\_10, 
              12, 36, 3264}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64034\>", {20, 4\_11, 
              44, 3264}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64035\>", {12, 4\_10, 
              12, 52, 3264}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {12, 13}}, {"\<g64036\>", {12, 
              4\_10, 12, 32, 3264}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64037\>", {4, 4\_10, 20, 
              32, 3264}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64038\>", {20, 4\_7, 16, 
              20, 2688}, 
            0, "\<co[ca[16,15],C4,2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64039\>", {4, 4\_6, 16, 20, 36, 2688}, 
            0, "\<co[ca[16,7],C4,2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64040\>", {12, 4\_6, 8\_2, 12, 24, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64041\>", {12, 4\_6, 8\_2, 12, 28, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64042\>", {20, 4\_7, 
              8\_2, 24, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64043\>", {4, 4\_6, 
              8\_2, 20, 24, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64044\>", {4, 4\_7, 
              8\_4, 32, 1536}, 
            0, "\<co[C4,ca[16],2]\>", {4, 
              16}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, {"\<g64045\>", \
{4, 4\_7, 8\_4, 32, 2304}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64046\>", {4, 4\_7, 
              8\_4, 24, 3072}, 
            0, "\<ca[]\>", {16, 
              4}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, {"\<g64047\>", \
{4, 4\_7, 32, 36, 2688}, 
            0, "\<co[ca[16],C4,2]\>", {16, 
              4}, {"\<ba\>" \[Rule] "\<a15b\>"}, {}, {}, {}}, {"\<g64048\>", \
{4, 4\_7, 16\_2, 36, 2688}, 
            0, "\<ca[]\>", {16, 
              4}, {"\<ba\>" \[Rule] "\<a7b\>"}, {}, {}, {}}, {"\<g64049\>", \
{4, 4\_7, 16\_2, 40, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64050\>", {4. , 4\_15, 
              32, 0}, 49, "\<co[ca[32],C2]\>", {32, 
              2}, {}, {}, {}, {}}, \
\[IndentingNewLine]\[IndentingNewLine]{"\<g64051\>", {4, 4\_15, 32, 1536}, 
            0, "\<ca[]\>", {32, 
              2}, {"\<ba\>" \[Rule] "\<a17b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64052\>", {34, 2\_15, 33, 2880}, 
            0, "\<ca[64,63]\>", {32, 
              2}, {"\<ba\>" \[Rule] "\<a31b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64053\>", {18, 2\_14, 18, 18, 2880}, 
            0, "\<co[ca[32,15],C2,2]\>", {32, 
              2}, {"\<ba\>" \[Rule] "\<a15b\>"}, {}, {}, {}}, {"\<g64054\>", \
{2, 2\_14, 34, 34, 2880}, 
            0, "\<ca[64,31]\>", {}, {}, {}, {}, {}}, {"\<g64055\>", {8. , 
              8\_7, 56, 0}, 
            0, "\<co[C4,C4,C4,1]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<d\>", "\<bb\>" \[Rule] "\<e\>", \
"\<cc\>" \[Rule] "\<f\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<g64056\>", \
{16, 16\_3, 48, 1536}, 
            69, "\<co[C4C2,C4C2,4]\>", {4, 4, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64057\>", {8, 8\_7, 56, 1536}, 
            0, "\<ca[]\>", {4, 4, 
              4}, {"\<ba\>" -> "\<abcc\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64058\>", {16, 8\_4, 16, 48, 1536}, 
            0, "\<co[C4,K,C4,2]\>", {4, 2, 2, 
              4}, {"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {7, 13, 
              30}}, {"\<g64059\>", {8, 8\_3, 16\_2, 56, 1536}, 
            0, "\<co[C4,C4,C4,2]\>", {4, 4, 
              4}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, {"\<g64060\>", \
{32, 8\_4, 32, 2304}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64061\>", {16, 16\_3, 48, 2304}, 
            68, "\<ca[]\>", {4, 4, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<cb\>" -> "\<bcd\>"}, {}, \
{}, {}}, {"\<g64062\>", {16, 8\_4, 16, 48, 2304}, 
            67, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64063\>", {8, 8\_3, 
              16\_2, 56, 2304}, 
            66, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64064\>", {8, 8\_7, 56, 
              2304}, 0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64065\>", {8, 
              8\_3, 32, 56, 2304}, 
            62, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64066\>", {16, 8\_3, 
              24, 48, 2304}, 
            0, "\<co[K,C4,C4,2,2]\>", {}, {}, {}, {}, {}}, {"\<g64067\>", \
{24, 8\_3, 16, 40, 2304}, 
            64, "\<co[K,K,C4,2,2]\>", {4, 4, 2, 
              2}, {"\<ba\>" -> "\<abc\>", "\<da\>" -> "\<a3d\>"}, {}, {}, \
{}}, {"\<g64068\>", {8, 8\_3, 16\_2, 56, 2304}, 
            66, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64069\>", {16, 8\_4, 
              16, 48, 2304}, 
            67, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64070\>", {8, 8\_2, 16, 
              24, 56, 2304}, 
            65, "\<ca[]\>", {4, 4, 
              4}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<accc\>"}, \
{}, {}, {}}, \[IndentingNewLine]\[IndentingNewLine]{"\<g64071\>", {24, 8\_3, 
              16, 40, 2304}, 
            64, "\<co[C4C2,D4,4]\>", {}, {}, {}, {}, {}}, {"\<g64072\>", {8, 
              8\_2, 16, 24, 56, 2304}, 
            65, "\<co[C4C2,Q8,4]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64073\>", {32, 8\_4, 32, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64074\>", {16, 8\_3, 24, 
              48, 2688}, 
            63, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64075\>", {24, 8\_3, 
              16, 40, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64076\>", {8, 8\_3, 32, 
              56, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64077\>", {16, 16\_3, 
              48, 2688}, 
            68, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64078\>", {16, 8\_4, 
              16, 48, 2688}, 
            21, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64079\>", {8, 8\_2, 16, 
              24, 56, 2688}, 
            65, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64080\>", {16, 8\_3, 24, 48, 2688}, 
            63, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64081\>", {8, 8\_3, 16\_2, 56, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64082\>", {8, 8\_7, 56, 
              2688}, 0, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64083\>", {8. , 8\_7, 32, 0}, 
            61, "\<co[C8,C4C2]\>", {8, 4, 2}, {}, {2, 12, 
              22}, {}, {}}, \[IndentingNewLine]{"\<g64084\>", {8, 8\_7, 32, 
              1536}, 60, "\<co[C8,C4C2,4]\>", {8, 4, 
              2}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {}}, {"\<g64085\>", \
{8, 8\_7, 32, 1536}, 
            60, "\<co[C4,C8,C2,4]\>", {8, 2, 
              4}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64086\>", {8, 8\_7, 32, 1536}, 
            60, "\<ca[]\>", {2, 4, 
              8}, {"\<ba\>" -> "\<abcccc\>"}, {}, {}, {}}, {"\<g64087\>", \
{16, 8\_4, 16, 32, 1536}, 
            0, "\<co[K,C8,C2,1,2]\>", {8, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>"}, {1, 3, 4, \(-14\)}, {1, 2, 
              15, 26}, {5, 7, 12}}, \[IndentingNewLine]{"\<g64088\>", {16, 
              8\_4, 16, 32, 2304}, 
            59, "\<co[K,C8,C2,4,2]\>", {}, {}, {}, {}, {}}, {"\<g64089\>", \
{16, 8\_4, 16, 32, 2304}, 
            59, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64090\>", {24, 8\_5, 
              40, 2688}, 
            0, "\<ca[]\>", {4, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<acd\>"}, \
{}, {}, {}}, \[IndentingNewLine]\[IndentingNewLine]{"\<g64091\>", {16, 8\_4, 
              16, 48, 2688}, 
            21, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64092\>", {24, 8\_5, 
              32, 2688}, 
            0, "\<ca[]\>", {8, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a5b\>", "\<ca\>" -> "\<abc\>"}, {}, \
{}, {}}, {"\<g64093\>", {8, 8\_4, 24, 32, 2688}, 
            0, "\<ca[]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<d\>", "\<bb\>" \[Rule] "\<e\>", \
"\<dd\>" \[Rule] "\<e\>", "\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ace\
\>", "\<db\>" \[Rule] "\<bde\>"}, {}, {}, {}}, {"\<g64094?\>", {16, 8\_4, 16, 
              32, 2688}, 
            0, "\<ca[]\>", {4, 2, 
              8}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<ac3\>"}, \
{}, {}, {}, {}, {}}, {"\<g64095\>", {24, 8\_3, 16, 24, 2304}, 
            0, "\<co[D4,C4,C2,1,2]\>", {8, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3bc\>"}, {2, 13, 
              22}, {}, {}}, \[IndentingNewLine]{"\<g64096\>", {8, 8\_2, 16, 
              24, 40, 2304}, 
            0, "\<co[Q8,C4C2,2]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<d\>", "\<bb\>" \[Rule] "\<e\>", \
"\<cc\>" \[Rule] "\<e\>", "\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ace\
\>", "\<cb\>" \[Rule] "\<bce\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64097\>", {16, 8\_4, 16, 32, 2304}, 
            59, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64098\>", {16, 8\_2, 
              16\_2, 32, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64099\>", {24, 8\_5, 24, 
              2688}, 72, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64100\>", {8, 8\_4, 24, 40, 2688}, 
            58, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64101\>", {16, 8\_4, 16, 32, 2304}, 
            59, "\<ca[]\>", {2, 2, 4, 
              4}, {"\<ca\>" \[Rule] "\<ad3\>", "\<da\>" \[Rule] "\<ac3\>"}, \
{24, 26, 29}, {}, {}}, {"\<g64102?\>", {16, 8\_4, 16, 32, 
              2688}, , "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64103\>", {8, 
              8\_3, 16\_2, 32, 1536}, 
            28, "\<co[C2,C4,C8,2]\>", {4, 8, 
              
              2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64104\>", {8, 8\_3, 16\_2, 32, 2304}, 
            28, "\<co[C4,C8,C2,4,2]\>", {8, 2, 
              4}, {"\<ba\>" \[Rule] "\<a5b\>", "\<ca\>" \[Rule] "\<ac3\>"}, \
{}, {}, {}}, {"\<g64105\>", {8, 8\_3, 16\_2, 32, 2304}, 
            28, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64106\>", {8, 8\_3, 
              16\_2, 40, 2304}, 
            52, "\<co[ca[8,5],C4C2,2]\>", {8, 4, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64107\>", {8, 8\_3, 32, 40, 2304}, 
            0, "\<co[C8,C4C2,2]\>", {8, 4, 
              2}, {"\<ba\>" \[Rule] "\<a7b\>"}, {6, 13, 17}, {1, 13, 27}, {1, 
              16, 22}}, {"\<g64108\>", {8, 8\_3, 16\_2, 40, 2304}, 
            52, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64109\>", {8, 8\_4, 24, 
              40, 2688}, 
            58, "\<ca[]\>", {8, 4, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<a5c\>"}, \
{}, {}, {}}, {"\<g64110\>", {8, 8\_3, 16\_2, 48, 2304}, 
            0, "\<ca[]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<d\>", "\<bb\>" \[Rule] "\<c\>", \
"\<cc\>" \[Rule] "\<e\>", "\<dd\>" \[Rule] "\<e\>", "\<ba\>" \[Rule] \
"\<abc\>", "\<ca\>" \[Rule] "\<ace\>"}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64111\>", {8, 8\_3, 16\_2, 48, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64112\>", {8, 8\_7, 32, 
              1536}, 0, "\<co[co[C2,C4],C8,4]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64113\>", {8, 8\_7, 32, 2304}, 
            62, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64114\>", {8, 8\_7, 32, 2304}, 
            62, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64115\>", {12, 4\_4, 
              12\_3, 32, 1536}, 
            0, "\<co[D4,C8]\>", {}, {4, 2, 
              8}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {2, 5, 
              22}}, \[IndentingNewLine]{"\<g64116?\>", {12, 4\_4, 12\_3, 32, 
              2304}, 34, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64117?\>", {12, 4\_4, 12\_3, 32, 2304}, 
            34, "\<co[C8,D4,4]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<g64118\>", {20, 4\_6, 20, 28, 2304}, 
            0, "\<co[C4,C8,C2,2]\>", {8, 2, 
              4}, {"\<ba\>" \[Rule] "\<a7b\>"}, {4, 12, 
              22}, {}, {}}, \[IndentingNewLine]{"\<g64119\>", {12, 4\_4, 
              12\_3, 36, 2304}, 
            0, "\<co[C4,Q8,C2,2]\>", {8, 2, 
              4}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64120\>", {4, 4\_5, 20\_2, 44, 2304}, 
            0, "\<co[ca[16,7],C4]\>", {2, 2, 2, 2, 
              4}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<dd\>" \[Rule] "\<c\>", "\<ba\>" \[Rule] "\<abc\>", "\<da\>" \[Rule] "\<abd\
\>", "\<db\>" \[Rule] "\<bcd\>"}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64121\>", {12, 4\_5, 12, 20, 36, 2688}, 
            0, "\<ca[]\>", {8, 2, 
              4}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<a5c\>"}, \
{}, {}, {}}, \[IndentingNewLine]{"\<g64122\>", {4, 4\_4, 12\_2, 20, 44, 
              2688}, 0, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64123\>", {20, 4\_5, 12\_2, 28, 2688}, 
            0, "\<ca[]\>", {8, 2, 
              4}, {"\<ba\>" \[Rule] "\<a7b\>", "\<ca\>" \[Rule] "\<a3c\>"}, \
{}, {}, {}}, {"\<g64124\>", {12, 4\_4, 12\_3, 32, 2304}, 
            34, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64125\>", {12, 4\_4, 12\_3, 32, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<Q8C8\>", {4, 4\_3, 12\_4, 
              32, 1536}, 
            0, "\<co[Q8,C8]\>", {2, 2, 2, 
              8}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}, {"\<Q8pC8\>", {4, 4\_3, 12\_4, 32, 
              2304}, 0, "\<co[C8,Q8,4]\>", {}, {}, {}, {}, {}}, \
{"\<g64128\>", {32, 4\_4, 8\_2, 31, 2880}, 
            0, "\<co[K,C8,C2,2,2]\>", {}, {}, {}, {}, {}}, {"\<g64129\>", \
{16, 4\_4, 8, 24, 32, 2880}, 
            70, "\<co[Q8,K,C2,2,2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64130\>", {24, 4\_4, 8, 16, 24, 2880}, 
            71, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64131\>", {24, 4\_4, 8, 16, 24, 2880}, 
            71, "\<co[K,Q8,C2,2,2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64132\>", {8, 4\_4, 8, 32, 40, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64133\>", {16, 4\_4, 8, 
              24, 32, 2880}, 
            70, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64134\>", {28, 4\_6, 12, 27, 3072}, 
            54, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64135\>", {20, 4\_6, 
              20, 28, 3072}, 
            53, "\<ca[]\>", {}, {}, {3, 12, 17}, {}, {4, 7, 
              12}}, \[IndentingNewLine]{"\<g64136\>", {20, 4\_6, 20, 28, 
              3072}, 53, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64137\>", {12, 
              4\_6, 28, 36, 3072}, 
            73, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64138\>", {28, 4\_6, 
              12, 36, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {1, 3, 
              4}}, \[IndentingNewLine]{"\<g64139\>", {20, 4\_6, 20, 44, 
              3072}, 0, "\<ca[]\>", {}, {}, {}, {}, {5, 13, 
              30}}, \[IndentingNewLine]{"\<g64140\>", {28, 4\_2, 8\_2, 12, 
              27, 2880}, 
            0, "\<co[D4,D4,2]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<Q8pD4\>", {20, 4, 8\_2, 12\_2, 28, 2880}, 
            0, "\<co[Q8,D4,2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64142\>", {12, 4, 8\_2, 12, 20, 36, 2880}, 
            74, "\<co[C4,Q8,C2,2,2]\>", {8, 2, 
              4}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<ac3\>"}, \
{}, {}, {}}, \[IndentingNewLine]{"\<g64143?\>", {4, 4, 8\_2, 12, 28, 44, 
              2880}, 0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64144\>", {20, 
              4, 8\_2, 12\_2, 28, 56}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64145\>", {12, 4, 8\_2, 
              12, 20, 36, 2880}, 
            74, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64146?\>", {16, 8\_4, 16, 32, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64147\>", {24, 8\_3, 16, 
              24, 2688}, 
            0, "\<co[C8,C4,C2,2,2]\>", {4, 2, 
              8}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<ac7\>"}, \
{2, 3, 22}, {}, {}}, \[IndentingNewLine]{"\<g64148\>", {8, 8\_2, 16, 24, 40, 
              2688}, 0, "\<co[K,ca[16,7],2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64149\>", {16, 8\_2, 16\_2, 32, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64150\
\>", {24, 8\_5, 24, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64151\>", {8, 8\_4, 24, 40, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64152\>", {16, 8\_4, 16, 
              32, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64153\>", {24, 8\_5, 32, 
              3072}, 0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64154\>", {8, 
              8\_4, 24, 32, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<D4nQ8\>", {12, 4\_2, 
              8\_2, 28, 36, 2880}, 
            0, "\<co[D4,Q8,2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<Q8pQ8\>", {4, 8\_2, 12\_2, 20, 44, 2880}, 
            75, "\<co[Q8,Q8,2]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<g64157\>", {12, 4, 8\_2, 12, 20, 36, 2880}, 
            74, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64158?\>", {4, 4, 8\_2, 
              12, 28, 44, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64159\>", {12, 4, 8\_2, 
              12, 20, 36, 2880}, 
            74, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64160\>", {4, 8\_2, 12\_2, 20, 44, 2880}, 
            75, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64161\>", {16, 4\_4, 8, 24, 32, 2880}, 
            70, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64162\>", {16, 4\_4, 8\_2, 16, 32, 2880}, 
            76, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64163\>", {16, 4\_4, 
              8\_2, 16, 32, 2880}, 
            76, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64164\>", {8, 4\_4, 8, 
              16\_2, 40, 2880}, 
            77, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64165\>", {8, 4\_4, 16, 
              24, 40, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64166\
\>", {8, 4\_4, 8, 16\_2, 40, 2880}, 
            77, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64167\>", {20, 4\_6, 20, 28, 2688}, 
            57, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64168\>", {4, 4\_5, 
              20\_2, 44, 2688}, 
            78, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64169\>", {12, 4\_4, 
              12\_3, 36, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64170\
\>", {12, 4\_5, 12, 20, 36, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64171\>", {20, 4\_5, 12\_2, 28, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64172\>", {4, 4\_4, 
              12\_2, 20, 44, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64173\
\>", {20, 4\_6, 20, 28, 2688}, 
            57, "\<ca[]\>", {4, 8, 
              2}, {"\<ca\>" \[Rule] "\<a3c\>", "\<cb\>" \[Rule] "\<b3c\>"}, \
{}, {}, {}}, {"\<g64174\>", {36, 4\_7, 35, 2688}, 
            79, "\<co[C4,ca[16,15],2]\>", {4, 8, 
              2}, {"\<ca\>" \[Rule] "\<a3c\>", "\<cb\>" \[Rule] "\<b7c\>"}, \
{3, 16, 22}, {}, {}}, \[IndentingNewLine]{"\<g64175\>", {4, 4\_6, 36, 44, 
              2688}, 80, "\<co[C4,ca[16,7],2]\>", {}, {}, {13, 14, 17}, {13, 
              14, 27}, {}}, \[IndentingNewLine]{"\<g64176\>", {20, 4\_6, 20, 
              28, 2688}, 
            57, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64177\>", {28, 4\_6, 
              12, 27, 3072}, 
            54, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64178\>", {12, 4\_6, 
              28, 36, 3072}, 
            73, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64179\>", {4, 4\_5, 
              20\_2, 44, 2688}, 
            78, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64180\>", {4, 4\_5, 20\_2, 44, 2688}, 
            78, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64181\>", {4, 4\_6, 36, 44, 2688}, 
            80, "\<co[C8,Q8,2]\>", {}, {}, {13, 14, 
              17}, {}, {}}, {"\<g64182\>", {4, 4\_5, 12, 28, 44, 3072}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64183\
\>", {8. , 8\_7, 32, 0}, 
            61, "\<co[K,ca[16],4]\>", {2, 2, 
              16}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64184\>", {8, 
              8\_7, 32, 1536}, 
            60, "\<ca[]\>", {16, 2, 
              2}, {"\<ba\>" \[Rule] "\<a9b\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64185\>", {8, 8\_7, 32, 1536}, 
            60, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64186\>", {36, 4\_7, 
              35, 2688}, 
            79, "\<co[ca[32,31],C2]\>", {16, 2, 
              2}, {"\<ba\>" \[Rule] "\<a15b\>"}, {}, {}, {}}, {"\<g64187\>", \
{20, 4\_6, 20, 20, 2688}, 
            81, "\<co[ca[16,9],K,2]\>", {16, 2, 
              2}, {"\<ba\>" \[Rule] "\<a7b\>"}, {}, {}, {}}, {"\<g64188\>", \
{4, 4\_6, 36, 36, 2688}, 
            0, "\<co[ca[32,15],C2]\>", {2, 2, 2, 2, 2, 
              
              2}, {"\<aa\>" \[Rule] "\<e\>", "\<bb\>" \[Rule] "\<e\>", \
"\<cc\>" \[Rule] "\<de\>", "\<dd\>" \[Rule] "\<e\>", "\<ba\>" \[Rule] \
"\<abc\>", "\<ca\>" \[Rule] "\<acd\>", "\<da\>" \[Rule] "\<ade\>", "\<db\>" \
\[Rule] "\<bde\>", "\<cb\>" \[Rule] "\<bcd\>"}, {}, {}, {}}, {"\<g64189\>", \
{20, 4\_6, 20, 20, 2688}, 
            81, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64190\>", {28, 4\_6, 
              12, 27, 3072}, 
            54, "\<ca[]\>", {16, 2, 
              2}, {"\<ba\>" \[Rule] "\<a15b\>", "\<ca\>" \[Rule] "\<a7c\>"}, \
{}, {}, {}}, \[IndentingNewLine]\[IndentingNewLine]{"\<g64191\>", {12, 4\_6, 
              28, 28, 3072}, 
            0, "\<ca[]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<e\>", "\<bb\>" \[Rule] "\<e\>", \
"\<cc\>" \[Rule] "\<de\>", "\<dd\>" \[Rule] "\<e\>", "\<ba\>" \[Rule] \
"\<abc\>", "\<ca\>" \[Rule] "\<acd\>", "\<da\>" \[Rule] "\<ade\>", "\<db\>" \
\[Rule] "\<bde\>", "\<cb\>" \[Rule] "\<bcd\>", "\<ff\>" -> "\<e\>", "\<fa\>" -> \
"\<afe\>"}, {}, {}, {}}, {"\<g64192\>", {16. , 16\_3, 48, 0}, 
            0, "\<co[C4C2,C4C2]\>", {2, 2, 4, 
              4}, {}, {}, {}, {}}, {"\<g64193\>", {32, 16\_2, 32, 1536}, 
            0, "\<co[K,K,C4,2]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<e\>", "\<ca\>" \[Rule] "\<abce\>"}, \
{1, 2, 3, 6, 9}, {}, {}}, {"\<g64194\>", {16, 16, 32, 48, 1536}, 
            0, "\<co[K,C4,C4,2]\>", {4, 4, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {6, 8, 13, 16}, {1, 3, 4, 13, 
              14}, {1, 3, 4, 13, 14}}, \[IndentingNewLine]{"\<g64195\>", {16, 
              16\_3, 48, 1536}, 
            69, "\<co[C2,co[C2,C4],C4,4]\>", {4, 2, 4, 
              2}, {"\<ba\>" \[Rule] "\<abcc\>"}, {}, {}, {}}, {"\<g64196\>", \
{24, 8\_2, 24, 40, 1536}, 
            0, "\<co[C4C2,D4]\>", {4, 2, 4, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {2, 13, 14, 16}, {}, {1, 2, 
              7, 30}}, \[IndentingNewLine]{"\<Q8C4C2\>", {8, 8, 24\_2, 56, 
              1536}, 0, "\<co[Q8,C4C2]\>", {2, 2, 2, 4, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<g64198\>", \
{16, 16\_3, 48, 1536}, 
            69, "\<co[co[P4,C4],C4]\>", {2, 2, 2, 2, 
              4}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>", "\<da\>" \[Rule] "\<acd\>"}, {}, {}, {}}, \
{"\<g64199\>", {24, 8, 16\_2, 40, 1920}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64200\
\>", {8, 16\_2, 24, 56, 1920}, 
            0, "\<ca[]\>", {2, 2, 2, 2, 
              4}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>", "\<ed\>" -> "\<cde\>"}, {}, {}, {}}, \
\[IndentingNewLine]\[IndentingNewLine]{"\<g64201\>", {16, 8, 16, 24, 48, 
              1920}, 0, "\<ca[]\>", {2, 2, 2, 2, 
              4}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>", "\<da\>" \[Rule] "\<adc\>", "\<ed\>" -> \
"\<cde\>"}, {}, {}, {}}, {"\<g64202\>", {40, 8\_3, 39, 2304}, 
            82, "\<ca[]\>", {4, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<acd\>"}, \
{6, 8, 9, 22}, {1, 3, 4, 5, 34}, {}}, \[IndentingNewLine]{"\<g64203\>", {32, 
              16\_2, 32, 2304}, 
            0, "\<co[C2,K,D4,2,2]\>", {4, 2, 4, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<ac3\>"}, \
{}, {}, {}}, {"\<g64204\>", {16, 16, 32, 48, 2304}, 
            0, "\<co[K,co[Q8,C2],2]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>", "\<da\>" \[Rule] "\<ade\>"}, {}, {}, {}}, \
{"\<g64205\>", {24, 8\_2, 24, 40, 2304}, 
            83, "\<co[K,Q8,C2,4,2]\>", {2, 2, 2, 2, 2, 
              2}, {"\<cc\>" \[Rule] "\<d\>", "\<ba\>" \[Rule] "\<abd\>", \
"\<ca\>" \[Rule] "\<ace\>"}, {}, {}, {}}, {"\<g64206\>", {24, 8\_2, 24, 40, 
              2304}, 83, "\<ca[]\>", {2, 2, 2, 2, 2, 
              2}, {"\<bb\>" \[Rule] "\<e\>", "\<cc\>" \[Rule] "\<d\>", \
"\<ba\>" \[Rule] "\<abd\>", "\<ca\>" \[Rule] "\<ace\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64207\>", {24, 8\_2, 24, 40, 2304}, 
            83, "\<co[C4,co[P4,C4],2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64208\>", {8, 8, 24\_2, 56, 2304}, 
            84, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64209\>", {16, 16\_3, 48, 2304}, 
            68, "\<ca[]\>", {2, 2, 2, 2, 2, 
              2}, {"\<bb\>" \[Rule] "\<de\>", "\<cc\>" \[Rule] "\<d\>", "\<ba\
\>" \[Rule] "\<abd\>", "\<ca\>" \[Rule] "\<ace\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64210\>", {16, 16\_3, 48, 2304}, 
            68, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64211\>", {40, 8\_3, 39, 2304}, 
            82, "\<co[C2,C4,D4,2]\>", {4, 4, 2, 
              2}, {"\<cb\>" \[Rule] "\<b3c\>", "\<ca\>" \[Rule] "\<a3c\>"}, \
{}, {}, {}}, {"\<g64212\>", {8, 8\_2, 40, 56, 2304}, 
            0, "\<co[C2,C4,Q8,2]\>", {4, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<bb\>" \[Rule] "\<c\>", \
"\<dd\>" \[Rule] "\<c\>", "\<db\>" \[Rule] "\<bcd\>"}, {8, 13, 14, 
              16}, {}, {}}, \[IndentingNewLine]{"\<g64213\>", {24, 8\_2, 24, 
              40, 2304}, 
            83, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64214\>", {8, 8, 24\_2, 
              56, 2304}, 
            84, "\<co[co[C2,C4],Q8,4]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<d\>", "\<bb\>" \[Rule] "\<e\>", \
"\<cc\>" \[Rule] "\<d\>", "\<ba\>" \[Rule] "\<abd\>", "\<ca\>" \[Rule] "\<ace\
\>"}, {}, {}, {}}, {"\<g64215\>", {32, 8\_2, 16, 32, 2688}, 
            85, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64216\>", {32, 8\_2, 16, 32, 2688}, 
            85, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64217\>", {16, 8\_2, 
              32, 48, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64218\>", {24, 16, 24, 
              40, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64219\>", {24, 8, 16\_2, 
              40, 2688}, 
            87, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64220?\>", {16, 8, 16, 
              24, 48, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64221\>", {24, 8, 16\_2, 40, 2688}, 
            87, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64222\>", {8, 16\_2, 
              24, 56, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64223?\>", {16, 8, 16, 
              24, 48, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64224\
\>", {16, 24\_2, 48, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64225\>", {8, 8, 16, 32, 
              56, 2688}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64226\>", {36, 4, 12\_2, 
              35, 2496}, 
            0, "\<co[D4,D4]\>", {4, 2, 4, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<dc\>" \[Rule] "\<c3d\>"}, \
{}, {}, {}}, \[IndentingNewLine]{"\<g64227\>", {28, 4, 12, 20, 36, 2496}, 
            86, "\<co[K,P16i,2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64228\>", {20, 4, 12, 28, 44, 2496}, 
            88, "\<co[C4,P16i,-2]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64229\>", {20, 4, 12, 28, 44, 2496}, 
            88, "\<co[D4,D4,4]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\
\<Q8D4\>", {12, 4, 12, 36, 52, 2496}, 
            0, "\<co[Q8,D4]\>", {2, 2, 2, 4, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>", "\<ed\>" \[Rule] "\<d3e\>"}, {}, {}, {}}, \
\[IndentingNewLine]\[IndentingNewLine]{"\<g64231\>", {28, 4, 12, 20, 36, 
              2496}, 86, "\<co[Q8,D4,4]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64232\>", {20, 12\_2, 20, 44, 2496}, 
            89, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64233?\>", {12, 12, 20\_2, 52, 2496}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64234?\>", {20, 12\_2, 20, 44, 2496}, 
            89, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64235\>", {12, 4, 20, 28, 52, 2496}, 
            0, "\<co[D4,Q8,4]\>", {}, {}, {2, 4, 5, 
              11}, {}, {}}, \[IndentingNewLine]{"\<g64236?\>", {20, 12\_2, 
              20, 44, 2496}, 
            89, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64237?\>", {12, 12, 20\_2, 52, 2496}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<Q8pQ8\>", {4, 12, 20, 28, 
              60, 2496}, 
            0, "\<co[Q8,Q8,4]\>", {}, {}, {}, {}, {}}, {"\<Q8Q8\>", {4, 
              12\_2, 36, 60, 2496}, 
            0, "\<co[Q8,Q8]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>", "\<dd\>" \[Rule] "\<f\>", "\<ee\>" \[Rule] \
"\<f\>", "\<ed\>" \[Rule] "\<def\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64240\>", {20, 12\_2, 20, 44, 2496}, 
            89, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]\
\[IndentingNewLine]{"\<g64241\>", {28, 12\_3, 36, 2880}, 
            90, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64242\>", {28, 12\_3, 
              36, 2880}, 
            90, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64243\>", {20, 4, 
              20\_2, 44, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64244\>", {12, 12\_2, 
              28, 52, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64245\
\>", {4, 20\_3, 60, 2880}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<g64246\
\>", {16. , 16\_3, 32, 0}, 
            0, "\<co[C8,K,C2,1]\>", {2, 2, 2, 8}, {}, {2, 6, 8, 
              22}, {}, {}}, \[IndentingNewLine]{"\<g64247\>", {16, 16\_3, 32, 
              1536}, 91, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64248\>", {16, 
              16\_3, 32, 1536}, 
            91, "\<co[C2,C8,K,4]\>", {8, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {}}, {"\<g64249\>", \
{16, 16\_3, 32, 1920}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64250?\>", {40, 8\_3, 39, 2304}, 
            82, "\<co[C2,D4,K,2]\>", {8, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a7b\>"}, {}, {}, {}}, \
\[IndentingNewLine]\[IndentingNewLine]{"\<g64251\>", {24, 8\_2, 24, 24, 
              2304}, 92, "\<ca[]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64252\>", {8, 8\_2, 40, 40, 2304}, 
            0, "\<co[ca[16,7],K]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<dd\>" \[Rule] "\<c\>", "\<ba\>" \[Rule] "\<abc\>", "\<da\>" \[Rule] "\<abd\
\>", "\<db\>" \[Rule] "\<bcd\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g64253\>", {24, 8\_2, 24, 24, 2304}, 
            92, "\<co[C2,Q8,K,2]\>", {8, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}, {"\<g64254\>", \
{32, 8\_2, 16, 31, 2688}, 
            93, "\<ca[]\>", {8, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>", "\<ca\>" \[Rule] "\<a5c\>"}, \
{}, {}, {}}, {"\<g64255\>", {16, 8\_2, 32, 32, 2688}, 
            95, "\<ca[]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<e\>", "\<bb\>" \[Rule] "\<e\>", \
"\<cc\>" \[Rule] "\<e\>", "\<dd\>" \[Rule] "\<e\>", "\<ba\>" \[Rule] \
"\<abe\>", "\<ca\>" \[Rule] "\<abc\>", "\<cb\>" \[Rule] "\<bce\>", "\<dc\>" \
\[Rule] "\<cde\>"}, {}, {}, {}}, {"\<g64256\>", {24, 8\_2, 24, 24, 2688}, 
            94, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64257\>", {32, 8\_2, 
              16, 31, 2688}, 
            93, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64258\>", {24, 8\_2, 
              24, 24, 2688}, 
            94, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64259\>", {16, 8\_2, 
              32, 32, 2688}, 
            95, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<g64260\>", {32. , 32, 
              32, 0}, 0, "\<co[C4C2,KC2]\>", {2, 2, 2, 2, 4}, {}, {1, 2, 6, 
              8, 16}, {}, {}}, \
\[IndentingNewLine]\[IndentingNewLine]{"\<g64261\>", {48, 16, 47, 1536}, 
            0, "\<co[D4,KC2]\>", {4, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a3b\>"}, {1, 3, 6, 8, 
              9}, {}, {}}, \[IndentingNewLine]{"\<g64262\>", {16, 48, 48, 
              1536}, 0, "\<co[Q8,KC2]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}, \[IndentingNewLine]{"\<g64263\>", \
{32, 32, 32, 1536}, 
            0, "\<co[co[P4,C4],K]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<e\>", "\<fd\>" \[Rule] "\<def\>"}, {2, 
              3, 4, 6, 8}, {1, 2, 3, 15, 
              36}, {}}, \[IndentingNewLine]{"\<CL32C2\>", {40, 24, 39, 1920}, 
            0, "\<co[cl[3,2],C2]\>", {2, 2, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ed\>" \[Rule] "\<cde\>"}, \
{}, {}, {}}, \[IndentingNewLine]{"\<CL5C2\>", {24, 40, 40, 1920}, 
            0, "\<co[cl[5],C2]\>", {2, 2, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<abe\>", "\<ca\>" \[Rule] "\<ace\>", \
"\<cb\>" \[Rule] "\<bce\>", "\<da\>" \[Rule] "\<ade\>", "\<db\>" \[Rule] \
"\<bde\>", "\<dc\>" \[Rule] "\<cde\>"}, {}, {}, {}}, \
\[IndentingNewLine]{"\<CL41C2\>", {32, 32, 32, 1920}, 
            0, "\<co[cl[4,1],C2]\>", {2, 2, 2, 2, 2, 
              2}, {"\<aa\>" \[Rule] "\<e\>", "\<cb\>" \[Rule] "\<bce\>", \
"\<fd\>" \[Rule] "\<def\>"}, {}, {}, {}}, {"\<KKK\>", {64. , 63, 0}, 
            0, "\<co[K,K,K,1]\>", {}, {}, {}, {}, {}}, {"\<CL6\>", {\(-36\), 
              28, 36, 2016}, 
            0, "\<cl[6]\>", {}, {}, {}, {}, {}}, {"\<OctC4\>", {4, 4, 28\_2, 
              60, 2688}, 
            0, "\<co[Oct,C4]\>", {}, {}, {}, {}, {}}, {"\<OctiC4n\>", {4, 
              4\_2, 8\_3, 28, 36, 3008}, 
            0, "\<co[Oct,C4,2]\>", {}, {}, {}, {}, {}}, {"\<OctK\>", {8, 56, 
              56, 2688}, 
            0, "\<co[Oct,K]\>", {}, {}, {}, {}, {}}, {"\<OctiKn\>", {12, 
              4\_2, 8\_2, 28, 28, 3008}, 
            0, "\<co[Oct,K,2]\>", {}, {}, {}, {}, {}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[{
    \(\(loop[\([65]\)] = {{"\<g6501\>", {1. , 1\_64}, 
            0, "\<ca[65]\>", {13, 
              5}, {}, {}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([66]\)] = {{"\<g6601\>", {4, 1\_22, 4\_10}, 
            0, "\<ca[66,23]\>", {3, 2, 
              11}, {"\<ba\>" \[Rule] "\<a2b\>"}, {}, {}, {}}, {"\<g6602\>", \
{12, 1\_30, 12\_2}, 
            0, "\<ca[66,43]\>", {11, 2, 
              3}, {"\<ba\>" \[Rule] "\<a10b\>"}, {}, {}, {}}, {"\<D33\>", \
{34, 1\_32}, 
            0, "\<ca[66,65]\>", {33, 
              2}, {"\<ba\>" \[Rule] "\<a32b\>"}, {}, {}, {}}, {"\<g6604\>", \
{2. , 2\_32}, 
            0, "\<ca[66]\>", {66}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([67]\)] = {{"\<C67\>", {1. , 1\_66}, 
            0, "\<ca[67]\>", {67}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([68]\)] = {{"\<Q68\>", {2, 2\_16, 34}, 
            0, "\<ca[68,33]\>", {17, 
              4}, {"\<ba\>" \[Rule] "\<a16b\>"}, {}, {}, {}}, {"\<C68\>", {2. \
, 2\_33}, 
            0, "\<ca[68]\>", {68}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<g6803\>", {18, 1\_16, 2\_17}, 
            0, "\<ca[]\>", {}, {}, {}, {}, {}}, {"\<D34\>", {36, 2\_16}, 
            0, "\<ca[68,67]\>", {34, 
              2}, {"\<ba\>" \[Rule] "\<a33b\>"}, {}, {}, {}}, {"\<C17K\>", \
{4. , 4\_16}, 
            0, "\<ca[68,35]\>", {17, 2, 
              2}, {}, {}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([69]\)] = {{"\<g6901\>", {1. , 1\_68}, 
            0, "\<ca[69]\>", {69}, {}, {}, {}, {}}};\)\), \
"\[IndentingNewLine]", 
    \(\(loop[\([70]\)] = {{"\<g7001\>", {6, 1\_28, 6\_6}, 
            0, "\<ca[70,29]\>", {}, {}, {}, {}, {}}, {"\<g7002\>", {8, 1\_30, 
              8\_4}, 0, "\<ca[70,41]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<D35\>", {36, 1\_34}, 
            0, "\<ca[70,69]\>", {}, {}, {3, 18, 21}, {2, 16, 
              24}, {}}, \[IndentingNewLine]{"\<C70\>", {2. , 2\_34}, 
            0, "\<ca[70]\>", {70}, {}, {\(-18\), 21}, {16, 30}, {20, 
              25}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([71]\)] = {{"\<C71\>", {1. , 1\_70}, 
            0, "\<ca[71]\>", {}, {}, {}, {}, {}}};\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(loop[\([72]\)]\), "=", 
        RowBox[{"{", 
          
          RowBox[{\({"\<g7201\>", {2, 2\_17, 18\_2, 1}, 
              0, "\<ca[72,53]\>", {}, {}, {23, 35}, {26, 28}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<C72\>", {2. , 2\_35, 1}, 
              0, "\<ca[72]\>", {9, 8}, {}, {22, 23}, {25, 33}, {22, 23}}\), 
            ",", "\[IndentingNewLine]", \({"\<g7203\>", {2, 2\_26, 6\_3, 1}, 
              0, "\<ca[]\>", {}, {}, {}, {}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<Q72\>", {2, 2\_16, 38, 1}, 
              0, "\<ca[72,35]\>", {}, {}, {13, 14, 23}, {}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<D9C4\>", {20, 2\_16, 20, 1}, 
              0, "\<co[ca[18,17],C4,2]\>", {9, 2, 
                4}, {"\<ba\>" \[Rule] "\<a8b\>"}, {3, 12, 23}, {}, {}}\), ",",
             "\[IndentingNewLine]", \({"\<D36\>", {38, 2\_17, 1}, 
              0, "\<ca[72,71]\>", {36, 2}, {"\<ba\>" -> "\<a35b\>"}, {3, 4, 
                23}, {2, 15, 28}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<Q36C2\>", {4, 4\_8, 36, 1}, 
              0, "\<co[ca[36,17],C2]\>", {9, 4, 
                2}, {"\<ba\>" \[Rule] "\<a8b\>"}, {6, 13, 23}, {}, {}}\), 
            ",", \({"\<KnD9\>", {22, 4\_8, 18, 1}, 
              0, "\<co[ca[36,17],C2,2]\>", {18, 2, 
                2}, {"\<ba\>" \[Rule] "\<a17bc\>"}, {2, 3, 23}, {}, {}}\), 
            ",", "\[IndentingNewLine]", \({"\<C9C4C2\>", {4. , 4\_17, 1}, 
              0, "\<co[ca[36],C2]\>", {9, 4, 2}, {}, {7, 12}, {15, 
                31}, {12, \(-23\)}}\), ",", 
            "\[IndentingNewLine]", \({"\<D4C9\>", {6, 2\_9, 6\_8, 1}, 
              0, "\<ca[72,7]\>", {4, 2, 9}, {"\<ba\>" \[Rule] "\<a3b\>"}, {2, 
                7}, {3, 5, 33}, {}}\), ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \({"\<Q8C9\>", {2, 2\_8, 6\_9, 1}, 
              0, "\<ca[72,19]\>", {2, 2, 2, 
                9}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}\), 
            ",", \({"\<g7212\>", {2, 2\_17, 6\_6, 4}, 
              0, "\<co[ca[3],ca[8],ca[3],3]\>", {3, 
                24}, {"\<ba\>" \[Rule] "\<a2b\>"}, {29, 33}, {8, 25}, {8, 
                21}}\), "\[InvisibleSpace]", 
            ",", \({\*"\"\<\!\(C3\^2\)nC8\>\"", {2, 2\_17, 18\_2, 4}, 
              0, "\<co[C3,ca[24,5],2]\>", {3\ , 3, \ 
                8}, {"\<cb\>" \[Rule] "\<bbc\>", "\<ca\>" \[Rule] "\<aac\>"}, \
{}, {8, 26, 32}, {}}\), 
            ",", \({\*"\"\<\!\(C8C3\^2\)\>\"", {2. , 2\_35, 4}, 
              0, "\<co[ca[24],C3]\>", {8, 3, 3}, {}, {10, 11, 22}, {8, 12, 
                27}, {8, 11, 22}}\), ",", 
            "\[IndentingNewLine]", \({"\<g7215\>", {22, 1\_24, 4\_2, 6\_3, 
                1}, 0, "\<ca[]\>", {}, {}, {}, {}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<g3603C2\>", {8, 2\_24, 8\_2, 1}, 
              0, "\<ca[]\>", {}, {}, {}, {}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<D9K\>", {40, 4\_8, 1}, 
              0, "\<co[ca[18,17],K]\>", {9, 2, 2, 
                2}, {"\<ba\>" \[Rule] "\<a8b\>"}, {3, 6, \(-23\)}, {2, 3, 
                31}, {}}\), ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
              RowBox[{
              "\"\<C9\!\(TraditionalForm\`C2\^3\)\>\"", 
                ",", \({8. , 8\_8, 1}\), ",", "0", ",", 
                "\"\<co[C2,ca[36,19]]\>\"", ",", \({9, 2, 2, 2}\), 
                ",", \({}\), ",", \({2, 6, \(-23\)}\), ",", \({}\), 
                ",", \({1, 5, 6, 23}\)}], "}"}], ",", 
            "\[IndentingNewLine]", \({"\<g7219\>", {2, 2\_26, 18, 4}, 
              0, "\<ca[]\>", {8, 3, 
                3}, {"\<ba\>" -> "\<acc\>", "\<ca\>" \[Rule] "\<ab\>"}, {}, \
{}, {}}\), 
            ",", \({"\<Q12D3\>", {8, 2\_6, 6\_2, 8\_2, 24, 4}, 
              0, "\<co[ca[12,5],D3]\>", {3, 2, 3, 
                4}, {"\<ba\>" -> "\<a2b\>", "\<dc\>" \[Rule] "\<ccd\>"}, {}, \
{}, {16, 27}}\), ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \({"\<g7221\>", {20, 2\_8, 6\_4, 12, 4}, 
              0, "\<co[C3,co[ca[6,5],C4,2],2]\>", {}, {}, {}, {}, {4, 27}}\), 
            ",", "\[IndentingNewLine]", \({"\<g7222\>", {14, 2\_4, 8\_4, 18, 
                4}, 0, "\<ca[]\>", {}, {}, {}, {}, {7, 8, 16}}\), 
            ",", \({"\<Q12nD3\>", {26, 2\_6, 6\_3, 8\_2, 4}, 
              0, "\<co[ca[12,5],D3,2]\>", {12, 3, 
                2}\[InvisibleSpace], {"\<ba\>" \[Rule] "\<abb\>", "\<ca\>" \
\[Rule] "\<a11c\>"}, {}, {}, {4, 7, 8}}\), ",", 
            "\[IndentingNewLine]", \({"\<g7224\>", {2, 2\_8, 6\_4, 30, 4}, 
              0, "\<ca[]\>", {}, {}, {}, {}, {8, 15, 16}}\), ",", 
            "\[IndentingNewLine]", \({"\<SL23C3\>", {2, 2\_26, 6\_3, 13}, 
              0, "\<co[SL23,C3]\>", {}, {}, {}, {}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<Q24C3\>", {2, 2\_14, 14\_3, 4}, 
              0, "\<co[ca[24,11],C3]\>", {3, 2, 2, 2, 
                3}, {"\<ba\>" \[Rule] "\<a2b\>", "\<bb\>" \[Rule] "\<d\>", \
"\<cc\>" \[Rule] "\<d\>", "\<cb\>" \[Rule] "\<bcd\>"}, {}, {8, 13, 14}, {8, 
                14, 30}}\), ",", 
            "\[IndentingNewLine]", \({"\<D3C3C4\>", {8, 2\_12, 8\_5, 4}, 
              0, "\<co[D3,C3,C4,1]\>", {3, 6, 
                4}, {"\<ba\>" \[Rule] "\<a2b\>"}, {13, 32}, {7, 46}, {}}\), 
            ",", \({"\<C4nD3C3\>", {14, 2\_15, 14\_2, 4}, 
              0, "\<co[co[C4,D3,2],C3]\>", {12, 2, 
                3}, {"\<ba\>" \[Rule] "\<a11b\>"}, {3, 32}, {8, 15, 19}, {8, 
                39, 40}}\), ",", 
            "\[IndentingNewLine]", \({"\<Q12C3C2\>", {4, 4\_8, 12\_3, 4}, 
              0, "\<co[ca[12,5],C3C2]\>", {6, 4, 
                3}, {"\<ba\>" -> "\<a5b\>"}, {}, {13, 18}, {15, 19}}\), ",", 
            "\[IndentingNewLine]", \({"\<g7230\>", {10, 4\_6, 6\_3, 10\_2, 
                4}, 0, "\<co[ca[12,7],ca[6],2]\>", {6, 2, 2, 
                3}, {"\<ba\>" \[Rule] "\<a5bc\>"}, {14, 32}, {3, 5, 8}, {2, 
                19}}\), ",", 
            "\[IndentingNewLine]", \({"\<C3nQ24\>", {2, 2\_16, 38, 4}, 
              0, "\<co[C3,ca[24,11],2]\>", {}, {}, {11, 13, 15}, {}, {}}\), 
            ",", \({"\<E18C4\>", {20, 2\_16, 20, 4}, 
              0, "\<co[co[C3,ca[6,5],2],C4]\>", {2, 3, 3, 
                4}, {"\<ba\>" \[Rule] "\<abb\>", "\<ca\>" \[Rule] "\<acc\>"}, \
{3, 11, 15}, {}, {}}\), 
            ",", \({"\<C12nD3\>", {38, 2\_17, 4}, 
              0, "\<co[ca[12],ca[6,5],2]\>", {3, 12, 
                2}, {"\<cb\>" \[Rule] "\<b11c\>", "\<ca\>" \[Rule] \
"\<aac\>"}, {3, 5, 11}, {2, 8, 15, 32}, {}}\), 
            ",", \({"\<C6nQ12\>", {4, 4\_8, 36, 4}, 
              0, "\<co[ca[6],ca[12,5],2]\>", {3, 4, 3, 
                2}, {"\<ba\>" \[Rule] "\<a2b\>", "\<cb\>" \[Rule] "\<bcc\>"}, \
{10, 13, 19}, {1, 8, 18, 32, 36}, {}}\), 
            ",", \({"\<g7235\>", {22, 4\_8, 18, 4}, 
              0, "\<co[ca[12,7],ca[6,5],2]\>", {}, {}, {3, 11, 20}, {}, {}}\),
             ",", "\[IndentingNewLine]", \({"\<g7236\>", {4. , 4\_17, 4}, 
              0, "\<ca[]\>", {4, 3, 3, 2}, {}, {10, 12, 19}, {8, 15, 17}, {8, 
                12, 19}}\), ",", 
            "\[IndentingNewLine]", \({"\<D4C3C3\>", {6, 2\_9, 6\_8, 4}, 
              0, "\<co[C3,ca[24,7]]\>", {4, 2, 3, 
                3}, {"\<ba\>" \[Rule] "\<a3b\>"}, {}, {}, {}}\), 
            ",", \({"\<Q8C3C3\>", {2, 2\_8, 6\_9, 4}, 
              0, "\<co[ca[24,19],C3]\>", {2, 2, 2, 3, 
                3}, {"\<aa\>" \[Rule] "\<c\>", "\<bb\>" \[Rule] "\<c\>", \
"\<ba\>" \[Rule] "\<abc\>"}, {}, {}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<g7239\>", {10, 1\_8, 2\_27, a_}, 
              0, "\<ca[]\>", {}, {}, {}, {}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<P72\>", {22, 2\_9, 4\_8, 4}, 
              0, "\<ca[]\>", {}, {}, {}, {}, {2, 7, 8}}\), ",", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \({"\<g7241\>", {10, 1\_8, 6\_9, a_}, 
              0, "\<ca[]\>", {}, {}, {}, {}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<S4C3\>", {10, 1\_24, 2\_9, 10\_2, 
                13}, 0, "\<co[sgroup[4],C3]\>", {3, 2, 2, 2, 
                3}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>", "\
\<da\>" \[Rule] "\<a2d\>", "\<db\>" \[Rule] "\<cd\>", "\<dc\>" \[Rule] \
"\<bd\>"}, {}, {9, 13}, {3, 10}}\), ",", 
            "\[IndentingNewLine]", \({"\<g7243\>", {22, 1\_24, 4\_2, 6\_3, 
                a_}, 0, "\<ca[]\>", {}, {}, {}, {}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<A4D3\>", {16, 1\_16, 4\_10, 13}, 
              0, "\<co[A4a,ca[6,5]]\>", {3, 2, 2, 3, 
                2}, {"\<ba\>" \[Rule] "\<abc\>", "\<ca\>" \[Rule] "\<ab\>", "\
\<ed\>" \[Rule] "\<dde\>"}, {}, {}, {}}\), 
            ",", \({"\<g7245\>", {20, 2\_8, 4\_9, 4}, 
              0, "\<ca[]\>", {4, 3, 3, 
                2}, {"\<ba\>" -> "\<acc\>", "\<ca\>" \[Rule] "\<ab\>"}, {}, \
{}, {\(-8\), 13}}\), ",", 
            "\[IndentingNewLine]", \({\*"\"\<\!\(D3\^2\)C2\>\"", {32, 2\_4, 
                8\_4, 4}, 
              0, "\<co[co[ca[6,5],ca[6,5]],C2]\>", {3, 2, 3, 2, 
                2}, {"\<ba\>" -> "\<a2b\>", "\<dc\>" \[Rule] "\<ccd\>"}, {}, \
{}, {}}\), ",", 
            "\[IndentingNewLine]", \({"\<A4C6\>", {8, 2\_24, 8\_2, 13}, 
              0, "\<co[A4a,ca[6]]\>", {3, 2, 2, 3, 
                2}, {"\<ca\>" \[Rule] "\<ab\>", "\<ba\>" \[Rule] "\<abc\>"}, \
{}, {9, 21}, {5, 10, 11}}\), 
            ",", \({"\<g7248\>", {16, 4\_6, 16\_2, 4}, 
              0, "\<co[ca[6],ca[12,7],2]\>", {6, 2, 3, 
                2}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {2, 18, 22}, {5, 7, 
                19}}\), ",", 
            "\[IndentingNewLine]", \({"\<E18K\>", {40, 4\_8, 4}, 
              0, "\<co[co[C3,ca[6,5],2],K]\>", {2, 3, 3, 2, 
                2}, {"\<ba\>" \[Rule] "\<abb\>", "\<ca\>" \[Rule] "\<acc\>"}, \
{\(-4\), 5, 19}, {2, 3, 18, 32}, {}}\), ",", 
            "\[IndentingNewLine]", \({\*"\"\<\!\(C3\^2\)\!\(C2\^3\)\>\"", {8. \
, 8\_8, 4}, 0, "\<co[C3C3,K,C2,1]\>", {3, 3, 2, 2, 2}, {}, {1, 19, 20}, {3, 
                18, 22}, {1, \(-8\), 19}}\)}], "}"}]}], ";"}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(loop[\([73]\)] = {{"\<C73\>", {1. , 1\_72}, 
          0, "\<ca[73]\>", {}, {}, {}, {}, {}}}; 
    loop[\([74]\)] = {{"\<D34\>", {38, 1\_36}, 
          0, "\<ca[74,73]\>", {}, {}, {}, {}, {}}};\), "\[IndentingNewLine]", \

    \(\({"\<C74\>", {2. , 2\_36}, 
        0, "\<ca[74]\>", {}, {}, {}, {}, {}};\)\), "\[IndentingNewLine]", 
    \(loop[\([75]\)] = {{"\<C3C25\>", {1. , 1\_74}, 
          4, "\<co[ca[5],ca[5],C3,1]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<C75\>", {1. , 1\_74}, 
          4, "\<ca[75]\>", {}, {}, {}, {}, {}}}; 
    loop[\([80]\)] = {{"\<OctC5\>", {2, 2\_4, 14\_5}, 
          0, "\<co[Oct,C5]\>", {}, {}, {}, {}, {}}, {"\<OctC5n\>", {10, 70}, 
          0, "\<co[Oct,C5n]\>", {}, {}, {}, {}, {}}, {"\<OctiC5n\>", {2, 
            2\_6, 4\_6, 14\_3}, 
          0, "\<co[Oct,C5,2]\>", {}, {}, {}, {}, {}}};\), \
"\[IndentingNewLine]", 
    \(\(loop[\([96]\)] = {{"\<P48C2?\>", {32, 8\_4, 32}, 
            0, "\<co[co[C3,P16a,2],C2]\>", {3, 2, 2, 2, 2, 
              2}, {"\<ba\>" \[Rule] "\<a2b\>", "\<ca\>" \[Rule] "\<aac\>", \
"\<cb\>" \[Rule] "\<bce\>", "\<db\>" \[Rule] "\<bde\>", "\<dc\>" \[Rule] \
"\<cde\>"}, {}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(\(loop[\([104]\)] = {{"\<g104003\>", {2, 2\_38, 26}, 
            0, "\<ca[]\>", {13, 
              8}, {"\<ba\>" \[Rule] "\<a5b\>"}, {}, {}, {}}};\)\), "\
\[IndentingNewLine]", 
    \(\(loop[\([120]\)] = {{"\<S5\>", {26, 1\_24, 2\_35}, 
            0, "\<sgroup[5]\>", {}, {}, {}, {}, {}}, {"\<SL25\>", {2, 2\_44, 
              30}, 0, "\<pe[{{1,3,5,7,9,6,12,14,15,17,19,8,11,4,2,13,23,18,22,\
24,21,16,20,10},
{2,4,6,8,10,11,13,3,16,18,20,21,22,23,5,9,19,7,1,17,24,12,14,15}},120]\>", \
{}, {}, {}, {}, {}}};\)\), "\[IndentingNewLine]", 
    \(loop[\([144]\)] = {{"\<P144?\>", {52, 4\_4, 6\_4, 10\_4, 12}, 
          0, "\<ca[]\>", {}, {}, {}, {}, {}}}; 
    loop[\([168]\)] = {{"\<SL32?\>", {22, 1\_104, 2\_21}, 
          0, "\<ca[]\>", {}, {}, {}, {}, {}}}; 
    loop[\([256]\)] = {{"\<CL8\>", {\(-120\), 136, 32512}, 
          0, "\<cl[8]\>", {}, {}, {}, {}, {}}, \[IndentingNewLine]{"\<OctOctn\
\>", {4, 28\_2, 196}, 
          0, "\<co[Oct,Oct]\>", {}, {}, {}, {}, {}}, \
\[IndentingNewLine]{"\<OctiOctn\>", {4, 16\_2, 28, 32\_2, 44, 84}, 
          0, "\<co[Oct,Oct,2]\>", {}, {}, {}, {}, {}}}; 
    loop[\([257]\)] = {{"\<Unrecognised\>", {}, 
          0, "\<Unrecognised\>", {}, {}, {}, {}, {}}};\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".6 Creating Polar-Vector & Hyperbolic functions."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[TextData[{
  "Standard Rules for ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(toPol, \ toVec, \ toHyPol\),
          FontSlant->"Italic"], TraditionalForm]]],
  " & ",
  StyleBox["toHyVec",
    FontSlant->"Italic"],
  " synthesis.\n1. Sum of 2 squares  ",
  Cell[BoxData[
      \(TraditionalForm\`a1\^2\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\(a1 \[PlusMinus] a2\)\(+\)\) .. )\)\^2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b1\^2\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\(b1 \[PlusMinus] b2\)\(+\)\) .. )\)\^2\)]],
  ";  s2=",
  Cell[BoxData[
      \(TraditionalForm\`a1\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b1\)]],
  ",\nInclude s2 in the toPol output, followed by \[Theta]=If[b1==0,If[a1==0,\
\[Pi],0],ArcTan[a1,b1]]\nIn toVec, calculate s= m",
  Cell[BoxData[
      \(TraditionalForm\`\@s2\)]],
  ", where m is the required weighting.\nSet up the result list, with an \
entry for each of {a1,a2,..b1,b2,..}, divided by ",
  StyleBox["mm",
    FontSlant->"Italic"],
  ", the number of elements. Add \[PlusMinus]s Cos[\[Theta]] wherever \
\[PlusMinus]ai occurs, \[PlusMinus]s Sin[\[Theta]] wherever \[PlusMinus]bi \
occurs.\n2. Sum of 3 squares\n",
  Cell[BoxData[
      \(TraditionalForm\`a1\^2\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\(a \[PlusMinus] b\)\(+\)\) .. )\)\^2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b1\^2\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\(h \[PlusMinus] i\)\(+\)\) .. )\)\^2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c1\^2 = \((\(\(p \[PlusMinus] q\)\(+\)\) \
.. )\)\^2\)]],
  ", s3=(a1+b1+c1)/2.\nThey all have the 2 divisor. Include s3, followed by \
\[Theta] =If[b1=0, 0, ArcTan[a1-c1, -",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  " b1]]. Start toVec in the same way, but add \[PlusMinus]s Cos[\[Theta]] \
wherever \[PlusMinus]ai occurs, \[PlusMinus]s Cos[\[Theta]+2\[Pi]/3] wherever \
\[PlusMinus]bi occurs, \[PlusMinus]s Cos[\[Theta]-2\[Pi]/3] wherever \
\[PlusMinus]ci occurs.\n3. Difference of 2 squares  ",
  Cell[BoxData[
      \(TraditionalForm\`a1\^2\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\(a1 \[PlusMinus] a2\)\(+\)\) .. )\)\^2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b1\^2\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\(b1 \[PlusMinus] b2\)\(+\)\) .. )\)\^2\)]],
  "; s2=",
  Cell[BoxData[
      \(TraditionalForm\`a1\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`b1\)]],
  ",\nInclude s2 in the toHyPol output, followed by \
\[Theta]=If[b1==0,If[a1==0,\[Pi],0], arcTanh[a1,b1]]. Note that this must be \
my 2-argument version, NOT ArcTanh[ai/b1].\nIn toVec, calculate s= m",
  Cell[BoxData[
      \(TraditionalForm\`\@s2\)]],
  ", where m is the required weighting.\nSet up the result list, with an \
entry for each of {a1,a2,..b1,b2,..}, divided by ",
  StyleBox["mm",
    FontSlant->"Italic"],
  ", the number of elements. Add \[PlusMinus]s Cosh[\[Theta]] wherever \
\[PlusMinus]ai occurs, \[PlusMinus]s Sinh[\[Theta]] wherever \[PlusMinus]bi \
occurs."
}], "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".7 Shapes, Polar-Vector, Hyperbolics, ",
  StyleBox["sh, toPol, toVec, tohyPol, tohyVec ",
    FontSlant->"Italic"],
  "for 2, 3, & 4 element loops."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(sh["\<C2\>"] := 
      Module[{}, gi = {1, 2, 1, 1}; gp = {1, 1}; 
        plex = {a, \(-b\)}; {a - b, a + b}]\), "\n", 
    \(toPol[{x_, y_}, "\<C2\>"] := {x - y, x + y}\), "\n", 
    \(toVec[{x_, y_}, "\<C2\>"] := {x + y, y - x}/2\), "\n", 
    \(tohyPol[{a_, b_}, "\<C2\>"] := 
      Chop[{a\^2 - b\^2, arcTanh[a, b]}]\), "\n", 
    \(tohyVec[{uu_, \[Phi]_}, "\<C2\>"] := 
      Chop[\@uu\ {Cosh[\[Phi]], Sinh[\[Phi]]}]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(sh["\<C4c\>"] := 
      Module[{}, gi = {1, \(-2\), 1}; gp = {1, 0. }; 
        plex = {a, \(-b\)}; {\(-a\^2\) - b\^2}]\), "\[IndentingNewLine]", 
    \(toPol[{a_, b_}, "\<C4c\>"] := {a\^2 + b\^2, 
        ArcTan[a, b]}\), "\[IndentingNewLine]", 
    \(toVec[{x_, y_}, "\<C4c\>"] := {\@x\ Cos[y], \@x\ Sin[y]}\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(sh["\<C3\>"] := 
      Module[{}, gi = {1, 3, 2, 1, 1}; gp = {1, 1, 0. }; 
        plex = {a, c, b}; \[IndentingNewLine] (*strictly, \ 
          shape\ should\ be\ symdiff^2, \ 
          not\ \((a - b)\)^2\ \(\(etc\)\(.\)\)*) {a + b + 
            c, \((\((a - b)\)^2 + \((b - c)\)^2 + \((c - a)\)^2)\)/
            2}]\), "\[IndentingNewLine]", 
    \(toPol[{a_, b_, c_}, "\<C3\>"] := {a + b + 
          c, \((\((a - b)\)^2 + \((b - c)\)^2 + \((c - a)\)^2)\)/
          2, \[IndentingNewLine]ArcTan[
          2*a - b - c, \(-Sqrt[3]\)*\((b - c)\)]}\), "\[IndentingNewLine]", 
    \(toVec[{\[Alpha]_, rr_, \[Theta]_}, "\<C3\>"] := 
      Chop[{\[Alpha] + 2*Sqrt[rr]*Cos[\[Theta]], \[Alpha] + 
              2*Sqrt[rr]*
                Cos[\[Theta] + 2*Pi/3], \[IndentingNewLine]\[Alpha] + 
              2*Sqrt[rr]*Cos[\[Theta] - 2*Pi/3]}/3]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(sh["\<C3C2c\>"] := 
      Module[{}, gi = {1, \(-3\), \(-2\), 1, 1}; gp = {1, 1, 0. }; 
        plex = {a, \(-c\), \(-b\)}; {a - b + 
            c, \((\((a + b)\)^2 + \((b + c)\)^2 + \((c - a)\)^2)\)/2}]; 
    toPol[{a_, b_, c_}, "\<C3C2c\>"] := {a - b + 
          c, \((\((a + b)\)^2 + \((b + c)\)^2 + \((c - a)\)^2)\)/
          2, \[IndentingNewLine]ArcTan[
          2*a + b - c, \(-Sqrt[3]\)*\((b + c)\)]};\), "\n", 
    \(\(toVec[{\[Alpha]_, rr_, \[Theta]_}, "\<C3C2c\>"] := 
        Chop[{\[Alpha] + 2*Sqrt[rr]*Cos[\[Theta]], \(-\[Alpha]\) - 
                2*Sqrt[rr]*
                  Cos[\[Theta] - 2*Pi/3], \[IndentingNewLine]\[Alpha] + 
                2*Sqrt[rr]*Cos[\[Theta] + 2*Pi/3]}/
            3];\)\), "\[IndentingNewLine]", 
    \(\(sh["\<C12c\>"] := 
        Module[{}, gi = {1, 3\ \[ImaginaryI], 2\ \[ImaginaryI], 1, 1}; 
          gp = {1, 1, 0. }; 
          plex =. ; {a + \[ImaginaryI]\ b - 
              c, \ \((\((a - \[ImaginaryI]\ b)\)\^2 + \((a + c)\)\^2 + \((\
\[ImaginaryI]\ b + c)\)\^2)\)/2}];\)\), "\n", 
    \(toPol[{a_, b_, c_}, "\<C12c\>"] := {a + \[ImaginaryI]\ b - 
          c, \ \((\((a - \[ImaginaryI]\ b)\)\^2 + \((a + c)\)\^2 + \((\
\[ImaginaryI]\ b + c)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
          2*a - \[ImaginaryI]\ b + c, 
          Sqrt[3]*\((\[ImaginaryI]\ b + c)\)]}\), "\[IndentingNewLine]", 
    \(\(toVec[{\[Alpha]_, rr_, \[Theta]_}, "\<C12c\>"] := 
        Chop[{\[Alpha] + 
                2*Sqrt[rr]*
                  Cos[\[Theta]], \[IndentingNewLine]\(-\[ImaginaryI]\) \((\
\[Alpha] + 2*Sqrt[rr]*Cos[\[Theta] - 2*Pi/3])\), \(-\((\[Alpha] + 
                    2*Sqrt[rr]*Cos[\[Theta] + 2*Pi/3])\)\)}/
            3];\)\), "\[IndentingNewLine]", 
    \(\(sh["\<C3i\>"] := 
        Module[{}, 
          gi = {1, \(-3\)\ \[ImaginaryI], \(-2\)\ \[ImaginaryI], 1, 1}; 
          gp = {1, 1, 0. }; 
          plex =. ; {a - \[ImaginaryI]\ b - 
              c, \ \((\((a + \[ImaginaryI]\ b)\)\^2 + \((\[ImaginaryI]\ b - \
c)\)\^2 + \((c + a)\)\^2)\)/2}];\)\), "\[IndentingNewLine]", 
    \(toPol[{a_, b_, c_}, "\<C3i\>"] := {a - \[ImaginaryI]\ b - 
          c, \ \((\((a + \[ImaginaryI]\ b)\)\^2 + \((\[ImaginaryI]\ b - \
c)\)\^2 + \((c + a)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
          2*a + \[ImaginaryI]\ b + c, 
          Sqrt[3]*\((\(-\[ImaginaryI]\)\ b + 
                c)\)]}\), "\[IndentingNewLine]", 
    \(toVec[{\[Alpha]_, 
          rr_, \[Theta]_}, "\<C3i\>"] := \[IndentingNewLine]Chop[{\[Alpha] + 
              2*Sqrt[rr]*
                Cos[\[Theta]], \[ImaginaryI] \((\[Alpha] + 
                  2*Sqrt[rr]*Cos[\[Theta] - 2*Pi/3])\), \(-\((\[Alpha] + 
                  2*Sqrt[rr]*Cos[\[Theta] + 2*Pi/3])\)\)}/
          3]\), "\[IndentingNewLine]", 
    \(\(sh["\<C4C3c\>"] := 
        Module[{}, gi = {1, \(-3\), \(-2\), 1, 1}; gp == {1, 1, 0. }; 
          plex =. ; {a + \[ImaginaryI]\ b + \[ImaginaryI]\ c, \((\((a - \
\[ImaginaryI]\ b)\)^2 + \((a - \[ImaginaryI]\ c)\)^2 - \((b - c)\)^2)\)/
              2}];\)\), "\[IndentingNewLine]", 
    \(toPol[{a_, b_, c_}, "\<C4C3c\>"] := {a - \[ImaginaryI]\ b - 
          c, \ \((\((a + \[ImaginaryI]\ b)\)\^2 + \((\[ImaginaryI]\ b - \
c)\)\^2 + \((c + a)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
          2*a + \[ImaginaryI]\ b + c, 
          Sqrt[3]*\((\(-\[ImaginaryI]\)\ b + 
                c)\)]}\), "\[IndentingNewLine]", 
    \(toVec[{\[Alpha]_, rr_, \[Theta]_}, "\<C4C3c\>"] := 
      Chop[{\[Alpha] + 
              2*Sqrt[rr]*
                Cos[\[Theta]], \[ImaginaryI] \((\[Alpha] + 
                  2*Sqrt[rr]*Cos[\[Theta] - 2*Pi/3])\), \(-\((\[Alpha] + 
                  2*Sqrt[rr]*Cos[\[Theta] + 2*Pi/3])\)\)}/3]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(sh["\<C9j\>"] := 
        Module[{}, gi = {1, 3, 2, 1}; gp = {}; 
          plex =. ; {a\^3 + b\^3\ \[DoubleStruckCapitalJ]\^2 + 
              c\^3\ \[DoubleStruckCapitalJ]\  - 
              3\ a\ b\ c}];\)\), "\[IndentingNewLine]", 
    \(\(sh["\<C3C3j\>"] := 
        Module[{}, 
          gi = {1, 3  \[DoubleStruckCapitalJ]\^2, 
              2  \[DoubleStruckCapitalJ]\^2, 1, 1}; gp = {}; 
          plex =. ; {\((a + b\ \[DoubleStruckCapitalJ]\^2 + 
                c\ \[DoubleStruckCapitalJ]\^2)\), \((\((a - 
                        b\ \ \[DoubleStruckCapitalJ]\^2)\)^2 + \((b\ \
\[DoubleStruckCapitalJ]\^2 - 
                        c\ \[DoubleStruckCapitalJ]\^2)\)^2 + \((c\ \
\[DoubleStruckCapitalJ]\^2 - a)\)^2)\)/2}];\)\), "\[IndentingNewLine]", 
    \(\(sh["\<C9J\>"] := 
        Module[{}, 
          gi = {1, 3  \[DoubleStruckCapitalJ]^2, 
              2  \[DoubleStruckCapitalJ]^2, 1}; gp = {}; 
          plex =. ; {a\^3 + b\^3\ \[DoubleStruckCapitalJ] + 
              c\^3\ \[DoubleStruckCapitalJ]\^2 - 
              3\ a\ b\ c\ \[DoubleStruckCapitalJ]}];\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FormatType->TraditionalForm],

Cell[BoxData[{
    \(sh["\<C4\>"] := 
      Module[{}, gi = {1, 4, 3, 2, 1, 1, 1}; 
        gp = {1, 1, 1, 0. }; \[IndentingNewLine]plex = {a, \ \(-b\), \ 
            c, \(-\ d\)}; {a + b + c + d, 
          a - b + c - 
            d, \((a - c)\)\^2 + \((b - d)\)\^2}\[IndentingNewLine] (*\((a\^2 \
+ c\^2 - 2\ b\ d)\)\^2 - \((b\^2 + d\^2 - 2\ a\ c)\)\^2*) ]\), "\
\[IndentingNewLine]", 
    \(toPol[{a_, b_, c_, d_}, "\<C4\>"] := {a + b + c + d, 
        a - b + c - 
          d, \((a - c)\)\^2 + \((b - d)\)\^2, \[IndentingNewLine]ArcTan[
          a - c, b - d]}\), "\[IndentingNewLine]", 
    \(toVec[{\[Alpha]_, \[Beta]_, \[Epsilon]\[Epsilon]_, \[Sigma]_}, \
"\<C4\>"] := {\[Alpha] + \[Beta] + 
            2*Sqrt[\[Epsilon]\[Epsilon]]*Cos[\[Sigma]], \[Alpha] - \[Beta] + 
            2*Sqrt[\[Epsilon]\[Epsilon]]*Sin[\[Sigma]], \[Alpha] + \[Beta] - 
            2*Sqrt[\[Epsilon]\[Epsilon]]*
              Cos[\[Sigma]], \[IndentingNewLine]\[Alpha] - \[Beta] - 
            2*Sqrt[\[Epsilon]\[Epsilon]]*Sin[\[Sigma]]}/
        4\), "\[IndentingNewLine]", 
    \(tohyPol[{a_, b_, c_, d_}, "\<C4\>"] := 
      Chop[{\((a + c)\)^2 - \((b + d)\)^2, 
          arcTanh[a + c, b + d], \((a - c)\)^2 + \((b - d)\)^2, 
          ArcTan[a - c, b - d]}]\), "\[IndentingNewLine]", 
    \(tohyVec[{uu_, \[Phi]_, rr_, \[Theta]_}, "\<C4\>"] := 
      Module[{r = Sqrt[rr], u = Sqrt[uu]}, 
        Chop[r*{Cos[\[Theta]], 
                  Sin[\[Theta]], \(-Cos[\[Theta]]\), \(-Sin[\[Theta]]\)}/2 + 
            u*{Cosh[\[Phi]], Sinh[\[Phi]], Cosh[\[Phi]], Sinh[\[Phi]]}/
                2]]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(sh["\<K\>"] := 
      Module[{}, gi = {1, 2, 3, 4, 1, 1, 1, 1}; gp = {1, 1, 1, 1}; 
        plex = {a, \(-\ b\), \ \(-c\), d}; \[IndentingNewLine]{a + b - c - d, 
          a - b + c - d, a - b - c + d, 
          a + b + c + d} (*\((a\^2 - b\^2 - c\^2 + d\^2)\)\^2 - 
            4 \((a\ d - b\ c)\)\^2*) ]\), "\[IndentingNewLine]", 
    \(\(toPol[{a_, b_, c_, d_}, "\<K\>"] := {a + b - c - d, a - b + c - d, 
          a - b - c + d, a + b + c + d};\)\), "\[IndentingNewLine]", 
    \(toVec[{o1_, o2_, o3_, o4_}, "\<K\>"] := {o1 + o2 + o3 + o4, 
          o1 - o2 - o3 + o4, \(-o1\) + o2 - o3 + o4, \(-o1\) - o2 + o3 + o4}/
        4\), "\[IndentingNewLine]", 
    \(tohyPol[{a_, b_, c_, d_}, "\<K\>"] := 
      Chop[{\((a + c)\)^2 - \((b + d)\)^2, 
          arcTanh[a + c, 
            b + d], \[IndentingNewLine]\((a - c)\)^2 - \((b - d)\)^2, 
          arcTanh[a - c, b - d]}]\), "\[IndentingNewLine]", 
    \(tohyVec[{uu_, \[Phi]_, vv_, \[Psi]_}, "\<K\>"] := 
      Module[{v = Sqrt[vv], u = Sqrt[uu]}, \[IndentingNewLine]Chop[
          v*{Cosh[\[Psi]], 
                  Sinh[\[Psi]], \(-Cosh[\[Psi]]\), \(-Sinh[\[Psi]]\)}/2 + 
            u*{Cosh[\[Phi]], Sinh[\[Phi]], Cosh[\[Phi]], Sinh[\[Phi]]}/
                2]]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    StyleBox[\(sh["\<Qr\>"] (*Signature\ \((4, 0)\)*)  := 
        Module[{}, gi = {1, \(-2\), \(-3\), \(-4\), 2}; 
          gp = {1, 0. , 1, 0. }; 
          plex = {a, \(-\ b\), \ \(-c\), \(-d\)}; {a\^2 + b\^2 + c\^2 + 
              d\^2}]\),
      FormatType->StandardForm], "\n", 
    RowBox[{
      RowBox[{
        StyleBox[\(toPol[{a_, b_, c_, d_}, "\<Qr\>"]\),
          FormatType->StandardForm], 
        StyleBox[":=",
          FormatType->StandardForm], 
        RowBox[{
          StyleBox["{",
            FormatType->StandardForm], 
          RowBox[{
            StyleBox[\(a\^2 + b\^2 + c\^2 + d\^2\),
              FormatType->StandardForm], 
            StyleBox[",",
              FormatType->StandardForm], 
            RowBox[{
              StyleBox[
                RowBox[{"A", 
                  StyleBox["rcTan",
                    FormatType->StandardForm]}]], 
              StyleBox["[",
                FormatType->StandardForm], \(a, b\), "]"}], ",", 
            StyleBox[\(c\^2 + d\^2\),
              FormatType->StandardForm], ",", 
            RowBox[{
              StyleBox[
                RowBox[{"A", 
                  StyleBox["rcTan",
                    FormatType->StandardForm]}]], "[", \(c, d\), "]"}]}], 
          StyleBox["}",
            FormatType->StandardForm]}]}], 
      StyleBox[" ",
        FormatType->StandardForm]}], "\n", 
    StyleBox[\(toVec[{rr_, \[Rho]_, 
            ss_, \[Sigma]_}, "\<Qr\>"] := {\@\(rr - ss\)\ Cos[\[Rho]], \@\(rr \
- ss\)\ Sin[\[Rho]], \@ss\ Cos[\[Sigma]], \@ss\ Sin[\[Sigma]]}\),
      FormatType->StandardForm], "\n", 
    StyleBox[\(sh["\<C8c\>"] := 
        Module[{}, 
          gi = {1, \(-4\), \(-3\), \(-2\), 1, 1}; \ {a\^2 + b\^2 + c\^2 + 
              d\^2 + \(\@2\) \((a\ b + b\ c - a\ d + c\ d)\), 
            a\^2 + b\^2 + c\^2 + 
              d\^2 - \(\@2\) \((a\ b + b\ c - a\ d + 
                    c\ d)\)} (*{\((a\^2 + b\^2 + c\^2 + d\^2)\)\^2 - 
                2\ \((a\ b + b\ c - a\ d + c\ d)\)\^2}*) ]\),
      FormatType->StandardForm]}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      StyleBox[\(sh["\<P4\>"]\),
        FormatType->StandardForm], \( (*Signature\ \((1, 3)\)*) \), 
      StyleBox[":=",
        FormatType->StandardForm], 
      StyleBox[" ",
        FormatType->StandardForm], 
      RowBox[{
        StyleBox["Module",
          FormatType->StandardForm], 
        StyleBox["[",
          FormatType->StandardForm], 
        StyleBox[\({}, gi = {1, 2, 3, 4, 2}; gp = {1, 0. , 1, 0. }; 
          plex = {a, \(-\ b\), \ \(-c\), \(-d\)}; {\ 
            a\^2 - b\^2 - c\^2 - d\^2}\),
          FormatType->StandardForm], "]"}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[\(toPol[{a_, b_, c_, d_}, "\<P4\>"]\),
          FormatType->StandardForm], 
        StyleBox[":=",
          FormatType->StandardForm], 
        RowBox[{
          StyleBox["Module",
            FormatType->StandardForm], 
          StyleBox["[",
            FormatType->StandardForm], 
          RowBox[{
            
            StyleBox[\({r = \[Sqrt]\((\((\((b - c)\)\^2 + \((c - d)\)\^2 + \
\((d - b)\)\^2)\)/2)\)}\),
              FormatType->StandardForm], 
            StyleBox[",",
              FormatType->StandardForm], 
            RowBox[{
              StyleBox["{",
                FormatType->StandardForm], 
              RowBox[{
                StyleBox["r",
                  FormatType->StandardForm], 
                StyleBox[",",
                  FormatType->StandardForm], 
                RowBox[{
                  StyleBox[
                    RowBox[{"A", 
                      StyleBox["rcTan",
                        FormatType->StandardForm]}]], 
                  StyleBox["[",
                    FormatType->StandardForm], 
                  RowBox[{"a", "/", 
                    StyleBox["r",
                      FormatType->StandardForm]}], "]"}], 
                ",", \(\((b + c + d)\)/3\), ",", 
                RowBox[{"If", "[", 
                  RowBox[{\(c \[Equal] d\), ",", "0", ",", 
                    RowBox[{
                      StyleBox[
                        RowBox[{"A", 
                          StyleBox["rcTan",
                            FormatType->StandardForm]}]], 
                      "[", \(2  b - c - d, \(-\@3\) \((c - d)\)\), "]"}]}], 
                  "]"}]}], 
              StyleBox["}",
                FormatType->StandardForm]}]}], 
          StyleBox[" ",
            FormatType->StandardForm], 
          StyleBox["]",
            FormatType->StandardForm]}]}], 
      StyleBox[";",
        FormatType->StandardForm]}], "\[IndentingNewLine]", 
    StyleBox[\(toVec[{r_, \[Sigma]_, 
              s_, \[Theta]_}, "\<P4\>"] := {r\ Tan[\[Sigma]], 
            s + 2*r*Cos[\[Theta]]/3, 
            s + 2*r*Cos[\[Theta] + 2*Pi/3]/3, \[IndentingNewLine]s + 
              2*r*Cos[\[Theta] + 4*Pi/3]/3};\),
      FormatType->
        StandardForm], "\[IndentingNewLine]", \(tohyPol[{a_, b_, c_, 
            d_}, "\<P4\>"] := 
        Chop[{a\^2 - b\^2, arcTanh[a, b], c\^2 + d\^2, 
            ArcTan[c, d]}];\), "\n", \(tohyVec[{uu_, \[Phi]_, 
          vv_, \[Psi]_}, "\<P4\>"] := 
      Module[{v = \@vv, u = \@uu}, 
        Chop[\ v\ {0, 0, Cos[\[Psi]], Sin[\[Psi]]} + 
            u\ {Cosh[\[Phi]], Sinh[\[Phi]], 0, 0}]]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    StyleBox[
      RowBox[{
        RowBox[{\(sh["\<Dav\>"]\), ":=", 
          RowBox[{"Module", "[", 
            RowBox[{\({}\), ",", 
              
              RowBox[{\(gi = {1, \(-2\), \(-3\), 4, 1, 1}\), 
                ";", \(gp = {1, 0. , 1, 0. }\), 
                ";", \(plex = {a, \(-\ b\), \ \(-c\), d}\), ";", " ", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{
                          StyleBox["(",
                            FormatType->StandardForm], \(a - d\), ")"}], "2"],
                       "+", 
                      SuperscriptBox[
                        RowBox[{
                          StyleBox["(",
                            FormatType->StandardForm], \(b + c\), ")"}], 
                        "2"]}], ",", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{
                          StyleBox["(",
                            FormatType->StandardForm], 
                          RowBox[{"a", 
                            StyleBox["+",
                              FormatType->StandardForm], "d"}], ")"}], "2"], 
                      "+", 
                      SuperscriptBox[
                        RowBox[{
                          StyleBox["(",
                            FormatType->StandardForm], 
                          RowBox[{"b", 
                            StyleBox["-",
                              FormatType->StandardForm], "c"}], ")"}], 
                        "2"]}]}], "}"}]}]}], 
            "\[IndentingNewLine]", \( (*L4\ equivalent\ is \((a\^2 + b\^2 + c\
\^2 + d\^2)\)\^2 + 4 \((a\ d - b\ c)\)\^2*) \), "]"}]}], ";"}],
      FormatType->StandardForm], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[\(toPol[{a_, b_, c_, d_}, "\<Dav\>"]\),
          FormatType->StandardForm], 
        StyleBox[":=",
          FormatType->StandardForm], 
        RowBox[{
          StyleBox["{",
            FormatType->StandardForm], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  StyleBox["(",
                    FormatType->StandardForm], \(a - d\), ")"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  StyleBox["(",
                    FormatType->StandardForm], \(b + c\), ")"}], "2"]}], 
            StyleBox[",",
              FormatType->StandardForm], 
            RowBox[{
              StyleBox[
                RowBox[{"A", 
                  StyleBox["rcTan",
                    FormatType->StandardForm]}]], 
              StyleBox["[",
                FormatType->StandardForm], \(a - d, b + c\), "]"}], ",", 
            "\[IndentingNewLine]", 
            StyleBox[
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"a", 
                      StyleBox["+",
                        FormatType->StandardForm], "d"}], ")"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    StyleBox["(",
                      FormatType->StandardForm], 
                    RowBox[{"b", 
                      StyleBox["-",
                        FormatType->StandardForm], "c"}], ")"}], "2"]}],
              FormatType->StandardForm], ",", 
            RowBox[{
              StyleBox[
                RowBox[{"A", 
                  StyleBox["rcTan",
                    FormatType->StandardForm]}]], "[", \(a + d, b - c\), 
              "]"}]}], 
          StyleBox["}",
            FormatType->StandardForm]}]}], 
      StyleBox[" ",
        FormatType->StandardForm], 
      StyleBox[";",
        FormatType->StandardForm]}], "\n", 
    StyleBox[\(toVec[{rr_, \[Rho]_, 
              ss_, \[Sigma]_}, "\<Dav\>"] := \[IndentingNewLine]{\ \@rr\ Cos[\
\[Rho]] + \@ss\ Cos[\[Sigma]], \ \@rr\ Sin[\[Rho]] + \@ss\ Sin[\[Sigma]], \ \
\@rr\ Sin[\[Rho]] - \@ss\ Sin[\[Sigma]], \(-\@rr\)\ Cos[\[Rho]] + \@ss\ Cos[\
\[Sigma]]}/2;\),
      FormatType->StandardForm]}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(sh["\<O2\>"]\), ":=", 
        RowBox[{
        "Module", "[", \({}, gi = {1, \(-2\), 3, \(-4\), 1, 1}; 
          gp = {1, 0. , 1, 0. }; 
          plex = {a, \(-\ 
                b\), \(-c\), \(-d\)}; \[IndentingNewLine]\ {\((a - c)\)\^2 + \
\((b - d)\)\^2, \((a + c)\)\^2 + \((b + d)\)\^2}\), "\[IndentingNewLine]", 
          RowBox[{"(*", 
            RowBox[{\(\((a\^2 + b\^2 + c\^2 + d\^2)\)\^2\), "-", 
              RowBox[{"4", 
                SuperscriptBox[
                  RowBox[{"(", 
                    StyleBox[\(a\ c + b\ d\),
                      FormatType->StandardForm], ")"}], "2"]}]}], "*)"}], 
          "]"}]}], ";", 
      RowBox[{
        StyleBox[\(toPol[{a_, b_, c_, d_}, "\<O2\>"]\),
          FormatType->StandardForm], 
        StyleBox[":=",
          FormatType->StandardForm], 
        StyleBox[" ",
          FormatType->StandardForm], 
        RowBox[{
          StyleBox["{",
            FormatType->StandardForm], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  StyleBox["(",
                    FormatType->StandardForm], 
                  RowBox[{"a", "-", 
                    StyleBox["c",
                      FormatType->StandardForm]}], ")"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  StyleBox["(",
                    FormatType->StandardForm], 
                  RowBox[{"b", 
                    StyleBox["-",
                      FormatType->StandardForm], 
                    StyleBox["d",
                      FormatType->StandardForm]}], ")"}], "2"]}], 
            StyleBox[",",
              FormatType->StandardForm], 
            RowBox[{
              StyleBox["ArcTan",
                FormatType->StandardForm], 
              StyleBox["[",
                FormatType->StandardForm], \(a - c, b - d\), "]"}], ",", 
            "\[IndentingNewLine]", 
            StyleBox[\(\((a + c)\)\^2 + \((b + d)\)\^2\),
              FormatType->StandardForm], ",", 
            RowBox[{
              StyleBox["ArcTan",
                FormatType->StandardForm], "[", \(a + c, b + d\), "]"}]}], 
          StyleBox["}",
            FormatType->StandardForm]}]}], 
      StyleBox[" ",
        FormatType->StandardForm], 
      StyleBox[";",
        FormatType->StandardForm], 
      StyleBox[\(toVec[{rr_, \[Rho]_, 
              ss_, \[Sigma]_}, "\<O2\>"] := {\ \ \@rr\ Cos[\[Rho]] + \@ss\ \
Cos[\[Sigma]], \ \@rr\ Sin[\[Rho]] + \@ss\ Sin[\[Sigma]], \[IndentingNewLine]\
\(-\@rr\)\ Cos[\[Rho]] + \(\@ss\) 
                  Cos[\[Sigma]], \ \(-\@rr\)\ Sin[\[Rho]] + \@ss\ \
Sin[\[Sigma]]}/2\),
        FormatType->StandardForm], 
      StyleBox[";",
        FormatType->StandardForm]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(sh["\<C8r\>"] := 
        Module[{}, gi = {1, 4, \(-3\), 2, 1, 1}; 
          plex = {a, \(-\ b\), 
              c, \(-d\)};  (*\({\((a\^2 + b\^2 + c\^2 + d\^2)\)\^2 - 
                  2 \((a\ b - b\ c + a\ d + c\ d)\)\^2} {\((a\^2 - b\^2 + \
c\^2 - d\^2)\)\^2 + 2 \((a\ b + b\ c - a\ d + c\ d)\)\^2}\)\(,\)*) {a\^2 + 
              b\^2 + c\^2 + d\^2 + \(\@2\) \((a\ b - b\ c + a\ d + c\ d)\), 
            a\^2 + b\^2 + c\^2 + 
              d\^2 - \(\@2\) \((a\ b - b\ c + a\ d + 
                    c\ d)\)}];\)\), "\[IndentingNewLine]", 
    \(\(sh["\<C3C4j\>"] := 
        Module[{}, gi = {1, \(-4\), 3, \(-2\), 1, 1, 1}; gp = {1, 1, 1, 0. }; 
          plex = {a, \ \(-b\), \ c, \(-d\)}; {a + b - c - d, 
            a - b - c + 
              d, \((a + c)\)\^2 + \((b + d)\)\^2} (*\((a\^2 + c\^2 + 2  b\ d)\
\)\^2 + \((b\^2 + 2\ ac + d\^2)\)\^2*) ];\)\), "\[IndentingNewLine]", 
    \(\(toPol[{a_, b_, c_, d_}, "\<C3C4j\>"] := {a + b - c - d, 
          a - b - c + d, \((a + c)\)\^2 + \((b + d)\)\^2, 
          ArcTan[a + c, b + d]};\)\), "\[IndentingNewLine]", 
    \(\(toVec[{\[Alpha]_, \[Beta]_, \[Epsilon]\[Epsilon]_, \[Sigma]_}, \
"\<C3C4j\>"] := {\[Alpha] + \[Beta] + 
              2*Sqrt[\[Epsilon]\[Epsilon]]*
                Cos[\[Sigma]], \[IndentingNewLine]\[Alpha] - \[Beta] + 
              2*Sqrt[\[Epsilon]\[Epsilon]]*
                Sin[\[Sigma]], \[IndentingNewLine]\(-\[Alpha]\) - \[Beta] + 
              2*Sqrt[\[Epsilon]\[Epsilon]]*
                Cos[\[Sigma]], \[IndentingNewLine]\(-\[Alpha]\) + \[Beta] + 
              2*Sqrt[\[Epsilon]\[Epsilon]]*Sin[\[Sigma]]}/4;\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{\(sh["\<CL2\>"] (*Signature\ \((2, 2)\), \ 
        matching\ \(Twistors!\)\ *)  := 
      Module[{}, gi = {1, 2, \(-3\), 4, 2}; gp = {1, 0. , 1, 0. }; 
        plex = {a, \(-\ b\), \ \(-c\), \(-d\)}; \[IndentingNewLine]\ {a\^2 - 
            b\^2 + c\^2 - d\^2}]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[\(toPol[{a_, b_, c_, d_}, "\<CL2\>"]\),
          FormatType->StandardForm], 
        StyleBox[":=",
          FormatType->StandardForm], 
        StyleBox[" ",
          FormatType->StandardForm], 
        RowBox[{
          StyleBox["{",
            FormatType->StandardForm], 
          RowBox[{
            RowBox[{
              StyleBox[\(a\^2\),
                FormatType->StandardForm], 
              StyleBox["+",
                FormatType->StandardForm], 
              StyleBox[\(c\^2\),
                FormatType->StandardForm], 
              StyleBox["-",
                FormatType->StandardForm], 
              StyleBox[\(b\^2\),
                FormatType->StandardForm], 
              StyleBox["-",
                FormatType->StandardForm], \(d\^2\)}], 
            StyleBox[",",
              FormatType->StandardForm], 
            StyleBox[\(ArcTan[a, c]\),
              FormatType->StandardForm], 
            StyleBox[",",
              FormatType->StandardForm], 
            RowBox[{
              StyleBox[\(b\^2\),
                FormatType->StandardForm], 
              StyleBox["+",
                FormatType->StandardForm], \(d\^2\)}], ",", 
            RowBox[{
              StyleBox[
                RowBox[{"A", 
                  StyleBox["rcTan",
                    FormatType->StandardForm]}]], "[", \(b, d\), "]"}]}], 
          StyleBox["}",
            FormatType->StandardForm]}]}], 
      StyleBox[" ",
        FormatType->StandardForm]}], "\n", 
    StyleBox[\(toVec[{rr_, \[Rho]_, 
            ss_, \[Sigma]_}, "\<CL2\>"] := {\ \ \@\(rr + ss\)\ Cos[\[Rho]], \ \
\@ss\ Cos[\[Sigma]], \@\(rr + ss\)\ Sin[\[Rho]], \@ss\ Sin[\[Sigma]]}\),
      FormatType->StandardForm]}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{\(sh["\<C4C2r\>"] := 
      Module[{}, gi = {1, \(-4\), 3, \(-2\), 1, 1, 1}; gp = {1, 1, 1, 0. }; 
        plex = {a, \(-b\), c, \(-d\)}; \[IndentingNewLine]\ {a + b + c - d, 
          a - b + c + 
            d, \((a - c)\)\^2 + \((b + d)\)\^2}\[IndentingNewLine] (*\((a\^2 \
+ c\^2 + 2\ b\ d)\)\^2 - \((b\^2 - 2\ a\ c + d\^2)\)\^2*) ]\), "\n", 
    RowBox[{
      RowBox[{
        StyleBox[\(toPol[{a_, b_, c_, d_}, "\<C4C2r\>"]\),
          FormatType->StandardForm], 
        StyleBox[":=",
          FormatType->StandardForm], 
        StyleBox[" ",
          FormatType->StandardForm], 
        RowBox[{
          StyleBox["{",
            FormatType->StandardForm], 
          
          RowBox[{\(a + b + c - d\), ",", \(a - b + c + d\), 
            ",", \(\((a - c)\)\^2 + \((b + d)\)\^2\), 
            StyleBox[",",
              FormatType->StandardForm], 
            RowBox[{
              StyleBox[
                RowBox[{"A", 
                  StyleBox["rcTan",
                    FormatType->StandardForm]}]], 
              StyleBox["[",
                FormatType->StandardForm], \(a - c, b + d\), "]"}]}], 
          StyleBox["}",
            FormatType->StandardForm]}]}], 
      StyleBox[" ",
        FormatType->StandardForm]}], "\n", 
    StyleBox[\(toVec[{\[Alpha]_, \[Beta]_, \[Epsilon]\[Epsilon]_, \[Sigma]_}, \
"\<C4C2r\>"] := \[IndentingNewLine]{\[Alpha] + \[Beta] + 
              2*Sqrt[\[Epsilon]\[Epsilon]]*
                Cos[\[Sigma]], \[IndentingNewLine]\[Alpha] - \[Beta] + 
              2*Sqrt[\[Epsilon]\[Epsilon]]*
                Sin[\[Sigma]], \[IndentingNewLine]\[Alpha] + \[Beta] - 
              2*Sqrt[\[Epsilon]\[Epsilon]]*
                Cos[\[Sigma]], \[IndentingNewLine]\(-\[Alpha]\) + \[Beta] + 
              2*Sqrt[\[Epsilon]\[Epsilon]]*Sin[\[Sigma]]}/4\),
      FormatType->
        StandardForm], "\[IndentingNewLine]", \(tohyPol[{a_, b_, c_, 
          d_}, "\<C4C2r\>"] := 
      Chop[{\((a + c)\)^2 - \((b - d)\)^2, 
          arcTanh[a + c, b - d], \((a - c)\)^2 + \((b + d)\)^2, 
          ArcTan[a - c, 
            b + d]}]\), "\[IndentingNewLine]", \(tohyVec[{uu_, \[Phi]_, 
          rr_, \[Theta]_}, "\<C4C2r\>"] := 
      Module[{r = Sqrt[rr], u = Sqrt[uu]}, 
        Chop[r*{Cos[\[Theta]], Sin[\[Theta]], \(-Cos[\[Theta]]\), 
                  Sin[\[Theta]]}/2 + 
            u*{Cosh[\[Phi]], Sinh[\[Phi]], Cosh[\[Phi]], \(-Sinh[\[Phi]]\)}/
                2]]\), "\[IndentingNewLine]", \(sh["\<P16c\>"] (*Signature\ \
\((3, 1)\)*)  := 
      Module[{}, gi = {1, \(-2\), \(-3\), 4, 2}; gp = {1, 0. , 1, 0. }; 
        plex = {a, \(-\ b\), \ \(-c\), \(-d\)}; \[IndentingNewLine]\ {a\^2 + 
            b\^2 + c\^2 - d\^2}]\), "\n", 
    RowBox[{
      RowBox[{
        StyleBox[\(toPol[{a_, b_, c_, d_}, "\<P16c\>"]\),
          FormatType->StandardForm], 
        StyleBox[":=",
          FormatType->StandardForm], 
        StyleBox[" ",
          FormatType->StandardForm], 
        RowBox[{
          StyleBox["{",
            FormatType->StandardForm], 
          RowBox[{
            StyleBox[\(a\^2 + b\^2\),
              FormatType->StandardForm], 
            StyleBox[",",
              FormatType->StandardForm], 
            StyleBox[\(If[b \[NotEqual] 0, ArcTan[a, b], 0]\),
              FormatType->StandardForm], 
            StyleBox[",",
              FormatType->StandardForm], \(c\^2 - d\^2\), ",", 
            RowBox[{"If", "[", 
              RowBox[{\(d \[NotEqual] 0\), ",", 
                RowBox[{
                  StyleBox[
                    RowBox[{"a", 
                      StyleBox["rcTanh",
                        FormatType->StandardForm]}]], "[", \(c, d\), "]"}], 
                ",", "0"}], "]"}]}], 
          StyleBox["}",
            FormatType->StandardForm]}]}], 
      StyleBox[" ",
        FormatType->StandardForm]}], "\n", 
    StyleBox[\(toVec[{rr_, \[Rho]_, 
            ss_, \[Sigma]_}, "\<P16c\>"] := {\ \ \@rr\ Cos[\[Rho]], \ \@rr\ \
Sin[\[Rho]], \@ss\ Cosh[\[Sigma]], \@ss\ Sinh[\[Sigma]]}\),
      FormatType->StandardForm], "\[IndentingNewLine]", \(sh["\<Q4n\>"] := 
      Module[{}, gi = {1, 2, 3, 4, 1, 1}; gp =. ; 
        plex =. ; \[IndentingNewLine]\ {a\^2 - b\^2 - c\^2 - d\^2, 
          a\^2 + b\^2 + c\^2 + d\^2}]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".8 Shapes, Polar-Vector, Hyperbolics, ",
  StyleBox["sh, toPol, toVec, tohyPol, tohyVec ",
    FontSlant->"Italic"],
  "for 5 & 6 element loops."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(sh["\<C5\>"] := 
      Module[{}, gp =. ; gi = {1, 5, 4, 3, 2, 1, 1}; 
        plex =. ; \[IndentingNewLine]{a + b + c + d + 
            e, \((\((a - b)\)^2 + \((b - c)\)^2 + \((c - d)\)^2 + \((d - 
                          e)\)^2 + \((e - a)\)^2 + \[IndentingNewLine]\((a - 
                          c)\)^2 + \((b - d)\)^2 + \((c - e)\)^2 + \((d - 
                          a)\)^2 + \((e - b)\)^2)\)^2/
              16 - \[IndentingNewLine]5\ \((a\ b - a\ c + b\ c - a\ d - b\ d \
+ c\ d + a\ e - b\ e - c\ e + d\ e)\)\^2/4}]\), "\n", 
    \(toVec[{\[Alpha]_, \[Epsilon]_, \[Sigma]_}, "\<C5\>"] := \(\({\[Alpha] + \
\[Epsilon]*Sin[\[Sigma]], \[Alpha] + \[Epsilon]*
              Sin[\[Sigma] + 
                  2  \[Pi]/5], \[IndentingNewLine]\[Alpha] + \[Epsilon]*
              Sin[\[Sigma] + 4  \[Pi]/5], \[Alpha] + \[Epsilon]*
              Sin[\[Sigma] + 6  \[Pi]/5], \[Alpha] + \[Epsilon]*
              Sin[\[Sigma] + 8  \[Pi]/5]}/5\)\(\ \)\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(sh["\<C3C2\>"] := 
      Module[{}, gi = {1, 3, 2, 4, 6, 5, 1, 1, 1, 1}; 
        gp = {1, 1, 1, 0. , 1, 0. }; 
        plex = {a, c, b, d, f, e}; \[IndentingNewLine]{a + b + c + d + e + f, 
          a + b + c - d - e - 
            f, \((\((a - b + d - e)\)\^2 + \((a - c + d - f)\)\^2 + \((b - c \
+ e - f)\)\^2)\)/
            2, \((\((a - b - d + e)\)\^2 + \((a - c - d + f)\)\^2 + \((b - c \
- e + f)\)\^2)\)/2}]\), "\n", 
    \(toVec[{\[Alpha]_, \[Delta]_, \[Eta]\[Eta]_, \[Chi]_, \[Kappa]\[Kappa]_, \
\[Psi]_}, "\<C3C2\>"] := 
      Module[{\[Eta] = 2 \@ \[Eta]\[Eta], \[Kappa] = 
            2 \@ \[Kappa]\[Kappa]}, {\ \ \[Alpha] + \[Delta] + \[Eta]\ Cos[\
\[Chi]] + \[Kappa]\ Cos[\[Psi]], \[Alpha] + \[Delta] + \[Eta]\ Cos[\[Chi] + 
                    2\ \[Pi]/3] + \[Kappa]\ Cos[\[Psi] + 
                    2  \[Pi]/3], \[Alpha] + \[Delta] + \[Eta]\ Cos[\[Chi] - 
                    2\ \[Pi]/3] + \[Kappa]\ Cos[\[Psi] - 
                    2\ \[Pi]/
                        3], \[IndentingNewLine]\[Alpha] - \[Delta] + \[Eta]\ \
Cos[\[Chi]] - \[Kappa]\ Cos[\[Psi]], \[Alpha] - \[Delta] + \[Eta]\ Cos[\[Chi] \
+ 2\ \[Pi]/3] - \[Kappa]\ Cos[\[Psi] + 
                    2  \[Pi]/3], \[Alpha] - \[Delta] + \[Eta]\ Cos[\[Chi] - 
                    2\ \[Pi]/3] - \[Kappa]\ Cos[\[Psi] - 2\ \[Pi]/3]}/
          6]\), "\n", 
    \(toPol[{a_, b_, c_, d_, e_, f_}, "\<C3C2\>"] := 
      Module[{a1 = Chop[2  a - b - c + 2  d - e - f], 
          a2 = Chop[2  a - b - c - 2  d + e + f], 
          b1 = Chop[Simplify[c - b - e + f]], 
          b2 = Chop[Simplify[c - b + e - f]]}, {a + b + c + d + e + f, 
          a + b + c - d - e - 
            f, \((\((a - b + d - e)\)\^2 + \((b - c + e - f)\)\^2 + \((c - a \
+ f - d)\)\^2)\)/2, 
          ArcTan[a1, 
            Sqrt[3] b1], \((\((a - b - d + e)\)\^2 + \((b - c - e + f)\)\^2 + \
\((c - a - f + d)\)\^2)\)/2, ArcTan[a2, Sqrt[3] b2]}]\), "\n", 
    \(tohyPol[{a_, b_, c_, d_, e_, f_}, "\<C3C2\>"] := 
      Module[{a1 = Chop[2  a - b - c + 2  d - e - f], 
          a2 = Chop[2  a - b - c - 2  d + e + f], 
          b1 = Chop[Simplify[c - b - e + f]], 
          b2 = Chop[
              Simplify[
                c - b + e - f]]}, {\((a + b + c)\)\^2 - \((d + e + f)\)\^2, 
          arcTanh[a + b + c, 
            d + e + 
              f], \((\((a - b + d - e)\)\^2 + \((b - c + e - f)\)\^2 + \((c - \
a + f - d)\)\^2)\)/2, 
          ArcTan[a1, 
            Sqrt[3] b1], \((\((a - b - d + e)\)\^2 + \((b - c - e + f)\)\^2 + \
\((c - a - f + d)\)\^2)\)/2, ArcTan[a2, Sqrt[3] b2]}]\), "\n", 
    \(tohyVec[{\[Gamma]\[Gamma]_, \[Delta]_, \[Eta]\[Eta]_, \[Chi]_, \[Kappa]\
\[Kappa]_, \[Psi]_}, "\<C3C2\>"] := 
      Module[{\[Gamma] = \@\[Gamma]\[Gamma], \[Eta] = \@\[Eta]\[Eta], \
\[Kappa] = \@\[Kappa]\[Kappa]}, {\ \[Gamma]\ Cosh[\[Delta]] + \[Eta]\ Cos[\
\[Chi]] + \[Kappa]\ Cos[\[Psi]], \[Gamma]\ Cosh[\[Delta]] + \[Eta]\ \
Cos[\[Chi] + 2\ \[Pi]/3] + \[Kappa]\ Cos[\[Psi] + 
                    2  \[Pi]/
                        3], \[Gamma]\ Cosh[\[Delta]] + \[Eta]\ Cos[\[Chi] - 
                    2\ \[Pi]/3] + \[Kappa]\ Cos[\[Psi] - 
                    2\ \[Pi]/
                        3], \[Gamma]\ Sinh[\[Delta]] + \[Eta]\ Cos[\[Chi]] - \
\[Kappa]\ Cos[\[Psi]], \[Gamma]\ Sinh[\[Delta]] + \[Eta]\ Cos[\[Chi] + 
                    2\ \[Pi]/3] - \[Kappa]\ Cos[\[Psi] + 
                    2  \[Pi]/
                        3], \[Gamma]\ Sinh[\[Delta]] + \[Eta]\ Cos[\[Chi] - 
                    2\ \[Pi]/3] - \[Kappa]\ Cos[\[Psi] - 2\ \[Pi]/3]}/
          3]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0],

Cell[BoxData[{
    \(\(sh["\<D3\>"] := 
        Module[{}, gi = {1, 2, 5, 4, 3, 6, 1, 1, 2}; 
          gp = {1, 1, 1, 0. , 1, 0. }; 
          plex =. ; \[IndentingNewLine]{a + b + c + d + e + f, 
            a - b + c - d + e - 
              f, \((\((a - c)\)\^2 + \((c - e)\)\^2 + \((e - a)\)\^2 - \((b - \
d)\)\^2 - \((d - f)\)\^2 - \((f - b)\)\^2)\)/2}];\)\), "\n", 
    \(toPol[{a_, b_, c_, d_, e_, f_}, "\<D3\>"] := 
      Module[{ace = \((\((a - c)\)\^2 + \((c - e)\)\^2 + \((e - a)\)\^2)\)/
              2, \[Chi] = ArcTan[2\ a - c - e, Sqrt[3] \((e - c)\)], 
          bdf = \((\((b - d)\)\^2 + \((d - f)\)\^2 + \((f - b)\)\^2)\)/
              2, \[Psi] = ArcTan[2\ b - d - f, Sqrt[3] \((f - d)\)]}, {a + 
            b + c + d + e + f, a - b + c - d + e - f, ace - bdf, \[Chi], 
          ace, \[Psi]}]\), "\n", 
    \(toVec[{\[Gamma]_, \[Delta]_, \[Eta]\[Eta]_, \[Chi]_, \[Kappa]\[Kappa]_, \
\[Psi]_}, "\<D3\>"] := 
      Module[{\[Eta] = 4 \@ \[Kappa]\[Kappa], \[Kappa] = 
            4 \@\( \[Kappa]\[Kappa] - \[Eta]\[Eta]\)}, {\ \[Gamma] + \[Delta] \
+ \[Eta]\ Cos[\[Chi]]\ , \[Gamma] - \[Delta] + \[Kappa]\ \ Cos[\[Psi]], \
\[Gamma] + \[Delta] + \[Eta]\ Cos[\[Chi] + 
                    2\ \[Pi]/
                        3], \[Gamma] - \[Delta] + \[Kappa]\ \ Cos[\[Psi] + 
                    2  \[Pi]/3], \[Gamma] + \[Delta] + \[Eta]\ Cos[\[Chi] - 
                    2\ \[Pi]/
                        3], \[Gamma] - \[Delta] + \[Kappa]\ \ Cos[\[Psi] - 
                    2\ \[Pi]/3]}/6]\), "\n", 
    \(tohyPol[{a_, b_, c_, d_, e_, f_}, "\<D3\>"] := 
      Module[{\[Chi]}, {\((a + c + e)\)\^2 - \((b + d + f)\)\^2, 
          arcTanh[a + c + e, 
            b + d + f], \((\((a - c)\)\^2 + \((c - e)\)\^2 + \((e - \
a)\)\^2)\)/2, \[IndentingNewLine]\[Chi] = 
            ArcTan[2\ a - c - e, 
              Sqrt[3] \((e - 
                    c)\)], \((\((b - d)\)\^2 + \((d - f)\)\^2 + \((f - \
b)\)\^2)\)/
            2, \[IndentingNewLine]ArcTan[2\ b - d - f, 
              Sqrt[3] \((f - d)\)] - \[Chi]}]\), "\n", 
    \(tohyVec[{\[Gamma]\[Gamma]_, \[Phi]_, \[Eta]\[Eta]_, \[Chi]_, \[Kappa]\
\[Kappa]_, \[Psi]_}, "\<D3\>"] := 
      Module[{\[Gamma] = 2 \@ \[Gamma]\[Gamma], \[Eta] = 
            4 \@ \[Eta]\[Eta], \[Kappa] = 
            4 \@ \[Kappa]\[Kappa]}, {\[Gamma]\ Cosh[\[Phi]] + \[Eta]\ Cos[\
\[Chi]], \[Gamma]\ Sinh[\[Phi]] + \[Kappa]\ \ Cos[\[Chi] + \[Psi]], \[Gamma]\ \
Cosh[\[Phi]] + \[Eta]\ Cos[\[Chi] + 
                    2\ \[Pi]/
                        3], \[IndentingNewLine]\[Gamma]\ Sinh[\[Phi]] + \
\[Kappa]\ \ Cos[\[Chi] + \[Psi] + 
                    2  \[Pi]/
                        3], \[Gamma]\ Cosh[\[Phi]] + \[Eta]\ Cos[\[Chi] - 
                    2\ \[Pi]/
                        3], \[Gamma]\ Sinh[\[Phi]] + \[Kappa]\ \ Cos[\[Chi] + \
\[Psi] - 2\ \[Pi]/3]}/6]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`sh["\<C6n\>"] := 
      Module[{}, gi = {1, 3, 2, 5, 4, 6, 1, 1, 1, 1}; gp =. ; 
        plex =. ; \[IndentingNewLine]{a + b + c - d - e - f, 
          a + b + c + d + e + 
            f, \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((c - a)\)\^2 - \((d - \
e)\)\^2 - \((e - f)\)\^2 - \((f - d)\)\^2)\)/
            2, \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((c - a)\)\^2 + \((d - \
e)\)\^2 + \((e - f)\)\^2 + \((f - d)\)\^2)\)/2}]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    \(sh["\<C3C4c\>"] :=  (*Revised\ \(8/1\)/
            6*) \[IndentingNewLine]Module[{}, gp = {1, 0. , 1, 0. , 1, 0. }; 
        gi = {1, 3, 2, \(-4\), \(-6\), \(-5\), 1, 1, 1}; 
        plex = {a, b, 
            c, \(-d\), \(-e\), \(-f\)}; \[IndentingNewLine]{\((a + b + \
c)\)\^2 + \((d + e + f)\)\^2, 
          3 \((\((a - b + \((d + e - 2  f)\) r3)\)\^2 + \((\((a + b - 2  c)\) \
r3 - d + e)\)\^2)\)/4, 
          3 \((\((a - b - \((d + e - 2  f)\) r3)\)\^2 + \((\((a + b - 2  c)\) \
r3 + d - e)\)\^2)\)/4}]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(toPol[{a_, b_, c_, d_, e_, f_}, "\<C3C4c\>"] := 
      Module[{f1 = a - b + \((d + e - 2  f)\) r3, 
          f2 = \((a + b - 2  c)\) r3 - d + e, 
          f3 = a - b - \((d + e - 2  f)\) r3, 
          f4 = \((a + b - 2  c)\)/r3 + d - 
              e}, {\((a + b + c)\)\^2 + \((d + e + f)\)\^2 (*\[Epsilon]\
\[Epsilon]*) , 
          If[d + e + f \[Equal] 0, If[a + b + c < 0, \[Pi], 0], 
            ArcTan[a + b + c, 
              d + e + f]] (*\[Sigma]*) , \[IndentingNewLine]Expand[
            3 \((f1\^2 + f2\^2)\)/4] (*\[Eta]\[Eta]*) , 
          If[f2 \[Equal] 0, If[f1 < 0, \[Pi], 0], ArcTan[f1, f2]] - \[Pi]/
              6 (*\[CurlyKappa]*) , \[IndentingNewLine]Expand[
            3 \((f3\^2 + f4\^2)\)/4] (*\[Kappa]\[Kappa]*) , 
          If[f4 \[Equal] 0, If[f3 < 0, \[Pi], 0], ArcTan[f3, f4]] - \[Pi]/
              6 (*\[Psi]*) }]\), "\[IndentingNewLine]", 
    \(toVec[{\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Eta]\[Eta]_, \[Chi]_, \
\[Kappa]\[Kappa]_, \[Psi]_}, "\<C3C4c\>"] := 
      Module[{\[Epsilon] = \@\[Epsilon]\[Epsilon]/
              3, \[Eta] = \@\(\[Eta]\[Eta]/12\), \[Kappa] = \@\(\[Kappa]\
\[Kappa]/12\), x = \[Chi] + \[Pi]/6, 
          y = \[Psi] + \[Pi]/
                6}, \[IndentingNewLine]{ (*a*) \[Epsilon]\ Cos[\[Sigma]] + \
\[Eta]\ Cos[x] + \[Eta]\ r3\ Sin[x] + \[Kappa]\ Cos[y] + \[Kappa]\ r3\ Sin[
                y], \[IndentingNewLine] (*b*) \[Epsilon]\ Cos[\[Sigma]] - \
\[Eta]\ Cos[x] + \[Eta]\ r3\ Sin[x] - \[Kappa]\ Cos[y] + \[Kappa]\ r3\ Sin[
                y], \[IndentingNewLine] (*c*) \[Epsilon]\ Cos[\[Sigma]] - \
\[Eta]\ 2  r3\ Sin[x] - \[Kappa]\ 2  
              r3\ Sin[y], \[IndentingNewLine] (*d*) \[Epsilon]\ Sin[\[Sigma]] \
+ \[Eta]\ r3\ Cos[x] - \[Eta]\ Sin[x] - \[Kappa]\ r3\ Cos[y] + \[Kappa]\ Sin[
                y], \[IndentingNewLine] (*e*) \[Epsilon]\ Sin[\[Sigma]] + \
\[Eta]\ r3\ Cos[x] + \[Eta]\ Sin[x] - \[Kappa]\ r3\ Cos[y] - \[Kappa]\ Sin[
                y], \[IndentingNewLine] (*f*) \[Epsilon]\ Sin[\[Sigma]] - \
\[Eta]\ 2  r3\ Cos[x] + \[Kappa]\ 2  r3\ Cos[y]}]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(sh["\<Q12c\>"] := 
      Module[{}, gi = {1, 3, 2, \(-4\), \(-5\), \(-6\), 1, 2}; 
        gp = {1, 2, 1, 0. , 1, 0. }; 
        plex = {a, c, 
            b, \(-d\), \(-e\), \(-f\)}; {\((a + b + c)\)\^2 + \((d + e + f)\)\
\^2, \((\((a - b)\)\^2 + \((a - c)\)\^2 + \((b - c)\)\^2 + \((d - e)\)\^2 + \
\((d - f)\)\^2 + \((e - f)\)\^2)\)/2}]\), "\[IndentingNewLine]", 
    \(toPol[{a_, b_, c_, d_, e_, f_}, "\<Q12c\>"] := 
      Module[{abc = \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((c - a)\)\^2)\)/2, 
          def = \((\((d - e)\)\^2 + \((e - f)\)\^2 + \((f - d)\)\^2)\)/
              2}, {\((a + b + c)\)\^2 + \((d + e + f)\)\^2, 
          If[d + e + f === 0, 0, ArcTan[a + b + c, d + e + f]], abc + def, 
          If[c == b, 0, ArcTan[2\ a - b - c, Sqrt[3] \((c - b)\)]], def, 
          If[e == f, 0, 
            ArcTan[2\ d - e - f, Sqrt[3] \((f - e)\)]]}]\), "\n", 
    \(toVec[{\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Eta]\[Eta]_, \[Chi]_, \
\[Kappa]\[Kappa]_, \[Psi]_}, "\<Q12c\>"] := 
      Module[{\[Epsilon] = \@\[Epsilon]\[Epsilon]/3, \[Eta] = 
            2 \@\( \[Eta]\[Eta] - \[Kappa]\[Kappa]\)/3, \[Kappa] = 
            2 \@ \[Kappa]\[Kappa]/
                3}, {\ \[Epsilon]\ Cos[\[Sigma]] + \[Eta]\ Cos[\[Chi]]\ , \
\[IndentingNewLine]\[Epsilon]\ Cos[\[Sigma]] + \[Eta]\ Cos[\[Chi] + 
                  2\ \[Pi]/
                      3], \[IndentingNewLine]\[Epsilon]\ Cos[\[Sigma]] + \
\[Eta]\ Cos[\[Chi] - 
                  2\ \[Pi]/
                      3], \[IndentingNewLine]\[Epsilon]\ Sin[\[Sigma]] + \
\[Kappa]\ \ Cos[\[Psi]], \[IndentingNewLine]\[Epsilon]\ Sin[\[Sigma]] + \
\[Kappa]\ \ Cos[\[Psi] + 
                  2\ \[Pi]/
                      3], \[IndentingNewLine]\[Epsilon]\ Sin[\[Sigma]] + \
\[Kappa]\ \ Cos[\[Psi] - 2\ \[Pi]/3]}]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(sh["\<Q12r\>"] := 
      Module[{}, gi = {1, \(-2\), \(-5\), \(-4\), \(-3\), \(-6\), 1, 2}; 
        gp = {1, 1, 1, 0. , 1, 0. }; 
        plex = {a, c, 
            b, \(-d\), \(-e\), \(-f\)}; {\((a - c + e)\)\^2 + \((b - d + f)\)\
\^2, \((\((a + c)\)^2 + \((c + e)\)^2 + \((a - e)\)^2 + \((b + 
                      d)\)^2 + \((d + f)\)^2 + \((b - f)\)^2)\)/
            2}]\), "\[IndentingNewLine]", 
    \(toPol[{a_, b_, c_, d_, e_, f_}, "\<Q12r\>"] := 
      Module[{ace = \((\((a + c)\)^2 + \((a - e)\)^2 + \((c + e)\)^2)\)/2, 
          bdf = \((\((b + d)\)^2 + \((d + f)\)^2 + \((b - f)\)^2)\)/
              2}, {\((a - c + e)\)\^2 + \((b - d + f)\)\^2, 
          If[b + f === d, 0, 
            ArcTan[a - c + e, b - d + f]], \[IndentingNewLine]ace + bdf, 
          If[c \[Equal] \(-e\), 0, 
            ArcTan[2\ a - e + c, 
              Sqrt[3] \((\(-c\) - e)\)]], \[IndentingNewLine]bdf, 
          If[d \[Equal] \(-f\), 0, 
            ArcTan[2\ b + d - f, Sqrt[3] \((\(-d\) - f)\)]]}]\), "\n", 
    \(\(toVec[{\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Eta]\[Eta]_, \[Chi]_, \
\[Kappa]\[Kappa]_, \[Psi]_}, "\<Q12r\>"] := 
        Module[{\[Epsilon] = \@\[Epsilon]\[Epsilon]/3, \[Eta] = 
              2 \@\( \[Eta]\[Eta] - \[Kappa]\[Kappa]\)/3, \[Kappa] = 
              2 \@ \[Kappa]\[Kappa]/
                  3}, {\ \ \[Epsilon]\ Cos[\[Sigma]] + \[Eta]\ Cos[\[Chi]]\ , \
\[IndentingNewLine]\ \ \[Epsilon]\ Sin[\[Sigma]] + \[Kappa]\ Cos[\[Psi]], \
\[IndentingNewLine]\(-\[Epsilon]\)\ Cos[\[Sigma]] - \[Eta]\ Cos[\[Chi] - 
                    2\ \[Pi]/
                        3], \[IndentingNewLine]\(-\[Epsilon]\)\ Sin[\[Sigma]] \
- \[Kappa]\ Cos[\[Psi] - 
                    2\ \[Pi]/
                        3], \[IndentingNewLine]\ \[Epsilon]\ Cos[\[Sigma]] + \
\[Eta]\ Cos[\[Chi] + 
                    2\ \[Pi]/
                        3], \[IndentingNewLine]\ \[Epsilon]\ Sin[\[Sigma]] + \
\[Kappa]\ Cos[\[Psi] + 2\ \[Pi]/3]}];\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
sh[\"g2401c\"]:=Module[{},gi={1,3,2,-4*I,-5*I,-6*I,2,1};gp={1,1,1,0.,1,0.};;\
plex={a,c,b,-d,-e,-f}; 
{((a-b)^2+(a-c)^2+(b-c)^2-I*((d-e)^2+(d-f)^2+(e-f)^2))/2,(a+b+c)^2-I*(d+e+f)^\
2}]
sh[\"D6r\"]:=Module[{},gi={1,2,-5,4,-3,6,1,1,2};
gp={1,1,1,0.,1,0.};;plex=.;{a-b-c+d+e-f,a+b-c-d+e+f,
((a+c)^2+(c+e)^2+(a-e)^2-(b+d)^2-(d+f)^2-(b-f)^2)/2}]
sh[\"D3C2c\"]:=Module[{},gi={1,2,3,5,4,6,1,1,2};plex={a,c,b,-d,-e,-f};
gp={1,1,1,0.,1,0.};{(a-b+c-d-e-f),(a+b-c-d-e+f), \
((a+d)^2+(a+e)^2+(d-e)^2-(b+c)^2-(b-f)^2-(c+f)^2)/
    2}]\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell["\<\
(*Two relabellings of C3C2*)
sh[\"KC3c\"]:=Module[{},gi={1,-3,-2,4,-6,-5,1,1,1,1};gp={1,1,1,0.,1,0.};;plex=\
{a,b,c,-d,-e,-f};{a-b+c-d+e-f,a-b+c+d-e+f,((a+b-d-e)^2+(a-c-d+f)^2+(b+c-e-f)^\
2)/2,((a+b+d+e)^2+(a-c+d-f)^2+(b+c+e+f)^2)/2}];
sh[\"C3Kr\"]:=Module[{},gi={1,3,2,4,6,5,1,1,1,1};gp={1,1,1,0.,1,0.};;{a-b-c-d+\
e+f,a-b-c+d-e-f,((a+b-d-e)^2+(a+c-d-f)^2+(b-c-e+f)^2)/2,((a+b+d+e)^2+(a+c+d+f)\
^2+(b-c+e-f)^2)/2}]\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(sh["\<Cl3r\>"] := 
      Module[{}, \(gp = {1, 1, 1, 0. , 1, 0. };\); 
        gi = {1, \(-3\), \(-2\), \(-4\), 6, 5, 1, 1}; 
        plex = {a, b, 
            c, \(-d\), \(-e\), \(-f\)}; \[IndentingNewLine]{\((a - b + \
c)\)\^2 + \((d - e + f)\)\^2, \((\((\((a + b)\)^2 + \((\ 
                            b + c)\)^2 + \((a - \ c)\)^2)\) + \((d + 
                          e)\)^2 + \((e + f)\)^2 + \((\ f - d)\)^2)\)^2/4 - 
            3\ \((\(-b\)\ d - c\ d + a\ e - c\ e + a\ f + b\ f)\)\^2}]\)], \
"Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(sh["\<Clm3r\>"] := 
      Module[{}, \(gp = {1, 1, 1, 0. , 1, 0. };\); 
        gi = {1, 3, 2, \(-4\), \(-6\), \(-5\), 1, 1}; 
        plex = {a, b, 
            c, \(-d\), \(-e\), \(-f\)}; \[IndentingNewLine]{\((a - b - \
c)\)\^2 + \((d - e - f)\)\^2, \((\((\((a + b)\)^2 + \((\ 
                            b - c)\)^2 + \((a + \ c)\)^2)\) + \((d + 
                          e)\)^2 + \((e - f)\)^2 + \((\ f + d)\)^2)\)^2/4 - 
            3\ \((\(-b\)\ d + c\ d + a\ e + c\ e - a\ f - b\ f)\)\^2}]\)], \
"Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".9 Shapes, Polar-Vector, Hyperbolics, ",
  StyleBox["sh, toPol, toVec, tohyPol, tohyVec ",
    FontSlant->"Italic"],
  "for 8 & 9 element loops."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(sh["\<C8\>"] := 
        Module[{}, gi = {1, 8, 7, 6, 5, 4, 3, 2, 1, 1, 1, 1}; 
          gp = {1, 1, 1, 1, 0. , 1, 0.  (*?*) }; 
          plex = {a, \(-b\), c, \(-d\), e, \(-f\), 
              g, \(-h\)}; {\((a - b + c - d + e - f + g - h)\)\ , \((a + b + 
                c + d + e + f + g + 
                h)\), \((a - c + e - g)\)\^2 + \((b - d + f - h)\)\^2, \
\((\((a - e)\)\^2 + \((c - g)\)\^2)\)\^2 + \((\((b - f)\)\^2 + \((d - \
h)\)\^2)\)\^2 + 
              4\ \((\((a - e)\)\ \((d - h)\) + \((f - b)\)\ \((c - 
                          g)\))\)\ \((\((a - e)\)\ \((b - f)\) + \((c - 
                          g)\)\ \((d - h)\))\)}];\)\), "\n", 
    \(\(sh["\<KC2\>"] := 
        Module[{}, gp = {1, 1, 1, 1, 1, 1, 1, 1}; 
          plex = {a, b, c, d, \(-e\), \(-f\), \(-g\), \(-h\)}; 
          gi = {1, 2, 3, 4, 5, 6, 7, 8, 1, 1, 1, 1, 1, 1, 1, 
              1}; \[IndentingNewLine]{a + b + c + d - e - f - g - h, 
            a + b - c - d + e + f - g - h, a - b + c - d + e - f + g - h, 
            a - b - c + d - e + f + g - h, a - b - c + d + e - f - g + h, 
            a - b + c - d - e + f - g + h, a + b - c - d - e - f + g + h, 
            a + b + c + d + e + f + g + h}];\)\), "\[IndentingNewLine]", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, 
            h_}, "\<KC2\>"] := \[IndentingNewLine]{a + b + c + d - e - f - 
            g - h, a + b - c - d + e + f - g - h, \[IndentingNewLine]a - b + 
            c - d + e - f + g - h, 
          a - b - c + d - e + f + g - h, \[IndentingNewLine]a - b - c + d + 
            e - f - g + h, 
          a - b + c - d - e + f - g + h, \[IndentingNewLine]a + b - c - d - 
            e - f + g + h, a + b + c + d + e + f + g + h};\)\), "\n", 
    \(toVec[{\[Alpha]_, \[Beta]_, \[Gamma]_, \[Delta]_, \[Epsilon]_, \
\[Sigma]_, \[Zeta]_, \[Theta]_}, "\<KC2\>"] := \[IndentingNewLine]{\ \[Alpha] \
+ \[Beta] + \[Gamma] + \[Delta] + \[Epsilon]\  + \[Sigma] + \[Zeta]\  + \
\[Theta], \[Alpha] + \[Beta] - \[Gamma] - \[Delta] - \[Epsilon]\  - \[Sigma] \
+ \[Zeta]\  + \[Theta], \[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \
\[Delta] - \[Epsilon] + \[Sigma] - \[Zeta] + \[Theta], \[Alpha] - \[Beta] - \
\[Gamma] + \[Delta] + \[Epsilon] - \[Sigma] - \[Zeta] + \[Theta], \
\[IndentingNewLine]\(-\[Alpha]\) + \[Beta] + \[Gamma] - \[Delta] + \[Epsilon]\
\  - \[Sigma] - \[Zeta]\  + \[Theta], \(-\[Alpha]\) + \[Beta] - \[Gamma] + \
\[Delta] - \[Epsilon]\  + \[Sigma] - \[Zeta]\  + \[Theta], \
\[IndentingNewLine]\(-\[Alpha]\) - \[Beta] + \[Gamma] + \[Delta] - \[Epsilon]\
\  - \[Sigma] + \[Zeta]\  + \[Theta], \(-\[Alpha]\) - \[Beta] - \[Gamma] - \
\[Delta] + \[Epsilon]\  + \[Sigma] + \[Zeta]\  + \[Theta]}/8\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(sh["\<C4C2\>"] := 
        Module[{}, gi = {1, 4, 3, 2, 5, 8, 7, 6, 1, 1, 1, 1, 1, 1}; 
          gp = {1, 1, 1, 1, 1, 0. , 1, 0. }; 
          plex = {a, \(-b\), c, \(-d\), e, \(-f\), 
              g, \(-h\)}; \[IndentingNewLine]{a + b + c + d - e - f - g - h, 
            a - b + c - d + e - f + g - h, a - b + c - d - e + f - g + h, 
            a + b + c + d + e + f + g + 
              h, \((a - c - e + g)\)\^2 + \((b - d - f + h)\)\^2, \((a - c + \
e - g)\)\^2 + \((b - d + f - h)\)\^2}];\)\), "\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_}, "\<C4C2\>"] := {a + b + c + 
            d + e + f + g + h, a - b + c - d + e - f + g - h, 
          a + b + c + d - e - f - g - h, 
          a - b + c - d - e + f - g + 
            h, \((a - c - e + g)\)\^2 + \((b - d - f + h)\)\^2, \
\[IndentingNewLine]ArcTan[a - c - e + g, 
            b - d - f + 
              h], \[IndentingNewLine]\((a - c + e - g)\)\^2 + \((b - d + f - \
h)\)\^2, \[IndentingNewLine]ArcTan[a - c + e - g, 
            b - d + f - h]};\)\), "\n", 
    \(toVec[{\[Alpha]_, \[Beta]_, \[Gamma]_, \[Delta]_, \
\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Zeta]\[Zeta]_, \[Theta]_}, "\<C4C2\>"] := 
      Module[{\[Epsilon] = 2 \@ \[Epsilon]\[Epsilon], \[Zeta] = 
            2 \@ \[Zeta]\[Zeta]}, \[IndentingNewLine]{\ \ \[Alpha] + \[Beta] \
+ \[Gamma] + \[Delta] + \[Epsilon]\ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Theta]], \
\[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Epsilon]\ Sin[\[Sigma]] + \
\[Zeta]\ Sin[\[Theta]], \[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \
\[Delta] - \[Epsilon]\ Cos[\[Sigma]] - \[Zeta]\ Cos[\[Theta]], \[Alpha] - \
\[Beta] + \[Gamma] - \[Delta] - \[Epsilon]\ Sin[\[Sigma]] - \[Zeta]\ Sin[\
\[Theta]], \[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \[Delta] - \
\[Epsilon]\ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Theta]], \[Alpha] - \[Beta] - \
\[Gamma] + \[Delta] - \[Epsilon]\ Sin[\[Sigma]] + \[Zeta]\ Sin[\[Theta]], \
\[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Epsilon]\ \
Cos[\[Sigma]] - \[Zeta]\ Cos[\[Theta]], \[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] + \[Epsilon]\ Sin[\[Sigma]] - \[Zeta]\ Sin[\[Theta]]}/8]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(sh["\<D4\>"] := 
        Module[{}, gi = {1, 2, 7, 4, 5, 6, 3, 8, 1, 1, 1, 1, 2}; 
          gp = {1, 1, 1, 1, 1, 0. , 1, 0. }; 
          plex =. ; {a + b - c - d + e + f - g - h, 
            a - b + c - d + e - f + g - h, a - b - c + d + e - f - g + h, 
            a + b + c + d + e + f + g + 
              h, \[IndentingNewLine]\((a - e)\)\^2 - \((b - f)\)\^2 + \((c - \
g)\)\^2 - \((d - h)\)\^2 (*repeated*) }];\)\), "\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_}, "\<D4\>"] := {a + b + c + d + 
            e + f + g + h, a + b - c - d + e + f - g - h, 
          a - b + c - d + e - f + g - h, 
          a - b - c + d + e - f - g + 
            h, \[IndentingNewLine]\((a - e)\)\^2 + \((c - g)\)\^2 - \((b - f)\
\)\^2 - \((d - h)\)\^2, 
          ArcTan[a - e, 
            c - g], \[IndentingNewLine]\((b - f)\)\^2 + \((d - h)\)\^2, 
          ArcTan[b - f, d - h]};\)\), "\n", 
    \(\(toVec[{\[Alpha]_, \[Beta]_, \[Gamma]_, \[Delta]_, \
\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Zeta]\[Zeta]_, \[Theta]_}, "\<D4\>"] := 
        Module[{\[Epsilon] = 
                4 \@\( \[Epsilon]\[Epsilon] + \[Zeta]\[Zeta]\), \[Zeta] = 
                4 \@ \[Zeta]\[Zeta]}, \[IndentingNewLine]{\[Alpha] + \[Beta] \
+ \[Gamma] + \[Delta] + \[Epsilon]\ Cos[\[Sigma]], \[Alpha] + \[Beta] - \
\[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Theta]], \[Alpha] - \[Beta] + \[Gamma] - \
\[Delta] + \[Epsilon]\ Sin[\[Sigma]], \[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] + \[Zeta]\ Sin[\[Theta]], \[Alpha] + \[Beta] + \[Gamma] + \[Delta] - \
\[Epsilon]\ Cos[\[Sigma]], \[Alpha] + \[Beta] - \[Gamma] - \[Delta] - \[Zeta]\
\ Cos[\[Theta]], \[Alpha] - \[Beta] + \[Gamma] - \[Delta] - \[Epsilon]\ Sin[\
\[Sigma]], \[Alpha] - \[Beta] - \[Gamma] + \[Delta] - \[Zeta]\ \
Sin[\[Theta]]}]/8;\)\), "\n", 
    \(\(tohyPol[{a_, b_, c_, d_, e_, f_, g_, 
            h_}, "\<D4\>"] := {\((a + b + e + f)\)\^2 - \((c + d + g + \
h)\)\^2, arcTanh[a + b + e + f, 
            c + d + g + 
              h], \[IndentingNewLine]\((a - b + e - f)\)\^2 - \((c - d + g - \
h)\)\^2, arcTanh[a - b + e - f, 
            c - d + g - 
              h], \[IndentingNewLine]\((a - e)\)\^2 + \((c - g)\)\^2, 
          ArcTan[a - e, 
            c - g], \[IndentingNewLine]\((b - f)\)\^2 + \((d - h)\)\^2, 
          ArcTan[b - f, d - h]};\)\), "\n", 
    \(\(tohyVec[{\[Alpha]\[Alpha]_, \[Phi]_, \[Gamma]\[Gamma]_, \[Rho]_, \
\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Zeta]\[Zeta]_, \[Theta]_}, "\<D4\>"] := 
        Module[{\[Alpha] = \@\[Alpha]\[Alpha], \[Gamma] = \@\[Gamma]\[Gamma], \
\[Epsilon] = 2 \@ \[Epsilon]\[Epsilon], \[Zeta] = 
                2 \@ \[Zeta]\[Zeta]}, \[IndentingNewLine]{\[Alpha]\ Cosh[\
\[Phi]] + \[Gamma]\ Cosh[\[Rho]] + \[Epsilon]\ Cos[\[Sigma]], \[Alpha]\ Cosh[\
\[Phi]] - \[Gamma]\ Cosh[\[Rho]] + \[Zeta]\ Cos[\[Theta]], \[Alpha]\ Sinh[\
\[Phi]] + \[Gamma]\ Sinh[\[Rho]] + \[Epsilon]\ Sin[\[Sigma]], \[Alpha]\ Sinh[\
\[Phi]] - \[Gamma]\ Sinh[\[Rho]] + \[Zeta]\ Sin[\[Theta]], \[Alpha]\ Cosh[\
\[Phi]] + \[Gamma]\ Cosh[\[Rho]] - \[Epsilon]\ Cos[\[Sigma]], \[Alpha]\ Cosh[\
\[Phi]] - \[Gamma]\ Cosh[\[Rho]] - \[Zeta]\ Cos[\[Theta]], \[Alpha]\ Sinh[\
\[Phi]] + \[Gamma]\ Sinh[\[Rho]] - \[Epsilon]\ Sin[\[Sigma]], \[Alpha]\ Sinh[\
\[Phi]] - \[Gamma]\ Sinh[\[Rho]] - \[Zeta]\ Sin[\[Theta]]}]/4;\)\)}], "Input",\

  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0],

Cell[BoxData[{
    \(\(sh["\<Q8\>"] := 
        Module[{}, gi = {1, 6, 7, 8, 5, 2, 3, 4, 1, 1, 1, 1, 2}; 
          gp = {1, 1, 1, 1, 1, 0. , 1, 0. }; 
          plex = {a, \(-b\), \(-c\), \(-d\), 
              e, \(-f\), \(-g\), \(-h\)}; \[IndentingNewLine]{a + b - c - d + 
              e + f - g - h, a - b + c - d + e - f + g - h, 
            a - b - c + d + e - f - g + h, 
            a + b + c + d + e + f + g + 
              h, \((a - e)\)\^2 + \((b - f)\)\^2 + \((c - g)\)\^2 + \((d - h)\
\)\^2 (*repeated*) }];\)\), "\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_}, "\<Q8\>"] := {a + b + c + d + 
            e + f + g + h, a - b + c - d + e - f + g - h, 
          a - b - c + d + e - f - g + h, 
          a + b - c - d + e + f - g - h, \((a - e)\)\^2 + \((b - f)\)\^2, 
          ArcTan[a - e, b - f], \((c - g)\)\^2 + \((d - h)\)\^2, 
          ArcTan[c - g, d - h]};\)\), "\n", 
    \(\(toVec[{\[Alpha]_, \[Beta]_, \[Gamma]_, \[Delta]_, \
\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Zeta]\[Zeta]_, \[Theta]_}, "\<Q8\>"] := {\
\ \ \[Alpha] + \[Beta] + \[Gamma] + \[Delta] + 
              4 \@ \[Epsilon]\[Epsilon]\ Cos[\[Sigma]], \[Alpha] - \[Beta] - \
\[Gamma] + \[Delta] + 
              4 \@ \[Epsilon]\[Epsilon]\ Sin[\[Sigma]], \[Alpha] + \[Beta] - \
\[Gamma] - \[Delta] + 
              4 \@ \[Zeta]\[Zeta]\ Cos[\[Theta]], \[Alpha] - \[Beta] + \
\[Gamma] - \[Delta] + 
              4 \@ \[Zeta]\[Zeta]\ Sin[\[Theta]], \[Alpha] + \[Beta] + \
\[Gamma] + \[Delta] - 
              4 \@ \[Epsilon]\[Epsilon]\ Cos[\[Sigma]], \[Alpha] - \[Beta] - \
\[Gamma] + \[Delta] - 
              4 \@ \[Epsilon]\[Epsilon]\ Sin[\[Sigma]], \[Alpha] + \[Beta] - \
\[Gamma] - \[Delta] - 
              4 \@ \[Zeta]\[Zeta]\ Cos[\[Theta]], \[Alpha] - \[Beta] + \
\[Gamma] - \[Delta] - 4 \@ \[Zeta]\[Zeta]\ Sin[\[Theta]]}/8;\)\), "\n", 
    \(\(tohyPol[{a_, b_, c_, d_, e_, f_, g_, 
            h_}, "\<Q8\>"] := {\((a + b + e + f)\)\^2 - \((c + d + g + \
h)\)\^2, arcTanh[a + b + e + f, 
            c + d + g + 
              h], \[IndentingNewLine]\((a - b + e - f)\)\^2 - \((c - d + g - \
h)\)\^2, arcTanh[a - b + e - f, 
            c - d + g - 
              h], \[IndentingNewLine]\((a - e)\)\^2 + \((b - f)\)\^2, 
          ArcTan[a - e, 
            b - f], \[IndentingNewLine]\((c - g)\)\^2 + \((d - h)\)\^2, 
          ArcTan[c - g, d - h]};\)\), "\n", 
    \(\(tohyVec[{\[Alpha]\[Alpha]_, \[Phi]_, \[Gamma]\[Gamma]_, \[Rho]_, \
\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Zeta]\[Zeta]_, \[Theta]_}, "\<Q8\>"] := 
        Module[{\[Alpha] = \@\[Alpha]\[Alpha], \[Gamma] = \@\[Gamma]\[Gamma], \
\[Epsilon] = 2 \@ \[Epsilon]\[Epsilon], \[Zeta] = 
                2 \@ \[Zeta]\[Zeta]}, \[IndentingNewLine]{\[Alpha]\ Cosh[\
\[Phi]] + \[Gamma]\ Cosh[\[Rho]] + \[Epsilon]\ Cos[\[Sigma]], \[Alpha]\ Cosh[\
\[Phi]] - \[Gamma]\ Cosh[\[Rho]] + \[Epsilon]\ Sin[\[Sigma]], \
\[IndentingNewLine]\[Alpha]\ Sinh[\[Phi]] + \[Gamma]\ Sinh[\[Rho]] + \[Zeta]\ \
Cos[\[Theta]], \[Alpha]\ Sinh[\[Phi]] - \[Gamma]\ Sinh[\[Rho]] + \[Zeta]\ \
Sin[\[Theta]], \[IndentingNewLine]\[Alpha]\ Cosh[\[Phi]] + \[Gamma]\ Cosh[\
\[Rho]] - \[Epsilon]\ Cos[\[Sigma]], \[Alpha]\ Cosh[\[Phi]] - \[Gamma]\ Cosh[\
\[Rho]] - \[Epsilon]\ Sin[\[Sigma]], \[IndentingNewLine]\[Alpha]\ \
Sinh[\[Phi]] + \[Gamma]\ Sinh[\[Rho]] - \[Zeta]\ Cos[\[Theta]], \[Alpha]\ \
Sinh[\[Phi]] - \[Gamma]\ Sinh[\[Rho]] - \[Zeta]\ Sin[\[Theta]]}]/
          4;\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0],

Cell[BoxData[{
    \(\(sh["\<Octr\>"] := 
        Module[{}, 
          gi = {1, \(-2\), \(-3\), \(-4\), \(-5\), \(-6\), \(-7\), \(-8\), 
              4}; gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          plex = {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), \(-h\)}; \
\[IndentingNewLine]{a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + 
              h\^2}];\)\), "\n", 
    \(toPol[{a_, b_, c_, d_, e_, f_, g_, h_}, "\<Octr\>"] := 
      Module[{}, {a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2, 
          ArcTan[a, b], c\^2 + d\^2, ArcTan[c, d], e\^2 + f\^2, ArcTan[e, f], 
          g\^2 + h\^2, ArcTan[g, h]}]\), "\n", 
    \(toVec[{pp_, \[Phi]_, qq_, \[Psi]_, rr_, \[Rho]_, 
          ss_, \[Sigma]_}, "\<Octr\>"] := 
      Module[{p = \@\(pp - qq - rr - ss\), q = \@qq, r = \@rr, 
          s = \@ss}, {\ \ p\ Cos[\[Phi]]\ , p\ Sin[\[Phi]], q\ Cos[\[Psi]]\ , 
          q\ Sin[\[Psi]]\ , r\ Cos[\[Rho]]\ , r\ Sin[\[Rho]], 
          s\ Cos[\[Sigma]], s\ Sin[\[Sigma]]}]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(sh["\<KiC4c\>"] := 
      Module[{}, gi = {1, 2, 3, 4, \(-5\), \(-8\), \(-7\), \(-6\), 1, 1, 2}; 
        gp = {1, 0. , 1, 0. , 1, 0, 1, 
            0. }; \[IndentingNewLine]{\((a - b + c - d)\)\^2 + \((e - f + g - \
h)\)\^2, \((a + b + c + d)\)\^2 + \((e + f + g + h)\)\^2, \((a - c)\)\^2 - \
\((b - d)\)\^2 + \((e - g)\)\^2 - \((f - h)\)\^2 (*repeated*) }]\), "\n", 
    \(toPol[{a_, b_, c_, d_, e_, f_, g_, h_}, "\<KiC4c\>"] := 
      Module[{}, { (*pp*) \((a - c)\)\^2 - \((b - d)\)\^2 + \((e - g)\)\^2 - \
\((f - h)\)\^2,  (*\[Phi]*) If[e == g, 0, 
            ArcTan[a - c, 
              e - g]], \[IndentingNewLine] (*qq*) \((b - d)\)\^2 + \((f - \
h)\)\^2, \[IndentingNewLine] (*\[Psi]*) If[f == h, 0, 
            ArcTan[b - d, 
              f - h]],  (*rr*) \((a - b + c - d)\)\^2 + \((e - f + g - \
h)\)\^2,  (*\[Rho]*) If[e + g \[Equal] f + h, 0, 
            ArcTan[a - b + c - d, 
              e - f + g - 
                h]],  (*ss*) \((a + b + c + d)\)\^2 + \((e + f + g + h)\)\^2, \
 (*\[Sigma]*) If[e + f \[Equal] g + h, 0, 
            ArcTan[a + b + c + d, e + f + g + h]]}]\), "\n", 
    \(toVec[{pp_, \[Phi]_, qq_, \[Psi]_, rr_, \[Rho]_, 
          ss_, \[Sigma]_}, "\<KiC4c\>"] := 
      Module[{p = \@\(pp + qq\)/2, q = \@qq/2, r = \@rr/4, 
          s = \@ss/4}, { (*a*) \ \ p\ Cos[\[Phi]]\  + r\ Cos[\[Rho]] + 
            s\ Cos[\[Sigma]], \[IndentingNewLine]\ \ \  (*b*) \ \(+q\)\ Cos[\
\[Psi]] - r\ Cos[\[Rho]] + 
            s\ Cos[\[Sigma]], \[IndentingNewLine] (*c*) \(-p\)\ Cos[\[Phi]] + 
            r\ Cos[\[Rho]] + 
            s\ Cos[\[Sigma]]\ , \[IndentingNewLine]\ \ \  (*d*) \(-q\)\ Cos[\
\[Psi]] - r\ Cos[\[Rho]] + 
            s\ Cos[\[Sigma]], \[IndentingNewLine] (*e*) \ \ p\ Sin[\[Phi]] + 
            r\ Sin[\[Rho]] + 
            s\ Sin[\[Sigma]], \[IndentingNewLine]\ \ \  (*f*) \(+q\)\ Sin[\
\[Psi]] - r\ Sin[\[Rho]] + 
            s\ Sin[\[Sigma]], \[IndentingNewLine] (*g*) \(-p\)\ Sin[\[Phi]] + 
            r\ Sin[\[Rho]] + 
            s\ Sin[\[Sigma]], \[IndentingNewLine]\ \ \  (*h*) \ \(-q\)\ Sin[\
\[Psi]] - r\ Sin[\[Rho]] + s\ Sin[\[Sigma]]}]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(sh["\<O4\>"] := 
        Module[{}, gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          gi = {1, 2, 3, 4, \(-5\), \(-6\), \(-7\), \(-8\), 1, 1, 1, 1}; 
          plex = {a, b, c, 
              d, \(-e\), \(-f\), \(-g\), \(-h\)}; \[IndentingNewLine]{\((a - \
b - c + d)\)\^2 + \((e - f - g + h)\)\^2, \((a - b + c - d)\)\^2 + \((e - f + \
g - h)\)\^2, \[IndentingNewLine]\((a + b - c - d)\)\^2 + \((e + f - g - \
h)\)\^2, \((a + b + c + d)\)\^2 + \((e + f + g + h)\)\^2}];\)\), "\n", 
    \(toPol[{a_, b_, c_, d_, e_, f_, g_, h_}, "\<O4\>"] := 
      Module[{}, 
        gp = {1, 0. , 1, 0. , 1, 0. , 1, 
            0. }; {\((a - b - c + d)\)\^2 + \((e - f - g + h)\)\^2, 
          If[e + h \[Equal] f + g, 0, 
            ArcTan[a - b - c + d, 
              e - f - g + 
                h]], \((a - b + c - d)\)\^2 + \((e - f + g - h)\)\^2, 
          If[e + g \[Equal] f + h, 0, 
            ArcTan[a - b + c - d, 
              e - f + g - 
                h]], \((a + b - c - d)\)\^2 + \((e + f - g - h)\)\^2, 
          If[e + f \[Equal] g + h, 0, 
            ArcTan[a + b - c - d, 
              e + f - g - 
                h]], \((a + b + c + d)\)\^2 + \((e + f + g + h)\)\^2, 
          If[e + f + g + h \[Equal] 0, 0, 
            ArcTan[a + b + c + d, e + f + g + h]]}]\), "\n", 
    \(toVec[{pp_, \[Phi]_, qq_, \[Psi]_, rr_, \[Rho]_, 
          ss_, \[Sigma]_}, "\<O4\>"] := 
      Module[{p = Sqrt[pp], q = Sqrt[qq], r = Sqrt[rr], 
            s = Sqrt[ss]}, {\ \ p\ Cos[\[Phi]]\  + q\ Cos[\[Psi]]\  + 
              r\ Cos[\[Rho]]\  + s\ Cos[\[Sigma]], \(-\ p\)\ Cos[\[Phi]] - 
              q\ Cos[\[Psi]] + r\ Cos[\[Rho]]\  + 
              s\ Cos[\[Sigma]], \(-p\)\ Cos[\[Phi]]\  + q\ Cos[\[Psi]]\  - 
              r\ Cos[\[Rho]]\  + s\ Cos[\[Sigma]], \ 
            p\ Cos[\[Phi]] - q\ Cos[\[Psi]]\  - r\ Cos[\[Rho]]\  + 
              s\ Cos[\[Sigma]], \[IndentingNewLine]\ \ p\ Sin[\[Phi]]\  + 
              q\ Sin[\[Psi]]\  + r\ Sin[\[Rho]]\  + 
              s\ Sin[\[Sigma]], \(-p\)\ Sin[\[Phi]] - q\ Sin[\[Psi]]\  + 
              r\ Sin[\[Rho]]\  + 
              s\ Sin[\[Sigma]], \[IndentingNewLine]\(-p\)\ Sin[\[Phi]]\  + 
              q\ Sin[\[Psi]]\  - r\ Sin[\[Rho]]\  + s\ Sin[\[Sigma]], \ 
            p\ Sin[\[Phi]]\  - q\ Sin[\[Psi]] - r\ Sin[\[Rho]] + 
              s\ Sin[\[Sigma]]}]/4\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(sh["\<O4a\>"] := 
        Module[{}, gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          gi = {1, \(-2\), 3, \(-4\), \(-5\), 6, \(-7\), 8, 1, 1, 1, 1}; 
          plex = {a, \(-b\), c, \(-d\), \(-e\), f, \(-g\), 
              h}; \[IndentingNewLine]{\((a - c - f + h)\)\^2 + \((b - d + e - \
g)\)\^2, \((a - c + f - h)\)\^2 + \((b - d - e + g)\)\^2, \[IndentingNewLine]\
\((a + c - f - h)\)\^2 + \((b + d + e + g)\)\^2, \((a + c + f + h)\)\^2 + \
\((b + d - e - g)\)\^2}];\)\), "\n", 
    \(\(sh["\<O4b\>"] := 
        Module[{}, gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          gi = {1, \(-2\), \(-3\), 4, \(-5\), 6, 7, \(-8\), 1, 1, 1, 1}; 
          plex = {a, \(-b\), \(-c\), d, \(-e\), f, 
              g, \(-h\)}; \[IndentingNewLine]{\((\(-a\) + d + f + g)\)\^2 + \
\((b + c + e - h)\)\^2, \((a - d + f + g)\)\^2 + \((b + c - e + h)\)\^2, \
\[IndentingNewLine]\((a + d - f + g)\)\^2 + \((b - c + e + h)\)\^2, \((a + d \
+ f - g)\)\^2 + \((\(-b\) + c + e + h)\)\^2}];\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(sh["\<C4C4c\>"] := 
      Module[{}, gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
        gi = {1, 4, 3, 2, \(-5\), \(-8\), \(-7\), \(-6\), 1, 1, 1, 1}; 
        plex = {a, \(-b\), c, \(-d\), \(-e\), f, \(-g\), 
            h}; {\((b - d + e - g)\)\^2 + \((a - c - f + h)\)\^2, \((b - d - \
e + g)\)\^2 + \((a - c + f - h)\)\^2, \[IndentingNewLine]\((a - b + c - \
d)\)\^2 + \((e - f + g - h)\)\^2, \((a + b + c + d)\)\^2 + \((e + f + g + \
h)\)\^2}]; 
    toPol[{a_, b_, c_, d_, e_, f_, g_, h_}, "\<C4C4c\>"] := 
      Module[{aa, bb, ss, w}, 
        ss := aa^2 + bb^2; \[IndentingNewLine]w := 
          Which[bb === 0 && aa < 0, \[Pi], bb \[Equal] 0, 0, 
            aa \[Equal] 0, \[Pi]/2\ Sign[bb], True, ArcTan[aa, bb]]; {aa = 
            a - c - f + h; bb = b - d + e - g; ss, w, aa = a - c + f - h; 
          bb = b - d - e + g; ss, w, aa = a - b + c - d; bb = e - f + g - h; 
          ss, w, aa = a + b + c + d; bb = e + f + g + h; ss, w}];\), "\n", 
    \(toVec[{pp_, \[Phi]_, qq_, \[Psi]_, rr_, \[Rho]_, 
          ss_, \[Sigma]_}, "\<C4C4c\>"] := 
      Module[{p = Sqrt[pp], q = Sqrt[qq], r = Sqrt[rr], 
          s = Sqrt[ss]}, {\ \ \ \ p\ Cos[\[Phi]] + q\ Cos[\[Psi]] + 
              r\ Cos[\[Rho]] + s\ Cos[\[Sigma]], \[IndentingNewLine]\ 
            p\ Sin[\[Phi]] + q\ Sin[\[Psi]] - r\ Cos[\[Rho]] + 
              s\ Cos[\[Sigma]], \[IndentingNewLine]\(-p\)\ Cos[\[Phi]] - 
              q\ Cos[\[Psi]] + r\ Cos[\[Rho]] + 
              s\ Cos[\[Sigma]], \(-p\)\ Sin[\[Phi]] - q\ Sin[\[Psi]] - 
              r\ Cos[\[Rho]] + 
              s\ Cos[\[Sigma]], \[IndentingNewLine]\ \ p\ Sin[\[Phi]] - 
              q\ Sin[\[Psi]] + r\ Sin[\[Rho]] + 
              s\ Sin[\[Sigma]], \(-p\)\ Cos[\[Phi]] + q\ Cos[\[Psi]] - 
              r\ Sin[\[Rho]] + 
              s\ Sin[\[Sigma]], \[IndentingNewLine]\(-p\)\ Sin[\[Phi]] + 
              q\ Sin[\[Psi]] + r\ Sin[\[Rho]] + 
              s\ Sin[\[Sigma]], \ \ p\ Cos[\[Phi]] - q\ Cos[\[Psi]] - 
              r\ Sin[\[Rho]] + s\ Sin[\[Sigma]]}/4]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(sh["\<C4C4r\>"] := 
        Module[{}, gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          gi = {1, \(-4\), 3, \(-2\), \(-5\), 8, \(-7\), 6, 1, 1, 1, 1}; 
          plex = {a, \(-b\), c, \(-d\), \(-e\), f, \(-g\), 
              h}; {\((b + d + e + g)\)\^2 + \((a + c - f - h)\)\^2, \((a + b \
- c - d)\)\^2 + \((e + f - g - h)\)\^2, \((a - b - c + d)\)\^2 + \((e - f - g \
+ h)\)\^2, \((b + d - e - g)\)\^2 + \((a + c + f + h)\)\^2}];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FormatType->TraditionalForm],

Cell[BoxData[{
    \(\(sh["\<Q8C2r\>"] := 
        Module[{}, 
          gi = {1, 3, 2, \(-7\), 5, \(-8\), \(-4\), \(-6\), 1, 1, 1, 1, 2}; 
          gp = {1, 1, 1, 1, 1, 0. , 1, 0. }; 
          plex = {a, \(-b\), \(-c\), \(-d\), e, \(-f\), \(-g\), \(-h\)}; {a - 
              b - c - d - e - f + g + h, a + b + c - d - e + f + g - h, 
            a + b + c + d - e - f - g + h, 
            a - b - c + d - e + f - g - 
              h, \((a + e)\)^2 + \((b - c)\)^2 + \((d + g)\)^2 + \((f + 
                    h)\)^2 (*repeated*) }];\)\), "\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, 
            h_}, "\<Q8C2r\>"] := \[IndentingNewLine]{a - b - c - d - e - f + 
            g + h, a + b + c - d - e + f + g - h, 
          a + b + c + d - e - f - g + h, 
          a - b - c + d - e + f - g - h, \((a + e)\)^2 + \((b - c)\)^2, 
          ArcTan[a + e, b - c], \((d + g)\)^2 + \((f + h)\)^2\ , 
          ArcTan[d + g, f + h]};\)\), "\n", 
    \(\(toVec[{\[Alpha]_, \[Beta]_, \[Gamma]_, \[Delta]_, \
\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Zeta]\[Zeta]_, \[Theta]_}, "\<Q8C2r\>"] := 
        Module[{\[Epsilon] = 4 \@ \[Epsilon]\[Epsilon], \[Zeta] = 
              4 \@ \[Zeta]\[Zeta]}, \[IndentingNewLine]{\ \ \ \ \ \[Alpha] + \
\[Beta] + \[Gamma] + \[Delta] + \[Epsilon]\ Cos[\[Sigma]], \(-\[Alpha]\) + \
\[Beta] + \[Gamma] - \[Delta] + \[Epsilon]\ Sin[\[Sigma]], \(-\[Alpha]\) + \
\[Beta] + \[Gamma] - \[Delta] - \[Epsilon]\ Sin[\[Sigma]], \(-\[Alpha]\) - \
\[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Theta]], \(-\[Alpha]\) - \
\[Beta] - \[Gamma] - \[Delta] + \[Epsilon]\ Cos[\[Sigma]], \(-\[Alpha]\) + \
\[Beta] - \[Gamma] + \[Delta] + \[Zeta]\ Sin[\[Theta]], \ \ \[Alpha] + \
\[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Theta]], \ \ \ \[Alpha] - \
\[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ Sin[\[Theta]]}/8];\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(sh["\<C2D4r\>"] := 
        Module[{}, gi = {1, 2, 3, 4, \(-5\), \(-6\), 7, 8, 2, 2}; 
          gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          plex = {a, 
              b, \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), \(-h\)}; {\((a + \
b)\)\^2 - \((c + d)\)\^2 + \((e + f)\)\^2 - \((g + h)\)\^2 (*repeated*) , \
\((a - b)\)\^2 - \((c - d)\)\^2 + \((e - f)\)\^2 - \((g - h)\)\^2 \
(*repeated*) }];\)\), "\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, 
            h_}, "\<C2D4r\>"] := \[IndentingNewLine]{\((a + b)\)\^2 + \((e + \
f)\)\^2, If[e \[Equal] \(-f\), 0, 
            ArcTan[a + b, 
              e + f]], \[IndentingNewLine]\((c + d)\)\^2 + \((g + h)\)\^2, 
          If[g \[Equal] \(-h\), 0, 
            ArcTan[c + d, g + h]], \((a - b)\)\^2 + \((e - f)\)\^2, 
          If[e \[Equal] f, 0, 
            ArcTan[a - b, 
              e - f]], \[IndentingNewLine]\((c - d)\)\^2 + \((g - h)\)\^2, 
          If[g \[Equal] h, 0, ArcTan[c - d, g - h]]};\)\), "\n", 
    \(\(toVec[{\[Epsilon]\[Epsilon]_, \[Sigma]_, \[Zeta]\[Zeta]_, \[Theta]_, \
\[Eta]\[Eta]_, \[Phi]_, \[Kappa]\[Kappa]_, \[Psi]_}, "\<C2D4r\>"] := 
        Module[{\[Epsilon] = \@\[Epsilon]\[Epsilon], \[Zeta] = \@\[Zeta]\
\[Zeta], \[Eta] = \@\[Eta]\[Eta], \[Kappa] = \@\[Kappa]\[Kappa]}, \
\[IndentingNewLine]{\ \ \[Epsilon]\ Cos[\[Sigma]] + \[Eta]\ Cos[\[Phi]], \
\[Epsilon]\ Cos[\[Sigma]] - \[Eta]\ Cos[\[Phi]], \[IndentingNewLine]\[Zeta]\ \
Cos[\[Theta]] + \[Kappa]\ Cos[\[Psi]], \[Zeta]\ Cos[\[Theta]] - \[Kappa]\ \
Cos[\[Psi]], \[IndentingNewLine]\[Epsilon]\ Sin[\[Sigma]] + \[Eta]\ \
Sin[\[Phi]], \[Epsilon]\ Sin[\[Sigma]] - \[Eta]\ Sin[\[Phi]], \
\[IndentingNewLine]\[Zeta]\ Sin[\[Theta]] + \[Kappa]\ Sin[\[Psi]], \[Zeta]\ \
Sin[\[Theta]] - \[Kappa]\ Sin[\[Psi]]}/2];\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(sh["\<P8\>"] (*Signature\ \((1, 3)\)\ repeated*)  := 
        Module[{}, gi = {1, 2, 3, 4, 5, 6, 7, 8, 2, 2}; 
          gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          plex = {a, \(-b\), \(-c\), \(-d\), 
              e, \(-f\), \(-g\), \(-h\)}; \[IndentingNewLine]{\((a + e)\)\^2 \
- \((b + f)\)\^2 - \((c + g)\)\^2 - \((d + h)\)\^2 (*repeated*) , \((a - e)\)\
\^2 - \((b - f)\)\^2 - \((c - g)\)\^2 - \((d - h)\)\^2 (*repeated*) }];\)\), \
"\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_}, "\<P8\>"] := 
        Module[{}, 
          gp = {1, 0. , 1, 0. , 1, 0. , 1, 
              0. }; {\((a + e)\)\^2 - \((b + f)\)\^2, 
            arcTanh[a + e, 
              b + f], \[IndentingNewLine]\((c + g)\)\^2 + \((d + h)\)\^2, 
            ArcTan[c + g, 
              d + h], \[IndentingNewLine]\((a - e)\)\^2 - \((b - f)\)\^2, 
            arcTanh[a - e, 
              b - f], \[IndentingNewLine]\((c - g)\)\^2 + \((d - h)\)\^2, 
            ArcTan[c - g, d - h]}];\)\), "\n", 
    \(toVec[{pp_, \[Phi]_, qq_, \[Psi]_, rr_, \[Rho]_, 
          ss_, \[Sigma]_}, "\<P8\>"] := 
      Module[{p = Sqrt[pp], q = Sqrt[qq], r = Sqrt[rr], s = Sqrt[ss]}, {\ 
            p\ Cosh[\[Phi]] + r\ Cosh[\[Rho]], \ 
            p\ Sinh[\[Phi]] + r\ Sinh[\[Rho]]\ , 
            q\ Cos[\[Psi]]\ \  + s\ Cos[\[Sigma]], 
            q\ Sin[\[Psi]]\ \  + 
              s\ Sin[\[Sigma]], \[IndentingNewLine]p\ Cosh[\[Phi]] - 
              r\ Cosh[\[Rho]], p\ Sinh[\[Phi]] - r\ Sinh[\[Rho]]\ , 
            q\ Cos[\[Psi]] - s\ Cos[\[Sigma]], 
            q\ Sin[\[Psi]] - s\ Sin[\[Sigma]]}]/2\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0],

Cell[BoxData[{
    \(\(sh["\<CL3\>"] := 
        Module[{}, gp =. ; 
          gi = {1, 2, 3, \(-4\), 5, \(-6\), \(-7\), \(-8\), 2}; 
          plex = {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), 
              h}; \[IndentingNewLine]{4\ \((a\ h - b\ g + c\ f - d\ e)\)\^2 + \
\((a\^2 - b\^2 - c\^2 + d\^2 - e\^2 + f\^2 + g\^2 - h\^2)\)\^2}];\)\), "\
\[IndentingNewLine]", 
    \(\(sh["\<CL12\>"] :=  (*\ CL3\ isotope*) Module[{}, gp =. ; 
          gi = {1, \(-2\), \(-3\), \(-4\), 5, 6, 7, \(-8\), 2}; 
          plex = {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), 
              h}; {4 \((a\ h - b\ g + c\ f - d\ e)\)\^2 + \((a\^2 + b\^2 + \
c\^2 + d\^2 - e\^2 - f\^2 - g\^2 - h\^2)\)\^2}];\)\), "\[IndentingNewLine]", 
    \(sh["\<C4iC4c\>"] := 
      Module[{}, gi = {1, 4, 3, 2, \(-5\), \(-6\), \(-7\), \(-8\), 2, 1, 1}; 
        gp = {1, 1, 2, 1, 0. , 1, 0.  (*?*) }; 
        plex = {a, \(-b\), 
            c, \(-d\), \(-e\), \(-f\), \(-g\), \(-h\)}; {\((a - c)\)\^2 + \
\((b - d)\)\^2 + \((e - g)\)\^2 + \((f - h)\)\^2 (*repeated*) , \
\[IndentingNewLine]\((a - b + c - d)\)\^2 + \((e - f + g - h)\)\^2, \((a + b \
+ c + d)\)\^2 + \((e + f + g + h)\)\^2}]\), "\[IndentingNewLine]", 
    \(sh["\<QC2r\>"] := 
      Module[{}, 
        gi = {1, 2, \(-3\), \(-4\), \(-5\), \(-6\), \(-7\), \(-8\), 2, 2}; 
        plex = {a, b, \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), \(-h\)}; 
        gp = {1, 1, 1, 1, 0. , 1, 
            0.  (*?*) }; {\((a - b)\)\^2 + \((c - d)\)\^2 + \((e - f)\)\^2 + \
\((g - h)\)\^2, \((a + b)\)\^2 + \((c + d)\)\^2 + \((e + f)\)\^2 + \((g + \
h)\)\^2}]\), "\[IndentingNewLine]", 
    \(sh["\<KiC4r\>"] := 
      Module[{}, gi = {1, 2, \(-3\), \(-8\), 5, 6, \(-7\), \(-4\), 2, 1, 1}; 
        plex = {a, \(-b\), \(-c\), \(-d\), e, \(-f\), \(-g\), \(-h\)}; 
        gp = {1, 1, 1, 1, 0. , 1, 
            0.  (*?*) }; {\((a - e)\)\^2 - \((b - f)\)\^2 + \((c - g)\)\^2 - \
\((d - h)\)\^2 (*repeated*) , \((a + b + e + f)\)\^2 + \((c - d + g - \
h)\)\^2, \((a - b + e - f)\)\^2 + \((c + d + g + h)\)\^2}]\), "\
\[IndentingNewLine]", 
    \(\(sh["\<CL21\>"] := 
        Module[{}, gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          gi = {1, \(-2\), 3, 4, 5, 6, \(-7\), 8, 2, 2}; 
          plex = {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), 
              h}; \[IndentingNewLine]{\((a - h)\)\^2 + \((b + g)\)\^2 - \((c \
+ f)\)\^2 - \((d - e)\)\^2 (*repeated*) , \((a + h)\)\^2 + \((b - g)\)\^2 - \
\((c - f)\)\^2 - \((d + e)\)\^2 (*repeated*) }];\)\), "\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, 
            h_}, "\<CL21\>"] := \[IndentingNewLine]{ (*p, \[Phi]*) \((a - \
h)\)\^2 + \((b + g)\)\^2, 
          ArcTan[a - h, 
            b + g], \[IndentingNewLine] (*q, \[Psi]*) \((c + f)\)\^2 + \((d - \
e)\)\^2, ArcTan[c + f, 
            d - e], \[IndentingNewLine] (*r, \[Rho]*) \((a + h)\)\^2 + \((b - \
g)\)\^2, ArcTan[a + h, 
            b - g], \[IndentingNewLine] (*s, \[Sigma]*) \((c - f)\)\^2 + \((d \
+ e)\)\^2, ArcTan[c - f, d + e]};\)\), "\n", 
    \(\(toVec[{pp_, \[Phi]_, qq_, \[Psi]_, rr_, \[Rho]_, 
            ss_, \[Sigma]_}, "\<CL21\>"] := 
        Module[{p = Sqrt[pp], q = Sqrt[qq], r = Sqrt[rr], 
            s = Sqrt[ss]}, { (*a*) \ 
              p\ Cos[\[Phi]]\  + r\ Cos[\[Rho]],  (*b*) \ 
              p\ Sin[\[Phi]]\  + r\ Sin[\[Rho]], \[IndentingNewLine] (*c*) 
                q\ Cos[\[Psi]] + s\ Cos[\[Sigma]],  (*d*) q\ Sin[\[Psi]] + 
                s\ Sin[\[Sigma]], \[IndentingNewLine] (*e*) \(-q\)\ \
Sin[\[Psi]] + s\ Sin[\[Sigma]],  (*f*) \ 
              q\ Cos[\[Psi]] - s\ Cos[\[Sigma]], \[IndentingNewLine] (*g*) \ 
              p\ Sin[\[Phi]]\  - 
                r\ Sin[\[Rho]],  (*h*) \(-\ p\)\ Cos[\[Phi]] + 
                r\ Cos[\[Rho]]}/2];\)\), "\[IndentingNewLine]", 
    \(\(sh["\<CL03\>"] := 
        Module[{}, gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          gi = {1, \(-2\), \(-3\), \(-4\), \(-5\), \(-6\), \(-7\), 8, 2, 2}; 
          plex = {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), 
              h}; \[IndentingNewLine]{\((a - h)\)\^2 + \((b + g)\)\^2 + \((c \
- f)\)\^2 + \((d + e)\)\^2 (*repeated*) , \((a + h)\)\^2 + \((b - g)\)\^2 + \
\((c + f)\)\^2 + \((d - e)\)\^2 (*repeated*) }];\)\), "\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, 
            
            h_}, "\<CL03\>"] := \[IndentingNewLine]{ (*p, \[Phi]*) \((a - \
h)\)\^2 + \((b + g)\)\^2, 
          ArcTan[a - h, 
            b + g], \[IndentingNewLine] (*q, \[Psi]*) \((c - f)\)\^2 + \((d + \
e)\)\^2, ArcTan[c - f, 
            d + e], \[IndentingNewLine] (*r, \[Rho]*) \((a + h)\)\^2 + \((b - \
g)\)\^2, ArcTan[a + h, 
            b - g], \[IndentingNewLine] (*s, \[Sigma]*) \((c + f)\)\^2 + \((d \
- e)\)\^2, ArcTan[c + f, d - e]};\)\), "\n", 
    \(toVec[{pp_, \[Phi]_, qq_, \[Psi]_, rr_, \[Rho]_, 
          ss_, \[Sigma]_}, "\<CL03\>"] := 
      Module[{p = Sqrt[pp], q = Sqrt[qq], r = Sqrt[rr], 
          s = Sqrt[ss]}, { (*a*) \ 
            p\ Cos[\[Phi]]\  + r\ Cos[\[Rho]],  (*b*) \ 
            p\ Sin[\[Phi]]\  + r\ Sin[\[Rho]], \[IndentingNewLine] (*c*) 
              q\ Cos[\[Psi]] + s\ Cos[\[Sigma]],  (*d*) q\ Sin[\[Psi]] + 
              s\ Sin[\[Sigma]], \[IndentingNewLine] (*e*) q\ Sin[\[Psi]] - 
              s\ Sin[\[Sigma]],  (*f*) \(-q\)\ Cos[\[Psi]] + 
              s\ Cos[\[Sigma]], \[IndentingNewLine] (*g*) \ 
            p\ Sin[\[Phi]]\  - 
              r\ Sin[\[Rho]],  (*h*) \(-\ \(p\ Cos[\[Phi]]\)\) + 
              r\ Cos[\[Rho]]}/2]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(sh["\<Octi\>"] := 
        Module[{}, gi = {1, 2, \(-3\), 4, \(-5\), 6, \(-7\), 8, 4}; 
          gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          plex = {a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), \(-h\)}; \
\[IndentingNewLine]{a\^2 - b\^2 + c\^2 - d\^2 + e\^2 - f\^2 + g\^2 - 
              h\^2}];\)\), "\n", 
    \(toPol[{a_, b_, c_, d_, e_, f_, g_, h_}, "\<Octi\>"] := 
      Module[{}, {a\^2 + c\^2, ArcTan[a, c], b\^2 + d\^2, ArcTan[b, d], 
          e\^2 + g\^2, ArcTan[e, g], f\^2 + h\^2, ArcTan[f, h]}]\), "\n", 
    \(toVec[{pp_, \[Phi]_, qq_, \[Psi]_, rr_, \[Rho]_, 
          ss_, \[Sigma]_}, "\<Octi\>"] := 
      Module[{p = Sqrt[pp], q = Sqrt[qq], r = Sqrt[rr], 
          s = Sqrt[ss]}, {p\ Cos[\[Phi]]\ , q\ Cos[\[Psi]], p\ Sin[\[Phi]]\ , 
          q\ Sin[\[Psi]]\ , r\ Cos[\[Rho]]\ , s\ Cos[\[Sigma]], 
          r\ Sin[\[Rho]], s\ Sin[\[Sigma]]}]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(sh["\<Q8n\>"] := 
        Module[{},  (*L2\ shapes\ not\ conserved*) 
            gp = {1, 1, 1, 1, 1, 0. , 1, 0. }; plex =. ; 
          gi = {1, 2, 3, 4, 5, 6, 7, 8, 1, 1, 1, 1, 1, 
              1}; \[IndentingNewLine]{a + b + c + d + e + f + g + h, 
            a + b - c - d + e + f - g - h, \[IndentingNewLine]a - b + c - d + 
              e - f + g - h, 
            a + b + c + d + e + f + g + 
              h, \((a - e)\)\^2 - \((b - f)\)\^2 - \((c - g)\)\^2 - \((d - h)\
\)\^2, \((a - e)\)\^2 + \((b - f)\)\^2 + \((c - g)\)\^2 + \((d - h)\)\^2}];\)\
\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(sh["\<C3C3\>"] := 
        Module[{}, gi = {1, 3, 2, 7, 9, 8, 4, 6, 5, 1, 1, 1, 1, 1}; 
          gp = {1, 1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          plex = {a, c, b, g, i, h, d, f, 
              e}; {\((a + b + c + d + e + f + g + h + 
                i)\)\ , \[IndentingNewLine]\((\((a - b - d + f + h - i)\)\^2 \
+ \((b - c + d - e + i - g)\)\^2 + \((\(-a\) + c + e - f + g - h)\)\^2)\)/
              2, \((\((a - b + e - f - g + i)\)\^2 + \((b - c - d + f + g - \
h)\)\^2 + \((a - c - d + e - h + i)\)\^2)\)/
              2, \((\((a - b + d - e + g - h)\)\^2 + \((b - c + e - f + h - \
i)\)\^2 + \((c - a + f - d + i - g)\)\^2)\)/
              2, \((\((a + b + c - d - e - f)\)\^2 + \((d + e + f - g - h - \
i)\)\^2 + \((a + b + c - g - h - i)\)\^2)\)/2}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_}, "\<C3C3\>"] := {a + b + 
            c + d + e + f + g + h + 
            i, \((\((a - b - d + f + h - i)\)\^2 + \((b - c + d - e + i - \
g)\)\^2 + \((\(-a\) + c + e - f + g - h)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
            2\ a - b - c - d - e + 2\ f - g + 2\ h - 
              i, \(-Sqrt[3]\) \((b - c + d - e + i - 
                  g)\)], \[IndentingNewLine]\((\((a - b + e - f - g + i)\)\^2 \
+ \((b - c - d + f + g - h)\)\^2 + \((a - c - d + e - h + i)\)\^2)\)/
            2, \[IndentingNewLine]ArcTan[
            2\ a - b - c - d + 2\ e - f - g - h + 
              2\ i, \(-Sqrt[3]\) \((b - c - d + f + g - 
                  h)\)], \[IndentingNewLine]\((\((a - b + d - e + g - h)\)\^2 \
+ \((b - c + e - f + h - i)\)\^2 + \((c - a + f - d + i - g)\)\^2)\)/
            2, \[IndentingNewLine]ArcTan[
            2\ a - b - c + 2\ d - e - f + 2\ g - h - 
              i, \(-Sqrt[3]\) \((b - c + e - f + h - 
                  i)\)], \[IndentingNewLine]\((\((a + b + c - d - e - f)\)\^2 \
+ \((d + e + f - g - h - i)\)\^2 + \((a + b + c - g - h - i)\)\^2)\)/
            2, \[IndentingNewLine]ArcTan[
            2\ a + 2\ b + 2\ c - d - e - f - g - h - 
              i, \(-Sqrt[3]\) \((d + e + f - g - h - i)\)]};\)\), "\n", 
    \(toVec[{\[Alpha]_, \[Zeta]2_, \[Theta]_, \[Eta]2_, \[CurlyTheta]_, \
\[Kappa]2_, \[CurlyKappa]_, \[Lambda]2_, \[Phi]_}, "\<C3C3\>"] := 
      Module[{\[Zeta] = \@\[Zeta]2, \[Eta] = \@\[Eta]2, \[Kappa] = \
\@\[Kappa]2, \[Lambda] = \@\[Lambda]2}, \[IndentingNewLine]{\ \ \[Alpha] + 
              2  \[Zeta]\ Cos[\[Theta]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
              2  \[Eta]\ Cos[\[CurlyTheta]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
              2  \[Kappa]\ Cos[\[CurlyKappa]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
              2  \[Lambda]\ Cos[\[Phi]], \ \[Alpha] + 
              2  \[Zeta]\ Cos[\[Theta] + 2  \[Pi]/3] + 
              2  \[Eta]\ Cos[\[CurlyTheta] + 2  \[Pi]/3] + 
              2  \[Kappa]\ Cos[\[CurlyKappa] + 2  \[Pi]/3] + 
              2  \[Lambda]\ Cos[\[Phi]], \[IndentingNewLine]\[Alpha] + 
              2  \[Zeta]\ Cos[\[Theta] + 4  \[Pi]/3] + 
              2  \[Eta]\ Cos[\[CurlyTheta] + 4  \[Pi]/3] + 
              2  \[Kappa]\ Cos[\[CurlyKappa] + 4  \[Pi]/3] + 
              2  \[Lambda]\ Cos[\[Phi]], \[Alpha] + 
              2  \[Zeta]\ Cos[\[Theta] + 2  \[Pi]/3] + 
              2  \[Eta]\ Cos[\[CurlyTheta] + 4  \[Pi]/3] + 
              2  \[Kappa]\ Cos[\[CurlyKappa]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
              2  \[Lambda]\ Cos[\[Phi] + 
                    2  \[Pi]/3], \[IndentingNewLine]\[Alpha] + 
              2  \[Zeta]\ Cos[\[Theta] + 4  \[Pi]/3] + 
              2  \[Eta]\ Cos[\[CurlyTheta]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
              2  \[Kappa]\ Cos[\[CurlyKappa] + 2  \[Pi]/3] + 
              2  \[Lambda]\ Cos[\[Phi] + 2  \[Pi]/3], \ \[Alpha] + 
              2  \[Zeta]\ Cos[\[Theta]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
              2  \[Eta]\ Cos[\[CurlyTheta] + 2  \[Pi]/3] + 
              2  \[Kappa]\ Cos[\[CurlyKappa] + 4  \[Pi]/3] + 
              2  \[Lambda]\ Cos[\[Phi] + 
                    2  \[Pi]/3], \[IndentingNewLine]\[Alpha] + 
              2  \[Zeta]\ Cos[\[Theta] + 4  \[Pi]/3] + 
              2  \[Eta]\ Cos[\[CurlyTheta] + 2  \[Pi]/3] + 
              2  \[Kappa]\ Cos[\[CurlyKappa]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
              2  \[Lambda]\ Cos[\[Phi] + 4  \[Pi]/3], \ \[Alpha] + 
              2  \[Zeta]\ Cos[\[Theta]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
              2  \[Eta]\ Cos[\[CurlyTheta] + 4  \[Pi]/3] + 
              2  \[Kappa]\ Cos[\[CurlyKappa] + 2  \[Pi]/3] + 
              2  \[Lambda]\ Cos[\[Phi] + 4  \[Pi]/3], \ \[Alpha] + 
              2  \[Zeta]\ Cos[\[Theta] + 2  \[Pi]/3] + 
              2  \[Eta]\ Cos[\[CurlyTheta]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + 
              2  \[Kappa]\ Cos[\[CurlyKappa] + 4  \[Pi]/3] + 
              2  \[Lambda]\ Cos[\[Phi] + 4  \[Pi]/3]}/9]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0],

Cell[BoxData[{
    \(\(sh["\<C6C3c\>"] := 
        Module[{}, gi = {1, 3, 2, 9, 8, 7, 6, 5, 4, 1, 1, 1, 1, 1}; 
          gp = {1, 1, 1, 1, 1, 1, 0. , 1, 0. , 1, 0. , 1, 0.  (*?*) }; 
          plex =. ; {a + b + c - d + e + f + g + h - 
              i, \[IndentingNewLine]\ \((\((a + b + c + d - e - f)\)\^2 + \
\((a + b + c - g - h + i)\)\^2 + \((\(-d\) + e + f - g - h + i)\)\^2)\)/
              2, \ \((\((a - c + d + e - g + h)\)\^2 + \((b - c + d + f - g - \
i)\)\^2 + \((a - b + e - f + h + i)\)\^2)\)/
              2, \ \((\((a - b + d + f + g - h)\)\^2 + \((a - c - e + f + g + \
i)\)\^2 + \((b - c - d - e + h + i)\)\^2)\)/
              2, \((\((b - c + e - f + g - h)\)\^2 + \((a - b - d - e - g - \
i)\)\^2 + \((a - c - d - f - h - i)\)\^2)\)/2}];\)\), "\n", 
    \( (*\(sh["\<C9C3j\>"] := 
          Module[{}, 
            gi = {1, 3, 2, \(-7\), \(-9\), \(-8\), \(-4\), \(-6\), \(-5\), 1, 
                1, 1, 1, 1}; 
            gp = {1, 1, 1, 1, 1, 1, 0. , 1, 0. , 1, 0. , 1, 0.  (*?*) }; 
            plex =. ; {a + b + c - d - e - f + g + h + 
                i, \[IndentingNewLine]\((\((a - b - d + e + g - h)\)\^2 + \
\((a - c - d + f + g - i)\)\^2 + \((b - c - e + f + h - i)\)\^2)\)/
                2, \ \((\((b - c + d - f + g - h)\)\^2 + \((a - b - e + f - g \
+ i)\)\^2 + \((a - c + d - e - h + i)\)\^2)\)/
                2, \ \((\((a - c + e - f - g + h)\)\^2 + \((b - c - d + e - g \
+ i)\)\^2 + \((a - b + d - f + h - i)\)\^2)\)/
                2, \((\((a + b + c + d + e + f)\)\^2 + \((d + e + f + g + h + \
i)\)\^2 + \((a + b + c - g - h - i)\)\^2)\)/2}];\)*) \)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".10 Shapes, Polar-Vector, Hyperbolics, ",
  StyleBox["sh, toPol, toVec, tohyPol, tohyVec ",
    FontSlant->"Italic"],
  "for 12 element loops."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(sh["\<C3C4\>"] := 
        Module[{}, \[IndentingNewLine]gi = {1, 3, 2, 10, 12, 11, 7, 9, 8, 4, 
              6, 5, 1, 1, 1, 1, 1, 1, 1}; \[IndentingNewLine]gp = {1, 1, 1, 
              0. , 1, 0. , 1, 0. , 1, 0. , 1, 0. }; 
          plex = {a, c, b, d, f, e, g, i, h, j, l, k}; {a + b + c + d + e + 
              f + g + h + i + j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - 
              l, \[IndentingNewLine]\((a + b + c - g - h - i)\)\^2 + \((d + e \
+ f - j - k - l)\)\^2, \n\t\((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - \
c + e - f + h - i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + \
l)\)\^2)\)/
              2, \[IndentingNewLine]\((\((a - b - d + e + g - h - j + k)\)\^2 \
+ \((b - c - e + f + h - i - k + l)\)\^2 + \((\(-a\) + c + d - f - g + i + j \
- l)\)\^2)\)/
              2, \((\((\((a + b - 2  c - g - h + 2  i)\) r3 - d + e + j - \
k)\)\^2 + \((a - b - g + h + \((d + e - 2  f - j - k + 2  l)\) r3)\)\^2)\) 
              3/4, \((\((\((a + b - 2  c - g - h + 2  i)\) r3 + d - e - j + \
k)\)\^2 + \((a - b - g + h - \((d + e - 2  f - j - k + 2  l)\) r3)\)\^2)\) 
              3/4}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(toVec[{\[Alpha]_, \[Beta]_, \[Epsilon]\[Epsilon]_, \[Sigma]_, \[Zeta]\
\[Zeta]_, \[Tau]_, \[Lambda]\[Lambda]_, \[Phi]_, \[Eta]\[Eta]_, \[Chi]_, \
\[Kappa]\[Kappa]_, \[Psi]_}, "\<C3C4\>"] := \[IndentingNewLine]Module[{\
\[Epsilon] = 2 \@ \[Epsilon]\[Epsilon], \[Zeta] = 
              2 \@ \[Zeta]\[Zeta], \[Lambda] = 
              2 \@ \[Lambda]\[Lambda], \[Eta] = \@\(3  \[Eta]\[Eta]\), \
\[Kappa] = \@\(3  \[Kappa]\[Kappa]\), x = \[Chi] + \[Pi]/6, 
            y = \[Psi] + \[Pi]/
                  6}, \[IndentingNewLine]{\[Alpha] + \[Beta] + \[Epsilon]\ \
Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau]] + \[Lambda]\ Cos[\[Phi]] + \[Eta]\ Cos[
                    x] + \[Eta]\ r3\ Sin[x] + \[Kappa]\ Cos[
                    y] + \[Kappa]\ r3\ Sin[
                    y], \[IndentingNewLine]\[Alpha] + \[Beta] + \[Epsilon]\ \
Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ Cos[\[Phi] + \
\[Omega]] - \[Eta]\ Cos[x] + \[Eta]\ r3\ Sin[x] - \[Kappa]\ Cos[
                    y] + \[Kappa]\ r3\ Sin[
                    y], \[IndentingNewLine]\[Alpha] + \[Beta] + \[Epsilon]\ \
Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \
\[Omega]] - 2  \[Eta]\ r3\ Sin[x] - 
                2  \[Kappa]\ r3\ Sin[
                    y], \[IndentingNewLine]\[Alpha] - \[Beta] + \[Epsilon]\ \
Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]] - \[Lambda]\ Cos[\[Phi]] + \[Eta]\ r3\ \
Cos[x] - \[Eta]\ Sin[x] - \[Kappa]\ r3\ Cos[y] + \[Kappa]\ Sin[
                    y], \[IndentingNewLine]\[Alpha] - \[Beta] + \[Epsilon]\ \
Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ Cos[\[Phi] + \
\[Omega]] + \[Eta]\ r3\ Cos[x] + \[Eta]\ Sin[x] - \[Kappa]\ r3\ Cos[
                    y] - \[Kappa]\ Sin[
                    y], \[IndentingNewLine]\[Alpha] - \[Beta] + \[Epsilon]\ \
Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ Cos[\[Phi] - \
\[Omega]] - 2  \[Eta]\ r3\ Cos[x] + 
                2  \[Kappa]\ r3\ Cos[
                    y], \[IndentingNewLine]\[Alpha] + \[Beta] - \[Epsilon]\ \
Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau]] + \[Lambda]\ Cos[\[Phi]] - \[Eta]\ Cos[
                    x] - \[Eta]\ r3\ Sin[x] - \[Kappa]\ Cos[
                    y] - \[Kappa]\ r3\ Sin[
                    y], \[IndentingNewLine]\[Alpha] + \[Beta] - \[Epsilon]\ \
Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ Cos[\[Phi] + \
\[Omega]] + \[Eta]\ Cos[x] - \[Eta]\ r3\ Sin[x] + \[Kappa]\ Cos[
                    y] - \[Kappa]\ r3\ Sin[
                    y], \[IndentingNewLine]\[Alpha] + \[Beta] - \[Epsilon]\ \
Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \
\[Omega]] + 2  \[Eta]\ r3\ Sin[x] + 
                2  \[Kappa]\ r3\ Sin[
                    y], \[IndentingNewLine]\[Alpha] - \[Beta] - \[Epsilon]\ \
Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]] - \[Lambda]\ Cos[\[Phi]] - \[Eta]\ r3\ \
Cos[x] + \[Eta]\ Sin[x] + \[Kappa]\ r3\ Cos[y] - \[Kappa]\ Sin[
                    y], \[IndentingNewLine]\[Alpha] - \[Beta] - \[Epsilon]\ \
Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ Cos[\[Phi] + \
\[Omega]] - \[Eta]\ r3\ Cos[x] - \[Eta]\ Sin[x] + \[Kappa]\ r3\ Cos[
                    y] + \[Kappa]\ Sin[
                    y], \[IndentingNewLine]\[Alpha] - \[Beta] - \[Epsilon]\ \
Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ Cos[\[Phi] - \
\[Omega]] + 2  \[Eta]\ \ r3\ Cos[x] - 2  \[Kappa]\ r3\ Cos[y]}/
            12];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontSize->9],

Cell["\<\
Note that {\[Epsilon],\[Sigma]} defines 4-phases, {\[Zeta],\[Tau]} 3 phases, \
{\[Lambda],\[Phi]} 6 phases and both {\[Eta],\[Chi]} and {\[Kappa],\[Psi]} 12 \
phases. The {\[Eta],\[Chi]} and {\[Kappa],\[Psi]} systems are shown by the \
following plots:-\
\>", "Text"],

Cell[BoxData[{
    \(\(vv := 
        toVec[{0, 0, 0, 0, 0, 0, 0, 0, 36, \[Chi], 0, 
            0}, "\<C3C4\>"];\)\), "\n", 
    \(Plot[{vv[\([1]\)], vv[\([2]\)], vv[\([3]\)], vv[\([4]\)], vv[\([5]\)], 
        vv[\([6]\)], vv[\([7]\)], vv[\([8]\)], vv[\([9]\)], vv[\([10]\)], 
        vv[\([11]\)], vv[\([12]\)]}, {\[Chi], 0, 2  Pi}]; 
    vv := toVec[{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
          36, \[Psi]}, "\<C3C4\>"];\), "\n", 
    \(\(Plot[{vv[\([1]\)], vv[\([2]\)], vv[\([3]\)], vv[\([4]\)], 
          vv[\([5]\)], vv[\([6]\)], vv[\([7]\)], vv[\([8]\)], vv[\([9]\)], 
          vv[\([10]\)], vv[\([11]\)], vv[\([12]\)]}, {\[Psi], 0, 
          2  Pi}];\)\)}], "Input",
  FontSize->9],

Cell["\<\
Six of the 12 phases cancel if {\[Eta],\[Chi]} = {\[Kappa],\[Psi]} \
(displacement introduced to separate phases):-\
\>", "Text"],

Cell[BoxData[{
    \(\(vv := 
        toVec[{0, 0, 0, 0, 0, 0, 0, 0, 1, \[Chi], 
            1, \[Chi]}, "\<C3C4\>"];\)\), "\n", 
    \(\(Plot[{vv[\([1]\)], vv[\([2]\)] +  .01, vv[\([3]\)] +  .02, 
          vv[\([4]\)] +  .03, vv[\([5]\)] +  .04, vv[\([6]\)] +  .05, 
          vv[\([7]\)] +  .06, vv[\([8]\)] +  .07, vv[\([9]\)] +  .08, 
          vv[\([10]\)] +  .09, vv[\([11]\)] +  .1, 
          vv[\([12]\)] +  .11}, {\[Chi], 0, 2  Pi}];\)\)}], "Input",
  FontSize->9],

Cell[BoxData[
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, 
            l_}, "\<C3C4\>"] := \[IndentingNewLine]Module[{\[Epsilon], 
            r = \(-Sqrt[3]\), e1 = a + b + c - g - h - i, 
            e2 = d + e + f - j - k - l, \[IndentingNewLine]a1 = 
              a - b + d - e + g - h + j - k, 
            a2 = a - b - d + e + g - h - j + k, \[IndentingNewLine]b1 = 
              Chop[FullSimplify[b - c + e - f + h - i + k - l]], 
            b2 = Chop[
                FullSimplify[
                  b - c - e + f + h - i - k + l]], \[IndentingNewLine]c1 = 
              c - a + f - d + i - g + l - j, 
            c2 = c - a - f + d + i - g - l + j, 
            f1 = a - b - g + 
                h + \((d + e - 2\ f - j - k + 2  l)\) 
                  r3, \[IndentingNewLine]f2 = \((a + b - 2  c - g - h + 
                      2  i)\) r3 - d + e + j - k, \[IndentingNewLine]f3 = 
              a - b - g + 
                h - \((d + e - 2\ f - j - k + 2  l)\) 
                  r3, \[IndentingNewLine]f4 = \((a + b - 2  c - g - h + 
                      2  i)\) r3 + d - e - j + 
                k}, \[IndentingNewLine]Chop[{a + b + c + d + e + f + g + h + 
                i + j + k + l, 
              a + b + c - d - e - f + g + h + i - j - k - 
                l, \[IndentingNewLine]\[Epsilon] = e1\^2 + e2\^2, 
              If[\[Epsilon] == 0 && e2 \[Equal] 0, 0, ArcTan[e1, e2], 
                ArcTan[e1, 
                  e2]], \[IndentingNewLine]\((a1\^2 + b1\^2 + c1\^2)\)/2, 
              If[b1 \[Equal] 0, 0, 
                ArcTan[a1 - c1, 
                  r\ b1]], \[IndentingNewLine]\((a2\^2 + b2\^2 + c2\^2)\)/2, 
              If[b2 \[Equal] 0, 0, 
                ArcTan[a2 - c2, 
                  r\ b2]], \[IndentingNewLine]\((f1\^2 + f2\^2)\) 3/4, 
              If[f2 \[Equal] 0, \(-\[Pi]\)/6, 
                ArcTan[f1, f2] - \[Pi]/6], \[IndentingNewLine]\((f3\^2 + 
                    f4\^2)\) 3/4, 
              If[f4 \[Equal] 0, \(-\[Pi]\)/6, 
                ArcTan[f3, f4] - \[Pi]/6]}]];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[{
    \(\(sh["\<C3K\>"] := 
        Module[{}, 
          gi = {1, 3, 2, 4, 6, 5, 7, 9, 8, 10, 12, 11, 1, 1, 1, 1, 1, 1, 1, 
              1}; \[IndentingNewLine]gp = {1, 1, 1, 1, 1, 0. , 1, 0. , 1, 
              0. , 1, 0. }; 
          plex = {a, b, c, \(-d\), \(-e\), \(-f\), g, h, 
              i, \(-j\), \(-k\), \(-l\)}; \[IndentingNewLine]{a + b + c + d + 
              e + f + g + h + i + j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - 
              l, \[IndentingNewLine]a + b + c + d + e + f - g - h - i - j - 
              k - l, a + b + c - d - e - f - g - h - i + j + k + 
              l, \n\t\((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e \
- f + h - i + k - l)\)\^2 + \((c - a + f - d + i - g + l - j)\)\^2)\)/
              2, \((\((a - b - d + e + g - h - j + k)\)\^2 + \((b - c - e + f \
+ h - i - k + l)\)\^2 + \((c - a - f + d + i - g - l + j)\)\^2)\)/
              2, \((\((a - b + d - e - g + h - j + k)\)\^2 + \((b - c + e - f \
- h + i - k + l)\)\^2 + \((c - a + f - d - i + g - l + j)\)\^2)\)/
              2, \((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - c - e + f \
- h + i + k - l)\)\^2 + \((c - a - f + d - i + g + l - j)\)\^2)\)/
              2}];\)\), "\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_}, "\<C3K\>"] := 
        Module[{r = \(-Sqrt[3]\), a1 = a - b + d - e + g - h + j - k, 
            a2 = a - b - d + e + g - h - j + k, \[IndentingNewLine]a3 = 
              a - b + d - e - g + h - j + k, 
            a4 = a - b - d + e - g + h + j - k, \[IndentingNewLine]b1 = 
              Chop[FullSimplify[b - c + e - f + h - i + k - l]], 
            b2 = Chop[
                FullSimplify[
                  b - c - e + f + h - i - k + l]], \[IndentingNewLine]b3 = 
              Chop[FullSimplify[b - c + e - f - h + i - k + l]], 
            b4 = Chop[
                FullSimplify[
                  b - c - e + f - h + i + k - l]], \[IndentingNewLine]c1 = 
              c - a + f - d + i - g + l - j, 
            c2 = c - a - f + d + i - g - l + j, \[IndentingNewLine]c3 = 
              c - a + f - d - i + g - l + j, 
            c4 = c - a - f + d - i + g + l - j}, \[IndentingNewLine]Chop[{a + 
                b + c + d + e + f + g + h + i + j + k + l, 
              a + b + c - d - e - f + g + h + i - j - k - 
                l, \[IndentingNewLine]a + b + c + d + e + f - g - h - i - j - 
                k - l, 
              a + b + c - d - e - f - g - h - i + j + k + 
                l, \[IndentingNewLine]\((a1\^2 + b1\^2 + c1\^2)\)/2, 
              If[b1 \[Equal] 0, 0, 
                ArcTan[a1 - c1, 
                  r\ b1]], \[IndentingNewLine]\((a2\^2 + b2\^2 + c2\^2)\)/2, 
              If[b2 \[Equal] 0, 0, 
                ArcTan[a2 - c2, 
                  r\ b2]], \[IndentingNewLine]\((a3\^2 + b3\^2 + c3\^2)\)/2, 
              If[b3 \[Equal] 0, 0, 
                ArcTan[a3 - c3, 
                  r\ b3]], \[IndentingNewLine]\((a4\^2 + b4\^2 + c4\^2)\)/2, 
              If[b4 \[Equal] 0, 0, ArcTan[a4 - c4, r\ b4]]}]];\)\)}], "Input",\

  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0,
  FontSize->9],

Cell[BoxData[
    \(toVec[{\[Alpha]_, \[Beta]_, \[Gamma]_, \[Delta]_, \[Zeta]\[Zeta]_, \
\[Tau]_, \[Lambda]\[Lambda]_, \[Phi]_, \[Eta]\[Eta]_, \[Chi]_, \[Kappa]\
\[Kappa]_, \[Psi]_}, "\<C3K\>"] := \[IndentingNewLine]Module[{\[Zeta] = 
            2 \@ \[Zeta]\[Zeta], \[Lambda] = 
            2 \@ \[Lambda]\[Lambda], \[Eta] = 2 \@ \[Eta]\[Eta], \[Kappa] = 
            2 \@ \[Kappa]\[Kappa]}, \[IndentingNewLine]{\ \ \[Alpha] + \
\[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \  + \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  + \[Kappa]\ \
Cos[\[Psi]], \[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[Eta]\ \
Cos[\[Chi] + \[Omega]] + \[Kappa]\ Cos[\[Psi] + \[Omega]], \ \
\[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \
\[Omega]] + \[Kappa]\ Cos[\[Psi] - \[Omega]], \[IndentingNewLine]\[Alpha] - \
\[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \  + \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - \[Kappa]\ \
Cos[\[Psi]]\ , \[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[Eta]\ \
Cos[\[Chi] + \[Omega]] - \[Kappa]\ Cos[\[Psi] + \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] - \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \
\[Omega]] - \[Kappa]\ Cos[\[Psi] - \[Omega]], \[IndentingNewLine]\[Alpha] + \
\[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - \[Kappa]\ \
Cos[\[Psi]]\ , \[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Eta]\ \
Cos[\[Chi] + \[Omega]] - \[Kappa]\ Cos[\[Psi] + \[Omega]], \
\[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \
\[Omega]] - \[Kappa]\ Cos[\[Psi] - \[Omega]], \[IndentingNewLine]\[Alpha] - \
\[Beta] - \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  + \[Kappa]\ \
Cos[\[Psi]]\ , \[IndentingNewLine]\[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Eta]\ \
Cos[\[Chi] + \[Omega]] + \[Kappa]\ Cos[\[Psi] + \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] - \[Lambda]\ Cos[\[Phi] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \
\[Omega]] + \[Kappa]\ Cos[\[Psi] - \[Omega]]}/12]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontSize->9],

Cell["\<\
Note that in C3K,  {\[Zeta],\[Tau]} defines 3 phases, {\[Lambda],\[Phi]} {\
\[Eta],\[Chi]} and {\[Kappa],\[Psi]} 6 phases in different sequences. 12 \
equal phases arise if {\[Eta],\[Chi]} = {\[Kappa],\[Psi]+\[Pi]/2}. These \
systems are shown by the following plots:-\
\>", "Text"],

Cell[BoxData[{
    \(\(vv := 
        toVec[{0, 0, 0, 0, 1, \[Tau], 0, 0, 0, 0, 0, 
            0}, "\<C3K\>"];\)\), "\n", 
    \(\(Plot[{vv[\([1]\)], vv[\([2]\)], vv[\([3]\)], vv[\([4]\)], 
          vv[\([5]\)], vv[\([6]\)], vv[\([7]\)], vv[\([8]\)], vv[\([9]\)], 
          vv[\([10]\)], vv[\([11]\)], vv[\([12]\)]}, {\[Tau], 0, 
          2  \[Pi]}];\)\), "\n", 
    \(\(vv := 
        toVec[{0, 0, 0, 0, 0, 0, 1, \[Phi], 0, 0, 0, 
            0}, "\<C3K\>"];\)\), "\n", 
    \(\(Plot[{vv[\([1]\)], vv[\([2]\)], vv[\([3]\)], vv[\([4]\)], 
          vv[\([5]\)], vv[\([6]\)], vv[\([7]\)], vv[\([8]\)], vv[\([9]\)], 
          vv[\([10]\)], vv[\([11]\)], vv[\([12]\)]}, {\[Phi], 0, 
          2  \[Pi]}];\)\), "\n", 
    \(\(vv := 
        toVec[{0, 0, 0, 0, 0, 0, 0, 0, 1, \[Eta], 0, 
            0}, "\<C3K\>"];\)\), "\n", 
    \(\(Plot[{vv[\([1]\)], vv[\([2]\)], vv[\([3]\)], vv[\([4]\)], 
          vv[\([5]\)], vv[\([6]\)], vv[\([7]\)], vv[\([8]\)], vv[\([9]\)], 
          vv[\([10]\)], vv[\([11]\)], vv[\([12]\)]}, {\[Eta], 0, 
          2  \[Pi]}];\)\), "\n", 
    \(\(vv := 
        toVec[{0, 0, 0, 0, 0, 0, 0, 0, 1, \[Psi], 
            1, \[Psi] + \[Pi]/2}, "\<C3K\>"];\)\), "\n", 
    \(\(Plot[{vv[\([1]\)], vv[\([2]\)], vv[\([3]\)], vv[\([4]\)], 
          vv[\([5]\)], vv[\([6]\)], vv[\([7]\)], vv[\([8]\)], vv[\([9]\)], 
          vv[\([10]\)], vv[\([11]\)], vv[\([12]\)]}, {\[Psi], 0, 
          2  \[Pi]}];\)\)}], "Input",
  FontSize->9],

Cell[BoxData[{
    \(\(sh["\<Q12\>"] := 
        Module[{}, 
          gi = {1, 3, 2, 10, 11, 12, 7, 9, 8, 4, 5, 6, 1, 1, 1, 2, 
              2}; \[IndentingNewLine]gp = {1, 1, 1, 0. , 1, 0. , 1, 0. , 1, 
              0. , 1, 0. }; 
          plex =. ; \[IndentingNewLine]{a + b + c + d + e + f + g + h + i + 
              j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - 
              l, \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - l)\)\
\^2, \n\((\((\(-b\) + c - h + i)\)\^2 + \((a - c + g - i)\)\^2 + \((a - b + g \
- h)\)\^2 - \((\(-e\) + f - k + l)\)\^2 - \((d - f + j - l)\)\^2 - \((d - e + \
j - k)\)\^2)\)/
              2, \n\((\((\(-b\) + c + h - i)\)\^2 + \((a - c - g + i)\)\^2 + \
\((a - b - g + h)\)\^2 + \((\(-e\) + f + k - l)\)\^2 + \((d - f - j + l)\)\^2 \
+ \((d - e - j + k)\)\^2)\)/2}];\)\), "\n", 
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_}, "\<Q12\>"] := 
        Module[{\[Epsilon], r = \(-Sqrt[3]\), g1 = a + b + c - g - h - i, 
            g2 = d + e + f - j - k - l, \[IndentingNewLine]a1 = 
              a - b + g - h, 
            a2 = a - b - g + h, \[IndentingNewLine]b1 = 
              Chop[FullSimplify[b - c + h - i]], 
            b2 = Chop[
                FullSimplify[
                  b - c - h + i]], \[IndentingNewLine]c1 = \(-a\) + c - g + 
                i, c2 = \(-a\) + c + g - i, \[IndentingNewLine]d1 = 
              d - e + j - k, 
            d2 = d - e - j + k, \[IndentingNewLine]e1 = 
              Chop[FullSimplify[e - f + k - l]], 
            e2 = Chop[
                FullSimplify[
                  e - f - k + l]], \[IndentingNewLine]f1 = \(-d\) + f - j + 
                l, f2 = \(-d\) + f + j - l}, \[IndentingNewLine]Chop[{a + b + 
                c + d + e + f + g + h + i + j + k + l, 
              a + b + c - d - e - f + g + h + i - j - k - 
                l, \[IndentingNewLine]\[Epsilon] = g1\^2 + g2\^2, 
              If[\[Epsilon] == 0 && g2 \[Equal] 0, 0, ArcTan[g1, g2], 
                ArcTan[g1, 
                  g2]], \[IndentingNewLine]\((a1\^2 + b1\^2 + c1\^2)\)/2, 
              If[b1 \[Equal] 0, 0, 
                ArcTan[a1 - c1, 
                  r\ b1]], \[IndentingNewLine]\((d1\^2 + e1\^2 + f1\^2)\)/2, 
              If[e1 \[Equal] 0, 0, 
                ArcTan[d1 - f1, 
                  r\ e1]], \[IndentingNewLine]\((a2\^2 + b2\^2 + c2\^2)\)/2, 
              If[b2 \[Equal] 0, 0, 
                ArcTan[a2 - c2, 
                  r\ b2]], \[IndentingNewLine]\((d2\^2 + e2\^2 + f2\^2)\)/2, 
              If[e2 \[Equal] 0, 0, ArcTan[d2 - f2, r\ e2]]}]];\)\)}], "Input",\

  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0,
  FontSize->9],

Cell[BoxData[
    \(\(toVec[{\[Alpha]_, \[Beta]_, \[Epsilon]\[Epsilon]_, \[Sigma]_, \[Zeta]\
\[Zeta]_, \[Tau]_, \[Lambda]\[Lambda]_, \[Phi]_, \[Eta]\[Eta]_, \[Chi]_, \
\[Kappa]\[Kappa]_, \[Psi]_}, "\<Q12\>"] := \[IndentingNewLine]Module[{\
\[Epsilon] = 2 \@ \[Epsilon]\[Epsilon], \[Zeta] = 
              4 \@ \[Zeta]\[Zeta], \[Lambda] = 
              4 \@ \[Lambda]\[Lambda], \[Eta] = 4 \@ \[Eta]\[Eta], \[Kappa] = 
              4 \@ \[Kappa]\[Kappa]}, {\ \ \[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  + \[Eta]\ Cos[\
\[Chi]], \[IndentingNewLine]\[Alpha] + \[Beta] + \[Epsilon]\ \ Cos[\[Sigma]] \
+ \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]], \ \
\[IndentingNewLine]\[Alpha] + \[Beta] + \[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\
\ Cos[\[Tau] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] + \[Epsilon]\ \ Sin[\[Sigma]]\ \  + \
\[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \ \ \  + \[Kappa]\ Cos[\[Psi]]\ , \
\[IndentingNewLine]\[Alpha] - \[Beta] + \[Epsilon]\ \ Sin[\[Sigma]]\ \  + \
\[Lambda]\ Cos[\[Phi] + \[Omega]]\ \  + \[Kappa]\ Cos[\[Psi] + \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] + \[Epsilon]\ \ Sin[\[Sigma]]\ \  + \
\[Lambda]\ Cos[\[Phi] - \[Omega]]\ \  + \[Kappa]\ Cos[\[Psi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] + \[Beta] - \[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\
\ Cos[\[Tau]]\ \ \ \ \  - \[Eta]\ Cos[\[Chi]]\ \ , \
\[IndentingNewLine]\[Alpha] + \[Beta] - \[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\
\ Cos[\[Tau] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \[Omega]], \
\[IndentingNewLine]\[Alpha] + \[Beta] - \[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\
\ Cos[\[Tau] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] - \[Epsilon]\ \ Sin[\[Sigma]]\ \  + \
\[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \ \ \  - \[Kappa]\ Cos[\[Psi]]\ , \
\[IndentingNewLine]\[Alpha] - \[Beta] - \[Epsilon]\ \ Sin[\[Sigma]]\ \  + \
\[Lambda]\ Cos[\[Phi] + \[Omega]]\ \  - \[Kappa]\ Cos[\[Psi] + \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] - \[Epsilon]\ \ Sin[\[Sigma]]\ \  + \
\[Lambda]\ Cos[\[Phi] - \[Omega]]\ \  - \[Kappa]\ Cos[\[Psi] - \[Omega]]}/
            12];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(sh["\<D3C2\>"] := 
        Module[{}, 
          gi = {1, 3, 2, 4, 5, 6, 7, 9, 8, 10, 11, 12, 1, 1, 1, 1, 2, 
              2}; \[IndentingNewLine]gp = {1, 1, 1, 1, 1, 0. , 1, 0. , 1, 
              0. , 1, 0. }; 
          plex =. ; \[IndentingNewLine]{a + b + c + d + e + f + g + h + i + 
              j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - 
              l, \[IndentingNewLine]a + b + c + d + e + f - g - h - i - j - 
              k - l, a + b + c - d - e - f - g - h - i + j + k + 
              l, \n\t\((\((a - b + g - 
                        h)\)^2 + \((b - c + h - i)\)\^2 + \((\(-a\) + c - g + \
i)\)\^2 - \n\t\ \((\(-d\) + e - j + k)\)\^2 - \((\(-e\) + f - k + l)\)\^2 - \
\((d - f + j - l)\)\^2)\)/
              2, \n\t\((\((a - b - g + h)\)\^2 + \((b - c - h + i)\)\^2 + \((\
\(-a\) + c + g - i)\)\^2 - \n\t\ \ \ \((\(-d\) + e + j - k)\)\^2 - \((\(-e\) \
+ f + k - l)\)\^2 - \((d - f - j + l)\)\^2)\)/2}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0,
  FontSize->9],

Cell[BoxData[
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_}, "\<D3C2\>"] := 
        Module[{r = \(-Sqrt[3]\), a1 = a - b + g - h, 
            a2 = \(-d\) + e - j + k, a3 = a - b - g + h, 
            a4 = \(-d\) + e + j - k, \[IndentingNewLine]b1 = 
              Chop[FullSimplify[b - c + h - i]], 
            b2 = Chop[
                FullSimplify[\(-e\) + f - k + l]], \[IndentingNewLine]b3 = 
              Chop[FullSimplify[b - c - h + i]], 
            b4 = Chop[
                FullSimplify[\(-e\) + f + k - 
                    l]], \[IndentingNewLine]c1 = \(-a\) + c - g + i, 
            c2 = d - f + j - l, c3 = \(-a\) + c + g - i, 
            c4 = d - f - j + l}, \[IndentingNewLine]Chop[{a + b + c + d + e + 
                f + g + h + i + j + k + l, 
              a + b + c - d - e - f + g + h + i - j - k - 
                l, \[IndentingNewLine]a + b + c + d + e + f - g - h - i - j - 
                k - l, a + b + c - d - e - f - g - h - i + j + k + 
                l, \[IndentingNewLine]\((a1\^2 + b1\^2 + c1\^2)\)/2, 
              If[b1 \[Equal] 0, 0, 
                ArcTan[a1 - c1, 
                  r\ b1]], \[IndentingNewLine]\((a2\^2 + b2\^2 + c2\^2)\)/2, 
              If[b2 \[Equal] 0, 0, 
                ArcTan[a2 - c2, 
                  r\ b2]], \[IndentingNewLine]\((a3\^2 + b3\^2 + c3\^2)\)/2, 
              If[b3 \[Equal] 0, 0, 
                ArcTan[a3 - c3, 
                  r\ b3]], \[IndentingNewLine]\((a4\^2 + b4\^2 + c4\^2)\)/2, 
              If[b4 \[Equal] 0, 0, ArcTan[a4 - c4, r\ b4]]}]];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(toVec[{\[Alpha]_, \[Beta]_, \[Gamma]_, \[Delta]_, \[Zeta]\[Zeta]_, \
\[Tau]_, \[Lambda]\[Lambda]_, \[Phi]_, \[Eta]\[Eta]_, \[Chi]_, \[Kappa]\
\[Kappa]_, \[Psi]_}, "\<D3C2\>"] := \[IndentingNewLine]Module[{\[Zeta] = 
            4 \@ \[Zeta]\[Zeta], \[Lambda] = 
            4 \@ \[Lambda]\[Lambda], \[Eta] = 4 \@ \[Eta]\[Eta], \[Kappa] = 
            4 \@ \[Kappa]\[Kappa]}, {\ \ \ \ \ \ \[IndentingNewLine]\[Alpha] \
+ \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Eta]\ \
Cos[\[Chi]], \[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]], \ \
\[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]], \[IndentingNewLine]\
\[Alpha] - \[Beta] + \[Gamma] - \[Delta] - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  \
- \[Kappa]\ Cos[\[Psi]]\ , \[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \
\[Delta] - \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Kappa]\ Cos[\[Psi] + \
\[Omega]], \[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \[Delta] - \
\[Lambda]\ Cos[\[Phi] - \[Omega]] - \[Kappa]\ Cos[\[Psi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\
\[Tau]]\ \ \ \ \ \  - \[Eta]\ Cos[\[Chi]]\ , \[IndentingNewLine]\[Alpha] + \
\[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Eta]\ \
Cos[\[Chi] + \[Omega]], \[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \
\[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] - \[Gamma] + \[Delta] - \[Lambda]\ Cos[\
\[Phi]]\ \ \ \ \ \  + \[Kappa]\ Cos[\[Psi]]\ , \[IndentingNewLine]\[Alpha] - \
\[Beta] - \[Gamma] + \[Delta] - \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[Kappa]\ \
Cos[\[Psi] + \[Omega]], \[IndentingNewLine]\[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] - \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[Kappa]\ Cos[\[Psi] - \
\[Omega]]}/12]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(sh["\<A4\>"] := 
        Module[{}, gp =. ; plex =. ; 
          gi = {1, 3, 2, 4, 9, 11, 7, 12, 5, 10, 6, 8, 1, 1, 
              3}; \[IndentingNewLine]{a + b + c + d + e + f + g + h + i + j + 
              k + l, \n\t\((\((\(-a\) + c - d + f - g + i - j + l)\)\^2 + \
\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f + h - i + k - \
l)\)\^2)\)/2, \n\t\((a + d - g - j)\)\ \((a - d + g - j)\)\ \((a - d - g + 
                    j)\) + \((b + e - h - k)\)\ \((b - e + h - k)\)\ \((b - 
                    e - h + k)\) - \n\ \ \ \ \ \ \ \ \ \ \ \ \ \t\((a - d + 
                    g - j)\)\ \((b - e - h + k)\)\ \((c + f - i - 
                    l)\) - \((a - d - g + j)\)\ \((b + e - h - k)\)\ \((c - 
                    f + i - l)\) - \[IndentingNewLine]\ \ \ \((a + d - g - 
                    j)\)\ \((b - e + h - k)\)\ \((c - f - i + l)\) + \((c + 
                    f - i - l)\)\ \((c - f + i - l)\)\ \((c - f - i + 
                    l)\)}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0,
  FontSize->9],

Cell[BoxData[
    \(\(sh["\<C3Qr\>"] := 
        Module[{}, \[IndentingNewLine]gp = {1, 1, 1, 0. , 1, 0. , 1, 0. , 1, 
              0. , 1, 0.  (*?*) }; 
          gi = {1, 3, 
              2, \(-4\), \(-6\), \(-5\), \(-7\), \(-9\), \(-8\), \(-10\), \
\(-12\), \(-11\), 2, 2}; {a, c, 
            b, \(-d\), \(-f\), \(-e\), \(-g\), \(-i\), \(-h\), \(-j\), \
\(-l\), \(-k\)}; \[IndentingNewLine]{\((a + b + c)\)\^2 + \((d + e + f)\)\^2 \
+ \((g + h + i)\)\^2 + \((j + k + l)\)\^2, \[IndentingNewLine]\((\((a - \
b)\)\^2 + \((b - c)\)\^2 + \((c - a)\)\^2 + \((d - e)\)\^2 + \((e - f)\)\^2 + \
\((f - d)\)\^2 + \n\t\ \ \ \ \((g - h)\)\^2 + \((h - i)\)\^2 + \((i - g)\)\^2 \
+ \((j - k)\)\^2 + \((k - l)\)\^2 + \((l - j)\)\^2)\)^2/4 - 
              3 \((\((b\ d - c\ d - a\ e + c\ e + a\ f - b\ f)\)\^2 + \((h\ j \
- i\ j - g\ k + i\ k + g\ l - h\ l)\)\^2 + \n\t\((b\ j - c\ j - a\ k + c\ k + \
a\ l - b\ l)\)\^2 + \((b\ g - c\ g - a\ h + c\ h + a\ i - b\ i)\)\^2 + \n\t\
\((e\ g - f\ g - d\ h + f\ h + d\ i - e\ i)\)\^2 + \((\(-e\)\ j + f\ j + d\ k \
- f\ k - d\ l + e\ l)\)\^2)\)}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(sh["\<C3P4\>"] := 
        Module[{}, \[IndentingNewLine]gp = { (*?*) }; 
          gi = {1, 3, 2, 4, 6, 5, 7, 9, 8, 10, 12, 11, 2, 2}; {a, c, 
            b, \(-d\), \(-f\), \(-e\), \(-g\), \(-i\), \(-h\), \(-j\), \
\(-l\), \(-k\)}; \[IndentingNewLine]{\((a + b + c)\)\^2 - \((d + e + f)\)\^2 \
- \((g + h + i)\)\^2 - \((j + k + l)\)\^2, \[IndentingNewLine]\((\((a - \
b)\)\^2 + \((b - c)\)\^2 + \((a - c)\)\^2 - \((d - e)\)\^2 - \((e - f)\)\^2 - \
\((d - f)\)\^2 - \n\t\ \ \ \ \((g - h)\)\^2 - \((h - i)\)\^2 - \((g - i)\)\^2 \
- \((j - k)\)\^2 - \((k - l)\)\^2 - \((j - l)\)\^2)\)^2/4 + 
              3 \((\((b\ d - c\ d - a\ e + c\ e + a\ f - b\ f)\)\^2 - \((h\ j \
- i\ j - g\ k + i\ k + g\ l - h\ l)\)\^2 + \n\t\((b\ j - c\ j - a\ k + c\ k + \
a\ l - b\ l)\)\^2 + \((b\ g - c\ g - a\ h + c\ h + a\ i - b\ i)\)\^2 - \n\t\
\((e\ g - f\ g - d\ h + f\ h + d\ i - e\ i)\)\^2 - \((\(-e\)\ j + f\ j + d\ k \
- f\ k - d\ l + e\ l)\)\^2)\)}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(sh["\<C6Kr\>"] := 
        Module[{}, 
          gi = {1, 3, 2, 4, 6, 5, 7, 9, 8, 10, 12, 11, 1, 1, 1, 1, 1, 1, 1, 
              1}; \[IndentingNewLine]gp = {1, 1, 1, 1, 1, 0. , 1, 0. , 1, 
              0. , 1, 0. }; 
          plex = {a, c, b, d, f, e, g, i, h, j, l, 
              k}; \[IndentingNewLine]{a - b - c + d - e - f + g - h - i + j - 
              k - l, a - b - c - d + e + f - g + h + i + j - k - 
              l, \[IndentingNewLine]a - b - c - d + e + f + g - h - i - j + 
              k + l, a - b - c + d - e - f - g + h + i - j + k + 
              l, \n\t\((\((a + b - d - e - g - h + j + k)\)\^2 + \((b - c - e \
+ f - h + i + k - l)\)\^2 + \((a + c - d - f - g - i + j + l)\)\^2)\)/
              2, \((\((a + b - d - e + g + h - j - k)\)\^2 + \((b - c - e + f \
+ h - i - k + l)\)\^2 + \((a + c - d - f + g + i - j - l)\)\^2)\)/
              2, \((\((a + b + d + e + g + h + j + k)\)\^2 + \((b - c + e - f \
+ h - i + k - l)\)\^2 + \((a + c + d + f + g + i + j + l)\)\^2)\)/
              2, \[IndentingNewLine]\((\((a + b + d + e - g - h - j - k)\)\^2 \
+ \((b - c + e - f - h + i - k + l)\)\^2 + \((a + c + d + f - g - i - j - \
l)\)\^2)\)/2}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[{
    \(\(sh["\<C3KC2r\>"] := 
        Module[{}, 
          gi = {1, 3, 2, 4, 6, 5, 7, 9, 8, 10, 12, 11, 1, 1, 1, 1, 1, 1, 1, 
              1}; \[IndentingNewLine]gp = {1, 1, 1, 1, 1, 0. , 1, 0. , 1, 
              0. , 1, 0. }; 
          plex = {a, c, b, d, f, e, g, i, h, j, l, 
              k}; \[IndentingNewLine]{a + b + c + d + e + f + g - h - i - j - 
              k - l, \[IndentingNewLine]a + b + c - d - e - f - g + h + i - 
              j - k - l, \[IndentingNewLine]a + b + c - d - e - f + g - h - 
              i + j + k + l, \[IndentingNewLine]a + b + c + d + e + f - g + 
              h + i + j + k + 
              l, \n\t\((\((a - b + d - e - g - h + j - k)\)\^2 + \((b - c + e \
- f + h - i + k - l)\)\^2 + \((\(-a\) + c - d + f + g + i - j + l)\)\^2)\)/
              2, \n\t\((\((a - b - d + e + g + h + j - k)\)\^2 + \((b - c - e \
+ f - h + i + k - l)\)\^2 + \((\(-a\) + c + d - f - g - i - j + l)\)\^2)\)/
              2, \((\((a - b - d + e - g - h - j + k)\)\^2 + \((b - c - e + f \
+ h - i - k + l)\)\^2 + \((\(-a\) + c + d - f + g + i + j - l)\)\^2)\)/
              2, \((\((a - b + d - e + g + h - j + k)\)\^2 + \((b - c + e - f \
- h + i - k + l)\)\^2 + \((\(-a\) + c - d + f - g - i + j - l)\)\^2)\)/
              2}];\)\), "\[IndentingNewLine]", 
    \(\(sh["\<Q12C2c\>"] := 
        Module[{}, plex =. ; 
          gi = {1, 6, 5, 4, 3, 
              2, \(-7\), \(-8\), \(-9\), \(-10\), \(-11\), \(-12\), 1, 2, 2, 
              1}; \[IndentingNewLine]gp = {1, 0. , 1, 0. , 1, 0. , 1, 
              0. }; \n\t{\((a - b + c - d + e - f)\)\^2 + \((g - h + i - j + \
k - l)\)\^2, \((\((a - b + d - e)\)\^2 + \((a - c + d - f)\)\^2 + \((b - c + \
e - f)\)\^2 + \((g - h + j - k)\)\^2 + \((g - i + j - l)\)\^2 + \((h - i + k \
- l)\)\^2)\)/
              2, \((\((a + b - d - e)\)\^2 + \((b + c - e - f)\)\^2 + \((a - \
c - d + f)\)\^2 + \((g + h - j - k)\)\^2 + \((h + i - k - l)\)\^2 + \((g - i \
- j + l)\)\^2)\)/
              2, \((a + b + c + d + e + f)\)\^2 + \((g + h + i + j + k + l)\)\
\^2}];\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(sh["\<D3Mn\>"] := 
        Module[{}, gp =. ; 
          gi = {1, 2, 5, 4, 3, 7, \[IndentingNewLine]8, 9, 10, 11, 12, 1, 1, 
              1, 1, 2, 2, 2, 2}; \[IndentingNewLine]{a + b + c + d + e + f - 
              g - h - i - j - k - l, \[IndentingNewLine]a - b + c - d + e - 
              f + g - h + i - j + k - l, \[IndentingNewLine]a - b + c - d + 
              e - f - g + h - i + j - k + l, \[IndentingNewLine]a + b + c + 
              d + e + f + g + h + i + j + k + l, Unknown}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  TextJustification->0,
  FontSize->9],

Cell[BoxData[
    \(\(sh12[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_}] := 
        Module[{ab = a - b - g + h, ag = a - b + g - h, bc = b - c - h + i, 
            bh = b - c + h - i, \[IndentingNewLine]ca = a - c - g + i, 
            ci = a - c + g - i, de = d - e - j + k, 
            dj = d - e + j - k, \[IndentingNewLine]ef = e - f - k + l, 
            ek = e - f + k - l, fd = d - f - j + l, fl = d - f + j - l, 
            f1 = a - b - g + 
                h + \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f2 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 - d + e + j - 
                k, \[IndentingNewLine]f3 = 
              a - b - g + 
                h - \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f4 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 + d - e - j + k, abef, 
            agek}, \[IndentingNewLine]abef = 3 \((ab\ ef - bc\ de)\)\^2; 
          agek = 3 \((ag\ ek - bh\ dj)\)\^2; \[IndentingNewLine]{o1 = 
              a + b + c + d + e + f + g + h + i + j + k + l, 
            o2 = a + b + c - d - e - f + g + h + i - j - k - 
                l, \[IndentingNewLine]o3 = 
              a + b + c + d + e + f - g - h - i - j - k - l, 
            o4 = a + b + c - d - e - f - g - h - i + j + k + 
                l, \[IndentingNewLine] (*5*) l22a = 
              3 \((f1\^2 + f2\^2)\)/4,  (*6*) l22b = 
              3 \((f3\^2 + f4\^2)\)/4, \[IndentingNewLine] (*7*) 
              p22 = \((a + b + c + g + h + i)\)\^2 + \((d + e + f + j + k + \
l)\)\^2,  (*8*) 
              q22 = \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - \
l)\)\^2,  (*9*) 
              r22 = \((a + b + c + g + h + i)\)\^2 - \((d + e + f + j + k + \
l)\)\^2,  (*10*) 
              s22 = \((a + b + c - g - h - i)\)\^2 - \((d + e + f - j - k - \
l)\)\^2, \[IndentingNewLine] (*11*) 
              p23 = \((\((ag + dj)\)\^2 + \((bh + ek)\)\^2 + \((ci + \
fl)\)\^2)\)/2,  (*12*) 
              q23 = \((\((ag - dj)\)\^2 + \((bh - ek)\)\^2 + \((ci - \
fl)\)\^2)\)/2, \[IndentingNewLine] (*13*) 
              r23 = \((\((ab + de)\)\^2 + \((bc + ef)\)\^2 + \((ca + \
fd)\)\^2)\)/2,  (*14*) 
              s23 = \((\((ab - de)\)\^2 + \((bc - ef)\)\^2 + \((ca - \
fd)\)\^2)\)/2, \[IndentingNewLine] (*15*) 
              q24 = \((a + b + c)\)\^2 + \((d + e + f)\)\^2 + \((g + h + i)\)\
\^2 + \((j + k + l)\)\^2, \[IndentingNewLine] (*16*) 
              s24 = \((a + b + c)\)\^2 - \((d + e + f)\)\^2 - \((g + h + i)\)\
\^2 - \((j + k + l)\)\^2, \[IndentingNewLine] (*17*) 
              p26 = \((ag\^2 + bh\^2 + ci\^2 - dj\^2 - fl\^2 - ek\^2)\)/
                2,  (*18*) 
              q26 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)/
                2, \[IndentingNewLine] (*19*) 
              r26 = \((ag\^2 + bh\^2 + ci\^2 + dj\^2 + fl\^2 + ek\^2)\)/
                2,  (*20*) 
              s26 = \((ab\^2 + bc\^2 + ca\^2 + de\^2 + ef\^2 + fd\^2)\)/
                2, \n\ \ \ \ \ \ \ \  (*21*) \ 
            l3 = \((a + d - g - j)\)\ \((a - d + g - j)\)\ \((a - d - g + 
                      j)\) + \((b + e - h - k)\)\ \((b - e + h - k)\)\ \((b - 
                      e - h + k)\) + \[IndentingNewLine]\((c + f - \ i\  - 
                      l)\)\ \((c - f + \ i\  - l)\)\ \((c - f - \ i\  + 
                      l)\) - \((a - d + g - j)\)\ \((b - e - h + k)\)\ \((c + 
                      f - \ i\  - l)\) - \[IndentingNewLine]\((a - d - g + 
                      j)\)\ \((b + e - h - k)\)\ \((c - f + i - l)\) - \((a + 
                      d - g - j)\)\ \((b - e + h - k)\)\ \((c - f - \ i\  + 
                      l)\), \[IndentingNewLine] (*22*) l4p = 
              p26\^2 + agek, \[IndentingNewLine] (*23*) l4q = 
              q26\^2 + abef, \[IndentingNewLine] (*24*) l4r = 
              r26\^2 - 3  agek, \[IndentingNewLine] (*25*) l4s = 
              l22a\ l22b (*s26\^2 - abef*) ,  (*26*) 
              L4Q = \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((a - c)\)\^2 + \
\((d - e)\)\^2 + \((e - f)\)\^2 + \((d - f)\)\^2 + \((g - h)\)\^2 + \
\[IndentingNewLine]\((h - i)\)\^2 + \((g - i)\)\^2 + \((j - k)\)\^2 + \((k - \
l)\)\^2 + \((j - l)\)\^2)\)^2/4 - 
                3\ \((\((a\ \((f - e)\) + b\ \((d - f)\) + c\ \((e - \
d)\))\)\^2 + \((a\ \((i - h)\) + b\ \((g - i)\) + c\ \((h - g)\))\)\^2 + \((d\
\ \((h - i)\) + e\ \((i - g)\) + f\ \((g - h)\))\)\^2 + \((g\ \((k - l)\) + h\
\ \((l - j)\) + i\ \((j - k)\))\)\^2 + \[IndentingNewLine]\((\((b - c)\)\^2 + \
\((e - f)\)\^2)\)\ j\^2 + \((\((a - c)\)\^2 + \((d - f)\)\^2)\)\ k\^2 + \
\((\((a - b)\)\^2 + \((d - e)\)\^2)\)\ l\^2)\) + \[IndentingNewLine]6\ \((\((\
\((c - a)\)\ \((c - b)\) + \((f - d)\)\ \((f - e)\))\)\ j\ k + \((\((b - 
                        
                                a)\)\ \((b - c)\) + \((e - d)\)\ \((e - 
                                  f)\))\)\ j\ l + \[IndentingNewLine]\((\((a \
- b)\)\ \((a - c)\) + \((d - e)\)\ \((d - 
                                  f)\))\)\ k\ l)\), \[IndentingNewLine] (*27*) 
              L4\[Sigma] = \ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((c - a)\)\
\^2 - \((d - e)\)\^2 - \((e - f)\)\^2 - \((f - d)\)\^2 - \((g - h)\)\^2 - \
\((h - i)\)\^2 - \((i - g)\)\^2 - \((j - k)\)\^2 - \((k - l)\)\^2 - \((l - j)\
\)\^2)\)^2/4 + 
                3\ \((\((b\ d - c\ d - a\ e + c\ e + a\ f - b\ f)\)\^2 + \((b\
\ g - c\ g - a\ h + c\ h + a\ i - b\ i)\)\^2 - \((e\ g - f\ g - d\ h + f\ h + \
d\ i - e\ i)\)\^2 + \((b\ j - c\ j - a\ k + c\ k + a\ l - b\ l)\)\^2 - \
\((\(-e\)\ j + f\ j + d\ k - f\ k - d\ l + e\ l)\)\^2 - \((h\ j - i\ j - g\ k \
+ i\ k + g\ l - h\ l)\)\^2)\), \[IndentingNewLine] (*28*) 
              L4a3 = \((\((ag + dj)\)\^2 + \((bh + ek)\)\^2 + \((ci + \
fl)\)\^2)\)\^2/4 + agek,  (*29*) 
              L4b3 = \((\((ag - dj)\)\^2 + \((bh - ek)\)\^2 + \((ci - \
fl)\)\^2)\)\^2/4 + agek,  (*30*) 
              L4c3 = \((\((ab + de)\)\^2 + \((bc + ef)\)\^2 + \((ca + \
fd)\)\^2)\)\^2/4 - abef,  (*31*) 
              L4d3 = \((\((ab - de)\)\^2 + \((bc - ef)\)\^2 + \((ca - \
fd)\)\^2)\)\^2/4 - abef,  (*32*) 
              L4a6 = \((ag\^2 + bh\^2 + ci\^2 - dj\^2 - fl\^2 - ek\^2)\)\^2/
                  4 + agek,  (*33*) 
              L4b6 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)\^2/
                  4 + abef,  (*34*) 
              L4c6 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)\^2/
                  4 - abef, \n\t (*35*) 
              L4d6 = \ \((ag\^2 + bh\^2 + ci\^2 + dj\^2 + fl\^2 + ek\^2)\)\^2/
                  4 - agek, \[IndentingNewLine] (*36*) 
              L49 = \((\((ab\^2 - de\^2)\)\^2 + \((ab\^2 - ef\^2)\)\^2 + \
\((ab\^2 - fd\^2)\)\^2 + \((bc\^2 - de\^2)\)\^2 + \((bc\^2 - ef\^2)\)\^2 + \
\((bc\^2 - fd\^2)\)\^2 + \((ca\^2 - de\^2)\)\^2 + \((ca\^2 - ef\^2)\)\^2 + \
\((ca\^2 - fd\^2)\)\^2)\), \[IndentingNewLine] (*37*) 
              L49a = \((\((ag\^2 - dj\^2)\)\^2 + \((ag\^2 - ek\^2)\)\^2 + \
\((ag\^2 - fl\^2)\)\^2 + \((bh\^2 - dj\^2)\)\^2 + \((bh\^2 - ek\^2)\)\^2 + \
\((bh\^2 - fl\^2)\)\^2 + \((ci\^2 - dj\^2)\)\^2 + \((ci\^2 - ek\^2)\)\^2 + \
\((ci\^2 - fl\^2)\)\^2)\), \[IndentingNewLine] (*38*) 
              L49b = \((\((ab\^2 - dj\^2)\)\^2 + \((ab\^2 - ek\^2)\)\^2 + \
\((ab\^2 - fl\^2)\)\^2 + \((bc\^2 - dj\^2)\)\^2 + \((bc\^2 - ek\^2)\)\^2 + \
\((bc\^2 - fl\^2)\)\^2 + \((ca\^2 - dj\^2)\)\^2 + \((ca\^2 - ek\^2)\)\^2 + \
\((ca\^2 - fl\^2)\)\^2)\), \[IndentingNewLine] (*39*) 
              L49c = \((\((ag\^2 - de\^2)\)\^2 + \((ag\^2 - ef\^2)\)\^2 + \
\((ag\^2 - fd\^2)\)\^2 + \((bh\^2 - de\^2)\)\^2 + \((bh\^2 - ef\^2)\)\^2 + \
\((bh\^2 - fd\^2)\)\^2 + \((ci\^2 - de\^2)\)\^2 + \((ci\^2 - ef\^2)\)\^2 + \
\((ci\^2 - fd\^2)\)\^2)\)}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  PageBreakWithin->Automatic,
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(dozalcons = sh12[{a, b, c, d, e, f, g, h, i, j, k, l}];\)\)], "Input",\

  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(ds = {"\<o1\>", "\<o2\>", "\<o3\>", "\<o4\>", "\<l22a\>", "\<l22b\>", \
"\<p22\>", "\<q22\>", "\<r22\>", "\<s22\>", "\<p23\>", "\<q23\>", "\<r23\>", \
"\<s23\>", "\<q24\>", "\<s24\>", "\<p26\>", "\<q26\>", "\<r26\>", "\<s26\>", \
"\<l3\>", "\<l4p\>", "\<l4q\>", "\<l4r\>", "\<l4s\>", "\<L4Q\>", \
"\<L4\[Sigma]\>", "\<L4a3\>", "\<L4b3\>", "\<L4c3\>", "\<L4d3\>", "\<L4a6\>", \
"\<L4b6\>", "\<L4c6\>", "\<L4d6\>", "\<L49\>", "\<L49a\>", "\<L49b\>", \
"\<L49c\>"};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".11 Polar-Vector, Hyperbolics, ",
  StyleBox["sh, toPol, toVec, tohyPol, tohyVec ",
    FontSlant->"Italic"],
  "for 16 element loops."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
    \(sh["\<D8\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 2, 15, 4, 13, 6, 11, 8, 9, 10, 7, 12, 5, 14, 3, 16, 1, 1, 1, 
            1, 2, 2}; \[IndentingNewLine]{a + b + c + d + e + f + g + h + i + 
            j + k + l + m + n + o + p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
          a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + 
            p, \((a - e + i - m)\)^2 - \((b - f + j - n)\)^2 + \((c - g + k - 
                  o)\)^2 - \((d - h + l - 
                  p)\)^2, \(-2\)\ \((\((a - i)\)\ \((c - k)\) - \((b - 
                          j)\)\ \((d - l)\) + \((c - k)\)\ \((e - 
                          m)\) - \((d - l)\)\ \((f - n)\) - \((a - 
                          i)\)\ \((g - o)\) + \((e - m)\)\ \((g - 
                          o)\) + \((b - j)\)\ \((h - p)\) - \((f - 
                          n)\)\ \((h - 
                          p)\))\)^2 + \((\((a - i)\)\^2 - \((b - j)\)\^2 + \
\((c - k)\)\^2 - \((d - l)\)\^2 + \((e - m)\)\^2 - \((f - n)\)\^2 + \((g - o)\
\)\^2 - \((h - p)\)\^2)\)^2}]; 
    sh["\<Q16\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 10, 15, 12, 13, 14, 11, 16, 9, 2, 7, 4, 5, 6, 3, 8, 1, 1, 1, 
            1, 2, 2}; {a + b + c + d + e + f + g + h + i + j + k + l + m + 
            n + o + p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
          a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + 
            p, \((a - e + i - m)\)^2 - \((b - f + j - n)\)^2 + \((c - g + k - 
                  o)\)^2 - \((d - h + l - 
                  p)\)^2, \[IndentingNewLine]\((a - i)\)\^4 + 
            2\ \((a - i)\)\^2\ \((b - j)\)\^2 + \((b - j)\)\^4 + 
            2\ \((b - j)\)\^2\ \((c - k)\)\^2 + \((c - k)\)\^4 - 
            4\ \((a - i)\)\ \((b - j)\)\ \((c - k)\)\ \((d - l)\) + 
            2\ \((a - i)\)\^2\ \((d - l)\)\^2 + 
            2\ \((c - k)\)\^2\ \((d - l)\)\^2 + \((d - l)\)\^4 - 
            4\ \((a - i)\)\ \((c - k)\)\^2\ \((e - m)\) - 
            4\ \((b - j)\)\ \((c - k)\)\ \((d - l)\)\ \((e - m)\) + 
            2\ \((a - i)\)\^2\ \((e - m)\)\^2 + 
            2\ \((b - j)\)\^2\ \((e - m)\)\^2 + 
            2\ \((d - l)\)\^2\ \((e - m)\)\^2 + \((e - m)\)\^4 - 
            4\ \((a - i)\)\ \((c - k)\)\ \((d - l)\)\ \((f - n)\) - 
            4\ \((b - j)\)\ \((d - l)\)\^2\ \((f - n)\) - 
            4\ \((c - k)\)\ \((d - l)\)\ \((e - m)\)\ \((f - n)\) + 
            2\ \((a - i)\)\^2\ \((f - n)\)\^2 + 
            2\ \((b - j)\)\^2\ \((f - n)\)\^2 + 
            2\ \((c - k)\)\^2\ \((f - n)\)\^2 + 
            2\ \((e - m)\)\^2\ \((f - n)\)\^2 + \((f - n)\)\^4 + 
            4\ \((a - i)\)\^2\ \((c - k)\)\ \((g - o)\) + 
            4\ \((a - i)\)\ \((b - j)\)\ \((d - l)\)\ \((g - o)\) - 
            4\ \((b - j)\)\ \((d - l)\)\ \((e - m)\)\ \((g - o)\) - 
            4\ \((c - k)\)\ \((e - m)\)\^2\ \((g - o)\) + 
            4\ \((a - i)\)\ \((d - l)\)\ \((f - n)\)\ \((g - o)\) - 
            4\ \((d - l)\)\ \((e - m)\)\ \((f - n)\)\ \((g - o)\) + 
            2\ \((b - j)\)\^2\ \((g - o)\)\^2 + 
            2\ \((c - k)\)\^2\ \((g - o)\)\^2 + 
            2\ \((d - l)\)\^2\ \((g - o)\)\^2 + 
            4\ \((a - i)\)\ \((e - m)\)\ \((g - o)\)\^2 + 
            2\ \((f - n)\)\^2\ \((g - o)\)\^2 + \((g - o)\)\^4 + 
            4\ \((a - i)\)\ \((b - j)\)\ \((c - k)\)\ \((h - p)\) + 
            4\ \((b - j)\)\^2\ \((d - l)\)\ \((h - p)\) + 
            4\ \((b - j)\)\ \((c - k)\)\ \((e - m)\)\ \((h - p)\) - 
            4\ \((a - i)\)\ \((c - k)\)\ \((f - n)\)\ \((h - p)\) - 
            4\ \((c - k)\)\ \((e - m)\)\ \((f - n)\)\ \((h - p)\) - 
            4\ \((d - l)\)\ \((f - n)\)\^2\ \((h - p)\) - 
            4\ \((a - i)\)\ \((b - j)\)\ \((g - o)\)\ \((h - p)\) + 
            4\ \((b - j)\)\ \((e - m)\)\ \((g - o)\)\ \((h - p)\) + 
            4\ \((a - i)\)\ \((f - n)\)\ \((g - o)\)\ \((h - p)\) - 
            4\ \((e - m)\)\ \((f - n)\)\ \((g - o)\)\ \((h - p)\) + 
            2\ \((a - i)\)\^2\ \((h - p)\)\^2 + 
            2\ \((c - k)\)\^2\ \((h - p)\)\^2 + 
            2\ \((d - l)\)\^2\ \((h - p)\)\^2 + 
            2\ \((e - m)\)\^2\ \((h - p)\)\^2 + 
            4\ \((b - j)\)\ \((f - n)\)\ \((h - p)\)\^2 + 
            2\ \((g - o)\)\^2\ \((h - p)\)\^2 + \((h - p)\)\^4}]; 
    sh["\<D4C2\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 2, 7, 4, 5, 6, 3, 8, 9, 10, 15, 12, 13, 14, 11, 16, 1, 1, 1, 
            1, 1, 1, 1, 1, 2, 2}; \[IndentingNewLine]{a + b + c + d + e + f + 
            g + h - i - j - k - l - m - n - o - p, 
          a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p, 
          a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
          a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p, 
          a + b - c - d + e + f - g - h - i - j + k + l - m - n + o + p, 
          a + b + c + d + e + f + g + h + i + j + k + l + m + n + o + 
            p, \((a - e + i - m)\)\^2 - \((b - f + j - n)\)\^2 + \((c - g + k \
- o)\)\^2 - \((d - h + l - p)\)\^2, \((a - e - i + m)\)\^2 - \((b - f - j + \
n)\)\^2 + \((c - g - k + o)\)\^2 - \((d - h - l + p)\)\^2}];\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0,
  FontSize->9],

Cell[BoxData[
    \(sh["\<C4C4\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 4, 3, 2, 13, 16, 15, 14, 9, 12, 11, 10, 5, 8, 7, 6, 1, 1, 1, 
            1, 1, 1, 1, 1, 1, 1}; \[IndentingNewLine]{a + b + c + d + e + f + 
            g + h + i + j + k + l + m + n + o + p, 
          a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - 
            p, \((a + b + c + d - i - j - k - l)\)\^2 + \((e + f + g + h - m \
- n - o - p)\)\^2, \((a - b + c - d - i + j - k + l)\)\^2 + \((e - f + g - h \
- m + n - o + p)\)\^2, \((a - c + e - g + i - k + m - o)\)\^2 + \((b - d + f \
- h + j - l + n - p)\)\^2, \((a - c - e + g + i - k - m + o)\)\^2 + \((b - d \
- f + h + j - l - n + p)\)\^2, \((a - c + f - h - i + k - n + p)\)\^2 + \((b \
- d - e + g - j + l + m - o)\)\^2, \((a - c - f + h - i + k + n - p)\)\^2 + \
\((b - d + e - g - j + l - m + o)\)\^2}]; 
    sh["\<Q8C2\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 6, 7, 8, 5, 2, 3, 4, 9, 14, 15, 16, 13, 10, 11, 12, 1, 1, 1, 
            1, 1, 1, 1, 1, 2, 2}; \[IndentingNewLine]{a + b + c + d + e + f + 
            g + h + i + j + k + l + m + n + o + p, 
          a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
          a + b + c + d + e + f + g + h - i - j - k - l - m - n - o - p, 
          a + b - c - d + e + f - g - h - i - j + k + l - m - n + o + p, 
          a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p, 
          a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + 
            p, \((a - e + i - m)\)\^2 + \((b - f + j - n)\)\^2 + \((c - g + k \
- o)\)\^2 + \((d - h + l - p)\)\^2, \((a - e - i + m)\)\^2 + \((b - f - j + \
n)\)\^2 + \((c - g - k + o)\)\^2 + \((d - h - l + p)\)\^2}];\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(sh["\<KK\>"] := 
      Module[{}, 
        gi = {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 1, 1, 1, 
            1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
            1}; \[IndentingNewLine]gp = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
            1, 1, 1, 1}; {a + b + c + d + e + f + g + h + i + j + k + l + m + 
            n + o + p, 
          a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
          a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p, 
          a + b - c - d - e - f + g + h + i + j - k - l - m - n + o + p, 
          a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - p, 
          a - b - c + d - e + f + g - h + i - j - k + l - m + n + o - p, 
          a + b + c + d + e + f + g + h - i - j - k - l - m - n - o - p, 
          a + b + c + d - e - f - g - h - i - j - k - l + m + n + o + p, 
          a + b - c - d - e - f + g + h - i - j + k + l + m + n - o - p, 
          a - b + c - d - e + f - g + h - i + j - k + l + m - n + o - p, 
          a + b - c - d + e + f - g - h - i - j + k + l - m - n + o + p, 
          a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p, 
          a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p, 
          a - b - c + d - e + f + g - h - i + j + k - l + m - n - o + p}]; 
    toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_, m_, n_, o_, 
          p_}, "\<KK\>"] := {a + b + c + d + e + f + g + h + i + j + k + l + 
          m + n + o + p, 
        a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
        a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
        a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
        a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p, 
        a + b - c - d - e - f + g + h + i + j - k - l - m - n + o + p, 
        a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - p, 
        a - b - c + d - e + f + g - h + i - j - k + l - m + n + o - p, 
        a + b + c + d + e + f + g + h - i - j - k - l - m - n - o - p, 
        a + b + c + d - e - f - g - h - i - j - k - l + m + n + o + p, 
        a + b - c - d - e - f + g + h - i - j + k + l + m + n - o - p, 
        a - b + c - d - e + f - g + h - i + j - k + l + m - n + o - p, 
        a + b - c - d + e + f - g - h - i - j + k + l - m - n + o + p, 
        a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p, 
        a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p, 
        a - b - c + d - e + f + g - h - i + j + k - l + m - n - o + p}; 
    toVec[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_, m_, n_, o_, 
          p_}, "\<KK\>"] := {a + b + c + d + e + f + g + h + i + j + k + l + 
            m + n + o + p, 
          a - b - c + d - e + f + g - h + i + j + k - l + m - n - o - p, 
          a - b + c - d + e - f + g - h + i + j - k + l - m - n + o - p, 
          a + b - c - d - e - f + g + h + i + j - k - l - m + n - o + p, 
          a + b + c + d - e - f - g - h + i - j - k - l + m + n + o - p, 
          a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
          a - b + c - d - e + f - g + h + i - j + k - l - m - n + o + p, 
          a + b - c - d + e + f - g - h + i - j + k + l - m + n - o - p, 
          a + b + c + d + e + f + g + h - i - j - k - l - m - n - o - p, 
          a - b - c + d - e + f + g - h - i - j - k + l - m + n + o + p, 
          a - b + c - d + e - f + g - h - i - j + k - l + m + n - o + p, 
          a + b - c - d - e - f + g + h - i - j + k + l + m - n + o - p, 
          a + b + c + d - e - f - g - h - i + j + k + l - m - n - o + p, 
          a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p, 
          a - b + c - d - e + f - g + h - i + j - k + l + m + n - o - p, 
          a + b - c - d + e + f - g - h - i + j - k - l + m - n + o + p}/
        16;\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(sh["\<C4K\>"] := 
      Module[{}, 
        gi = {1, 4, 3, 2, 5, 8, 7, 6, 9, 12, 11, 10, 13, 16, 15, 14, 1, 1, 1, 
            1, 1, 1, 1, 1, 1, 1, 1, 1}; 
        gp = {1, 1, 1, 1, 1, 1, 1, 1, 1, 0. , 1, 0. , 1, 0. , 1, 
            0. }; \[IndentingNewLine]{a + b + c + d + e + f + g + h + i + j + 
            k + l + m + n + o + p, 
          a + b + c + d - e - f - g - h - i - j - k - l + m + n + o + p, 
          a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p, 
          a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p, 
          a - b + c - d - e + f - g + h - i + j - k + l + m - n + o - p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - p, 
          a + b + c + d + e + f + g + h - i - j - k - l - m - n - o - 
            p, \((a - c - e + g - i + k + m - o)\)\^2 + \((b - d - f + h - j \
+ l + n - p)\)\^2, \((a - c + e - g - i + k - m + o)\)\^2 + \((b - d + f - h \
- j + l - n + p)\)\^2, \((a - c - e + g + i - k - m + o)\)\^2 + \((b - d - f \
+ h + j - l - n + p)\)\^2, \((a - c + e - g + i - k + m - o)\)\^2 + \((b - d \
+ f - h + j - l + n - p)\)\^2}]; 
    toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_, m_, n_, o_, 
          p_}, "\<C4K\>"] := \[IndentingNewLine]{a + b + c + d + e + f + g + 
          h + i + j + k + l + m + n + o + p, 
        a + b + c + d - e - f - g - h - i - j - k - l + m + n + o + p, 
        a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + 
          p, \[IndentingNewLine]a - b + c - d - e + f - g + h + i - j + k - 
          l - m + n - o + p, \[IndentingNewLine]a - b + c - d - e + f - g + 
          h - i + j - k + l + m - n + o - p, \[IndentingNewLine]a - b + c - 
          d + e - f + g - h + i - j + k - l + m - n + o - 
          p, \[IndentingNewLine]a + b + c + d - e - f - g - h + i + j + k + 
          l - m - n - o - p, \[IndentingNewLine]a + b + c + d + e + f + g + 
          h - i - j - k - l - m - n - o - 
          p, \[IndentingNewLine] (*ij*) \((a - c - e + g - i + k + m - \
o)\)\^2 + \((b - d - f + h - j + l + n - p)\)\^2, 
        If[b - d - f + h - j + l + n - p \[Equal] 0, 0, 
          ArcTan[a - c - e + g - i + k + m - o, 
            b - d - f + h - j + l + n - 
              p]], \[IndentingNewLine] (*kl*) \((a - c + e - g - i + k - m + \
o)\)\^2 + \((b - d + f - h - j + l - n + p)\)\^2, 
        If[b - d + f - h - j + l - n + p \[Equal] 0, 0, 
          ArcTan[a - c + e - g - i + k - m + o, 
            b - d + f - h - j + l - n + 
              p]], \[IndentingNewLine] (*mn*) \((a - c - e + g + i - k - m + \
o)\)\^2 + \((b - d - f + h + j - l - n + p)\)\^2, 
        If[b - d - f + h + j - l - n + p \[Equal] 0, 0, 
          ArcTan[a - c - e + g + i - k - m + o, 
            b - d - f + h + j - l - n + 
              p]], \[IndentingNewLine] (*op*) \((a - c + e - g + i - k + m - \
o)\)\^2 + \((b - d + f - h + j - l + n - p)\)\^2, 
        If[b - d + f - h + j - l + n - p \[Equal] 0, 0, 
          ArcTan[a - c + e - g + i - k + m - o, 
            b - d + f - h + j - l + n - p]]}; 
    toVec[{a_, b_, c_, d_, e_, f_, g_, h_, ii_, j_, kk_, l_, mm_, n_, oo_, 
          p_}, \[IndentingNewLine]"\<C4K\>"] := 
      Module[{i = 2 \@ ii, k = 2 \@ kk, m = 2 \@ mm, 
          o = 2 \@ oo}, \[IndentingNewLine]{\ \  (*a*) a + b + c + d + e + 
              f + g + h + i\ Cos[j] + k\ Cos[l] + m\ Cos[n] + 
              o\ Cos[p], \[IndentingNewLine] (*b*) a + b - c - d - e - f + 
              g + h + i\ Sin[j] + k\ Sin[l] + m\ Sin[n] + 
              o\ Sin[p], \[IndentingNewLine] (*c*) a + b + c + d + e + f + 
              g + h - i\ Cos[j] - k\ Cos[l] - m\ Cos[n] - 
              o\ Cos[p], \[IndentingNewLine] (*d*) a + b - c - d - e - f + 
              g + h - i\ Sin[j] - k\ Sin[l] - m\ Sin[n] - 
              o\ Sin[p], \[IndentingNewLine] (*e*) a - b + c - d - e + f - 
              g + h - i\ Cos[j] + k\ Cos[l] - m\ Cos[n] + 
              o\ Cos[p], \[IndentingNewLine] (*f*) a - b - c + d + e - f - 
              g + h - i\ Sin[j] + k\ Sin[l] - m\ Sin[n] + 
              o\ Sin[p], \[IndentingNewLine] (*g*) a - b + c - d - e + f - 
              g + h + i\ Cos[j] - k\ Cos[l] + m\ Cos[n] - 
              o\ Cos[p], \[IndentingNewLine] (*h*) a - b - c + d + e - f - 
              g + h + i\ Sin[j] - k\ Sin[l] + m\ Sin[n] - 
              o\ Sin[p], \[IndentingNewLine] (*i*) a - b - c + d - e + f + 
              g - h - i\ Cos[j] - k\ Cos[l] + m\ Cos[n] + 
              o\ Cos[p], \[IndentingNewLine] (*j*) a - b + c - d + e - f + 
              g - h - i\ Sin[j] - k\ Sin[l] + m\ Sin[n] + 
              o\ Sin[p], \[IndentingNewLine] (*k*) a - b - c + d - e + f + 
              g - h + i\ Cos[j] + k\ Cos[l] - m\ Cos[n] - 
              o\ Cos[p], \[IndentingNewLine] (*l*) a - b + c - d + e - f + 
              g - h + i\ Sin[j] + k\ Sin[l] - m\ Sin[n] - 
              o\ Sin[p], \[IndentingNewLine] (*m*) a + b - c - d + e + f - 
              g - h + i\ Cos[j] - k\ Cos[l] - m\ Cos[n] + 
              o\ Cos[p], \[IndentingNewLine] (*n*) a + b + c + d - e - f - 
              g - h + i\ Sin[j] - k\ Sin[l] - m\ Sin[n] + 
              o\ Sin[p], \[IndentingNewLine] (*o*) a + b - c - d + e + f - 
              g - h - i\ Cos[j] + k\ Cos[l] + m\ Cos[n] - 
              o\ Cos[p], \[IndentingNewLine] (*p*) a + b + c + d - e - f - 
              g - h - i\ Sin[j] + k\ Sin[l] + m\ Sin[n] - o\ Sin[p]}/
          16];\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(sh["\<KiC4\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 2, 3, 4, 13, 16, 15, 14, 9, 10, 11, 12, 5, 8, 7, 6, 1, 1, 1, 
            1, 1, 1, 2, 2}; \[IndentingNewLine]{a + b + c + d + e + f + g + 
            h + i + j + k + l + m + n + o + p, 
          a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - 
            p, \((a + b + c + d - i - j - k - l)\)\^2 + \((\(-e\) - f - g - h \
+ m + n + o + p)\)\^2, \((a - b + c - d - i + j - k + l)\)\^2 + \((\(-e\) + f \
- g + h + m - n + o - p)\)\^2, \((a - c + i - k)\)\^2 - \((b - d + j - \
l)\)\^2 - \((e - g + m - o)\)\^2 + \((f - h + n - p)\)\^2, \((a - c - i + \
k)\)\^2 - \((b - d - j + l)\)\^2 + \((e - g - m + o)\)\^2 - \((f - h - n + p)\
\)\^2}]; sh["\<C4iC4\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 4, 3, 2, 13, 14, 15, 16, 9, 12, 11, 10, 5, 6, 7, 8, 1, 1, 1, 
            1, 1, 1, 2, 2}; \[IndentingNewLine]{a + b + c + d + e + f + g + 
            h + i + j + k + l + m + n + o + p, 
          a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - 
            p, \((a + b + c + d - i - j - k - l)\)\^2 + \((\(-e\) - f - g - h \
+ m + n + o + p)\)\^2, \((a - b + c - d - i + j - k + l)\)\^2 + \((\(-e\) + f \
- g + h + m - n + o - p)\)\^2, \((a - c + i - k)\)\^2 + \((b - d + j - \
l)\)\^2 - \((e - g + m - o)\)\^2 - \((f - h + n - p)\)\^2, \((a - c - i + \
k)\)\^2 + \((b - d - j + l)\)\^2 + \((e - g - m + o)\)\^2 + \((f - h - n + p)\
\)\^2}];\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(sh["\<P16\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 2, 3, 4, 13, 14, 15, 16, 9, 10, 11, 12, 5, 6, 7, 8, 1, 1, 1, 
            1, 1, 1, 1, 1, 2}; \[IndentingNewLine]{a + b + c + d + e + f + 
            g + h + i + j + k + l + m + n + o + p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
          a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
          a + b + c - d - e - f - g + h + i + j + k - l - m - n - o + p, 
          a + b - c + d - e - f + g - h + i + j - k + l - m - n + o - p, 
          a - b + c + d - e + f - g - h + i - j + k + l - m + n - o - p, 
          a - b - c - d - e + f + g + h + i - j - k - l - m + n + o + p, 
          4\ \((\((a - i)\)\ \((e - m)\) - \((b - j)\)\ \((f - n)\) - \((c - 
                          k)\)\ \((g - o)\) - \((d - l)\)\ \((h - 
                          p)\))\)^2 + \((\((a - i)\)\^2 - \((b - j)\)\^2 - \
\((c - k)\)\^2 - \((d - l)\)\^2 - \((e - m)\)\^2 + \((f - n)\)\^2 + \((g - o)\
\)\^2 + \((h - p)\)\^2)\)^2}]; 
    sh["\<Oct\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 10, 11, 12, 13, 14, 15, 16, 9, 2, 3, 4, 5, 6, 7, 8, 1, 1, 1, 
            1, 1, 1, 1, 1, 4}; \[IndentingNewLine]{a + b + c + d + e + f + 
            g + h + i + j + k + l + m + n + o + p, 
          a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
          a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
          a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
          a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p, 
          a + b - c - d - e - f + g + h + i + j - k - l - m - n + o + p, 
          a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - p, 
          a - b - c + d - e + f + g - h + i - j - k + l - m + n + o - 
            p, \((a - i)\)\^2 + \((b - j)\)\^2 + \((c - k)\)\^2 + \((d - l)\)\
\^2 + \((e - m)\)\^2 + \((f - n)\)\^2 + \((g - o)\)\^2 + \((h - \
p)\)\^2}];\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(sh["\<Q8M2\>"] := 
        Module[{}, gp =. ; 
          gi = {1, 6, 7, 8, 5, 2, 3, 4, 9, 10, 11, 12, 13, 
              14, \[IndentingNewLine]15, 16, 1, 1, 1, 1, 1, 1, 1, 1, 
              4}; \[IndentingNewLine]{a + b + c + d + e + f + g + h - i - j - 
              k - l - m - n - o - p, 
            a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
            a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
            a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p, 
            a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
            a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p, 
            a + b - c - d + e + f - g - h - i - j + k + l - m - n + o + p, 
            a + b + c + d + e + f + g + h + i + j + k + l + m + n + o + 
              p, \((a - e)\)\^2 + \((b - f)\)\^2 + \((c - g)\)\^2 + \((d - h)\
\)\^2 - \((j - n)\)\^2 - \[IndentingNewLine]\((k - o)\)\^2 - \((l - p)\)\^2 - \
\((i - m)\)\^2}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0,
  FontSize->9],

Cell[BoxData[{
    \(sh["\<CL4\>"] := 
      Module[{},  (*see\ Louenesto\ p86*) gp =. ; 
        gi = {1, 2, 3, \(-4\), 5, \(-6\), \(-7\), \(-8\), 
            9, \(-10\), \(-11\), \(-12\), \(-13\), \(-14\), \(-15\), 16, 
            4}; {\((a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2 + 
                  i\^2 + j\^2 + k\^2 + l\^2 + m\^2 + n\^2 + o\^2 + 
                  p\^2)\)^2 - 
            4 \((\((a\ b + c\ d + e\ f + g\ h + i\ j + k\ l + m\ n + 
                        o\ p)\)^2 + \((a\ c - b\ d + e\ g - f\ h + i\ k - 
                        j\ l + m\ o - n\ p)\)^2 + \((a\ e - b\ f - c\ g + 
                        d\ h + i\ m - j\ n - k\ o + l\ p)\)^2 + \((a\ i - 
                        b\ j - c\ k + d\ l - e\ m + f\ n + g\ o - 
                        h\ p)\)^2 + \((h\ i - g\ j + f\ k - e\ l - d\ m + 
                        c\ n - b\ o + a\ p)\)^2)\)}]; 
    sh["\<CL13\>"] := 
      Module[{}, gp =. ; 
        gi = {1, \(-2\), \(-3\), \(-4\), \(-5\), \(-6\), \(-7\), 8, 9, 10, 
            11, \(-12\), 13, \(-14\), \(-15\), \(-16\), 
            4}; {\((a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2 + 
                  i\^2 + j\^2 + k\^2 + l\^2 + m\^2 + n\^2 + o\^2 + 
                  p\^2)\)^2 - 
            4 \((\((\(-d\)\ e + c\ f - b\ g + a\ h - l\ m + k\ n - j\ o + 
                        i\ p)\)^2 + \((a\ i - b\ j - c\ k + d\ l - e\ m + 
                        f\ n + g\ o - 
                        h\ p)\)^2 + \[IndentingNewLine]\((b\ i + a\ j - 
                        d\ k - c\ l - f\ m - e\ n + h\ o + 
                        g\ p)\)^2 + \((c\ i + d\ j + a\ k + b\ l - g\ m - 
                        h\ n - e\ o - f\ p)\)^2 + \((e\ i + f\ j + g\ k + 
                        h\ l + a\ m + b\ n + c\ o + d\ p)\)^2)\)}];  (*\ 
      found\ from\ conjugation, \ 
      with\ negated\ \(terms!\)\ *) \), "\[IndentingNewLine]", 
    \(\(sh["\<CL22\>"] = 
        Module[{}, gp =. ; 
          gi = {1, \(-2\), \(-3\), \(-4\), 5, 6, 7, \(-8\), 9, 10, 
              11, \(-12\), \(-13\), 14, 15, 16, 
              4}; {\((a\^2 + b\^2 + c\^2 + d\^2 - e\^2 - f\^2 - g\^2 - h\^2 - 
                    i\^2 - j\^2 - k\^2 - l\^2 + m\^2 + n\^2 + o\^2 + 
                    p\^2)\)^2 - 
              4 \((\(-\((\(-d\)\ e + c\ f - b\ g + a\ h + l\ m - k\ n + 
                            j\ o - i\ p)\)^2\) - \((\(-d\)\ i + c\ j - b\ k + 
                          a\ l - h\ m + g\ n - f\ o + 
                          e\ p)\)^2\[IndentingNewLine] + \((\(-f\)\ i + 
                          e\ j - h\ k + g\ l - b\ m + a\ n - d\ o + 
                          c\ p)\)^2 + \((\(-g\)\ i + h\ j + e\ k - f\ l - 
                          c\ m + d\ n + a\ o - 
                          b\ p)\)^2\[IndentingNewLine] + \((\(-h\)\ i - 
                          g\ j + f\ k + e\ l - d\ m - c\ n + b\ o + 
                          a\ p)\)^2)\)}];\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(\(\( (*\ found\ from\ conjugation, \ 
      with\ negated\ \(terms!\)\ *) \)\(sh["\<CL31\>"] := 
      Module[{}, gp =. ; 
        gi = {1, \(-2\), 3, 4, 5, 6, \(-7\), 8, 9, 10, \(-11\), 12, \(-13\), 
            14, \(-15\), \(-16\), 
            4}; {\((a\^2 + b\^2 - c\^2 - d\^2 - e\^2 - f\^2 + g\^2 + h\^2 - 
                  i\^2 - j\^2 + k\^2 + l\^2 + m\^2 + n\^2 - o\^2 - 
                  p\^2)\)^2 - 
            4 \((\((\(-d\)\ e + c\ f - b\ g + a\ h + l\ m - k\ n + j\ o - 
                        i\ p)\)^2 + \((\(-d\)\ i + c\ j - b\ k + a\ l - 
                        h\ m + g\ n - f\ o + e\ p)\)^2 + \((\(-f\)\ i + 
                        e\ j + h\ k - g\ l - b\ m + a\ n + d\ o - 
                        c\ p)\)^2 - \((\(-g\)\ i + h\ j + e\ k - f\ l - 
                        c\ m + d\ n + a\ o - b\ p)\)^2 - \((\(-h\)\ i - 
                        g\ j + f\ k + e\ l - d\ m - c\ n + b\ o + 
                        a\ p)\)^2)\)}]; 
    sh["\<r31r\>"] := 
      Module[{}, gp =. ; 
        plex = {a, b, c, \(-d\), e, \(-f\), \(-g\), \(-h\), 
            i, \(-j\), \(-k\), \(-l\), \(-m\), \(-n\), \(-o\), p}; 
        gi = {1, 2, 3, \(-4\), \(-5\), 6, 7, 8, 9, \(-10\), \(-11\), \(-12\), 
            13, 14, 15, \(-16\), 
            4}; {\((a\^2 + b\^2 + c\^2 + d\^2 - e\^2 - f\^2 - g\^2 - h\^2 + 
                  i\^2 + j\^2 + k\^2 + l\^2 - m\^2 - n\^2 - o\^2 - 
                  p\^2)\)^2 - 
            4 \((\((a\ b + \ c\ d - \ e\ f - \ g\ h + \ i\ j + \ k\ l - \ 
                        m\ n - \ o\ p)\)^2 + \((\ 
                      a\ c - \ b\ d - \ e\ g + \ f\ h + \ i\ k - \ j\ l - \ 
                        m\ o + \ n\ p)\)^2 - \[IndentingNewLine]\((\ 
                      a\ e - \ b\ f - \ c\ g + \ d\ h + \ i\ m - \ j\ n - \ 
                        k\ o + \ l\ p)\)^2 + \((\ 
                      a\ i - \ b\ j - \ c\ k + \ d\ l + \ e\ m - \ f\ n - \ 
                        g\ o + \ h\ p)\)^2 - \((\ 
                      h\ i - \ g\ j + \ f\ k - \ e\ l - \ d\ m + \ c\ n - \ 
                        b\ o + \ a\ p)\)^2)\)}]; 
    sh["\<CL04\>"] := 
      Module[{}, gp =. ; 
        gi = {1, \(-2\), \(-3\), \(-4\), \(-5\), \(-6\), \(-7\), 
            8, \(-9\), \(-10\), \(-11\), 12, \(-13\), 14, 15, 16, 
            4}; {\((a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2 + 
                  i\^2 + j\^2 + k\^2 + l\^2 + m\^2 + n\^2 + o\^2 + 
                  p\^2)\)^2 - 
            4 \((\((\(-d\)\ e + c\ f - b\ g + a\ h - l\ m + k\ n - j\ o + 
                        i\ p)\)^2 + \((\(-d\)\ i + c\ j - b\ k + a\ l + 
                        h\ m - g\ n + f\ o - e\ p)\)^2 + \((\(-f\)\ i + 
                        e\ j - h\ k + g\ l - b\ m + a\ n - d\ o + 
                        c\ p)\)^2 + \((\(-g\)\ i + h\ j + e\ k - f\ l - 
                        c\ m + d\ n + a\ o - b\ p)\)^2 + \((\(-h\)\ i - 
                        g\ j + f\ k + e\ l - d\ m - c\ n + b\ o + 
                        a\ p)\)^2)\)}];\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(sh["\<O8\>"] := 
      Module[{}, 
        gp = {1, 0. , 1, 0. , 1, 0. , 1, 0. , 1, 0. , 1, 0. , 1, 0. , 1, 
            0. }; gi = {1, 2, 3, 4, 5, 6, 7, 
            8, \(-9\), \(-10\), \(-11\), \(-12\), \(-13\), \(-14\), \(-15\), \
\(-16\), 1, 1, 1, 1, 1, 1, 1, 
            1}; {\((a + b + c + d + e + f + g + h)\)\^2 + \((i + j + k + l + \
m + n + o + p)\)\^2, \((a - b - c + d + e - f - g + h)\)\^2 + \((i - j - k + \
l + m - n - o + p)\)\^2, \((a - b + c - d + e - f + g - h)\)\^2 + \((i - j + \
k - l + m - n + o - p)\)\^2, \((a + b - c - d + e + f - g - h)\)\^2 + \((i + \
j - k - l + m + n - o - p)\)\^2, \((a + b + c + d - e - f - g - h)\)\^2 + \
\((i + j + k + l - m - n - o - p)\)\^2, \((a - b - c + d - e + f + g - \
h)\)\^2 + \((i - j - k + l - m + n + o - p)\)\^2, \((a - b + c - d - e + f - \
g + h)\)\^2 + \((i - j + k - l - m + n - o + p)\)\^2, \((a + b - c - d - e - \
f + g + h)\)\^2 + \((i + j - k - l - m - n + o + p)\)\^2}]; 
    toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_, m_, n_, o_, 
          p_}, "\<O8\>"] := \ {\ \ \ \ \ \ \((a + b + c + d + e + f + g + \
h)\)\^2 + \((i + j + k + l + m + n + o + p)\)\^2, 
        ArcTan[a + b + c + d + e + f + g + h, 
          i + j + k + l + m + n + o + 
            p], \[IndentingNewLine]\ \ \ \ \ \ \((a - b - c + d + e - f - g + \
h)\)\^2 + \((i - j - k + l + m - n - o + p)\)\^2, 
        ArcTan[a - b - c + d + e - f - g + h, 
          i - j - k + l + m - n - o + 
            p], \[IndentingNewLine]\ \ \ \ \ \ \((a - b + c - d + e - f + g - \
h)\)\^2 + \((i - j + k - l + m - n + o - p)\)\^2, 
        ArcTan[a - b + c - d + e - f + g - h, 
          i - j + k - l + m - n + o - 
            p], \[IndentingNewLine]\ \ \ \ \ \ \((a + b - c - d + e + f - g - \
h)\)\^2 + \((i + j - k - l + m + n - o - p)\)\^2, 
        ArcTan[a + b - c - d + e + f - g - h, 
          i + j - k - l + m + n - o - 
            p], \[IndentingNewLine]\ \ \ \ \ \ \((a + b + c + d - e - f - g - \
h)\)\^2 + \((i + j + k + l - m - n - o - p)\)\^2, 
        ArcTan[a + b + c + d - e - f - g - h, 
          i + j + k + l - m - n - o - 
            
            p], \[IndentingNewLine]\ \ \ \ \ \ \((a - b - c + d - e + f + g - \
h)\)\^2 + \((i - j - k + l - m + n + o - p)\)\^2, 
        ArcTan[a - b - c + d - e + f + g - h, 
          i - j - k + l - m + n + o - 
            p], \[IndentingNewLine]\ \ \ \ \ \ \ \((a - b + c - d - e + f - g \
+ h)\)\^2 + \((i - j + k - l - m + n - o + p)\)\^2, 
        ArcTan[a - b + c - d - e + f - g + h, 
          i - j + k - l - m + n - o + 
            p], \[IndentingNewLine]\ \ \ \ \ \ \ \((a + b - c - d - e - f + g \
+ h)\)\^2 + \((i + j - k - l - m - n + o + p)\)\^2, 
        ArcTan[a + b - c - d - e - f + g + h, 
          i + j - k - l - m - n + o + p]}; 
    toVec[{ii_, j_, kk_, l_, mm_, n_, oo_, p_, qq_, r_, ss_, t_, uu_, v_, 
          ww_, x_}, "\<O8\>"] := 
      Module[{i = \@ii, k = \@kk, m = \@mm, o = \@oo, q = \@qq, s = \@ss, 
          u = \@uu, w = \@ww}, 
        2 {i\ Cos[j] + k\ Cos[l] + m\ Cos[n] + o\ Cos[p] + q\ Cos[r] + 
                s\ Cos[t] + u\ Cos[v] + 
                w\ Cos[x], \[IndentingNewLine]i\ Cos[j] - k\ Cos[l] - 
                m\ Cos[n] + o\ Cos[p] + q\ Cos[r] - s\ Cos[t] - u\ Cos[v] + 
                w\ Cos[x], \[IndentingNewLine]i\ Cos[j] - k\ Cos[l] + 
                m\ Cos[n] - o\ Cos[p] + q\ Cos[r] - s\ Cos[t] + u\ Cos[v] - 
                w\ Cos[x], \[IndentingNewLine]i\ Cos[j] + k\ Cos[l] - 
                m\ Cos[n] - o\ Cos[p] + q\ Cos[r] + s\ Cos[t] - u\ Cos[v] - 
                w\ Cos[x], \[IndentingNewLine]i\ Cos[j] + k\ Cos[l] + 
                m\ Cos[n] + o\ Cos[p] - q\ Cos[r] - s\ Cos[t] - u\ Cos[v] - 
                w\ Cos[x], \[IndentingNewLine]i\ Cos[j] - k\ Cos[l] - 
                m\ Cos[n] + o\ Cos[p] - q\ Cos[r] + s\ Cos[t] + u\ Cos[v] - 
                w\ Cos[x], \[IndentingNewLine]i\ Cos[j] - k\ Cos[l] + 
                m\ Cos[n] - o\ Cos[p] - q\ Cos[r] + s\ Cos[t] - u\ Cos[v] + 
                w\ Cos[x], \[IndentingNewLine]i\ Cos[j] + k\ Cos[l] - 
                m\ Cos[n] - o\ Cos[p] - q\ Cos[r] - s\ Cos[t] + u\ Cos[v] + 
                w\ Cos[x], \[IndentingNewLine]i\ Sin[j] + k\ Sin[l] + 
                m\ Sin[n] + o\ Sin[p] + q\ Sin[r] + s\ Sin[t] + u\ Sin[v] + 
                w\ Sin[x], \[IndentingNewLine]i\ Sin[j] - k\ Sin[l] - 
                m\ Sin[n] + o\ Sin[p] + q\ Sin[r] - s\ Sin[t] - u\ Sin[v] + 
                w\ Sin[x], \[IndentingNewLine]i\ Sin[j] - k\ Sin[l] + 
                m\ Sin[n] - o\ Sin[p] + q\ Sin[r] - s\ Sin[t] + u\ Sin[v] - 
                w\ Sin[x], \[IndentingNewLine]i\ Sin[j] + k\ Sin[l] - 
                m\ Sin[n] - o\ Sin[p] + q\ Sin[r] + s\ Sin[t] - u\ Sin[v] - 
                w\ Sin[x], \[IndentingNewLine]i\ Sin[j] + k\ Sin[l] + 
                m\ Sin[n] + o\ Sin[p] - q\ Sin[r] - s\ Sin[t] - u\ Sin[v] - 
                w\ Sin[x], \[IndentingNewLine]i\ Sin[j] - k\ Sin[l] - 
                m\ Sin[n] + o\ Sin[p] - q\ Sin[r] + s\ Sin[t] + u\ Sin[v] - 
                w\ Sin[x], \[IndentingNewLine]i\ Sin[j] - k\ Sin[l] + 
                m\ Sin[n] - o\ Sin[p] - q\ Sin[r] + s\ Sin[t] - u\ Sin[v] + 
                w\ Sin[x], \[IndentingNewLine]i\ Sin[j] + k\ Sin[l] - 
                m\ Sin[n] - o\ Sin[p] - q\ Sin[r] - s\ Sin[t] + u\ Sin[v] + 
                w\ Sin[x]}/16];\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".12 Shapes for larger tables."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[BoxData[
    \(sh["\<C3C4C2\>"] := 
      Module[{fa = a - b - g + h + m - n - s + t, 
          fb = b - c - h + i + n - o - t + u, 
          fc = c - a - i + g + o - m - u + s, 
          fd = d - e - j + k + p - q - v + w, 
          fe = e - f - k + l + q - r - w + x, 
          ff = f - d - l + j + r - p - x + v, 
          ga = a - b - g + h - m + n + s - t, 
          gb = b - c - h + i - n + o + t - u, 
          gc = c - a - i + g - o + m + u - s, 
          gd = d - e - j + k - p + q + v - w, 
          ge = e - f - k + l - q + r + w - x, 
          gf = f - d - l + j - r + p - v + x}, gp =. ; 
        gi = {1, 3, 2, 10, 12, 11, 7, 9, 8, 4, 6, 5, 13, 15, 14, 22, 24, 23, 
            19, 21, 20, 16, 18, 17, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}; {a + 
            b + c + d + e + f + g + h + i + j + k + l + m + n + o + p + q + 
            r + s + t + u + v + w + x, \[IndentingNewLine]a + b + c - d - e - 
            f + g + h + i - j - k - l + m + n + o - p - q - r + s + t + u - 
            v - w - x, \[IndentingNewLine]a + b + c + d + e + f + g + h + i + 
            j + k + l - m - n - o - p - q - r - s - t - u - v - w - 
            x, \[IndentingNewLine]a + b + c - d - e - f + g + h + i - j - k - 
            l - m - n - o + p + q + r - s - t - u + v + w + 
            x, \[IndentingNewLine]\((a + b + c - g - h - i - m - n - o + s + \
t + u)\)\^2 + \((d + e + f - j - k - l - p - q - r + v + w + x)\)\^2, \
\[IndentingNewLine]\((a + b + c - g - h - i + m + n + o - s - t - u)\)\^2 + \
\((d + e + f - j - k - l + p + q + r - v - w - x)\)\^2, \
\[IndentingNewLine]\((\ \ \ \ \((a - b + d - e + g - h + j - k + m - n + p - \
q + s - t + v - w)\)\^2 + \((b - c + e - f + h - i + k - l + n - o + q - r + \
t - u + w - x)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l - m + o - p + r - \
s + u - v + x)\)\^2)\)/
            2, \[IndentingNewLine]\((\ \ \ \ \((a - b + d - e + g - h + j - k \
- m + n - p + q - s + t - v + w)\)\^2 + \((b - c + e - f + h - i + k - l - n \
+ o - q + r - t + u - w + x)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l + m \
- o + p - r + s - u + v - x)\)\^2)\)/
            2, \[IndentingNewLine]\((\ \ \ \ \((a - b - d + e + g - h - j + k \
+ m - n - p + q + s - t - v + w)\)\^2 + \((b - c - e + f + h - i - k + l + n \
- o - q + r + t - u - w + x)\)\^2 + \((\(-a\) + c + d - f - g + i + j - l - m \
+ o + p - r - s + u + v - x)\)\^2)\)/
            2, \[IndentingNewLine]\((\ \ \ \ \((a - b - d + e + g - h - j + k \
- m + n + p - q - s + t + v - w)\)\^2 + \((b - c - e + f + h - i - k + l - n \
+ o + q - r - t + u + w - x)\)\^2 + \((\(-a\) + c + d - f - g + i + j - l + m \
- o - p + r + s - u - v + x)\)\^2)\)/
            2, \[IndentingNewLine]\((\((fa + fd)\)\^4 + \((fa - fd)\)\^4 + \
\((fb + fe)\)\^4 + \((fb - fe)\)\^4 + \((fc + ff)\)\^4 + \((fc - ff)\)\^4)\)/
              4 - \((fa\^2 + fb\^2 + fc\^2)\) \((fd\^2 + fe\^2 + 
                  ff\^2)\), \[IndentingNewLine]\((\((ga + gd)\)\^4 + \((ga - \
gd)\)\^4 + \((gb + ge)\)\^4 + \((gb - ge)\)\^4 + \((gc + gf)\)\^4 + \((gc - \
gf)\)\^4)\)/4 - \((ga\^2 + gb\^2 + gc\^2)\) \((gd\^2 + ge\^2 + 
                  gf\^2)\)}]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(sh["\<CL31C2\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 18, 3, 4, 5, 6, 23, 8, 9, 10, 27, 12, 29, 14, 31, 32, 17, 2, 
            19, 20, 21, 22, 7, 24, 25, 26, 11, 28, 13, 30, 15, 16, 1, 1, 1, 
            1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 4}; {a + b + c + d + e + 
            f + g + h - i - j - k - l - m - n - o - p + q + r + s + t + u + 
            v + w + x - y - 
            z - \[Alpha] - \[Beta] - \[Gamma] - \[Delta] - \[CurlyEpsilon] - \
\[Zeta], a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - p + q + 
            r + s + t - u - v - w - x + y + 
            z + \[Alpha] + \[Beta] - \[Gamma] - \[Delta] - \[CurlyEpsilon] - \
\[Zeta], a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p + q + 
            r - s - t + u + v - w - x + y + 
            z - \[Alpha] - \[Beta] + \[Gamma] + \[Delta] - \[CurlyEpsilon] - \
\[Zeta], a + b - c - d - e - f + g + h - i - j + k + l + m + n - o - p + q + 
            r - s - t - u - v + w + x - y - 
            z + \[Alpha] + \[Beta] + \[Gamma] + \[Delta] - \[CurlyEpsilon] - \
\[Zeta], a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p + q - 
            r + s - t + u - v + w - x + y - 
            z + \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[CurlyEpsilon] - \
\[Zeta], a - b + c - d - e + f - g + h - i + j - k + l + m - n + o - p + q - 
            r + s - t - u + v - w + x - y + 
            z - \[Alpha] + \[Beta] + \[Gamma] - \[Delta] + \[CurlyEpsilon] - \
\[Zeta], a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p + q - 
            r - s + t + u - v - w + x - y + 
            z + \[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \[CurlyEpsilon] - \
\[Zeta], a - b - c + d - e + f + g - h + i - j - k + l - m + n + o - p + q - 
            r - s + t - u + v + w - x + y - 
            z - \[Alpha] + \[Beta] - \[Gamma] + \[Delta] + \[CurlyEpsilon] - \
\[Zeta], a - b - c + d - e + f + g - h - i + j + k - l + m - n - o + p + q - 
            r - s + t - u + v + w - x - y + 
            z + \[Alpha] - \[Beta] + \[Gamma] - \[Delta] - \[CurlyEpsilon] + \
\[Zeta], a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p + q - 
            r - s + t + u - v - w + x + y - 
            z - \[Alpha] + \[Beta] + \[Gamma] - \[Delta] - \[CurlyEpsilon] + \
\[Zeta], a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p + q - 
            r + s - t - u + v - w + x + y - 
            z + \[Alpha] - \[Beta] - \[Gamma] + \[Delta] - \[CurlyEpsilon] + \
\[Zeta], a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p + q - 
            r + s - t + u - v + w - x - y + 
            z - \[Alpha] + \[Beta] - \[Gamma] + \[Delta] - \[CurlyEpsilon] + \
\[Zeta], a + b - c - d - e - f + g + h + i + j - k - l - m - n + o + p + q + 
            r - s - t - u - v + w + x + y + 
            z - \[Alpha] - \[Beta] - \[Gamma] - \[Delta] + \[CurlyEpsilon] + \
\[Zeta], a + b - c - d + e + f - g - h - i - j + k + l - m - n + o + p + q + 
            r - s - t + u + v - w - x - y - 
            z + \[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[CurlyEpsilon] + \
\[Zeta], a + b + c + d - e - f - g - h - i - j - k - l + m + n + o + p + q + 
            r + s + t - u - v - w - x - y - 
            z - \[Alpha] - \[Beta] + \[Gamma] + \[Delta] + \[CurlyEpsilon] + \
\[Zeta], a + b + c + d + e + f + g + h + i + j + k + l + m + n + o + p + q + 
            r + s + t + u + v + w + x + y + 
            z + \[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[CurlyEpsilon] + \
\[Zeta], \(-4\)\ \((\(-\((\(-\((h - x)\)\)\ \((i - y)\) - \((g - w)\)\ \((j - 
                                z)\) + \((f - 
                                v)\)\ \((k - \[Alpha])\) + \((e - 
                                u)\)\ \((l - \[Beta])\) - \((d - 
                                t)\)\ \((m - \[Gamma])\) - \((c - 
                                s)\)\ \((n - \[Delta])\) + \((b - 
                                r)\)\ \((o - \[CurlyEpsilon])\) + \((a - 
                                q)\)\ \((p - \[Zeta])\))\)^2\) - \((\(-\((g - 
                                w)\)\)\ \((i - y)\) + \((h - x)\)\ \((j - 
                              z)\) + \((e - u)\)\ \((k - \[Alpha])\) - \((f - 
                              v)\)\ \((l - \[Beta])\) - \((c - 
                              s)\)\ \((m - \[Gamma])\) + \((d - 
                              t)\)\ \((n - \[Delta])\) + \((a - 
                              q)\)\ \((o - \[CurlyEpsilon])\) - \((b - 
                              r)\)\ \((p - \[Zeta])\))\)^2 + \((\(-\((f - 
                                v)\)\)\ \((i - y)\) + \((e - u)\)\ \((j - 
                              z)\) + \((h - x)\)\ \((k - \[Alpha])\) - \((g - 
                              w)\)\ \((l - \[Beta])\) - \((b - 
                              r)\)\ \((m - \[Gamma])\) + \((a - 
                              q)\)\ \((n - \[Delta])\) + \((d - 
                              t)\)\ \((o - \[CurlyEpsilon])\) - \((c - 
                              s)\)\ \((p - \[Zeta])\))\)^2 + \((\(-\((d - 
                                t)\)\)\ \((i - y)\) + \((c - s)\)\ \((j - 
                              z)\) - \((b - r)\)\ \((k - \[Alpha])\) + \((a - 
                              q)\)\ \((l - \[Beta])\) - \((h - 
                              x)\)\ \((m - \[Gamma])\) + \((g - 
                              w)\)\ \((n - \[Delta])\) - \((f - 
                              v)\)\ \((o - \[CurlyEpsilon])\) + \((e - 
                              u)\)\ \((p - \[Zeta])\))\)^2 + \((\(-\((d - 
                                t)\)\)\ \((e - u)\) + \((c - s)\)\ \((f - 
                              v)\) - \((b - r)\)\ \((g - w)\) + \((a - 
                              q)\)\ \((h - 
                              x)\) + \((l - \[Beta])\)\ \((m - \[Gamma])\) - \
\((k - \[Alpha])\)\ \((n - \[Delta])\) + \((j - 
                              z)\)\ \((o - \[CurlyEpsilon])\) - \((i - 
                              y)\)\ \((p - \[Zeta])\))\)^2)\) + \((\((a - \
q)\)\^2 + \((b - r)\)\^2 - \((c - s)\)\^2 - \((d - t)\)\^2 - \((e - u)\)\^2 - \
\((f - v)\)\^2 + \((g - w)\)\^2 + \((h - x)\)\^2 - \((i - y)\)\^2 - \((j - z)\
\)\^2 + \((k - \[Alpha])\)\^2 + \((l - \[Beta])\)\^2 + \((m - \[Gamma])\)\^2 \
+ \((n - \[Delta])\)\^2 - \((o - \[CurlyEpsilon])\)\^2 - \((p - \
\[Zeta])\)\^2)\)^2}]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9],

Cell[BoxData[
    \(sh["\<CL4C2\>"] := 
      Module[{}, gp =. ; 
        gi = {1, 2, 3, 20, 5, 22, 23, 24, 9, 26, 27, 28, 29, 30, 31, 16, 17, 
            18, 19, 4, 21, 6, 7, 8, 25, 10, 11, 12, 13, 14, 15, 32, 1, 1, 1, 
            1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 4}; {a + b + c + d + e + 
            f + g + h - i - j - k - l - m - n - o - p + q + r + s + t + u + 
            v + w + x - y - 
            z - \[Alpha] - \[Beta] - \[Gamma] - \[Delta] - \[CurlyEpsilon] - \
\[Zeta], a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - p + q + 
            r + s + t - u - v - w - x + y + 
            z + \[Alpha] + \[Beta] - \[Gamma] - \[Delta] - \[CurlyEpsilon] - \
\[Zeta], a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p + q + 
            r - s - t + u + v - w - x + y + 
            z - \[Alpha] - \[Beta] + \[Gamma] + \[Delta] - \[CurlyEpsilon] - \
\[Zeta], a + b - c - d - e - f + g + h - i - j + k + l + m + n - o - p + q + 
            r - s - t - u - v + w + x - y - 
            z + \[Alpha] + \[Beta] + \[Gamma] + \[Delta] - \[CurlyEpsilon] - \
\[Zeta], a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p + q - 
            r + s - t + u - v + w - x + y - 
            z + \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[CurlyEpsilon] - \
\[Zeta], a - b + c - d - e + f - g + h - i + j - k + l + m - n + o - p + q - 
            r + s - t - u + v - w + x - y + 
            z - \[Alpha] + \[Beta] + \[Gamma] - \[Delta] + \[CurlyEpsilon] - \
\[Zeta], a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p + q - 
            r - s + t + u - v - w + x - y + 
            z + \[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \[CurlyEpsilon] - \
\[Zeta], a - b - c + d - e + f + g - h + i - j - k + l - m + n + o - p + q - 
            r - s + t - u + v + w - x + y - 
            z - \[Alpha] + \[Beta] - \[Gamma] + \[Delta] + \[CurlyEpsilon] - \
\[Zeta], a - b - c + d - e + f + g - h - i + j + k - l + m - n - o + p + q - 
            r - s + t - u + v + w - x - y + 
            z + \[Alpha] - \[Beta] + \[Gamma] - \[Delta] - \[CurlyEpsilon] + \
\[Zeta], a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p + q - 
            r - s + t + u - v - w + x + y - 
            z - \[Alpha] + \[Beta] + \[Gamma] - \[Delta] - \[CurlyEpsilon] + \
\[Zeta], a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p + q - 
            r + s - t - u + v - w + x + y - 
            z + \[Alpha] - \[Beta] - \[Gamma] + \[Delta] - \[CurlyEpsilon] + \
\[Zeta], a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p + q - 
            r + s - t + u - v + w - x - y + 
            z - \[Alpha] + \[Beta] - \[Gamma] + \[Delta] - \[CurlyEpsilon] + \
\[Zeta], a + b - c - d - e - f + g + h + i + j - k - l - m - n + o + p + q + 
            r - s - t - u - v + w + x + y + 
            z - \[Alpha] - \[Beta] - \[Gamma] - \[Delta] + \[CurlyEpsilon] + \
\[Zeta], a + b - c - d + e + f - g - h - i - j + k + l - m - n + o + p + q + 
            r - s - t + u + v - w - x - y - 
            z + \[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[CurlyEpsilon] + \
\[Zeta], a + b + c + d - e - f - g - h - i - j - k - l + m + n + o + p + q + 
            r + s + t - u - v - w - x - y - 
            z - \[Alpha] - \[Beta] + \[Gamma] + \[Delta] + \[CurlyEpsilon] + \
\[Zeta], a + b + c + d + e + f + g + h + i + j + k + l + m + n + o + p + q + 
            r + s + t + u + v + w + x + y + 
            z + \[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[CurlyEpsilon] + \
\[Zeta], \(-\((2 \((h - x)\) \((i - y)\) - 2 \((g - w)\) \((j - z)\) + 
                    2 \((f - v)\) \((k - \[Alpha])\) - 
                    2 \((e - u)\) \((l - \[Beta])\) - 
                    2 \((d - t)\) \((m - \[Gamma])\) + 
                    2 \((c - s)\) \((n - \[Delta])\) - 
                    2 \((b - r)\) \((o - \[CurlyEpsilon])\) + 
                    2 \((a - q)\) \((p - \[Zeta])\))\)^2\) - \((2 \((a - 
                        q)\) \((i - y)\) - 2 \((b - r)\) \((j - z)\) - 
                  2 \((c - s)\) \((k - \[Alpha])\) + 
                  2 \((d - t)\) \((l - \[Beta])\) - 
                  2 \((e - u)\) \((m - \[Gamma])\) + 
                  2 \((f - v)\) \((n - \[Delta])\) + 
                  2 \((g - w)\) \((o - \[CurlyEpsilon])\) - 
                  2 \((h - x)\) \((p - \[Zeta])\))\)^2 - \((2 \((a - 
                        q)\) \((e - u)\) - 2 \((b - r)\) \((f - v)\) - 
                  2 \((c - s)\) \((g - w)\) + 2 \((d - t)\) \((h - x)\) + 
                  2 \((i - y)\) \((m - \[Gamma])\) - 
                  2 \((j - z)\) \((n - \[Delta])\) - 
                  2 \((k - \[Alpha])\) \((o - \[CurlyEpsilon])\) + 
                  2 \((l - \[Beta])\) \((p - \[Zeta])\))\)^2 - \((2 \((a - 
                        q)\) \((c - s)\) - 2 \((b - r)\) \((d - t)\) + 
                  2 \((e - u)\) \((g - w)\) - 2 \((f - v)\) \((h - x)\) + 
                  2 \((i - y)\) \((k - \[Alpha])\) - 
                  2 \((j - z)\) \((l - \[Beta])\) + 
                  2 \((m - \[Gamma])\) \((o - \[CurlyEpsilon])\) - 
                  2 \((n - \[Delta])\) \((p - \[Zeta])\))\)^2 - \((2 \((a - 
                        q)\) \((b - r)\) + 2 \((c - s)\) \((d - t)\) + 
                  2 \((e - u)\) \((f - v)\) + 2 \((g - w)\) \((h - x)\) + 
                  2 \((i - y)\) \((j - z)\) + 
                  2 \((k - \[Alpha])\) \((l - \[Beta])\) + 
                  2 \((m - \[Gamma])\) \((n - \[Delta])\) + 
                  2 \((o - \[CurlyEpsilon])\) \((p - \[Zeta])\))\)^2 + \
\((\((a - q)\)\^2 + \((b - r)\)\^2 + \((c - s)\)\^2 + \((d - t)\)\^2 + \((e - \
u)\)\^2 + \((f - v)\)\^2 + \((g - w)\)\^2 + \((h - x)\)\^2 + \((i - y)\)\^2 + \
\((j - z)\)\^2 + \((k - \[Alpha])\)\^2 + \((l - \[Beta])\)\^2 + \((m - \
\[Gamma])\)\^2 + \((n - \[Delta])\)\^2 + \((o - \[CurlyEpsilon])\)\^2 + \((p \
- \[Zeta])\)\^2)\)^2}]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True,
  FontSize->9]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["9. Exported functions.",
  FontFamily->"Times New Roman"]], "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".1 Loop Procedures ",
  StyleBox["abbr, gpd, shape, ",
    FontSlant->"Italic"],
  StyleBox["hoopFactor, hoopShape",
    FontSlant->"Italic"],
  StyleBox[", frag, frag2, tidy, toSignedTable, cosorbit, \[Omega]=2\[Pi]/3.",
    
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(abbr[t_, o_:  1, n_: {}] := 
        Module[{a = {}, l = Length[t] - 1, f = First[t], r = Drop[t, 1], s, 
            u = Union[Drop[t, 1]], ui}, 
          Do[ui = u[\([i]\)]; s = Length[Position[r, ui]]\ ; 
            If[s > 1, u[\([i]\)] = ui\_s], {i, Length[u]}]; 
          Flatten[Join[{o\ f}, u, n]]];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(gpd[gg_]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({g = 
                If[Length[gg] \[Equal] 1 && 
                    Head[gg] \[Equal] TraditionalForm, gg[\([1]\)], gg]}\), 
            ",", 
            RowBox[{"If", "[", 
              
              RowBox[{\(Length[g] \[Equal] 
                    Length[g[\([1]\)]] && \((MatrixQ[g[\([1, 1]\)]] || 
                      Union[Flatten[Abs[g], 1]] \[Equal] 
                        Sort[Abs[g[\([1]\)]]])\)\), ",", "g", ",", 
                RowBox[{
                  StyleBox[\(Print[Short[g], "\< is not a groupoid\>"]\),
                    FontColor->RGBColor[1, 0, 1]], ";", \(Abort[]\)}]}], 
              "]"}]}], "]"}]}], 
      ";"}], "\n", \(shape[a_?VectorQ, g_:  gmn] := 
        Chop[sh[g] /. fromAlph[a], hmin];\), "\n", \(hoopFactor[
          f_Symbol:  fp] := 
        Module[{i, gf, gl = Length[glo], n, res = {}}, 
          gi = Position[Abs[glo], 1]; 
          gi = \(Drop[Transpose[gi], 1]\)[\([1]\)]*
              Table[i = ii; 
                Sign[glo[\([gi[\([i, 1]\)], gi[\([i, 2]\)]]\)]], {ii, gl}]; 
          gf = f[glo]; 
          gf = If[Head[gf] === Times, List @@ gf, {gf}];  (*\ 
            that\ deals\ with\ single\ and\ repeated\ single\ factors . \ 
                  Remove\ any\  - 1\ factor\ *) \[IndentingNewLine]If[
            gf[\([1]\)] === \(-1\), gf = Drop[gf, 1]]; \[IndentingNewLine]Do[
            n = gf[\([i]\)]; 
            If[Head[n] === Power, AppendTo[res, n[\([1]\)]]; 
              AppendTo[gi, n[\([\(-1\)]\)]], AppendTo[res, n]; 
              AppendTo[gi, 1]], {i, Length[gf]}]; res];\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(hoopShape[]\), ":=", 
        RowBox[{"Which", "[", 
          
          RowBox[{\(Head[glo] === List\), ",", \(hoopShape[glo, \(-1\)]\), 
            ",", "\[IndentingNewLine]", \(Head[gmn] === Symbol\), ",", 
            StyleBox[\(Print["\<Neither glo nor gmn set\>"]\),
              FontColor->RGBColor[1, 0, 1]], ",", 
            "\[IndentingNewLine]", \(Head[sh[gmn]] === sh\), 
            ",", \(frag[hoopFactor[fa]]\), ",", "\[IndentingNewLine]", "True",
             ",", \(sh[gmn]\)}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(hoopShape[m_?IntegerQ, n_] := 
        hoopShape[
          mp[m, n]];\), "\[IndentingNewLine]", \(hoopShape[X_, 
            o_:  0] /; \((Head[X] === String)\) || Head[X] === Symbol := 
        hoopShape[makeProtoloop[X], 
          o];\), "\[IndentingNewLine]", \(hoopShape[X_, o_:  0] /; 
          Head[X] \[Equal] TraditionalForm := 
        hoopShape[X[\([1]\)], o];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(hoopShape[X_, o_:  0] /; MatrixQ[X]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({g = X, gf, gm, res = {}, r = {}}\), ",", 
            
            RowBox[{\(If[X === glo, Null, 
                g = If[o \[Equal] \(-1\), X, caylindex[gpd[X]]]]\), ";", 
              RowBox[{"If", "[", 
                RowBox[{\(o > 0 && \(! \((conservativeQ[])\)\)\), ",", 
                  RowBox[{
                    StyleBox[\(Print["\<Table not conservative\>"]\),
                      FontColor->RGBColor[1, 0, 1]], ";", \(Abort[]\)}]}], 
                "]"}], ";", "\[IndentingNewLine]", \(id[g]\), 
              ";", \(hoopFactor[]\), 
              ";", \(Do[
                If[Head[X\[LeftDoubleBracket]in, 1\[RightDoubleBracket]] === 
                    Symbol, 
                  AppendTo[r, 
                    alph\[LeftDoubleBracket]in\[RightDoubleBracket] \[Rule] 
                      X\[LeftDoubleBracket]in, 1\[RightDoubleBracket]]], {in, 
                  mm}]\), ";", "\[IndentingNewLine]", \(gm = fp[g] /. r\), 
              ";", \(res = sh[gmn]\), ";", "\[IndentingNewLine]", 
              RowBox[{"Which", "[", "\[IndentingNewLine]", 
                RowBox[{\(gmn \[Equal] "\<Unrecognised\>" || 
                    Head[res] \[Equal] sh\), ",", \(res = frag[fa[g]]; 
                  sh[gmn] = frag[res, o]\), ",", 
                  "\[IndentingNewLine]", \(\((gmn \[NotEqual] 
                        Unrecognized)\) && fp[makeProtoloop[gmn]] === gm\), 
                  ",", 
                  RowBox[{
                    RowBox[{"If", "[", 
                      RowBox[{\(o > 0\), ",", 
                        StyleBox[\(Print[gmn <> Protoloop]\),
                          FontColor->RGBColor[0, 1, 0]]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    "   ", \(If[Head[res] \[Equal] sh, res = hoopFactor[fa]; 
                      sh[gmn] = res]\)}], ",", 
                  "\[IndentingNewLine]", \(gmn \[NotEqual] Unrecognized && 
                    Length[res] === Length[gm]\), ",", 
                  RowBox[{"If", "[", 
                    RowBox[{\(o > 0\), ",", 
                      StyleBox[\(Print[gmn <> Isomorph]\),
                        FontColor->RGBColor[0, 1, 0]]}], "]"}], ",", 
                  "\[IndentingNewLine]", "True", ",", 
                  RowBox[{"If", "[", 
                    RowBox[{\(o \[NotEqual] 0\), ",", 
                      StyleBox[\(Print[gmn <> "\<Shape found\>"]\),
                        FontColor->RGBColor[0, 1, 0]]}], "]"}]}], "]"}], ";", 
              "\[IndentingNewLine]", \(If[Length[r] \[Equal] mm, res /. r, 
                res]\)}]}], "]"}]}], 
      ";"}], "\n", \(hoopShape[Unrecognized, o_:  0] := 
        sh[Unrecognized];\), "\n", \(hoopShape[X_, o_:  0] /; 
          Head[X] \[Equal] List := 
        hoopShape[makeProtoloop[{X[\([1]\)], X[\([2]\)]}], 
          0];\), "\[IndentingNewLine]", \(hoopShape[gg_, o_:  0] := 
        Module[{g = makeProtoloop[gg], res}, 
          res = If[g === "\<No Protoloop\>", hoopFactor[fa]; 
              sh[Unrecognized], 
              sh[\(gd[]\)\[LeftDoubleBracket]3, 1\[RightDoubleBracket]]]; 
          frag[If[Head[res] \[Equal] sh, hoopFactor[fa], res, res], 
            o]];\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(polsort[P_] := 
        Module[{i, j, l, p = Expand[P], t, v}, v = Variables[p]; \ 
          l = Length[v]; \ t = Table[Position[p, v[\([i]\)]], {i, l}]; \ 
          Table[Table[
              p[\([t[\([v, j, 1]\)]]\)], {j, Length[t[\([v]\)]]}], {v, 
              l}]];\)\ \), "\[IndentingNewLine]", 
    \(\(frag[p_, o_:  0] := 
        Module[{P, res}, P = If[MatrixQ[p], fa[p], p]; 
          If[Head[P] === Plus, P = {P}]; 
          If[Head[res = sh[P]] === List, res, res = {}; 
            Do[AppendTo[res, 
                If[Head[P[\([ii]\)]] === Power, frag2[P[\([ii, 1]\)], o], 
                  frag2[P[\([ii]\)], o]]], {ii, Length[P]}]; 
            res]];\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(frag2[\((P_)\)?PolynomialQ, o_:  0]\), ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({ai, aj, d = 1, err, f, fn = 0, f2 = {{}, {}, {}, {}}, i, 
              kf = {}, l, np = 1, nw, p = polsort[Expand[P]], pi, pip, p1, 
              p2, res = {}, sgn, t, v, vf = {}, addnew}\), ",", 
            RowBox[{
              RowBox[{"If", "[", 
                
                RowBox[{\(P === \(-a\^2\) - b\^2 || \((p = 
                        polsort[Expand[P]]; MatrixQ[p] === False)\) || 
                    Max[Exponent[Plus @@ p, a]] \[NotEqual] 2\), 
                  ",", \(Return[P]\), ",", "\[IndentingNewLine]", 
                  
                  RowBox[{\(addnew[t_] := 
                      If[MemberQ[res, t] === False, AppendTo[res, t]]\), ";", 
                    " ", \(l = Length[p]\), ";", 
                    " ", \(f = FactorInteger[l]\), ";", 
                    " ", \(v = Variables[p]\), ";", "\[IndentingNewLine]", 
                    RowBox[{"Do", "[", 
                      RowBox[{
                        
                        RowBox[{\(pi = p[\([i]\)]\), ";", 
                          " ", \(ai = v[\([i]\)]\), ";", 
                          " ", \(sgn = 
                            If[Position[pi, \(-ai^2\)] \[Equal] {}, 
                              1, \(-1\)]\), ";", "\[IndentingNewLine]", 
                          RowBox[{"Which", "[", 
                            
                            RowBox[{\(Length[pi] \[Equal] 1\), 
                              ",", \(addnew[pi]\), ",", 
                              "\[IndentingNewLine]", \(Length[pi] \[Equal] 
                                2\), ",", \(addnew[
                                sgn*pos[
                                      ai + \((sgn*\((Plus @@ pi - 
                                        sgn*ai^2)\))\)/\((2*ai)\)]^2]\), 
                              ",", \(Length[
                                  Union[Position[pi, sgn*2], 
                                    Position[
                                      pi, \(-sgn\)*2]]] \[GreaterEqual] 
                                Length[pi] - 1\), ",", "\[IndentingNewLine]", 
                              "  ", \(addnew[
                                sgn*pos[
                                    Simplify[\((ai/
                                        2 + \((sgn*
                                        Plus @@ pi)\)/\((ai*2)\))\)^2]]]\), 
                              ",", \(Mod[Length[pi], 3] \[Equal] 0\), ",", 
                              
                              RowBox[{\(d = 2\), ";", 
                                " ", \(If[\((p2 = 
                                        Position[vf, 
                                        ai])\) === {}, \(fn++\); \ np = fn; \ 
                                  AppendTo[vf, Variables[pi]]; \ 
                                  AppendTo[kf, sgn], aj = ai; \ 
                                  If[True, aj = \(-ai\)]; \ 
                                  np = First[Flatten[p2]]]\), ";", 
                                "\[IndentingNewLine]", \(pip = 
                                  Expand[Plus @@ pi/ai - sgn*ai]\), 
                                ";", \(AppendTo[f2[\([np]\)], 
                                  pos[Plus @@ 
                                      Flatten[{ai, 
                                        1/2*Union[
                                        sgn*Extract[pip, Position[pip, 2*_]], 
                                        sgn*Extract[pip, 
                                        Position[pip, \(-2\)*_]]]}]]]\), ";", 
                                
                                RowBox[{"If", "[", 
                                  RowBox[{\(o > 2\), ",", 
                                    
                                    StyleBox[\(Print[{"\<pi,pip,f2\>", pi, 
                                        pip, f2}]\),
                                      FontColor->RGBColor[0, 1, 0]]}], 
                                  "]"}]}], ",", "\[IndentingNewLine]", 
                              StyleBox["_",
                                FontColor->RGBColor[1, 0, 1]], 
                              StyleBox[",",
                                FontColor->RGBColor[1, 0, 1]], 
                              StyleBox[\(Abort[]\),
                                FontColor->RGBColor[1, 0, 1]]}], "]"}]}], 
                        ",", \({i, l}\)}], "]"}], ";", " ", 
                    RowBox[{"If", "[", 
                      RowBox[{\(d \[Equal] 2\), ",", 
                        RowBox[{"Do", "[", 
                          RowBox[{
                            
                            RowBox[{\(p1 = Union[f2[\([i]\)]]\), ";", 
                              " ", \(If[p1 \[NotEqual] {}, 
                                sgn = kf[\([i]\)]; \ 
                                AppendTo[res, 
                                  sgn*\((p1[\([1]\)] - p1[\([2]\)])\)^2]; \ 
                                AppendTo[res, 
                                  sgn*\((p1[\([2]\)] - p1[\([3]\)])\)^2]; \ 
                                AppendTo[res, 
                                  sgn*\((p1[\([1]\)] - p1[\([3]\)])\)^2]]\), 
                              ";", " ", 
                              RowBox[{"If", "[", 
                                RowBox[{\(o > 0\), ",", 
                                  
                                  StyleBox[\(Print[{"\<i,p1,res\>", i, p1, 
                                        res}]\),
                                    FontColor->RGBColor[0, 1, 0]]}], "]"}]}], 
                            ",", \({i, Length[f2]}\)}], "]"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", \(res = Plus @@ res/d\), ";", 
                    " ", \(If[Head[res] \[Equal] List, res = res[\([1]\)]]\), 
                    ";", "\[IndentingNewLine]", \(err = 
                      Flatten[{Expand[
                              P - res]} /. {Plus[a_, 
                                Times[c_, b_]] \[Rule] {a, b\ c}, 
                            Plus[a_, b_] \[Rule] {a, b}}]\), ";", 
                    "\[IndentingNewLine]", \(If[
                      err \[NotEqual] {0}, \[IndentingNewLine]Do[
                        v = Variables[err[\([i]\)]]; \ 
                        pip = Position[res, 
                            v[\([1]\)] + 
                              v[\([2]\)] \((sgn = 
                                    If[err[\([1]\)] < 0, 
                                      1, \(-1\), \(-1\)])\)]; \
\[IndentingNewLine]res = 
                          ReplacePart[res, v[\([1]\)] - sgn*v[\([2]\)], 
                            pip], \[IndentingNewLine]{i, 
                          Length[
                            err]}] (*End\ Do*) \[IndentingNewLine]]\), \( \
(*End\ \(\(If\)\([\)\(err \[NotEqual] {0}\)\)*) \), ";"}]}], 
                "\[IndentingNewLine]", 
                "]"}], \( (*End\ \(\(If\)\([\)\(P\)\(\ \)\)*) \), 
              ";", \(err = 
                Flatten[{Expand[
                        P - res]} /. {Plus[a_, Times[c_, b_]] \[Rule] {a, 
                          b\ c}, Plus[a_, b_] \[Rule] {a, b}}]\), ";", 
              "\[IndentingNewLine]", \(If[err \[NotEqual] {0}, 
                Print["\<Frag2 failed to correct an error\>"]; Abort[]]\), 
              ";", "res"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(SetAttributes[frag2, 
      Listable]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[TextData[{
  "\tfrag2 heuristically attempts to fragment the quadratic factors of loop \
tables. ",
  StyleBox["polsort ",
    FontSlant->"Italic"],
  "is used on the expanded polynomial; if this is not a matrix the polynomial \
is rejected as unsymmetrical. Polynomials higher than quadratic are returned \
unchanged. An ",
  StyleBox["addnew",
    FontSlant->"Italic"],
  " function is defined; it adds new terms to ",
  StyleBox["res",
    FontSlant->"Italic"],
  ", ignoring any already present. Factors of length = 1 ( and ",
  Cell[BoxData[
      \(\(-a\^2\) - b\^2\)],
    PageWidth->WindowWidth,
    InitializationCell->True],
  ") are passed through unchanged. Non-ternary terms are created with a \
positive first component. Ternary terms have a divisor ",
  StyleBox["d",
    FontSlant->"Italic"],
  "=2 and are handled next, with various adjustments. The result is compared \
with the original, and errors are fiddled."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
    RowBox[{\(tidy[gg_?indexTableQ, n_: - 1, o_:  1, p_: {}]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({a, b, c, d, 
            g = If[Length[gg] \[Equal] 1, gg[\([1]\)], gg], gl, m, nb, r, 
            q}\), ",", 
          
          RowBox[{\(gl = Length[g]\), ";", 
            "\[IndentingNewLine]", \(If[Length[n] == 0, 
              b = \(subgroups[g]\)[\([\(-n\)]\)], b = n, b = n]\), ";", " ", 
            StyleBox[\( (*\ Find\ subgroup\ if\ list\ not\ supplied\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(nb = Length[b]\), ";", \(m = gl/nb\), 
            ";", " ", \(If[\(! IntegerQ[m]\), Abort[]]\), ";", "  ", 
            StyleBox[\( (*\ nb\ must\ divide\ gl\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(r = Complement[Range[gl], b]\), 
            ";", \(If[MemberQ[r, o], b = Join[b, {o}]]\), 
            ";", \(r = Complement[r, b]\), ";", \(c = Join[b, r]\), 
            ";", \(b = c\), 
            ";", \(d = \(Transpose[reorder[g, c]]\)[\([nb + 1]\)]\), ";", 
            StyleBox[\( (*\ Run\ to\ find\ column\ for\ sorting\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(Do[
              b[\([j + nb]\)] = c[\([d[\([j]\)]]\)], {j, 2, nb}]\), ";", " ", 
            
            StyleBox[\( (*\ Rearrange\ col\ nb + 1\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(If[m > 2, b = Take[b, 2  nb]; 
              r = Complement[Range[gl], b]; \[IndentingNewLine]If[
                Length[p] > 1, b = Join[b, p]; 
                b = Join[b, Complement[Range[gl], b]], \[IndentingNewLine]If[
                  MemberQ[r, p], b = Join[b, {p}]]; \[IndentingNewLine]b = 
                  Join[b, Complement[r, b]]]]\), ";", 
            StyleBox[\( (*\ Add\ other\ elements\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(Print[b]\), ";", \(reorder[g, b]\)}]}], 
        "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{\(ts[a___] := toSignedTable[a]\), ";", 
      RowBox[{\(toSignedTable[g_?indexTableQ, r_Integer : 2, reo_ : {}, 
          o_ : 0]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({diags, diagelements, dis, gg = g, i, j, l = Length[g], 
              nex = 1, n = Abs[r], ps, rr = {}, res, s}\), ",", 
            RowBox[{
              RowBox[{"If", "[", 
                RowBox[{\(reo \[NotEqual] {}\), ",", 
                  RowBox[{\(gg = reorder[gg, reo]\), ";", 
                    RowBox[{"If", "[", 
                      RowBox[{\(o > 1\), ",", 
                        StyleBox[\(Print[{"\<reordered\>", tf[gg]}]\),
                          FontColor->RGBColor[0, 1, 0]]}], "]"}]}]}], "]"}], 
              ";", 
              RowBox[{"If", "[", 
                RowBox[{\(Length[gg] === Length[g]\), ",", 
                  RowBox[{"If", "[", 
                    RowBox[{\(negatableQ[gg, n] \[Equal] True\), ",", 
                      RowBox[{
                        RowBox[{"If", "[", 
                          RowBox[{\(o > 2\), ",", 
                            
                            StyleBox[\(Print[{"\<Immediately \>", 
                                  n, "\<negatable\>"}]\),
                              FontColor->RGBColor[0, 1, 0]]}], "]"}], 
                        ";", \(gg = Take[Transpose[Take[gg, l\/n]], l\/n]\)}],
                       ",", 
                      
                      RowBox[{\(diags = 
                          Table[gg\[LeftDoubleBracket]ii, 
                              ii\[RightDoubleBracket], {ii, l}]\), 
                        ";", \(diagelements = Union[diags]\), ";", 
                        RowBox[{"If", "[", 
                          RowBox[{\(o \[NotEqual] 0\), ",", 
                            
                            StyleBox[\(Print[{diags, "\<diags,elems\>", 
                                  diagelements}]\),
                              FontColor->RGBColor[0, 1, 0]]}], "]"}], 
                        ";", \(res = Table[0, {l\/n}]\), ";", 
                        RowBox[{"Do", "[", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"If", "[", 
                                
                                RowBox[{\(Mod[
                                      Length[
                                        diagelements\[LeftDoubleBracket]
                                        jj\[RightDoubleBracket]], 
                                      n] \[NotEqual] 0\), ",", 
                                  RowBox[{
                                    
                                    StyleBox[\(Print[{"\<not \>", 
                                        n, "\<negatable\>"}]\),
                                      FontColor->RGBColor[1, 0, 1]], 
                                    ";", \(Abort[]\)}], ",", 
                                  
                                  RowBox[{\(ps = 
                                      Position[
                                        diags, \(Union[
                                        diagelements]\)\[LeftDoubleBracket]jj\
\[RightDoubleBracket]]\), ";", 
                                    RowBox[{"If", "[", 
                                      RowBox[{\(o > 1\), ",", 
                                        
                                        StyleBox[\(Print[{"\<ps,jj,nex\>", 
                                        ps, jj, nex}]\),
                                        FontColor->RGBColor[0, 1, 0]]}], 
                                      "]"}], ";", 
                                    RowBox[{"If", "[", 
                                      
                                      RowBox[{\(Mod[Length[ps], 
                                        n] \[NotEqual] 0\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{"\<not \>", 
                                        n, "\<negatable\>"}]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        ";", \(Abort[]\)}]}], "]"}], 
                                    ";", \(Do[
                                      res\[LeftDoubleBracket]nex\
\[RightDoubleBracket] = 
                                        ps\[LeftDoubleBracket]nx\
\[RightDoubleBracket]; \(nex++\), {nx, Length[ps]\/n}]\)}]}], "]"}], ";", 
                              RowBox[{"If", "[", 
                                RowBox[{\(o \[NotEqual] 0\), ",", 
                                  RowBox[{
                                    StyleBox["Print",
                                      FontColor->RGBColor[0, 1, 0]], 
                                    StyleBox["[",
                                      FontColor->RGBColor[0, 1, 0]], 
                                    StyleBox[\(Flatten[{"\<res\>", res}]\),
                                      FontColor->RGBColor[0, 1, 0]], "]"}]}], 
                                "]"}]}], 
                            ",", \({jj, Length[diagelements\/n]}\)}], "]"}], 
                        ";", \(gg = reorder[g, Flatten[res]]\)}]}], "]"}]}], 
                "]"}], ";", \(s = Length[gg]\), ";", \(i =. \), 
              ";", \(rr = {}\), 
              ";", \(Do[
                Which[n \[Equal] 2, AppendTo[rr, i + s \[Rule] \(-i\)], 
                  n \[Equal] 3, 
                  AppendTo[rr, i + s \[Rule] \[DoubleStruckCapitalJ]\ i]; 
                  AppendTo[rr, 
                    i + 2\ s \[Rule] \[DoubleStruckCapitalJ]\ \
\[DoubleStruckCapitalJ]\ i], n \[Equal] 4, 
                  AppendTo[rr, i + s \[Rule] \[ImaginaryI]\ i]; 
                  AppendTo[rr, i + 2\ s \[Rule] \(-i\)]; 
                  AppendTo[rr, i + 3\ s \[Rule] \(-\[ImaginaryI]\)\ i]], {i, 
                  s}]\), ";", \(If[o > 1, Print[{rr, s}]]\), 
              ";", \(glo = 
                Table[gg\[LeftDoubleBracket]i, 
                      j\[RightDoubleBracket] /. \[InvisibleSpace]rr, {i, 
                    s}, {j, s}]\), ";", \(mm = Length[glo]\), ";", 
              RowBox[{"If", "[", 
                RowBox[{\(indexTableQ[glo]\), ",", 
                  RowBox[{"If", "[", 
                    
                    RowBox[{\(r > 0 && conservativeQ[glo] \[NotEqual] True\), 
                      ",", 
                      RowBox[{
                        StyleBox[\(Print["\<Fail, non-conservative.\>"]\),
                          FontColor->RGBColor[1, 0, 1]], 
                        ";", \("\<TraditionalForm\>"[glo]\)}], ",", "glo"}], 
                    "]"}], ",", 
                  StyleBox[\(Print["\<Fail, not an indexTable.\>"]\),
                    FontColor->RGBColor[1, 0, 1]]}], "]"}], ";", \(id[glo]\), 
              ";", "glo"}]}], "]"}]}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[\(collapse[g_, r_]\),
          FormatType->StandardForm,
          FontFamily->"Courier New"], 
        StyleBox[":=",
          FormatType->StandardForm,
          FontFamily->"Courier New"], 
        StyleBox[\( (*Skeleton\ toSignedTable*) \),
          FormatType->StandardForm,
          FontFamily->"Courier New",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox["\[IndentingNewLine]",
          FormatType->StandardForm,
          FontFamily->"Courier New"], 
        StyleBox[\(Module[{l = Length[g]/r, 
              sr = {{}, {1, \(-1\)}, {1, J, JJ}, \ {1, \(-1\), 
                    i, \(-1\), \(-i\)}}}, \ 
            Table[\((Mod[g[\([k, j]\)] - 1, l] + 1\ )\)\ sr[\([r, 
                    Floor[\((g[\([k, j]\)] - 1)\)/l] + 1]\)], {k, l}, {j, 
                l}]]\),
          FormatType->StandardForm,
          FontFamily->"Courier New"]}], 
      StyleBox[";",
        FormatType->StandardForm,
        FontFamily->"Courier New"]}]}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(abbrFactors[g_, p_:  power2]\), ":=", 
      StyleBox["\[IndentingNewLine]",
        FontColor->RGBColor[1, 0, 
        0]], \(Module[{ap, f, ff = fp[g, p], fi, fj, i = 1, l, res = {}, 
          temp}, \[IndentingNewLine]f = 
          If[NumberQ[First[ff]], Drop[ff, 1], ff]; 
        f = If[NumberQ[First[f]], {Drop[f, 1]}, f]; 
        If[First[f] < 0, f = \(-f\)]; \[IndentingNewLine]While[
          i \[LessEqual] Length[f], fi = f[\([i]\)]; 
          If[Length[f] === 1, \(i++\); 
            fi = \(Exponent[f, "\<a\>"]\)[\([1]\)]; fj = 1; 
            Goto[done]]; \[IndentingNewLine]If[Head[f] === Power, \(i++\); 
            fj = Last[f]; 
            fi = If[Head[f[\([\(-2\), \(-1\)]\)]] === Power, 
                f[\([\(-2\), \(-1\), \(-1\)]\)], 1]; 
            Goto[done]]; \[IndentingNewLine]If[
            Head[f] === 
                Plus && \((Head[f[\([\(-1\)]\)]] === Power || 
                  Head[f[\([\(-1\)]\)]] === Times)\), i = Length[f]; 
            fi = Exponent[f, "\<a\>"]; fj = 1; 
            Goto[done]]; \[IndentingNewLine]If[NumberQ[\((fj = Last[fi])\)], 
            fi = Last[Drop[fi, \(-1\)]], fj = 1]; \[IndentingNewLine]fi = 
            Switch[Length[fi], 0, 1, 1, 1, 2, Last[fi], _, 
              Last[Last[fi]]]; \[IndentingNewLine]Label[done]; 
          fi = fi /. {"\<a\>" \[Rule] 1, \(-"\<a\>"\) \[Rule] 1, a -> 1}; 
          AppendTo[res, 
            If[fj \[Equal] 1, 
              ToString[
                fi], \((ToString[fi])\)\^ToString[fj]]]; \
\[IndentingNewLine]\(i++\)]; \[IndentingNewLine]temp = 
          Union[res = Sort[Flatten[res]]]; \[IndentingNewLine]Table[
          ap = temp[\([i]\)]; l = Length[Position[res, ap, 1]]; 
          Which[Length[ap] > 1 && l \[Equal] 1, ap[\([1]\)]\^ap[\([2]\)], 
            Length[ap] > 1, \(ap[\([1]\)]\)\_l\%\(ap[\([2]\)]\), 
            l \[Equal] 1, ap, True, ap\_l], {i, Length[temp]}]]\)}]], "Input",\

  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(cosorbit[\[Theta]_, phaselist_: {0, 1, 2, 3, 4, 5}, scale_:  1, 
        meanlist_:  Table[0, {24}]] := 
      Module[{m = Length[phaselist], i}, 
        Table[i = phaselist[\([j]\)]; 
          meanlist[\([j]\)] + 
            If[NumberQ[i], scale*Cos[\[Theta] + 2*Mod[i, m]\ \[Pi]/m], 
              0], {j, m}]]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(\(\[Omega] = 2  \[Pi]/3;\)\( (*\ 
      Used\ widely\ in\ orbits . \ 
          Placed\ here\ to\ avoid\ evaluation\ in\ their\ \
\(\(definitions\)\(.\)\)*) \)\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".2 Generation by ",
  StyleBox["ca, co, unsign, sgroup",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{\(ca[{m_, a_:  1}] := ca[m, a]; 
    ca[m_Integer?Positive] := 
      Table[Mod[i + j - 2, m] + 1, {i, m}, {j, m}];\), "\[IndentingNewLine]", 
  
    RowBox[{
      RowBox[{\(ca[m_Integer?Positive, a_Integer]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({k = Abs[a], test}\), ",", 
            RowBox[{
              RowBox[{"test", "=", 
                RowBox[{"If", "[", 
                  
                  RowBox[{\(GCD[m, k] \[Equal] 1\), 
                    ",", \(Table[
                      Mod[i + If[EvenQ[i], j\ k - k + 1, j] - 2, m] + 1, {i, 
                        m}, {j, m}]\), ",", 
                    RowBox[{
                      
                      StyleBox[\(Print[m, "\< \>", 
                          k, "\< \>", "\<GCD not 1\>"]\),
                        FontColor->RGBColor[1, 0, 1]], ";", \({}\)}], 
                    ",", \({}\)}], "]"}]}], ";", 
              RowBox[{"If", "[", 
                
                RowBox[{\(a < 0 && associativeQ[test, 1] \[Equal] False\), 
                  ",", 
                  RowBox[{
                    StyleBox[\(Print["\<Not a group\>"]\),
                      FontColor->RGBColor[1, 0, 1]], ";", "test"}], ",", 
                  "test", ",", "test"}], "]"}]}]}], "]"}]}], ";", 
      RowBox[{
        RowBox[{"ca", "[", 
          RowBox[{"m_", ",", \(k_:  0\), ",", 
            StyleBox[
              RowBox[{
                StyleBox["c",
                  FontColor->RGBColor[1, 0, 0]], "_"}]]}], "]"}], ":=", 
        RowBox[{"(*", 
          StyleBox["skeleton",
            FontColor->RGBColor[1, 0, 0]], "*)"}], 
        "\[IndentingNewLine]", \(Table[
          Mod[i + If[EvenQ[i], j\ k - k + 1, j] - 2, m] + 
            1, \[IndentingNewLine]{i, m}, {j, m}]\)}], ";"}]}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{\(co[g_?indexTableQ, gg_?indexTableQ, hh_?indexTableQ, 
        a_Integer, o_:  0] := 
      co[g, co[gg, hh, a], o]\), "\[IndentingNewLine]", \(co[g_?indexTableQ, 
        h_?indexTableQ, gg_?indexTableQ, hh_?indexTableQ, a_Integer, 
        o_Integer:  0, p_:  0] := 
      co[g, co[h, co[gg, hh, a], o], p]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(co[gg_?indexTableQ, hh_?indexTableQ, a_:  0]\), ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({any, as = Abs[a], 
              g1 = \(Dimensions[
                    gg]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
              h1 = \(Dimensions[
                    hh]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
              g = unsign[gg], h = unsign[hh], im, lm, test = {}, t, m}\), ",",
             
            
            RowBox[{\(m = g1\ h1\), ";", 
              "\[IndentingNewLine]", \(If[
                Position[gg, \[ImaginaryI]] \[NotEqual] {}, 
                g = gg /. {any_ /; Re[any] < 0 -> \(-any\) + 2  g1, 
                      Complex[r_, i_] \[Rule] 
                        If[i < 0, \(-i\) + 3  g1, i + g1]}]\), 
              ";", \(If[Position[gg, \[DoubleStruckCapitalJ]] \[NotEqual] {}, 
                g = Mod[\((gg /. {Times[\[DoubleStruckCapitalJ]\ \
\[DoubleStruckCapitalJ], any_] \[Rule] any + 2  g1, 
                              Times[\[DoubleStruckCapitalJ], any_] \[Rule] 
                                any + 
                                  g1, \[DoubleStruckCapitalJ]\ \
\[DoubleStruckCapitalJ] \[Rule] 2  g1 + 1, \[DoubleStruckCapitalJ] \[Rule] 
                                g1 + 1})\) - 1, 3  g1] + 1]\), ";", 
              RowBox[{"If", "[", 
                RowBox[{\(h \[NotEqual] hh\), ",", 
                  StyleBox[\(Print["\<Second matrix must not be signed\>"]\),
                    FontColor->RGBColor[1, 0, 1]], ",", 
                  RowBox[{"If", "[", 
                    RowBox[{\(as \[Equal] 7 && h \[NotEqual] C3\), ",", 
                      StyleBox[\(Print["\<Second matrix must be C3\>"]\),
                        FontColor->RGBColor[1, 0, 1]], ",", 
                      RowBox[{"Do", "[", 
                        RowBox[{
                          RowBox[{\(lm = l - 1\), ";", 
                            RowBox[{"Do", "[", 
                              RowBox[{
                                RowBox[{\(t = {}\), ";", 
                                  RowBox[{"Do", "[", "\[IndentingNewLine]", 
                                    RowBox[{
                                      RowBox[{"Do", "[", 
                                        RowBox[{
                                        RowBox[{
                                        "Which", "[", "\[IndentingNewLine]", 
                                        
                                        RowBox[{\(as \[Equal] 0 || 
                                        as \[Equal] 1\), 
                                        ",", \(AppendTo[
                                        t, \((h\[LeftDoubleBracket]k, 
                                        l\[RightDoubleBracket] - 1)\)\ g1 + 
                                        g\[LeftDoubleBracket]i, 
                                        j\[RightDoubleBracket]]\), ",", 
                                        "\[IndentingNewLine]", \(as < 3\), 
                                        ",", \(If[EvenQ[l] && i > 1, 
                                        AppendTo[
                                        t, \((h\[LeftDoubleBracket]k, 
                                        l\[RightDoubleBracket] - 1)\)\ g1 + 
                                        g\[LeftDoubleBracket]g1 + 2 - i, 
                                        j\[RightDoubleBracket]], 
                                        AppendTo[
                                        t, \((h\[LeftDoubleBracket]k, 
                                        l\[RightDoubleBracket] - 1)\)\ g1 + 
                                        g\[LeftDoubleBracket]i, 
                                        j\[RightDoubleBracket]]]\), ",", 
                                        "\[IndentingNewLine]", \(as \[Equal] 
                                        3\), ",", \(If[EvenQ[j] && k > 1, 
                                        AppendTo[t, 
                                        Mod[\((k + h\[LeftDoubleBracket]k, 
                                        l\[RightDoubleBracket] - 2)\)\ g1 + 
                                        g\[LeftDoubleBracket]i, 
                                        j\[RightDoubleBracket] - 1, m] + 1], 
                                        AppendTo[
                                        t, \((h\[LeftDoubleBracket]k, 
                                        l\[RightDoubleBracket] - 1)\)\ g1 + 
                                        g\[LeftDoubleBracket]i, 
                                        j\[RightDoubleBracket]]]\), ",", 
                                        "\[IndentingNewLine]", \(as \[Equal] 
                                        4\), ",", \(im = 4\ lm\ \((i - 1)\); 
                                        If[EvenQ[l] && EvenQ[i], 
                                        AppendTo[
                                        t, \((h\[LeftDoubleBracket]k, 
                                        l\[RightDoubleBracket] - 1)\)\ g1 + 
                                        g\[LeftDoubleBracket]Mod[i + im - 1, 
                                        g1] + 1, j\[RightDoubleBracket]], 
                                        AppendTo[
                                        t, \((h\[LeftDoubleBracket]k, 
                                        l\[RightDoubleBracket] - 1)\)\ g1 + 
                                        g\[LeftDoubleBracket]i, 
                                        j\[RightDoubleBracket]]]\), ",", 
                                        "\[IndentingNewLine]", \(as \[Equal] 
                                        7\), ",", \(If[lm \[Equal] 2, 
                                        lm = 3]; im = lm\ \((i - 1)\); 
                                        AppendTo[
                                        t, \((h\[LeftDoubleBracket]k, 
                                        l\[RightDoubleBracket] - 1)\)\ g1 + 
                                        g\[LeftDoubleBracket]Mod[i + im - 1, 
                                        g1] + 1, j\[RightDoubleBracket]]\), 
                                        ",", "\[IndentingNewLine]", "True", 
                                        ",", 
                                        RowBox[{
                                        StyleBox[\(Print[Unknown\ a]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        ";", \(Abort[]\)}]}], "]"}], 
                                        ",", \({i, g1}\)}], "]"}], 
                                      ",", \({k, h1}\)}], "]"}], 
                                  ";", \(AppendTo[test, 
                                    Mod[t - 1, m] + 
                                      1\[IndentingNewLine]\ \ ]\)}], 
                                ",", \({j, g1}\)}], "]"}]}], 
                          ",", \({l, h1}\)}], "]"}]}], "]"}]}], "]"}], ";", 
              RowBox[{"If", "[", 
                RowBox[{\(a < 0 || as \[Equal] 1\), ",", 
                  RowBox[{"If", "[", 
                    RowBox[{\(loopQ[test]\), ",", 
                      RowBox[{"If", "[", 
                        RowBox[{\(associativeQ[test]\), ",", "test", ",", 
                          RowBox[{
                            StyleBox[\(Print["\<Not associative\>"]\),
                              FontColor->RGBColor[0, 1, 0]], ";", "test"}]}], 
                        "]"}], ",", 
                      StyleBox[\(Print["\<Not a quasigroup\>"]\),
                        FontColor->RGBColor[0, 1, 0]]}], "]"}], ",", "test", 
                  ",", "test"}], "]"}]}]}], "]"}]}], ";"}]}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"co", "[", 
          RowBox[{"g_", ",", "h_", ",", \(a_:  0\), ",", 
            StyleBox[
              RowBox[{
                StyleBox["c",
                  FontColor->RGBColor[1, 0, 0]], "_"}]]}], "]"}], ":=", 
        RowBox[{"(*", 
          StyleBox["skeleton",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["*)",
            FontColor->RGBColor[1, 0, 0]]}], 
        "\[IndentingNewLine]", \(Module[{g1 = \(Dimensions[
                  g]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
            h1 = \(Dimensions[h]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
            im, lm, test = {}, t, m}, 
          m = g1\ h1; \[IndentingNewLine]Do[lm = l - 1; 
            Do[t = {}; 
              Do[Do[\[IndentingNewLine]Which[a \[Equal] 0 || a \[Equal] 1, 
                    AppendTo[
                      t, \((h\[LeftDoubleBracket]k, l\[RightDoubleBracket] - 
                              1)\) g1 + 
                        g\[LeftDoubleBracket]i, 
                          j\[RightDoubleBracket]], \[IndentingNewLine]a \
\[Equal] 2, If[EvenQ[l] && i > 1, 
                      AppendTo[
                        t, \((h\[LeftDoubleBracket]k, 
                                  l\[RightDoubleBracket] - 1)\) g1 + 
                          g\[LeftDoubleBracket]g1 + 2 - i, 
                            j\[RightDoubleBracket]], 
                      AppendTo[
                        t, \((h\[LeftDoubleBracket]k, 
                                  l\[RightDoubleBracket] - 1)\) g1 + 
                          g\[LeftDoubleBracket]i, 
                            j\[RightDoubleBracket]]], \[IndentingNewLine]a \
\[Equal] 3, If[EvenQ[j] && k > 1, 
                      AppendTo[t, 
                        Mod[\((k + h\[LeftDoubleBracket]k, 
                                      l\[RightDoubleBracket] - 2)\) g1 + 
                              g\[LeftDoubleBracket]i, 
                                j\[RightDoubleBracket] - 1, m] + 1], 
                      AppendTo[
                        t, \((h\[LeftDoubleBracket]k, 
                                  l\[RightDoubleBracket] - 1)\) g1 + 
                          g\[LeftDoubleBracket]i, 
                            j\[RightDoubleBracket]]], \[IndentingNewLine]a \
\[Equal] 4, im = 4  lm\ \((i - 1)\); \[IndentingNewLine]If[
                      EvenQ[l] && EvenQ[i], 
                      AppendTo[
                        t, \((h\[LeftDoubleBracket]k, 
                                  l\[RightDoubleBracket] - 1)\)\ g1 + 
                          g\[LeftDoubleBracket]Mod[i + im - 1, g1] + 1, 
                            j\[RightDoubleBracket]], 
                      AppendTo[
                        t, \((h\[LeftDoubleBracket]k, 
                                  l\[RightDoubleBracket] - 1)\) g1 + 
                          g\[LeftDoubleBracket]i, 
                            j\[RightDoubleBracket]]], \
\[IndentingNewLine]True, Print["\<Unknown a \>", a]; Abort[]], {i, g1}], {k, 
                  h1}]; AppendTo[test, Mod[t - 1, m] + 1], {j, g1}], {l, 
              h1}]; test]\)}], ";"}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(unsign[g_?MatrixQ] := 
        Module[{l = Length[g], r, e, i, ar, ai, m, p}, 
          m = Switch[Length[Union[Flatten[Sign[g]]]], 1, p = 0; l, 2, p = l; 
              2  l, _, p = 2  l; 4  l]; 
          Table[e = g[\([j, k]\)]; r = Re[e]; ar = Abs[r]; i = Im[e]; 
            ai = Abs[i]; r = ar + If[r < 0, p, 0]; 
            i = ai + Which[i \[Equal] 0, 0, i < 0, 3  l, i > 0, l]; 
            Mod[r + i - 1, m] + 1, {j, l}, {k, 
              l}]];\)\), "\[IndentingNewLine]", 
    \(sgroup[m_?IntegerQ] := 
      Module[{e = Permutations[Range[m]], n, p}, 
        n = Length[e]; \[IndentingNewLine]Table[
          p = Position[e, 
              Apply[permute, {e[\([i]\)], 
                  e[\([j]\)]}]]; \[IndentingNewLine]If[p === {}, 0, 
            p[\([1, 1]\)]], {i, n}, {j, n}]]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell["\<\
permfromQ[p_List,n_Integer]:=
  Length[Complement[p,Range[n]]]\[Equal]0&&Sort[p]\[Equal]Union[p]
  permute[P_List,p_List]:=If[permfromQ[p,Length[P]],P[[p]],Print[{P,p,\" \
error\"}]];\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".3 Functions ",
  StyleBox["centralizer, period, orderCount",
    FontSlant->"Italic"],
  ", etc."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(centralizer[a_?IntegerQ, g_:  glo] := 
      Module[{gg = If[Length[g] \[Equal] 1, g[\([1]\)], g], b, c = {}}, 
        Do[b = gg[\([i, 1]\)]; 
          If[gg[\([a, i]\)] == gg[\([i, a]\)], AppendTo[c, b]], {i, 
            Length[gg]}]; c]\), "\n", 
    \(period[g_:  glo] := 
      Module[{gg = If[Length[g] \[Equal] 1, g[\([1]\)], g], lg, a, aa, b, j, 
          P = {1}}, lg = Length[gg]; 
        Do[a = gg[\([i, 1]\)]; aa = a; j = 2; 
          While[\((b = gg[\([a, aa]\)])\) != 1 && j < lg, \(j++\); aa = b]; 
          AppendTo[P, j], {i, 2, lg}]; P]\), "\n", 
    \(orderCount[g_:  glo] := 
      Table[Length[Position[period[g], i]], {i, 
          Max[Union[period[g]]]}]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(center[g_:  glo] := centre[g];\)\), "\n", 
    \(centre[g_:  glo] := 
      Module[{gg = If[Length[g] \[Equal] 1, g[\([1]\)], g], lg, a, j, 
          Z = {}}, 
        lg = Length[gg]; \[IndentingNewLine]Do[a = gg[\([i, 1]\)]; j = 1; 
          While[gg[\([a, j]\)] == gg[\([j, a]\)] && 
              j < lg, \(j++\)]; \[IndentingNewLine]If[j == lg, 
            AppendTo[Z, a]], {i, lg}]; Z]\), "\n", 
    \(gInverse[g_:  glo] := 
      Module[{gg = If[Length[g] \[Equal] 1, g[\([1]\)], g]}, 
        Flatten[Table[
            Position[gg[\([i]\)], 1], {i, Length[gg]}]]]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{\(lcoset[h_, g_:  glo] := 
      Module[{gg = gpd[g]}, 
        Intersection[
          Table[Union[Table[gg[\([x, h[\([j]\)]]\)], {j, Length[h]}]], {x, 
              Length[gg]}]]]\), "\n", \(rcoset[h_, g_:  glo] := 
      Module[{gg = gpd[g]}, 
        Intersection[
          Table[Union[Table[gg[\([h[\([j]\)], x]\)], {j, Length[h]}]], {x, 
              Length[gg]}]]]\), "\n", \(normalSubgroup[h_, g_:  glo] := 
        lcoset[h, g] \[Equal] rcoset[h, g];\), "\n", 
    RowBox[{
      RowBox[{\(factorGroup[n_, g_:  glo]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({gg = gpd[g], lc, loc, lg, lt}\), ",", 
            RowBox[{\(lg = Length[gg]\), ";", 
              RowBox[{"If", "[", 
                
                RowBox[{\(\((lc = lcoset[n, gg])\) \[NotEqual] 
                    rcoset[n, gg]\), ",", 
                  StyleBox[\(Print[n, "\< is not a Normal subgroup\>"]\),
                    FontColor->RGBColor[1, 0, 1]], 
                  ",", \(If[lg \[Equal] Length[n], id[gg], 
                    lt = First[Transpose[lc]]; 
                    loc = Table[\(Position[lc, i]\)[\([1, 1]\)], {i, lg}]; 
                    id[Table[
                        loc[\([gg[\([lt[\([i]\)], lt[\([j]\)]]\)]]\)], {i, 
                          Length[lt]}, {j, 
                          Length[lt]}]\[IndentingNewLine]]]\)}], "]"}]}]}], 
          "]"}]}], ";"}]}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(allFactorGroups[g_:  glo, o_:  0, i1_:  2, i2_:  49, p_: {}] := 
      Module[{a, b, f = {}, gg = gpd[g], i = If[p \[NotEqual] {}, i1, i2], 
          lc, lg, loc, lr, n, res, s}, lg = Length[gg]; 
        If[o \[Equal] 0, s = subgroups[gg, 0, i1, i]]; 
        s = sg; \[IndentingNewLine]Do[n = s[\([k]\)]; 
          If[\((lc = lcoset[n, gg])\) \[Equal] rcoset[n, gg], 
            res = First[Transpose[lc]]; 
            lr = Length[res]; \[IndentingNewLine]loc = 
              Table[\(Position[lc, i]\)[\([1, 1]\)], {i, lg}]; 
            a = id[Table[
                  loc[\([gg[\([res[\([i]\)], res[\([j]\)]]\)]]\)], {i, 
                    lr}, {j, lr}]]; \[IndentingNewLine]If[p \[NotEqual] {}, 
              If[MemberQ[p, b = \(gd[a]\)[\([2]\)]], f = b; 
                Goto[tag]]]]; \[IndentingNewLine]AppendTo[f, a], {k, 
            Length[s]}]; Label[tag]; f]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".4 Tests for Table Properties ",
  StyleBox["abelianQ ",
    FontSlant->"Italic"],
  "etc."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[TextData[{
  "Note that, for signed tables, these tests are \"up to a sign\" insofar as \
the absolute values of the indices replace signed indices. ",
  StyleBox["MoufangQ",
    FontSlant->"Italic"],
  " test for exact, ",
  StyleBox["moufangQ",
    FontSlant->"Italic"],
  " for a signed match."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[{
    \(abelianQ[gg_:  glo] := 
      Module[{g = gpd[gg]}, g === Transpose[g]]\), "\n", 
    \(associativeQ[gg_:  glo, o_:  0] := 
      Catch[Module[{a, i = 1, j = 1, k = 1, g = gpd[gg], m}, m = Length[g]; 
          a = abelianQ[g]; \[IndentingNewLine]While[
            i \[LessEqual] m, \[IndentingNewLine]While[
              j \[LessEqual] m, \[IndentingNewLine]While[k \[LessEqual] m, 
                If[Abs[g\[LeftDoubleBracket]
                        Abs[g\[LeftDoubleBracket]i, j\[RightDoubleBracket]], 
                        k\[RightDoubleBracket]] \[NotEqual] 
                    Abs[g\[LeftDoubleBracket]i, 
                        Abs[g\[LeftDoubleBracket]j, 
                            k\[RightDoubleBracket]]\[RightDoubleBracket]], 
                  If[o === 0, Throw[False], 
                    Throw[{False, i, j, 
                        k}]]]; \[IndentingNewLine]\(k++\)]; \(j++\); 
              k = If[a, j, 1]]; \(i++\); 
            j = If[a, i, 
                1]]; \[IndentingNewLine]True]]\), "\[IndentingNewLine]", 
    \(AssociativeQ[gg_:  glo, o_:  0] := 
      Catch[Module[{a, i = 1, j = 1, k = 1, g = gpd[gg], m}, m = Length[g]; 
          a = abelianQ[g]; \[IndentingNewLine]While[
            i \[LessEqual] m, \[IndentingNewLine]While[
              j \[LessEqual] m, \[IndentingNewLine]While[k \[LessEqual] m, 
                If[g\[LeftDoubleBracket]Abs[
                        g\[LeftDoubleBracket]i, j\[RightDoubleBracket]], 
                      k\[RightDoubleBracket] \[NotEqual] 
                    g\[LeftDoubleBracket]i, 
                      Abs[g\[LeftDoubleBracket]j, 
                          k\[RightDoubleBracket]]\[RightDoubleBracket], 
                  If[o === 0, Throw[False], 
                    Throw[{False, i, j, 
                        k}]]]; \[IndentingNewLine]\(k++\)]; \(j++\); 
              k = If[a, j, 1]]; \(i++\); 
            j = If[a, i, 1]]; \[IndentingNewLine]True]]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(abelGrassmanQ[gg_:  glo, o_:  0] := 
      Catch[Module[{a, i = 1, j = 1, k = 1, g = gpd[gg], m}, 
          m = \(Dimensions[g]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; 
          a = abelianQ[g]; \[IndentingNewLine]While[i \[LessEqual] m, 
            While[j \[LessEqual] m, 
              While[k \[LessEqual] m, 
                If[Abs[g\[LeftDoubleBracket]
                        Abs[g\[LeftDoubleBracket]i, j\[RightDoubleBracket]], 
                        k\[RightDoubleBracket]] \[NotEqual] 
                    Abs[g\[LeftDoubleBracket]Abs[
                          g\[LeftDoubleBracket]k, j\[RightDoubleBracket]], 
                        i\[RightDoubleBracket]], 
                  If[o === 0, Throw[False], 
                    Throw[{False, i, j, 
                        k}]]]; \[IndentingNewLine]\(k++\)]; \(j++\); 
              k = If[a, j, 1]]; \(i++\); 
            j = If[a, i, 1]]; \[IndentingNewLine]True]]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(alternativeQ[gg_:  glo, o_:  0] := 
      Catch[Module[{a, i = 1, j = 1, k = 1, g = gpd[gg], m, x, y, xy, x2, 
            y2}, m = Length[g]; a = abelianQ[g]; 
          While[i \[LessEqual] m, x = Abs[g[\([1, i]\)]]; 
            x2 = Abs[g\[LeftDoubleBracket]i, i\[RightDoubleBracket]]; 
            While[j \[LessEqual] m, \[IndentingNewLine]y = 
                Abs[g\[LeftDoubleBracket]1, j\[RightDoubleBracket]]; 
              xy = Abs[g\[LeftDoubleBracket]i, j\[RightDoubleBracket]]; 
              If[Abs[g\[LeftDoubleBracket]x, 
                      xy\[RightDoubleBracket]] \[NotEqual] 
                  Abs[g\[LeftDoubleBracket]x2, y\[RightDoubleBracket]], 
                If[o \[NotEqual] 0, Throw[{False, i, j, k}], Throw[False], 
                  Throw[False]]]; \[IndentingNewLine]If[
                Abs[g\[LeftDoubleBracket]xy, 
                      y\[RightDoubleBracket]] \[NotEqual] 
                  Abs[g\[LeftDoubleBracket]x, 
                      Abs[g\[LeftDoubleBracket]y, 
                          y\[RightDoubleBracket]]\[RightDoubleBracket]], 
                If[o \[NotEqual] 0, Throw[{False, i, j, k, 2}], Throw[False], 
                  Throw[False]]]; \[IndentingNewLine]\(j++\)]; \(i++\); 
            j = If[a, i, 1]]; \[IndentingNewLine]True]]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(amQ[gg_:  glo, 
        o_:  0] :=  (*ref\ raoulc@pacific . net . 
            ph*) \[IndentingNewLine]Catch[
        Module[{a, i = 1, j = 1, k = 1, g = gpd[gg], m, xy, yx, xz, zx}, 
          m = Length[g]; \[IndentingNewLine]While[
            i \[LessEqual] m, \[IndentingNewLine]While[j \[LessEqual] m, 
              xy = Abs[g\[LeftDoubleBracket]i, j\[RightDoubleBracket]]; 
              yx = Abs[
                  g\[LeftDoubleBracket]j, 
                    i\[RightDoubleBracket]]; \[IndentingNewLine]While[
                k \[LessEqual] m, xz = Abs[g[\([i, k]\)]]; 
                zx = Abs[g[\([k, i]\)]]; 
                If[g[\([i, Abs[g[\([yx, zx]\)]]]\)] \[NotEqual] 
                    g[\([Abs[g[\([xy, xz]\)]], i]\)], 
                  If[o === 0, Throw[False], 
                    Throw[{False, i, j, 
                        k\ , "\< amQ\>"}]]]; \[IndentingNewLine]\(k++\)]; \(j\
++\); k = 1]; \(i++\); j = 1]; \[IndentingNewLine]True]]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(bolQ[gg_:  glo, o_:  0]\), ":=", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({a, i = 1, j = 1, k = 1, g = gpd[gg], m, xz, yz, zx, 
              zy}\), ",", 
            
            RowBox[{\(If[Position[g, Complex[_, _]] \[NotEqual] {}, 
                Throw["\<Complex\>"]]\), ";", \(m = Length[g]\), 
              ";", \(a = abelianQ[g]\), ";", "\[IndentingNewLine]", 
              RowBox[{"While", "[", 
                RowBox[{\(i \[LessEqual] m\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"While", "[", 
                      
                      RowBox[{\(j \[LessEqual] m\), ",", 
                        "\[IndentingNewLine]", 
                        RowBox[{
                          RowBox[{"While", "[", 
                            RowBox[{\(k \[LessEqual] m\), ",", 
                              
                              RowBox[{\(xz = 
                                  Abs[g\[LeftDoubleBracket]i, 
                                      k\[RightDoubleBracket]]\), 
                                ";", \(yz = 
                                  Abs[g\[LeftDoubleBracket]j, 
                                      k\[RightDoubleBracket]]\), 
                                ";", \(zx = 
                                  Abs[g\[LeftDoubleBracket]k, 
                                      i\[RightDoubleBracket]]\), 
                                ";", \(zy = 
                                  Abs[g\[LeftDoubleBracket]k, 
                                      j\[RightDoubleBracket]]\), ";", 
                                RowBox[{"If", "[", 
                                  
                                  RowBox[{\(Abs[
                                        g[\([g\[LeftDoubleBracket]k, 
                                        yz\[RightDoubleBracket], 
                                        i]\)]] \[NotEqual] 
                                      Abs[g[\([k, 
                                        g[\([Abs[g[\([j, zx]\)]]]\)]]\)]]\), 
                                    ",", 
                                    RowBox[{"If", "[", 
                                      RowBox[{\(o === 0\), ",", 
                                        StyleBox[\(Throw[False]\),
                                        FontColor->RGBColor[1, 0, 1]], ",", 
                                        
                                        StyleBox[\(Throw[{False, i, j, 
                                        k\ , "\< left Bol\>"}]\),
                                        FontColor->RGBColor[1, 0, 1]]}], 
                                      "]"}]}], "]"}], ";", 
                                RowBox[{"If", "[", 
                                  RowBox[{\(Abs[
                                        g[\([i, 
                                        g\[LeftDoubleBracket]zy, 
                                        k\[RightDoubleBracket]]\)]] \
\[NotEqual] Abs[g[\([Abs[g[\([xz, j]\)]], k]\)]]\), ",", 
                                    RowBox[{"If", "[", 
                                      RowBox[{\(o === 0\), ",", 
                                        StyleBox[\(Throw[False]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        StyleBox[",",
                                        FontColor->RGBColor[1, 0, 1]], 
                                        
                                        StyleBox[\(Throw[{False, i, j, 
                                        k\ , "\< right Bol\>"}]\),
                                        FontColor->RGBColor[1, 0, 1]]}], 
                                      "]"}]}], "]"}], ";", 
                                "\[IndentingNewLine]", \(k++\)}]}], "]"}], 
                          ";", \(j++\), ";", \(k = If[a, j, 1]\)}]}], "]"}], 
                    ";", \(i++\), ";", \(j = If[a, i, 1]\)}]}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(cQ[gg_:  glo, o_:  0]\), 
      ":=", \( (*ref\ raoulc@pacific . net . ph*) \), "\[IndentingNewLine]", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          RowBox[{\({a, i = 1, j = 1, k = 1, g = gpd[gg], m, xy, yy}\), ",", 
            RowBox[{\(m = Length[g]\), ";", "\[IndentingNewLine]", 
              RowBox[{"While", "[", 
                RowBox[{\(i \[LessEqual] m\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"While", "[", 
                      RowBox[{\(j \[LessEqual] m\), ",", 
                        
                        RowBox[{\(xy = 
                            Abs[g\[LeftDoubleBracket]i, 
                                j\[RightDoubleBracket]]\), 
                          ";", \(yy = 
                            Abs[g\[LeftDoubleBracket]j, 
                                j\[RightDoubleBracket]]\), ";", 
                          "\[IndentingNewLine]", 
                          RowBox[{"While", "[", 
                            RowBox[{\(k \[LessEqual] m\), ",", 
                              RowBox[{
                                RowBox[{"If", "[", 
                                  
                                  RowBox[{\(g[\([Abs[
                                        g\[LeftDoubleBracket]xy, 
                                        j\[RightDoubleBracket]], 
                                        k]\)] \[NotEqual] 
                                      g[\([i, Abs[g[\([yy, k]\)]]]\)]\), ",", 
                                    
                                    RowBox[{"If", "[", 
                                      RowBox[{\(o === 0\), ",", 
                                        StyleBox[\(Throw[False]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        StyleBox[",",
                                        FontColor->RGBColor[1, 0, 1]], 
                                        
                                        StyleBox[\(Throw[{False, i, j, 
                                        k\ , "\< cQ\>"}]\),
                                        FontColor->RGBColor[1, 0, 1]]}], 
                                      "]"}]}], "]"}], ";", 
                                "\[IndentingNewLine]", \(k++\)}]}], "]"}], 
                          ";", \(j++\), ";", \(k = 1\)}]}], "]"}], 
                    ";", \(i++\), ";", \(j = 1\)}]}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(conservativeQ[] := 
      Module[{A, B, l}, 
        If[associativeQ[glo] && \(! signedTableQ[glo]\), True, 
          mm = Length[glo]; 
          While[A = Table[Random[Integer, {0, 99}], {i, mm}]; 
            B = Table[Random[Integer, {0, 99}], {i, mm}]; 
            AB = Det[gmap[glo, hoopTimes[A, B]]], AB == 0]; 
          A = Det[gmap[glo, A]]\ ; B = Det[gmap[glo, B]]; A = A\ B; 
          B = Abs[AB - A]; A = Abs[AB\  + A]; 
          Chop[Min[A, B]/Max[A, B]] == 0]]\), "\[IndentingNewLine]", 
    \(conservativeQ[gg_:  glo, t_:  Complex, 
        r_: {\(-1\) - \[ImaginaryI], 1 + \[ImaginaryI]}/2] := 
      Module[{A, B, da, db, dab, g = gpd[gg], l, R = r}, mm = Length[g]; 
        If[associativeQ[g] && \(! signedTableQ[g]\), True, 
          If[t === Real, R = Re[r]]; A = Table[Random[t, R], {i, mm}]; 
          B = Table[Random[t, R], {i, mm}]; da = Det[gmap[g, A]]; 
          db = \ Det[gmap[g, B]]; dab = Det[gmap[g, hoopTimes[A, B, g]]]; 
          A = Abs[da\ db - dab]; B = Abs[da\ db + dab]; 
          Chop[Min[A, B]/Max[A, B]] == 0]]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(entropicQ[gg_:  glo, o_:  0] := 
      Catch[Module[{g = gpd[gg], i = 1, j = 1, k = 1, l = 1, m = Length[g]}, 
          If[abelianQ[g], Throw[True]]; 
          While[i \[LessEqual] m, 
            While[j \[LessEqual] m, \[IndentingNewLine]While[
                k \[LessEqual] m, \[IndentingNewLine]While[l \[LessEqual] m, 
                  If[Abs[g[\([Abs[g[\([i, j]\)]], 
                            Abs[g[\([k, l]\)]]]\)]] \[NotEqual] 
                      Abs[g[\([Abs[g[\([i, k]\)]], Abs[g[\([j, l]\)]]]\)]], 
                    If[o === 0, Throw[False], 
                      Throw[{False, i, j, k, 
                          l}]]]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(l++\)]; \
\(k++\)]; l = 1; \(j++\); k = 1]; \(i++\); 
            j = 1]; \[IndentingNewLine]True]]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(flexibleQ[gg_:  glo, o_:  0]\), ":=", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          RowBox[{\({i = 1, j = 1, k = 1, g = gpd[gg], m}\), ",", 
            RowBox[{\(m = Length[g]\), ";", "\n", 
              RowBox[{"While", "[", 
                RowBox[{\(i \[LessEqual] m\), ",", 
                  
                  StyleBox[\( (*\ 
                      Negated\ associators . \ \ This\ is\ NOT\ as\ described\
\ in\ PMA\ p92\ *) \),
                    FontColor->RGBColor[0, 0, 1]], 
                  "\[IndentingNewLine]", \(While[
                    j \[LessEqual] m, \[IndentingNewLine]While[
                      k \[LessEqual] m, 
                      If[g[\([Abs[g[\([i, j]\)]], k]\)] - 
                            g[\([i, 
                                Abs[g[\([j, 
                                      k]\)]]]\)] \[NotEqual] \(-g[\([Abs[
                                    g[\([k, j]\)]], i]\)]\) + 
                            g[\([k, Abs[g[\([j, i]\)]]]\)], 
                        If[o === 0, Throw[False], 
                          Throw[{False, i, j, k, 
                              l}]]]; \[IndentingNewLine]\(k++\)]; \(j++\); 
                    k = 1]; \(i++\); j = 1\)}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(fenyvesQ[gg_:  glo, o_:  0] := 
      Catch[Module[{a, i = 1, j = 1, k = 1, g = gpd[gg], m, axy, zx, azx}, 
          m = Length[g]; 
          a = abelianQ[g]; \[IndentingNewLine]While[
            i \[LessEqual] m, \[IndentingNewLine]While[j \[LessEqual] m, 
              axy = Abs[g\[LeftDoubleBracket]i, j\[RightDoubleBracket]]; 
              While[k \[LessEqual] m, 
                zx = g\[LeftDoubleBracket]k, i\[RightDoubleBracket]; 
                azx = Abs[zx]; 
                If[Abs[g[\([i, 
                          Abs[g\[LeftDoubleBracket]axy, 
                              k\[RightDoubleBracket]]]\)]] \[NotEqual] 
                    Abs[g\[LeftDoubleBracket]i, 
                        Abs[g[\([j, azx]\)]]\[RightDoubleBracket]], 
                  If[o \[NotEqual] 0, 
                    Print[{g[\([i, 
                            Abs[g\[LeftDoubleBracket]axy, 
                                k\[RightDoubleBracket]]]\)], 
                        g\[LeftDoubleBracket]i, 
                          Abs[g[\([j, azx]\)]]\[RightDoubleBracket]}]; 
                    Throw[{False, i, j, k}], Throw[False], 
                    Throw[False]]]; \[IndentingNewLine]\(k++\)]; \(j++\); 
              k = If[a, j, 1]]; \(i++\); 
            j = If[a, i, 1]]; \[IndentingNewLine]True]]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(flexQ[gg_:  glo, o_:  0]\), ":=", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          RowBox[{\({j = 1, k = 1, g = gpd[gg], m}\), ",", 
            RowBox[{\(m = Length[g]\), ";", "\n", 
              RowBox[{"While", "[", 
                RowBox[{\(j \[LessEqual] m\), ",", 
                  
                  StyleBox[\( (*\ This\ is\ as\ described\ in\ PMA\ p92, \ 
                      with\ Abs\ *) \),
                    FontColor->RGBColor[0, 0, 1]], 
                  "\[IndentingNewLine]", \(While[k \[LessEqual] m, 
                    If[Abs[g[\([Abs[g[\([k, j]\)]], k]\)]] === 
                        Abs[g[\([k, Abs[g[\([j, k]\)]]]\)]], , 
                      If[o === 0, Throw[False], 
                        Throw[{False, j, 
                            k}]]]; \[IndentingNewLine]\(k++\)]; \(j++\); 
                  k = 1\)}], "]"}], ";", "\[IndentingNewLine]", "True"}]}], 
          "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(hamiltonianQ[g_:  glo] := 
        Module[{s = 
              subgroups[g]}, \(! abelianQ[g]\) && \(! MemberQ[
                Table[normalSubgroup[s[\([i]\)]], {i, Length[s]}], 
                False]\)];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(indexTableQ[gg_:  glo] := 
      Module[{g, i = 2, l, r, c, t}, 
        If[gg \[NotEqual] {{}}, g = Abs[gpd[gg]]; 
          r = If[Length[gg] \[Equal] 1, gg[\([1, 1]\)], gg[\([1]\)]]; 
          t = Transpose[g]; c = t[\([1]\)]; l = Length[g]; 
          If[r \[Equal] c \[Equal] Range[l], 
            While[i \[LessEqual] l && 
                r \[Equal] Union[Abs[g[\([i]\)]]] \[Equal] 
                  Union[Abs[t[\([i]\)]]], \(i++\)]], l = i]; 
        i > l]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(jordanQ[gg_:  glo, o_:  0]\), ":=", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({a, i = 1, j, k, g = gpd[gg], m, xx, axx, xy, axy}\), ",",
             
            
            RowBox[{\(m = Length[g]\), ";", \(a = abelianQ[g]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"While", "[", 
                RowBox[{\(i \[LessEqual] m\), ",", 
                  
                  RowBox[{\(xx = g[\([i, i]\)]\), ";", \(axx = Abs[xx]\), ";",
                     "\[IndentingNewLine]", 
                    RowBox[{"While", "[", 
                      RowBox[{\(j \[LessEqual] m\), ",", 
                        
                        RowBox[{\(xy = 
                            g\[LeftDoubleBracket]i, j\[RightDoubleBracket]\), 
                          ";", \(axy = Abs[xy]\), ";", 
                          RowBox[{"If", "[", 
                            
                            RowBox[{\(Abs[
                                  g\[LeftDoubleBracket]axy, 
                                    axx\[RightDoubleBracket]] \[NotEqual] 
                                Abs[g\[LeftDoubleBracket]i, 
                                    Abs[g[\([j, 
                                        axx]\)]]\[RightDoubleBracket]]\), ",",
                               
                              RowBox[{"If", "[", 
                                RowBox[{\(o \[NotEqual] 0\), ",", 
                                  RowBox[{
                                    
                                    StyleBox[\(Print[{g\[LeftDoubleBracket]
                                        axy, axx\[RightDoubleBracket], 
                                        g\[LeftDoubleBracket]i, 
                                        Abs[g[\([j, 
                                        axx]\)]]\[RightDoubleBracket]}]\),
                                      FontColor->RGBColor[0, 1, 0]], 
                                    ";", \(Throw[{False, i, j}]\)}], 
                                  ",", \(Throw[False]\), 
                                  ",", \(Throw[False]\)}], "]"}]}], "]"}], 
                          ";", "\[IndentingNewLine]", \(j++\), 
                          ";", \(k = If[a, j, 1]\)}]}], "]"}], ";", \(i++\), 
                    ";", \(j = If[a, i, 1]\)}]}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FormatType->TraditionalForm],

Cell[BoxData[
    RowBox[{\(jacobiQ[gg_:  glo, o_:  0]\), ":=", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          RowBox[{\({g = gpd[gg], i = 1, j, k, m = Length[g]}\), ",", 
            
            RowBox[{\(If[abelianQ[g], Throw[False]]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"While", "[", 
                RowBox[{\(i \[LessEqual] m\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"While", "[", 
                      RowBox[{\(j \[LessEqual] m\), ",", 
                        
                        RowBox[{\(If[
                            g\[LeftDoubleBracket]i, 
                                j\[RightDoubleBracket] \[NotEqual] \(-g[\([j, 
                                    i]\)]\), Throw[False]]\), ";", 
                          RowBox[{"While", "[", 
                            RowBox[{\(k \[LessEqual] m\), ",", 
                              RowBox[{
                                RowBox[{"If", "[", 
                                  
                                  RowBox[{\(g[\([i, 
                                        g\[LeftDoubleBracket]j, 
                                        k\[RightDoubleBracket]]\)] + 
                                        g[\([j, 
                                        g\[LeftDoubleBracket]k, 
                                        i\[RightDoubleBracket]]\)] + 
                                        g[\([k, 
                                        g\[LeftDoubleBracket]i, 
                                        j\[RightDoubleBracket]]\)] \
\[NotEqual] 0\), ",", 
                                    RowBox[{"If", "[", 
                                      RowBox[{\(o \[NotEqual] 0\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{g[\([i, 
                                        g\[LeftDoubleBracket]j, 
                                        k\[RightDoubleBracket]]\)], 
                                        g[\([j, g\[LeftDoubleBracket]k, 
                                        i\[RightDoubleBracket]]\)], 
                                        g[\([k, g\[LeftDoubleBracket]i, 
                                        j\[RightDoubleBracket]]\)]}]\),
                                        FontColor->RGBColor[0, 1, 0]], 
                                        ";", \(Throw[{False, i, j, k}]\)}], 
                                        ",", \(Throw[False]\), 
                                        ",", \(Throw[False]\)}], "]"}]}], 
                                  "]"}], ";", 
                                "\[IndentingNewLine]", \(k++\)}]}], "]"}], 
                          ";", \(j++\), ";", \(k = 1\)}]}], "]"}], 
                    ";", \(i++\), ";", \(j = 1\)}]}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(MoufangQ[gg_:  glo, o_:  0]\), ":=", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({a, i = 1, j = 1, k = 1, g = gpd[gg], m, axy, zx, azx, 
              yz, ayz}\), ",", 
            
            RowBox[{\(m = Length[g]\), ";", \(a = abelianQ[g]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"While", "[", 
                RowBox[{\(i \[LessEqual] m\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"While", "[", 
                      RowBox[{\(j \[LessEqual] m\), ",", 
                        
                        RowBox[{\(axy = 
                            Abs[g\[LeftDoubleBracket]i, 
                                j\[RightDoubleBracket]]\), ";", 
                          RowBox[{"While", "[", 
                            RowBox[{\(k \[LessEqual] m\), ",", 
                              
                              RowBox[{\(zx = 
                                  g\[LeftDoubleBracket]k, 
                                    i\[RightDoubleBracket]\), 
                                ";", \(azx = Abs[zx]\), 
                                ";", \(yz = 
                                  g\[LeftDoubleBracket]j, 
                                    k\[RightDoubleBracket]\), 
                                ";", \(ayz = Abs[yz]\), ";", 
                                RowBox[{"If", "[", 
                                  
                                  RowBox[{\(Sign[zx] Sign[yz] 
                                        g\[LeftDoubleBracket]azx, 
                                        ayz\[RightDoubleBracket] \[NotEqual] 
                                      g\[LeftDoubleBracket]Abs[
                                        g[\([k, axy]\)]], 
                                        k\[RightDoubleBracket]\), ",", 
                                    RowBox[{"If", "[", 
                                      RowBox[{\(o \[NotEqual] 0\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{Sign[zx] Sign[yz] 
                                        g\[LeftDoubleBracket]azx, 
                                        ayz\[RightDoubleBracket], 
                                        g\[LeftDoubleBracket]Abs[
                                        g[\([k, axy]\)]], 
                                        k\[RightDoubleBracket]}]\),
                                        FontColor->RGBColor[0, 1, 0]], 
                                        ";", \(Throw[{False, i, j, k}]\)}], 
                                        ",", \(Throw[False]\), 
                                        ",", \(Throw[False]\)}], "]"}]}], 
                                  "]"}], ";", 
                                "\[IndentingNewLine]", \(k++\)}]}], "]"}], 
                          ";", \(j++\), ";", \(k = If[a, j, 1]\)}]}], "]"}], 
                    ";", \(i++\), ";", \(j = If[a, i, 1]\)}]}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(moufangQ[gg_:  glo, o_:  0]\), ":=", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({a, i = 1, j = 1, k = 1, g = gpd[gg], m, axy, zx, azx, 
              yz, ayz}\), ",", 
            
            RowBox[{\(m = Length[g]\), ";", \(a = abelianQ[g]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"While", "[", 
                RowBox[{\(i \[LessEqual] m\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"While", "[", 
                      RowBox[{\(j \[LessEqual] m\), ",", 
                        
                        RowBox[{\(axy = 
                            Abs[g\[LeftDoubleBracket]i, 
                                j\[RightDoubleBracket]]\), ";", 
                          RowBox[{"While", "[", 
                            RowBox[{\(k \[LessEqual] m\), ",", 
                              
                              RowBox[{\(zx = 
                                  g\[LeftDoubleBracket]k, 
                                    i\[RightDoubleBracket]\), 
                                ";", \(azx = Abs[zx]\), 
                                ";", \(yz = 
                                  g\[LeftDoubleBracket]j, 
                                    k\[RightDoubleBracket]\), 
                                ";", \(ayz = Abs[yz]\), ";", 
                                RowBox[{"If", "[", 
                                  
                                  RowBox[{\(Abs[
                                        g\[LeftDoubleBracket]azx, 
                                        ayz\[RightDoubleBracket]] \[NotEqual] 
                                      Abs[g\[LeftDoubleBracket]
                                        Abs[g[\([k, axy]\)]], 
                                        k\[RightDoubleBracket]]\), ",", 
                                    RowBox[{"If", "[", 
                                      RowBox[{\(o \[NotEqual] 0\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{g\
\[LeftDoubleBracket]azx, ayz\[RightDoubleBracket], 
                                        g\[LeftDoubleBracket]Abs[
                                        g[\([k, axy]\)]], 
                                        k\[RightDoubleBracket]}]\),
                                        FontColor->RGBColor[0, 1, 0]], 
                                        ";", \(Throw[{False, i, j, k}]\)}], 
                                        ",", \(Throw[False]\), 
                                        ",", \(Throw[False]\)}], "]"}]}], 
                                  "]"}], ";", 
                                "\[IndentingNewLine]", \(k++\)}]}], "]"}], 
                          ";", \(j++\), ";", \(k = If[a, j, 1]\)}]}], "]"}], 
                    ";", \(i++\), ";", \(j = If[a, i, 1]\)}]}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(moufangLQ[gg_:  glo, o_:  0]\), ":=", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          RowBox[{\({a, i = 1, j = 1, k = 1, g = gpd[gg], m}\), ",", 
            
            RowBox[{\(m = Length[g]\), ";", \(a = abelianQ[g]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"While", "[", 
                RowBox[{\(i \[LessEqual] m\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"While", "[", 
                      
                      RowBox[{\(j \[LessEqual] m\), ",", 
                        "\[IndentingNewLine]", 
                        RowBox[{
                          RowBox[{"While", "[", 
                            RowBox[{\(k \[LessEqual] m\), ",", 
                              RowBox[{
                                RowBox[{"If", "[", 
                                  
                                  RowBox[{\(Abs[
                                        g[\([Abs[
                                        g\[LeftDoubleBracket]Abs[
                                        g\[LeftDoubleBracket]k, 
                                        j\[RightDoubleBracket]], 
                                        k\[RightDoubleBracket]], 
                                        i]\)]] \[NotEqual] 
                                      Abs[g\[LeftDoubleBracket]k, 
                                        Abs[g[\([j, 
                                        Abs[g\[LeftDoubleBracket]k, 
                                        i\[RightDoubleBracket]]]\)]]\
\[RightDoubleBracket]]\), ",", 
                                    RowBox[{"If", "[", 
                                      RowBox[{\(o \[NotEqual] 0\), ",", 
                                        StyleBox[\(Throw[{False, i, j, k}]\),
                                        FontColor->RGBColor[0, 1, 0]], 
                                        ",", \(Throw[False]\), 
                                        ",", \(Throw[False]\)}], "]"}]}], 
                                  "]"}], ";", 
                                "\[IndentingNewLine]", \(k++\)}]}], "]"}], 
                          ";", \(j++\), ";", \(k = If[a, j, 1]\)}]}], "]"}], 
                    ";", \(i++\), ";", \(j = If[a, i, 1]\)}]}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(moufangRQ[gg_:  glo, o_:  0]\), ":=", 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          RowBox[{\({a, i = 1, j = 1, k = 1, g = gpd[gg], m}\), ",", 
            
            RowBox[{\(m = Length[g]\), ";", \(a = abelianQ[g]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"While", "[", 
                RowBox[{\(i \[LessEqual] m\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"While", "[", 
                      
                      RowBox[{\(j \[LessEqual] m\), ",", 
                        "\[IndentingNewLine]", 
                        RowBox[{
                          RowBox[{"While", "[", 
                            RowBox[{\(k \[LessEqual] m\), ",", 
                              RowBox[{
                                RowBox[{"If", "[", 
                                  
                                  RowBox[{\(Abs[
                                        g[\([i, 
                                        Abs[g\[LeftDoubleBracket]k, 
                                        Abs[g\[LeftDoubleBracket]j, 
                                        k\[RightDoubleBracket]]\
\[RightDoubleBracket]]]\)]] \[NotEqual] 
                                      Abs[g[\([Abs[
                                        g\[LeftDoubleBracket]Abs[
                                        g\[LeftDoubleBracket]i, 
                                        k\[RightDoubleBracket]], 
                                        j\[RightDoubleBracket]], k]\)]]\), 
                                    ",", 
                                    RowBox[{"If", "[", 
                                      RowBox[{\(o \[NotEqual] 0\), ",", 
                                        StyleBox[\(Throw[{False, i, j, k}]\),
                                        FontColor->RGBColor[0, 1, 0]], 
                                        ",", \(Throw[False]\), 
                                        ",", \(Throw[False]\)}], "]"}]}], 
                                  "]"}], ";", 
                                "\[IndentingNewLine]", \(k++\)}]}], "]"}], 
                          ";", \(j++\), ";", \(k = If[a, j, 1]\)}]}], "]"}], 
                    ";", \(i++\), ";", \(j = If[a, i, 1]\)}]}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(negatableQ[gg_:  glo, f_:  2] := 
      Module[{g = gpd[gg], g1, s1, i, j, g2, l, m, t}, \[IndentingNewLine]l = 
          Length[g]; m = Length[g]/f; 
        If[\(! IntegerQ[m]\), False, g1 = pick[g, {1, m}, {1, m}]; 
          s1 = Table[
              Sign[g1[\([i, j]\)]], {i, m}, {j, m}]; \[IndentingNewLine]g1 = 
            g1/s1; g2 = Table[Mod[g1 + e\ m - 1, l] + 1*s1, {e, f}]; j = 0; 
          Catch[While[
              i = 0; \[IndentingNewLine]While[
                If[MemberQ[g2, 
                    pick[g, {m\ i + 1, m\ i + m}, {m\ j + 1, m\ j + m}]], 
                  Null, Throw[False]]; \(i++\); i < f]; \(j++\); j < f]; 
            True]]]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    FormBox[
      RowBox[{\(loopQ[gg_:  glo, O_:  0]\), ":=", 
        RowBox[{"Catch", "[", 
          RowBox[{"Module", "[", 
            RowBox[{\({i = 1, g = gpd[gg], Len, l, o, t}\), ",", 
              
              RowBox[{\(Len = Length[g[\([1]\)]]\), 
                ";", \(l = Union[g[\([1]\)]]\), ";", \(t = Transpose[g]\), 
                ";", "\n", "  ", 
                RowBox[{"If", "[", 
                  
                  RowBox[{\(\((Length[l] \[Equal] 
                          Len)\) && \((Union[t[\([1]\)]] \[Equal] l)\)\), ",",
                     ",", 
                    RowBox[{
                      RowBox[{"If", "[", 
                        RowBox[{\(O \[NotEqual] 0\), ",", 
                          
                          StyleBox[\(Print[{"\< First row, col incorrect\>", 
                                l, t[\([1]\)]}]\),
                            FontColor->RGBColor[1, 0, 1]]}], "]"}], 
                      ";", \(Throw[False]\)}]}], "]"}], ";", "\n", "  ", 
                RowBox[{"While", "[", 
                  RowBox[{\(i \[LessEqual] Len\), ",", 
                    RowBox[{\(o = Complement[l, Abs[g[\([i]\)]]]\), ";", 
                      RowBox[{"If", "[", 
                        RowBox[{\(o \[NotEqual] {}\), ",", 
                          RowBox[{
                            RowBox[{"If", "[", 
                              RowBox[{\(O \[NotEqual] 0\), ",", 
                                
                                StyleBox[\(Print[{i, "\< row missing\>", 
                                      o}]\),
                                  FontColor->RGBColor[0, 1, 0]]}], "]"}], 
                            ";", \(Throw[False]\)}]}], "]"}], ";", "\n", 
                      "\t", \(o = Complement[l, Abs[t[\([i]\)]]]\), ";", 
                      RowBox[{"If", "[", 
                        RowBox[{\(o \[NotEqual] {}\), ",", 
                          RowBox[{
                            RowBox[{"If", "[", 
                              RowBox[{\(O \[NotEqual] 0\), ",", 
                                
                                StyleBox[\(Print[{\ i, "\< col missing\>", 
                                      o}]\),
                                  FontColor->RGBColor[0, 1, 0]]}], "]"}], 
                            ";", \(Throw[False]\)}]}], "]"}], ";", 
                      "\n", \(i++\)}]}], "]"}], ";", "True"}]}], "]"}], 
          "]"}]}], TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    \(signedTableQ[gg_:  glo] := 
      If[\((Union[gg[\([1]\)]] \[NotEqual] Union[Flatten[gg]])\) && 
          indexTableQ[gg], True, False, False]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(associator[g_:  glo, i_, j_, k_] := 
      g[\([g[\([i, j]\)], k]\)] - 
        g[\([i, g[\([j, k]\)]]\)]\), "\[IndentingNewLine]", 
    \(\(pick[g_, m_, n_] := 
        Transpose[Take[Transpose[Take[g, m]], n]];\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(reductiveQ[gg_:  glo, o_ : 0]\), 
      ":=", \( (*Ref \(?? \ Everything, \ including\ C5n, C6n, Alt12n, \ 
            passes\)*) \), 
      RowBox[{"Catch", "[", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({g = gpd[gg], i = 1, j = 1, k = 1, m = Length[g], xy, xx, 
              yxx}\), ",", 
            RowBox[{
              RowBox[{"If", "[", 
                RowBox[{\(MatrixQ[g]\), ",", 
                  RowBox[{"While", "[", 
                    RowBox[{\(i \[LessEqual] m\), ",", 
                      
                      RowBox[{\(xx = 
                          Abs[g\[LeftDoubleBracket]i, 
                              i\[RightDoubleBracket]]\), ";", 
                        "\[IndentingNewLine]", 
                        RowBox[{"While", "[", 
                          RowBox[{\(j \[LessEqual] m\), ",", 
                            
                            RowBox[{\(xy = 
                                Abs[g\[LeftDoubleBracket]i, 
                                    j\[RightDoubleBracket]]\), 
                              ";", \(yxx = 
                                Abs[g\[LeftDoubleBracket]j, 
                                    xx\[RightDoubleBracket]]\), 
                              ";", \( (*\(Print[{i, j, xx, xy, 
                                      g\[LeftDoubleBracket]xy, 
                                        xx\[RightDoubleBracket], 
                                      g\[LeftDoubleBracket]i, 
                                        yxx\[RightDoubleBracket]}];\)*) \), 
                              "\[IndentingNewLine]", 
                              RowBox[{"If", "[", 
                                
                                RowBox[{\(Abs[
                                      g\[LeftDoubleBracket]xy, 
                                        xx\[RightDoubleBracket]] \[Equal] 
                                    Abs[g[\([Abs[
                                        g\[LeftDoubleBracket]i, 
                                        yxx\[RightDoubleBracket]]]\)]]\), ",",
                                   "Null", ",", 
                                  RowBox[{"If", "[", 
                                    
                                    RowBox[{\(o === 0\), 
                                      ",", \(Throw[False]\), ",", 
                                      
                                      StyleBox[\(Throw[{False, i, 
                                        j, "\< reductiveQ\>"}]\),
                                        FontColor->RGBColor[0, 1, 0]]}], 
                                    "]"}]}], "]"}], ";", 
                              "\[IndentingNewLine]", \(j++\), 
                              ";", \(k = 1\)}]}], "]"}], ";", 
                        "\[IndentingNewLine]", \(i++\), ";", \(j = 1\)}]}], 
                    "]"}], ",", 
                  StyleBox[\(Throw[{False, g, "\< not a matrix\>"}]\),
                    FontColor->RGBColor[1, 0, 1]]}], "]"}], ";", 
              "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\( (*\ ref\ Raoul\ Cawagas\ *) \), 
      RowBox[{\(riffQ[gg_:  glo, o_ : 0]\), ":=", 
        RowBox[{"Catch", "[", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({g = gpd[gg], i = 1, j = 1, k = 1, m, xy, zxy, yz}\), 
              ",", 
              RowBox[{\(m = Length[g]\), ";", 
                RowBox[{"While", "[", 
                  RowBox[{\(i \[LessEqual] m\), ",", "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{"While", "[", 
                        RowBox[{\(j \[LessEqual] m\), ",", 
                          
                          RowBox[{\(xy = 
                              Abs[g\[LeftDoubleBracket]i, 
                                  j\[RightDoubleBracket]]\), ";", 
                            RowBox[{"While", "[", 
                              RowBox[{\(k \[LessEqual] m\), ",", 
                                
                                RowBox[{\(yz = 
                                    Abs[g\[LeftDoubleBracket]j, 
                                        k\[RightDoubleBracket]]\), 
                                  ";", \(zxy = 
                                    Abs[g\[LeftDoubleBracket]k, 
                                        xy\[RightDoubleBracket]]\), ";", 
                                  "\[IndentingNewLine]", 
                                  RowBox[{"If", "[", 
                                    
                                    RowBox[{\(Abs[
                                        g\[LeftDoubleBracket]xy, 
                                        zxy\[RightDoubleBracket]] \[Equal] 
                                        Abs[g\[LeftDoubleBracket]
                                        Abs[g\[LeftDoubleBracket]Abs[
                                        g\[LeftDoubleBracket]i, 
                                        yz\[RightDoubleBracket]], 
                                        i\[RightDoubleBracket]], 
                                        j\[RightDoubleBracket]]\), ",", 
                                      "Null", ",", 
                                      RowBox[{"If", "[", 
                                        
                                        RowBox[{\(o === 0\), 
                                        ",", \(Throw[False]\), ",", 
                                        
                                        StyleBox[\(Throw[{False, i, j, 
                                        k, "\< riffQ\>"}]\),
                                        FontColor->RGBColor[0, 1, 0]]}], 
                                        "]"}]}], "]"}], ";", 
                                  "\[IndentingNewLine]", \(k++\)}]}], "]"}], 
                            ";", "\[IndentingNewLine]", \(j++\), 
                            ";", \(k = 1\)}]}], "]"}], ";", 
                      "\[IndentingNewLine]", \(i++\), ";", \(j = 1\)}]}], 
                  "]"}], ";", "\[IndentingNewLine]", "True"}]}], "]"}], 
          "]"}]}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".5 Operations",
  StyleBox[" reorder, gmap, caylindex, toIndexTable, lmatrix, rmatrix",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
    RowBox[{\(reorder[g_?indexTableQ, p_]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({gg, n, m, l = Length[p], o, gp}\), ",", 
          
          RowBox[{\(gg = gpd[g]\), ";", \(n = Length[gg]\), 
            ";", \(gp = Abs[gg]\), ";", \(m = Min[n, l]\), 
            ";", \(o = Join[p, Complement[Range[n], p]]\), ";", 
            StyleBox[\( (*\ Extend\ p\ to\ full\ size\ of\ g\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(o = 
              Table[\(Position[o, i]\)[\([1, 1]\)], {i, n}]\), ";", "\n", 
            "   ", \(Table[
              o\[LeftDoubleBracket]gp\[LeftDoubleBracket]
                    p\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    p\[LeftDoubleBracket]
                      j\[RightDoubleBracket]\[RightDoubleBracket]\
\[RightDoubleBracket] Sign[gg[\([p[\([i]\)], p[\([j]\)]]\)]], {i, m}, {j, 
                m}]\)}]}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(gmap[g_:  glo, v_] := 
        Module[{gg = gpd[g], m, i, st = 1}, 
          If[MemberQ[Positive[gg], False, 2], 
            st = Table[
                Sign[gg[\([i, j]\)]], {i, Length[gg]}, {j, Length[gg]}]; 
            gg = Abs[gg]]; m[i_] := v[\([i]\)]; 
          Map[m, gg, 1]*st];\)\), "\n", 
    \(caylindex[g_] := 
      Module[{gg = gpd[g], e, j, l, n, s}, l = Length[gg]; 
        n = Table[j, {j, 1, l}]; e = gg[\([1]\)]; 
        s = Table[e[\([j]\)] -> n[\([j]\)], {j, l, 1, \(-1\)}]; gg /. s]; 
    toIndexTable[g_:  glo] := 
      unshuffle[Transpose[unshuffle[gpd[g]]]];\), "\n", 
    \(\(unshuffle[g_] := 
        Module[{p, l = Length[g]}, p = Table[g[\([i, 1]\)], {i, l}]; 
          Table[\(g[\([\(Position[p, i]\)[\([1]\)]]\)]\)[\([1]\)], {i, 
              l}]];\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(\(lmatrix[] := 
        Module[{s, t}, t = Table[0, {k, mm}, {l, mm}]; 
          Do[Do[s = glo\[LeftDoubleBracket]l, k\[RightDoubleBracket]; 
              t\[LeftDoubleBracket]Abs[s], k\[RightDoubleBracket] = 
                l\ Sign[s], {k, mm}], {l, mm}]; 
          t];\)\), "\[IndentingNewLine]", 
    \(\(lmatrix[g_?indexTableQ] := 
        Module[{gg = gpd[g], m, s, t}, m = Length[gg]; 
          t = Table[0, {k, m}, {l, m}]; 
          Do[Do[s = gg\[LeftDoubleBracket]l, k\[RightDoubleBracket]; 
              t\[LeftDoubleBracket]Abs[s], k\[RightDoubleBracket] = 
                l\ Sign[s], {k, m}], {l, m}]; t];\)\), "\n", 
    \(rmatrix[] := 
      Module[{s, t}, t = Table[0, {k, mm}, {l, mm}]; 
        Do[Do[s = glo\[LeftDoubleBracket]l, k\[RightDoubleBracket]; 
            t\[LeftDoubleBracket]l, Abs[s]\[RightDoubleBracket] = 
              l\ Sign[s], {k, mm}], {l, mm}]; t]; 
    rmatrix[g_?indexTableQ] := 
      Module[{gg = gpd[g], m, s, t}, m = Length[gg]; 
        t = Table[0, {k, m}, {l, m}]; 
        Do[Do[s = gg\[LeftDoubleBracket]l, k\[RightDoubleBracket]; 
            t\[LeftDoubleBracket]l, Abs[s]\[RightDoubleBracket] = 
              k\ Sign[s], {k, m}], {l, m}]; t];\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".6 Loops from Relators, ",
  StyleBox["ge; ",
    FontSlant->"Italic"],
  "Univectors Clifford ",
  StyleBox["cl",
    FontSlant->"Italic"],
  "; Cayley-Dickson ",
  StyleBox["cd; ",
    FontSlant->"Italic"],
  "Moufang doubling",
  StyleBox[" md.",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
    RowBox[{\(smax = 100\), ";", 
      RowBox[{\(streprpt[str_, rul_, imax_:  smax]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({s1 = str, s2, ii = 1}\), ",", 
            RowBox[{
              RowBox[{"While", "[", 
                
                RowBox[{\(\((s2 = StringReplace[s1, rul])\) \[NotEqual] s1\), 
                  ",", 
                  RowBox[{\(ii++\), ";", 
                    RowBox[{"If", "[", 
                      RowBox[{\(ii > imax\), ",", 
                        RowBox[{"If", "[", 
                          
                          RowBox[{\(imax \[Equal] 99\), 
                            ",", \(OK = "\<Fail\>"\), ",", 
                            RowBox[{
                              
                              StyleBox[\(Print[s1, "\< \>", 
                                  s2, "\< \>", "\<Failed. Increase \
smax?\>"]\),
                                FontColor->RGBColor[1, 0, 1]], 
                              ";", \(Abort[]\)}]}], "]"}]}], "]"}], 
                    ";", \(s1 = s2\)}]}], "]"}], ";", "s2"}]}], 
          "]"}]}]}], "\[IndentingNewLine]", \(matstrep[l_?MatrixQ, rul_, 
        sm_:  smax] := 
      Table[streprpt[l[\([i, j]\)], rul, 
          sm], {i, \(Dimensions[l, 1]\)[\([1]\)]}, {j, \(Dimensions[l, 
              2]\)[\([1]\)]}]\), "\[IndentingNewLine]", \(ruleExpand[a___] := 
        Table[Rule[stringExpand[ToString[a[\([i, 1]\)]]], 
            stringExpand[ToString[a[\([i, 2]\)]]]], {i, 
            Length[a]}];\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(stringExpand[t_] := 
      Module[{e, f, g, l, n = 1, res = "\<\>", s = ToString[t]}, 
        If[s \[Equal] "\<\>", res, l = StringLength[s]; g = StringTake[s, 1]; 
          res = res <> g; \[IndentingNewLine]While[
            g = StringTake[s, {n}]; \(n++\); n \[LessEqual] l, 
            f = StringTake[s, {n}]; \[IndentingNewLine]e = ToExpression[f]; 
            If[IntegerQ[e], 
              If[n < l && IntegerQ[ToExpression[StringTake[s, {n + 1}]]], 
                e = ToExpression[
                    StringTake[
                      s, {n, n + 1}]]; \(n++\);]; \[IndentingNewLine]Do[
                res = res <> g, {i, e - 1}], 
              res = res <> f]]]; \[IndentingNewLine]res]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ge[gp_?VectorQ, pre_: {}, o_:  0]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({g = {}, cr, j, l = IntegerPart[Plus @@ gp] + 2, 
              le = Length[gp], ln = 1, lh, n = {"\<\>"}, new, p, st, rhs, 
              lhs, t = ruleExpand[pre], si, sij}\), ",", 
            
            RowBox[{\(cr = Take[CharacterRange["\<a\>", "\<g\>"], le]\), ";", 
              
              RowBox[{"Catch", "[", 
                StyleBox[\( (*Reject\ bad\ \(\(rules\)\(.\)\)*) \),
                  FontColor->RGBColor[0, 0, 1]], 
                RowBox[{
                  RowBox[{"If", "[", 
                    RowBox[{\(o \[NotEqual] 0\), ",", 
                      RowBox[{"Do", "[", 
                        StyleBox[\( (*i\ loop, Relators*) \),
                          FontColor->RGBColor[0, 0, 1]], 
                        RowBox[{
                          RowBox[{"Do", "[", 
                            StyleBox[\( (*r\ loop, each\ rule*) \),
                              FontColor->RGBColor[0, 0, 1]], 
                            RowBox[{
                              RowBox[{"Do", "[", 
                                StyleBox[\( (*k\ loop, \(lhs\  &\)\ rhs*) \),
                                  FontColor->RGBColor[0, 0, 1]], 
                                RowBox[{
                                  RowBox[{
                                    RowBox[{"If", "[", 
                                      
                                      RowBox[{\(\((rhs = 
                                        Characters[
                                        t[\([r, 2]\)]])\) \[NotEqual] 
                                        Sort[rhs] || \((\((lhs = 
                                        Characters[t[\([r, 1]\)]])\) \[Equal] 
                                        Sort[lhs] && 
                                        Length[Union[lhs]] > 1)\)\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{"\<Bad order\>", 
                                        t[\([r]\)]}]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        ";", \(Throw[Null]\)}]}], "]"}], ";", 
                                    "\[IndentingNewLine]", 
                                    RowBox[{"If", "[", 
                                      
                                      RowBox[{\(Length[
                                        Complement[Union[lhs, rhs], cr]] > 
                                        0\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{"\<Unknown Relator \
\>", t[\([r]\)], cr}]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        StyleBox[";",
                                        FontColor->RGBColor[1, 0, 
                                        1]], \(Throw[Null]\)}]}], "]"}], ";", 
                                    "\[IndentingNewLine]", \(j = 
                                      Length[
                                        Position[Characters[t[\([r, k]\)]], 
                                        cr[\([i]\)]]]\), ";", 
                                    RowBox[{"If", "[", 
                                      
                                      RowBox[{\(GCD[j, 
                                        IntegerPart[gp[\([i]\)]]] > 1 && 
                                        j \[NotEqual] 0 && 
                                        j \[NotEqual] 
                                        IntegerPart[gp[\([i]\)]]\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{"\<Bad GCD \>", j, 
                                        gp[\([i]\)], t[\([r]\)]}]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        StyleBox[";",
                                        FontColor->RGBColor[1, 0, 
                                        1]], \(Throw[Null]\)}]}], "]"}]}], 
                                  ",", \({k, 2}\)}], "]"}], 
                              ",", \({r, Length[t]}\)}], "]"}], 
                          ",", \({i, Length[gp]}\)}], "]"}]}], "]"}], 
                  ";", \(strep = {}\), ";", "\[IndentingNewLine]", 
                  RowBox[{"Do", "[", 
                    
                    StyleBox[\( (*i\ loop . \ 
                            Add\ the\ rules\ to\ reduce\ repetitions*) \),
                      FontColor->RGBColor[0, 0, 1]], \(st = cr[\([i]\)]; 
                    AppendTo[t, 
                      Do[st = 
                          st <> cr[\([i]\)], {IntegerPart[gp[\([i]\)]] - 1}]; 
                      Rule[st, "\<\>"]], {i, le}\), "]"}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Do", "[", 
                    StyleBox[\( (*i, j\ loops . \ Add\ abelianQ\ rules*) \),
                      FontColor->RGBColor[0, 0, 1]], 
                    RowBox[{
                      
                      RowBox[{\(new = 
                          Rule[lh = cr[\([j]\)] <> cr[\([i]\)], 
                            cr[\([i]\)] <> cr[\([j]\)]]\), ";", 
                        RowBox[{"Do", "[", 
                          StyleBox[\( (*k\ loop, \ redundant\ rules*) \),
                            FontColor->RGBColor[0, 0, 1]], \(If[
                            lh \[Equal] t[\([k, 1]\)], new = "\<\>"], {k, 
                            Length[t] - 1}\), "]"}], 
                        ";", \(If[Length[new] \[Equal] 2, 
                          AppendTo[t, new]]\)}], ",", \({i, 1, le}\), 
                      ",", \({j, i + 1, le}\)}], "]"}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Do", "[", 
                    
                    StyleBox[\( (*i\ loop, 
                        symbols . \ Build\ the\ element\ list*) \),
                      FontColor->RGBColor[0, 0, 1]], 
                    RowBox[{
                      
                      RowBox[{\(si = cr[\([i]\)]\), ";", \(sij = si\), 
                        ";", \(p = IntegerPart[gp[\([i]\)]] - 1\), ";", 
                        "\[IndentingNewLine]", 
                        RowBox[{"Do", "[", 
                          StyleBox[\( (*j\ loop . Repetitions*) \),
                            FontColor->RGBColor[0, 0, 1]], 
                          "\[IndentingNewLine]", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"Do", "[", 
                                
                                StyleBox[\( (*k\ loop, 
                                    new\ element = 
                                      j\ repeats\ of\ k' 
                                        th\ existing\ element*) \),
                                  FontColor->RGBColor[0, 0, 1]], 
                                "\[IndentingNewLine]", \(AppendTo[n, 
                                  If[k \[Equal] 1, sij, 
                                    n[\([k]\)] <> sij]], {k, ln}\), "]"}], 
                              ";", \(sij = sij <> si\)}], ",", \({j, p}\)}], 
                          "]"}], ";", \(ln = Length[n]\)}], 
                      ",", \({i, le}\)}], "]"}], ";", 
                  StyleBox[\( (*element\ list\ completed*) \),
                    FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
                  RowBox[{"Do", "[", 
                    RowBox[{
                      RowBox[{"AppendTo", "[", 
                        RowBox[{"g", ",", 
                          
                          StyleBox[\( (*add\ successive\ n[\([i]\)] <> 
                                  n\ rows\ to\ g*) \),
                            FontColor->RGBColor[0, 0, 1]], \(MapThread[
                            StringJoin, {Table[n[\([i]\)], {j, ln}], n}]\)}], 
                        "]"}], ",", \({i, ln}\)}], "]"}], ";", 
                  "\[IndentingNewLine]", \(g = matstrep[g, t]\), ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                    
                    RowBox[{\(o == 0\), ",", \(genel =. ; matel =. ; 
                      strep =. \), ",", "\[IndentingNewLine]", 
                      
                      RowBox[{\(genel = n /. "\<\>" \[Rule] 1\), 
                        ";", \(matel = g /. "\<\>" \[Rule] 1\), ";", 
                        "\[IndentingNewLine]", 
                        RowBox[{"If", "[", 
                          RowBox[{\(o < 0\), ",", 
                            StyleBox[\( (*Noncommutative\ mods*) \),
                              FontColor->RGBColor[0, 0, 
                              1]], \(ClearAllOperators[]; 
                            SetOperators[Drop[genel, 1]]\)}], "]"}], 
                        ";", \(Do[
                          Do[st = 
                              Rule[If[o < 0, 
                                  matel[\([i, 1]\)] ** \ matel[\([1, j]\)], 
                                  Diamond[matel[\([i, 1]\)], \ 
                                    matel[\([1, j]\)]]], \ 
                                matel[\([i, j]\)]]; 
                            If[\ MemberQ[strep, st], , 
                              AppendTo[strep, st]], {j, 2, 
                              ln}], \[IndentingNewLine]{i, 2, ln}]\)}]}], 
                    "]"}], ";", "\[IndentingNewLine]", \(g = caylindex[g]\), 
                  ";", 
                  
                  StyleBox[\( (*Convert\ to\ a\ signed\ \(\(table\)\(?\)\)*) \
\),
                    FontColor->RGBColor[0, 0, 
                    1]], \(If[\(! IntegerQ[ln = Last[gp]]\), 
                    le = Length[g]/ln; g = ts[g, IntegerPart[ln]]; 
                    If[o \[NotEqual] 0, genel = Take[genel, le]; 
                      matel = 
                        Transpose[Take[Transpose[Take[matel, le]], le]]]]\), 
                  ";", "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                    RowBox[{\(Abs[o] \[NotEqual] 0\), ",", 
                      StyleBox[\( (*Report\ properties*) \),
                        FontColor->RGBColor[0, 0, 1]], 
                      RowBox[{"If", "[", 
                        RowBox[{\(loopQ[g]\), ",", 
                          RowBox[{"If", "[", 
                            RowBox[{\(associativeQ[g, 1]\), ",", "g", ",", 
                              RowBox[{
                                StyleBox[\(Print["\<Non-associative\>"]\),
                                  FontColor->RGBColor[0, 1, 0]], ";", "g"}]}],
                             "]"}], ",", 
                          StyleBox[\(Print["\<Not a quasigroup\>"]\),
                            FontColor->RGBColor[0, 1, 0]]}], "]"}]}], "]"}], 
                  ";", "\[IndentingNewLine]", \(glo = g\)}], "]"}]}]}], 
          "]"}]}], ";"}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ge[gp_?VectorQ, pre_: {}, o_:  0]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({g = {}, cr, j, l = IntegerPart[Plus @@ gp] + 2, 
              le = Length[gp], ln = 1, lh, n = {"\<\>"}, new, p, st, rhs, 
              lhs, t = ruleExpand[pre], si, sij}\), ",", 
            
            RowBox[{\(cr = Take[CharacterRange["\<a\>", "\<g\>"], le]\), ";", 
              
              RowBox[{"Catch", "[", 
                StyleBox[\( (*Reject\ bad\ \(\(rules\)\(.\)\)*) \),
                  FontColor->RGBColor[0, 0, 1]], 
                RowBox[{
                  RowBox[{"If", "[", 
                    RowBox[{\(o \[NotEqual] 0\), ",", 
                      RowBox[{"Do", "[", 
                        StyleBox[\( (*i\ loop, Relators*) \),
                          FontColor->RGBColor[0, 0, 1]], 
                        RowBox[{
                          RowBox[{"Do", "[", 
                            StyleBox[\( (*r\ loop, each\ rule*) \),
                              FontColor->RGBColor[0, 0, 1]], 
                            RowBox[{
                              RowBox[{"Do", "[", 
                                StyleBox[\( (*k\ loop, \(lhs\  &\)\ rhs*) \),
                                  FontColor->RGBColor[0, 0, 1]], 
                                RowBox[{
                                  RowBox[{
                                    RowBox[{"If", "[", 
                                      
                                      RowBox[{\(\((rhs = 
                                        Characters[
                                        t[\([r, 2]\)]])\) \[NotEqual] 
                                        Sort[rhs] || \((\((lhs = 
                                        Characters[t[\([r, 1]\)]])\) \[Equal] 
                                        Sort[lhs] && 
                                        Length[Union[lhs]] > 1)\)\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{"\<Bad order\>", 
                                        t[\([r]\)]}]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        ";", \(Throw[Null]\)}]}], "]"}], ";", 
                                    "\[IndentingNewLine]", 
                                    RowBox[{"If", "[", 
                                      
                                      RowBox[{\(Length[
                                        Complement[Union[lhs, rhs], cr]] > 
                                        0\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{"\<Unknown Relator \
\>", t[\([r]\)], cr}]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        StyleBox[";",
                                        FontColor->RGBColor[1, 0, 
                                        1]], \(Throw[Null]\)}]}], "]"}], ";", 
                                    "\[IndentingNewLine]", \(j = 
                                      Length[
                                        Position[Characters[t[\([r, k]\)]], 
                                        cr[\([i]\)]]]\), ";", 
                                    RowBox[{"If", "[", 
                                      
                                      RowBox[{\(GCD[j, 
                                        IntegerPart[gp[\([i]\)]]] > 1 && 
                                        j \[NotEqual] 0 && 
                                        j \[NotEqual] 
                                        IntegerPart[gp[\([i]\)]]\), ",", 
                                        RowBox[{
                                        
                                        StyleBox[\(Print[{"\<Bad GCD \>", j, 
                                        gp[\([i]\)], t[\([r]\)]}]\),
                                        FontColor->RGBColor[1, 0, 1]], 
                                        StyleBox[";",
                                        FontColor->RGBColor[1, 0, 
                                        1]], \(Throw[Null]\)}]}], "]"}]}], 
                                  ",", \({k, 2}\)}], "]"}], 
                              ",", \({r, Length[t]}\)}], "]"}], 
                          ",", \({i, Length[gp]}\)}], "]"}]}], "]"}], 
                  ";", \(strep = {}\), ";", 
                  RowBox[{"Do", "[", 
                    
                    StyleBox[\( (*i\ loop . \ 
                            Add\ the\ rules\ to\ reduce\ repetitions*) \),
                      FontColor->RGBColor[0, 0, 1]], 
                    StyleBox["\[IndentingNewLine]",
                      FontColor->RGBColor[0, 0, 1]], \(str = cr[\([i]\)]; 
                    AppendTo[t, 
                      Do[st = 
                          st <> cr[\([i]\)], {IntegerPart[gp[\([i]\)]] - 
                            1}]; \[IndentingNewLine]Rule[st, "\<\>"]], {i, 
                      le}\), "]"}], ";", "\[IndentingNewLine]", 
                  RowBox[{"Do", "[", 
                    StyleBox[\( (*i, j\ loops . \ Add\ abelianQ\ rules*) \),
                      FontColor->RGBColor[0, 0, 1]], 
                    RowBox[{
                      
                      RowBox[{\(new = 
                          Rule[lh = cr[\([j]\)] <> cr[\([i]\)], 
                            cr[\([i]\)] <> cr[\([j]\)]]\), ";", 
                        RowBox[{"Do", "[", 
                          StyleBox[\( (*k\ loop, \ redundant\ rules*) \),
                            FontColor->RGBColor[0, 0, 1]], \(If[
                            lh \[Equal] t[\([k, 1]\)], new = "\<\>"], {k, 
                            Length[t] - 1}\), "]"}], 
                        ";", \(If[Length[new] \[Equal] 2, 
                          AppendTo[t, new]]\)}], ",", \({i, 1, le}\), 
                      ",", \({j, i + 1, le}\)}], "]"}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Do", "[", 
                    
                    StyleBox[\( (*i\ loop, \ 
                        symbols . \ Build\ the\ element\ list*) \),
                      FontColor->RGBColor[0, 0, 1]], 
                    RowBox[{
                      
                      RowBox[{\(si = cr[\([i]\)]\), ";", \(sij = si\), 
                        ";", \(p = IntegerPart[gp[\([i]\)]] - 1\), ";", 
                        "\[IndentingNewLine]", 
                        RowBox[{"Do", "[", 
                          StyleBox[\( (*j\ loop, \ Repetitions*) \),
                            FontColor->RGBColor[0, 0, 1]], 
                          "\[IndentingNewLine]", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"Do", "[", 
                                
                                StyleBox[\( (*k\ loop, 
                                    new\ element = 
                                      j\ repeats\ of\ k' 
                                        th\ existing\ element*) \),
                                  FontColor->RGBColor[0, 0, 1]], 
                                "\[IndentingNewLine]", \(AppendTo[n, 
                                  If[k \[Equal] 1, sij, 
                                    n[\([k]\)] <> sij]], {k, ln}\), "]"}], 
                              ";", \(sij = sij <> si\)}], ",", \({j, p}\)}], 
                          "]"}], ";", \(ln = Length[n]\)}], 
                      ",", \({i, le}\)}], "]"}], ";", 
                  StyleBox[\( (*element\ list\ completed*) \),
                    FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
                  RowBox[{"Do", "[", 
                    RowBox[{
                      RowBox[{"AppendTo", "[", 
                        RowBox[{"g", ",", 
                          
                          StyleBox[\( (*add\ successive\ n[\([i]\)] <> 
                                  n\ rows\ to\ g*) \),
                            FontColor->RGBColor[0, 0, 1]], \(MapThread[
                            StringJoin, {Table[n[\([i]\)], {j, ln}], n}]\)}], 
                        "]"}], ",", \({i, ln}\)}], "]"}], ";", 
                  "\[IndentingNewLine]", \(g = matstrep[g, t]\), ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                    
                    RowBox[{\(o == 0\), ",", \(genel =. ; matel =. ; 
                      strep =. \), ",", "\[IndentingNewLine]", 
                      
                      RowBox[{\(genel = n /. "\<\>" \[Rule] 1\), 
                        ";", \(matel = g /. "\<\>" \[Rule] 1\), ";", 
                        "\[IndentingNewLine]", 
                        RowBox[{"If", "[", 
                          RowBox[{\(o < 0\), ",", 
                            StyleBox[\( (*Noncommutative\ mods*) \),
                              FontColor->RGBColor[0, 0, 
                              1]], \(ClearAllOperators[]; 
                            SetOperators[Drop[genel, 1]]\)}], "]"}], 
                        ";", \(Do[
                          Do[st = 
                              Rule[If[o < 0, 
                                  matel[\([i, 1]\)] ** \ matel[\([1, j]\)], 
                                  Diamond[matel[\([i, 1]\)], \ 
                                    matel[\([1, j]\)]]], \ 
                                matel[\([i, j]\)]]; 
                            If[\ MemberQ[strep, st], , 
                              AppendTo[strep, st]], {j, 2, 
                              ln}], \[IndentingNewLine]{i, 2, ln}]\)}]}], 
                    "]"}], ";", "\[IndentingNewLine]", \(g = caylindex[g]\), 
                  ";", 
                  
                  StyleBox[\( (*Convert\ to\ a\ signed\ \(\(table\)\(?\)\)*) \
\),
                    FontColor->RGBColor[0, 0, 
                    1]], \(If[\(! IntegerQ[ln = Last[gp]]\), 
                    le = Length[g]/ln; g = ts[g, IntegerPart[ln]]; 
                    If[o \[NotEqual] 0, genel = Take[genel, le]; 
                      matel = 
                        Transpose[Take[Transpose[Take[matel, le]], le]]]]\), 
                  ";", "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                    RowBox[{\(Abs[o] \[NotEqual] 0\), ",", 
                      StyleBox[\( (*Report\ properties*) \),
                        FontColor->RGBColor[0, 0, 1]], 
                      RowBox[{"If", "[", 
                        RowBox[{\(loopQ[g]\), ",", 
                          RowBox[{"If", "[", 
                            RowBox[{\(associativeQ[g, 1]\), ",", "g", ",", 
                              RowBox[{
                                StyleBox[\(Print["\<Non-associative\>"]\),
                                  FontColor->RGBColor[0, 1, 0]], ";", "g"}]}],
                             "]"}], ",", 
                          StyleBox[\(Print["\<Not a quasigroup\>"]\),
                            FontColor->RGBColor[0, 1, 0]]}], "]"}]}], "]"}], 
                  ";", "\[IndentingNewLine]", \(glo = g\)}], "]"}]}]}], 
          "]"}]}], ";"}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
    RowBox[{
      RowBox[{\(cl[p_Integer, q_:  0 (*\(,\)\(gr_: {}\)*) ]\), ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
          RowBox[{\({g, l, n = q, ng = Length[gr], o, result, z}\), ",", 
            RowBox[{
              RowBox[{"If", "[", 
                RowBox[{\(IntegerQ[n]\), ",", \(o = Range[p]\), ",", 
                  
                  StyleBox[\( (*\ no, \ 
                      extract\ negative\ squares\ from\ list\ {n}\ *) \),
                    FontColor->RGBColor[0, 0, 1]], 
                  " ", \(o = Complement[Range[p], q]; n = 0\)}], "]"}], ";", 
              "\[IndentingNewLine]", \(l = 2^\((p + n)\)\), ";", 
              "\[IndentingNewLine]", \(g = 
                Table[IntegerDigits[i, 2, p + n], {i, 0, l - 1}]\), ";", 
              
              StyleBox[\( (*\ 
                  binary\ form\ for\ indices\ e . g . \ if\ l = 8, \ 
                  index\ 6\ becomes\ {1, 1, 0}\ *) \),
                FontColor->RGBColor[0, 0, 1]], 
              "\[IndentingNewLine]", \(result = 
                Table[walsh[g[\([i]\)]*g[\([j]\)], o]*
                    walsh[g[\([i]\)]*
                        grayinv[g[\([j]\)]]]*\[IndentingNewLine]\((FromDigits[
                          Mod[g[\([i]\)] + g[\([j]\)], 2], 2]\  + 
                        1)\), \[IndentingNewLine]{j, l}, {i, l}]\), ";", 
              RowBox[{"(*", "\[IndentingNewLine]", 
                RowBox[{
                  RowBox[{"If", "[", 
                    RowBox[{\(ng > 0\), ",", 
                      StyleBox[\( (*\ Apply\ Grassmann\ negations\ *) \),
                        FontColor->RGBColor[0, 0, 1]], 
                      "\[IndentingNewLine]", \(Do[
                        z = 2^\((gr[\([i]\)] - 1)\) + 1; 
                        If[z < l && z > 0, result[\([z, z]\)] = 0], {i, 
                          ng}]\)}], "]"}], ";"}], "*)"}], 
              "\[IndentingNewLine]", "result"}]}], "]"}]}], ";"}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{\(cd[{g_String}] := ToExpression[g]; cd[{}] := {{1}}; 
    cd[{2}] := {{1, 2}, {2, 3}}; cd[{\(-2\)}] := {{1, 2}, {2, \(-3\)}}; 
    cd[{2. }] := {{1, 2}, {2, \(-1\)}}; 
    cd[{3}] := {{1, 2, 3}, {2, 3, 1}, {3, 1, 2}} (*C3*) ; 
    cd[{3. }] := {{1, 2, 3}, {2, 3, \(-1\)}, {3, \(-1\), \(-2\)}}; 
    cd[{\(-3\)}] := {{1, 2, 3}, {2, \(-3\), 1}, {3, 1, \(-2\)}}; 
    cd[{4}] := {{1, 2, 3, 4}, {2, 3, 4, 1}, {3, 4, 1, 2}, {4, 1, 2, 
          3}} (*C4*) ;\), "\[IndentingNewLine]", \(cd[{4. }] := {{1, 2, 3, 
            4}, {2, 1, \(-4\), \(-3\)}, {3, \(-4\), 
            1, \(-2\)}, {4, \(-3\), \(-2\), 
            1}};\), "\[IndentingNewLine]", \(cd[{\(-4\)}] := {{1, 2, 3, 
            4}, {2, 3, \(-4\), \(-1\)}, {3, \(-4\), 
            1, \(-2\)}, {4, \(-1\), \(-2\), 
            3}};\), "\[IndentingNewLine]", \(cd[{\(-4. \)}] := {{1, 2, 3, 
            4}, {2, 3, 4, \(-1\)}, {3, 
            4, \(-1\), \(-2\)}, {4, \(-1\), \(-2\), \(-3\)}};\), "\n", 
    RowBox[{\(cd[{gamma__}]\), ":=", "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\(l = Last[{gamma}]\), ",", "n", ",", "q", ",", "r", ",", 
              
              StyleBox[\( (*Recursion*) \),
                FontColor->RGBColor[0, 1, 1]], 
              StyleBox[\(m = cd[Drop[{gamma}, \(-1\)]]\),
                FontColor->RGBColor[0, 1, 1]]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          
          RowBox[{\(q = Length[m]\), ";", \(n = IntegerPart[l]\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Which", "[", 
              RowBox[{\(ListQ[l]\), ",", \(co[m, ca[l]]\), 
                StyleBox[\( (*compose\ with\ group*) \),
                  FontColor->RGBColor[0, 0, 1]], 
                StyleBox[",",
                  FontColor->GrayLevel[0]], 
                "\[IndentingNewLine]", \(StringQ[l]\), ",", 
                "\[IndentingNewLine]", \(co[m, ToExpression[l]]\), 
                "          ", 
                StyleBox[\( (*compose\ with\ hoop*) \),
                  FontColor->RGBColor[0, 0, 1]], 
                StyleBox[",",
                  FontColor->GrayLevel[0]], "\[IndentingNewLine]", "True", 
                "                                                 ", 
                StyleBox[\( (*\ new\ relator*) \),
                  FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
                RowBox[{"Table", "[", 
                  RowBox[{
                    RowBox[{"Which", "[", 
                      
                      RowBox[{\(i \[LessEqual] q && j \[LessEqual] q\), 
                        ",", \(m[\([i, j]\)]\), 
                        StyleBox[\( (*\ Top - left\ *) \),
                          FontColor->RGBColor[0, 0, 1]], ",", 
                        "\[IndentingNewLine]", \(i \[LessEqual] q\), 
                        ",", \(modqr[q, m[\([j - q, i]\)]]\), "          ", 
                        StyleBox[\( (*\ Top - right\ *) \),
                          FontColor->RGBColor[0, 0, 1]], ",", 
                        "\[IndentingNewLine]", \(j \[LessEqual] q\), ",", 
                        
                        RowBox[{\(r = m[\([i - q, j]\)]\), ";", 
                          "                     ", 
                          StyleBox[\( (*\ Bottom\ left*) \),
                            FontColor->RGBColor[0, 0, 1]], 
                          "\[IndentingNewLine]", 
                          RowBox[{"Which", "[", " ", 
                            RowBox[{\(! IntegerQ[l]\), ",", \(modqr[q, r]\), 
                              StyleBox[\( (*\ simple, \ real\ l\ *) \),
                                FontColor->RGBColor[0, 0, 1]], ",", 
                              "\[IndentingNewLine]", \(j \[NotEqual] 1\), 
                              ",", \(n\ modqr[q, r]\), "       ", 
                              
                              StyleBox[\( (*\ negate\ all\ but\ col\ 1\ *) \),
                                
                                FontColor->RGBColor[0, 0, 1]], ",", 
                              "\[IndentingNewLine]", "True", 
                              ",", \(q + Abs[r]\)}], "]"}]}], "            ", 
                        
                        StyleBox[\( (*\ shift\ by\ default*) \),
                          FontColor->RGBColor[0, 0, 1]], " ", 
                        StyleBox[",",
                          FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
                        "True", ",", 
                        RowBox[{\(r = m[\([j - q, i - q]\)]\), "      ", 
                          StyleBox[\( (*\ Bottom - right\ i, j > q*) \),
                            FontColor->RGBColor[0, 0, 1]], 
                          StyleBox[";",
                            FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
                          RowBox[{
                          "If", "[", \(IntegerQ[l] && j \[NotEqual] q + 1 && 
                              q > 1, \ r, \[IndentingNewLine]n\ r\), 
                            
                            StyleBox[\( (*\ 
                                negate\ all\ but\ col\ 1\ if\ l\ negative\ \
real*) \),
                              FontColor->RGBColor[0, 0, 1]], "]"}]}]}], "]"}],
                     ",", "\[IndentingNewLine]", \({i, 2  q}\), 
                    ",", \({j, 2  q}\)}], "]"}]}], "]"}]}]}], 
        "]"}]}], "\[IndentingNewLine]", \(modqr[q_, 
        r_] := \((Mod[\((q + Abs[r])\) - 1, 2  q] + 1)\) Sign[r]\)}], "Input",\

  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[TextData[{
  "Cayley-Dickson Doubling Procedure ",
  StyleBox["cd",
    FontSlant->"Italic"],
  ". The classic procedure started with reals with \"-\"\[Times]\"-\"=\"+\" \
and successively introduced new relators i,j,k... that square to -1 and \
anti-commute with earlier relators, thereby defining a product rule \
A\[Times]A\[RightArrow]B with a specific multiplication rule. This gives \
\[DoubleStruckCapitalR]\[Times]\[DoubleStruckCapitalR]\[RightArrow]\
\[DoubleStruckCapitalC], \[DoubleStruckCapitalC]\[Times]\
\[DoubleStruckCapitalC]\[RightArrow]\[DoubleStruckCapitalH], \
\[DoubleStruckCapitalH]\[Times]\[DoubleStruckCapitalH]\[RightArrow]\
\[DoubleStruckCapitalO], \[DoubleStruckCapitalO]\[Times]\
\[DoubleStruckCapitalO]\[RightArrow]Sed, etc. The procedure is implemented in \
",
  StyleBox["cd",
    FontSlant->"Italic"],
  ", with a list of the squares of the relators as argument. Hence cd[{-1}] \
gives the signed index table for \[DoubleStruckCapitalC] (called C4c), \
cd[{-1,-1}] gives \[DoubleStruckCapitalH] (called Qr), cd[{-1,-1,-1}] gives \
\[DoubleStruckCapitalO] (called Octr), cd[{-1,-1,-1,-1}] gives Sedenions \
(called Sed).  Commutativity is lost on going to \[DoubleStruckCapitalH], \
associativity is lost on going to \[DoubleStruckCapitalO], \
square-associativity and the Moufang property are lost on going to Sed. These \
algebras have symbolic multiplication tables with determinants that factorize \
into the sum of the squares of their elements. The factors are conserved \
functions (and denominators for vector inverses) for \[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], and \
\[DoubleStruckCapitalO], which are \"real algebras without divisors of zero\" \
because the denominator is only zero in the trivial (real) case. Sed is not \
conservative.\nThis procedure was generalized by Schaefer to allow new \
elements that square to +1. This is implemented by providing arguments that \
are 1; cd[{1,1}] gives Study numbers; cd[{1,-1}] gives Clifford(2). \
cd[{-1,1}], cd[{-1,1,1}], cd[{-1,1,1,1}] and cd[{-1,1,1,1,1}] give O2, O4, O8 \
& O16, i.e. algebras that consist of 2, 4, 8, and 16 copies of the complex \
plane.\nI noticed that there is a prior stage, in which unsigned numbers are \
doubled to give real numbers. This is included in the procedure, so cd[{}] \
and cd[{1}] give the C1 & C2 groups, corresponding to Primal & Real numbers.\n\
A few more hoops can be created by negating parts of the lower half of the \
table. This is implemented by using reals, \"1.\" or \"-1.\" but often gives \
non-conservative tables.\nI then realized that other tables could be doubled. \
This was implemented by providing a list of predefined tables and (later) \
\"",
  StyleBox["cd[{g_String}]:=ToExpression[g];",
    FontSlant->"Italic"],
  "\" to allow any loop incantation to be used as an optional first relator. \
\nAs ",
  StyleBox["cd",
    FontSlant->"Italic"],
  " created signed tables, it was further modified to compose the table with \
a cyclic group Cn by (optionally) making the final relators ",
  StyleBox["{n}",
    FontSlant->"Italic"],
  " or \"",
  StyleBox["loopname",
    FontSlant->"Italic"],
  "\". (Only the ",
  StyleBox["{n}",
    FontSlant->"Italic"],
  " format is acceptable in the ",
  StyleBox["loop[[]]",
    FontSlant->"Italic"],
  " lists as \"\" cannot be used there.) This gives the parent loops of the \
signed tables.\nAnother modification, Moufang doubling ",
  StyleBox["md,",
    FontSlant->"Italic"],
  " implements the creation of some Moufang Loops, described in the Wikipedia \
Moufang Loop article and implemented in the GAP Loop package. It reproduces \
13 of the D3Mn etc tables from GAP Loop package:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{\(Clear[md]\), ";", 
      RowBox[{\(md[g_?MatrixQ, l_: {}]\), 
        StyleBox[\( (*From\ Loop\ in\ GAP*) \),
          FontColor->RGBColor[0, 0, 1]], ":=", "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({m = Length[g], 
              gin = If[l \[Equal] {}, gInverse[g], l]}\), ",", 
            "\[IndentingNewLine]", 
            RowBox[{\(res = Table[0, {i, 2  m}, {j, 2  m}]\), ";", 
              RowBox[{"Do", "[", 
                RowBox[{
                  RowBox[{"Do", "[", 
                    RowBox[{
                      RowBox[{\(res[\([i, j]\)] = g[\([i, j]\)]\), 
                        StyleBox[\( (*\ Top - left\ g\ *) \),
                          FontColor->RGBColor[0, 0, 1]], ";", 
                        "\[IndentingNewLine]", \(res[\([i, j + m]\)] = 
                          g[\([j, i]\)] + m\), 
                        StyleBox[\( (*\ Top - right\ g\^T + m*) \),
                          FontColor->RGBColor[0, 0, 1]], ";", 
                        "\[IndentingNewLine]", \(res[\([i + m, j]\)] = 
                          g[\([i, gin[\([j]\)]]\)] + m\), 
                        StyleBox[\( (*\ Bottom\ left\ g + m\ reordered*) \),
                          FontColor->RGBColor[0, 0, 1]], ";", 
                        "\[IndentingNewLine]", \(res[\([i + m, j + m]\)] = 
                          g[\([gin[\([j]\)], i]\)]\)}], 
                      StyleBox[\( (*\ Bottom\ right\ g\^T\ reordered*) \),
                        FontColor->RGBColor[0, 0, 1]], ",", 
                      "\[IndentingNewLine]", \({i, m}\)}], "]"}], 
                  ",", \({j, m}\)}], "]"}], ";", "res"}]}], "]"}]}], 
      ";"}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(groupFromRelators[gp_, post_: {}]\), ":=", 
        RowBox[{"(*", " ", 
          RowBox[{
            RowBox[{
              StyleBox["skeleton",
                FontColor->RGBColor[1, 0, 0]], " ", "version", " ", "of", " ",
               "ge"}], ",", " ", \(for\ small\ groups\ only\)}], " ", 
          "*)"}], \(Module[{g = {}, cr, j, l = Plus @@ gp + 2, 
            le = Length[gp], ln = 1, lh, n = {"\<\>"}, new, p, st, rhs, si, 
            sij, t = post}, 
          cr = Take[{"\<a\>", "\<b\>", "\<c\>", "\<d\>", "\<e\>", "\<f\>", \
"\<g\>"}, le]; \[IndentingNewLine]Do[ (*i\ loop . \ 
                  Rules\ to\ reduce\ repetitions*) st = 
              cr[\([i]\)]; \[IndentingNewLine]AppendTo[t, 
              Do[st = st <> cr[\([i]\)], {gp[\([i]\)] - 1}]; 
              Rule[st, "\<\>"]], {i, le}]; \[IndentingNewLine]Do[ (*i, 
              j\ loops . Add\ abelian\ rules*) new = 
              Rule[lh = cr[\([j]\)] <> cr[\([i]\)], 
                cr[\([i]\)] <> 
                  cr[\([j]\)]]; \[IndentingNewLine]Do[ (*k\ loop . 
                    Omit\ redundant\ rules*) If[lh \[Equal] t[\([k, 1]\)], 
                new = "\<\>"], {k, Length[t] - 1}]; \[IndentingNewLine]If[
              Length[new] \[Equal] 2, AppendTo[t, new]], {i, 1, le - 1}, {j, 
              i + 1, le}]; \[IndentingNewLine]Do[ (*i\ loop . 
                  Build\ the\ element\ list*) si = cr[\([i]\)]; sij = si; 
            p = gp[\([i]\)] - 
                1; \[IndentingNewLine]Do[ (*j\ loop . Repetitions*) 
                Do[ (*k\ loop . New\ element = 
                    j\ repeats\ of\ k' th\ existing\ element*) AppendTo[n, 
                  If[k \[Equal] 1, sij, n[\([k]\)] <> sij]], {k, 
                  ln}]; \[IndentingNewLine]sij = sij <> si, {j, p}]; 
            ln = Length[n], {i, 
              le}];  (*element\ list\ \(\(completed\)\(.\)\)*) 
            Do[ (*i\ loop . Build\ table\ by\ \(\(concatenation\)\(.\)\)*) 
              AppendTo[
              g,  (*add\ successive\ n[\([i]\)] <> n\ rows\ to\ g*) MapThread[
                StringJoin, {Table[n[\([i]\)], {j, ln}], n}]], {i, 
              ln}]; \[IndentingNewLine]g = 
            Table[l = 0; s1 = g\[LeftDoubleBracket]i, j\[RightDoubleBracket]; 
              s1 = While[\((s2 = StringReplace[s1, t])\) \[NotEqual] s1 && 
                    l < 99, \(l++\); s1 = s2]; 
              s2, {i, ln}, {j, 
                ln}]; \[IndentingNewLine] (*Conversion\ to\ \
\(\(indices\)\(.\)\)*) st = 
            Table[g\[LeftDoubleBracket]j, 1\[RightDoubleBracket] \[Rule] 
                j, {j, ln, 1, \(-1\)}]; \[IndentingNewLine]g /. st]\)}], 
      ";"}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "9.7 Groups from Permutations, ",
  StyleBox["pe.",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{\(pe[mm_, maxel_:  72]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({m, g = {Range[Max[Flatten[mm]]]}, i, j, k, n, o = {}}\), 
          ",", 
          RowBox[{\(permel = {}\), ";", 
            RowBox[{"If", "[", 
              RowBox[{\(Depth[mm] < 3\), ",", 
                RowBox[{
                  
                  StyleBox[\(Print[
                      mm, "\<is not a list of permutations or cycles\>"]\),
                    FontColor->RGBColor[1, 0, 1]], ";", \(Goto[tag]\)}]}], 
              "]"}], ";", 
            RowBox[{"If", "[", 
              RowBox[{\(MemberQ[mm, g[\([1]\)]]\), ",", 
                RowBox[{
                  StyleBox[\(Print[g[\([1]\)], "\< unacceptable\>"]\),
                    FontColor->RGBColor[1, 0, 1]], ";", \(Goto[tag]\)}]}], 
              "]"}], ";", 
            "\[IndentingNewLine]", \(Do[j = mm[\([i]\)]; 
              k = If[VectorQ[j], j, fromCycles[j]]; 
              AppendTo[g, k], {i, Length[mm]}]\), ";", 
            "\[IndentingNewLine]", \(j = 2\), ";", \(k = 1\), 
            ";", \(While[j \[LessEqual] Length[g], \(k++\); 
              n = permute[g\[LeftDoubleBracket]j\[RightDoubleBracket], 
                  g\[LeftDoubleBracket]k\[RightDoubleBracket]]; 
              If[\(! \((MemberQ[g, n])\)\), AppendTo[g, n]]; 
              If[k \[GreaterEqual] Length[g], k = 1; \(j++\); 
                If[j > maxel + 1, Print["\<Large\>"]; i = l + 1; j = l + 1; 
                  i = 0; mm = 0; nn = 0; Goto[tag]]]]\), ";", \(permel = g\), 
            ";", \(o = 
              caylindex[
                Table[permute[g\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    g\[LeftDoubleBracket]j\[RightDoubleBracket]], {i, 
                    Length[g]}, {j, Length[g]}]]\), ";", \(Label[tag]\), 
            ";", \(glo = o\)}]}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".8 MatrixGroups using extended signs, ",
  StyleBox["ma, mg, ms",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ma[{mm__?MatrixQ}, maxel_:  73, o_:  0] := 
      Module[{m = {mm}, mi, g, j = 2, k = 1, mx = 2, n}, mi = minsign[m]; 
        g = union[{IdentityMatrix[
                Length[m\[LeftDoubleBracket]1\[RightDoubleBracket]]], mm}]; 
        While[j \[LessEqual] Length[g], \(k++\); 
          n = g\[LeftDoubleBracket]j\[RightDoubleBracket] . 
                g\[LeftDoubleBracket]k\[RightDoubleBracket] /. 
              mi; \[IndentingNewLine]If[\[InvisibleSpace]\(! \((MemberQ[g, 
                  n])\)\), AppendTo[g, n]; \(mx++\); 
            If[mx > maxel, k = 9999; j = mx]]; 
          If[k \[GreaterEqual] Length[g], k = 1; \(j++\); 
            If[j > maxel, matel = {}; g = {{}}; Goto[tag]]]]; matel = g; 
        If[o \[Equal] 0, 
          g = caylindex[
              Table[g\[LeftDoubleBracket]i\[RightDoubleBracket] . 
                    g\[LeftDoubleBracket]
                      j\[RightDoubleBracket] /. \[InvisibleSpace]mi, {i, 
                  Length[g]}, {j, Length[g]}]]; glo = g]; Label[tag]; 
        g]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"ma", "[", 
        RowBox[{\({mm__}\), ",", \(maxel_:  73\), ",", \(o_:  0\), ",", 
          StyleBox[
            RowBox[{
              StyleBox["skeleton",
                FontColor->RGBColor[1, 0, 0]], "_"}]]}], "]"}], ":=", 
      RowBox[{"Module", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\(m = {mm}\), ",", "g", ",", \(j = 2\), ",", \(k = 1\), 
              ",", "lg", ",", \(mx = 2\), ",", "n", ",", 
              RowBox[{"rs", "=", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox[
                        StyleBox["\[DoubleStruckCapitalJ]",
                          FontWeight->"Plain"], "any_"], "\[Rule]", 
                      SuperscriptBox[
                        StyleBox["\[DoubleStruckCapitalJ]",
                          FontWeight->"Plain"], \(Mod[any, 3]\)]}], 
                    ",", \(\[DoubleStruckK]\^any_ \[Rule] \
\[DoubleStruckK]\^Mod[any, 2]\)}], "}"}]}], ",", "st"}], "}"}], 
          ",", \(g = Insert[m, IdentityMatrix[Length[m[\([1, 1]\)]]], 1]; 
          While[lg = Length[g]; j \[LessEqual] lg, \(k++\); 
            n = g\[LeftDoubleBracket]j\[RightDoubleBracket] . 
                  g\[LeftDoubleBracket]
                    k\[RightDoubleBracket] /. \[InvisibleSpace]rs; 
            If[\(! MemberQ[g, n]\), AppendTo[g, n]; \(mx++\); 
              If[mx > maxel, k = 9999; j = mx]]; 
            If[k \[GreaterEqual] lg, k = 1; \(j++\); 
              If[j > maxel, g = {{}}; Goto[tag]]]]; 
          g = Table[
              g\[LeftDoubleBracket]i\[RightDoubleBracket] . 
                  g\[LeftDoubleBracket]j\[RightDoubleBracket] /. rs, {i, 
                lg}, {j, lg}]; Label[tag]; 
          st = Table[
              g\[LeftDoubleBracket]j, 1\[RightDoubleBracket] -> j, {j, lg, 
                1, \(-1\)}]; \ng /. st\)}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(mg[v_?VectorQ, u_] := 
      Module[{}, 
        ma[Table[u[\([Abs[v[\([i]\)]]]\)] Sign[v[\([i]\)]], {i, Length[v]}], 
          mm + 1]]\), "\n", 
    \(ms[v__?ListQ, u_:  u2, 
        maxel_:  64] :=  (*Version\ 2  s*) \[IndentingNewLine]Module[{gg, 
          gij, i = 2, j = 2, l, mi, new, n, p, s, tot = 0, 
          m = If[VectorQ[v], 
              Table[Sign[v[\([i]\)]] u[\([Abs[v[\([i]\)]]]\)], {i, 
                  Length[v]}], v]}, 
        s = Union[{1, \(-1\)}, 
            Variables[m] \[Intersection] signlist]; \[IndentingNewLine]If[
          MatrixQ[m[\([1]\)]] === True, , 
          Print[\ "\<Not a list or matrix\>"]; 
          Abort[]]; \[IndentingNewLine]l = Length[m[\([1]\)]]; 
        n = Length[m] + 1; matel = Prepend[m, IdentityMatrix[l]]; 
        mi = minsign[matel]; \[IndentingNewLine]While[
          j = 2; \[IndentingNewLine]While[
            new = matel[\([i]\)] . matel[\([j]\)] /. 
                mi; \[IndentingNewLine]If[mstst[new, s] \[Equal] 0, 
              AppendTo[matel, new]]; \(tot++\); 
            If[Length[matel] > maxel || tot > 4\ maxel, Print[matel]; 
              Abort[]]; \[IndentingNewLine]j < Length[matel], \(j++\)]; 
          i < Length[matel], \(i++\)]; \[IndentingNewLine]n = Length[matel]; 
        gg = Table[
            matel[\([i]\)] . matel[\([j]\)] /. mi, {i, n}, {j, 
              n}]; \[IndentingNewLine]Do[gij = gg[\([i, j]\)]; 
          p = mstst[gij, s]; 
          gg[\([i, j]\)] = p\ \(Position[matel, p\ gij]\)[\([1, 1]\)], {i, 
            n}, {j, n}]; glo =. ; If[indexTableQ[gg] == True, glo = gg]; 
        glo]\), "\[IndentingNewLine]", 
    \(\(mstst[m_, s_] := 
        Module[{i = 0, l = Length[s], res = 0}, 
          While[i < l, \(i++\); 
            If[Position[matel, s[\([i]\)] m] \[Equal] {}, , res = s[\([i]\)]; 
              i = l]]; res];\)\), "\[IndentingNewLine]", 
    \(msi[v__?ListQ, u_:  u2, 
        si_: {1, \(-1\), \[ImaginaryI], \(-\[ImaginaryI]\)}, 
        maxel_:  64] := \[IndentingNewLine]Module[{gg, gij, i = 2, j = 2, l, 
          mi, new, n, p, s, tot = 0, 
          m = If[VectorQ[v], 
              Table[Sign[v[\([i]\)]] u[\([Abs[v[\([i]\)]]]\)], {i, 
                  Length[v]}], v]}, 
        s = Union[si, 
            Variables[m] \[Intersection] signlist]; \[IndentingNewLine]If[
          MatrixQ[m[\([1]\)]] === True, , 
          Print[\ "\<Not a list or matrix\>"]; 
          Abort[]]; \[IndentingNewLine]l = Length[m[\([1]\)]]; 
        n = Length[m] + 1; matel = Prepend[m, IdentityMatrix[l]]; 
        mi = minsign[matel]; \[IndentingNewLine]While[
          j = 2; \[IndentingNewLine]While[
            new = matel[\([i]\)] . matel[\([j]\)] /. 
                mi; \[IndentingNewLine]If[mstst[new, s] \[Equal] 0, 
              AppendTo[matel, new]]; \(tot++\); 
            If[Length[matel] > maxel || tot > 4\ maxel, Print[matel]; 
              Abort[]]; \[IndentingNewLine]j < Length[matel], \(j++\)]; 
          i < Length[matel], \(i++\)]; \[IndentingNewLine]n = Length[matel]; 
        gg = Table[
            matel[\([i]\)] . matel[\([j]\)] /. mi, {i, n}, {j, 
              n}]; \[IndentingNewLine]Do[gij = gg[\([i, j]\)]; 
          p = mstst[gij, s]; 
          gg[\([i, j]\)] = p\ \(Position[matel, p\ gij]\)[\([1, 1]\)], {i, 
            n}, {j, n}]; glo =. ; If[indexTableQ[gg] == True, glo = gg]; 
        glo]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9.",
    FontFamily->"Times New Roman"],
  "9 Protoloops",
  StyleBox[" makeProtoloop[G_,o_],  mp, gd.",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(mp[] := makeProtoloop[{mm, nn}, 0];\)\), "\n", 
    \(\(mp[m_?IntegerQ, n_?IntegerQ] := makeProtoloop[{m, n}, 0];\)\), "\n", 
    \(\(mp[{a_, b_}, o_?IntegerQ] := makeProtoloop[{a, b}, o];\)\), "\n", 
    \(\(mp[m_?IntegerQ, n_?IntegerQ, o_?IntegerQ] := 
        makeProtoloop[{m, n}, o];\)\), "\n", 
    \(\(mp[a_] := makeProtoloop[a, 0];\)\), "\[IndentingNewLine]", 
    \(\(makeProtoloop[m_?IntegerQ, n_?IntegerQ, o_?IntegerQ] := 
        makeProtoloop[{m, n}, o];\)\), "\[IndentingNewLine]", 
    \(\(makeProtoloop[m_?IntegerQ, n_?IntegerQ] := 
        makeProtoloop[{m, n}, 0];\)\), "\[IndentingNewLine]", 
    \(\(makeProtoloop[G_] := makeProtoloop[G, 0];\)\), "\n", 
    \(\(makeProtoloop[G_, o_?IntegerQ] := 
        Module[{g, l, res, mx = mg}, matel =. ; 
          If[Head[G] === Symbol, 
            Print[{G, "\<not a known Table. Changed to a string.\>"}]; 
            G = ToString[
                G]]; \[IndentingNewLine]Which[\[IndentingNewLine]MatrixQ[G], 
            id[caylindex[G]], \[IndentingNewLine]Head[G] === String, 
            g = Position[loop, G, 3, 1]; \[IndentingNewLine]\ \ If[g === {}, 
              Print[{"\<Unknown case \>", o, "\< \>", G}]; 
              Abort[]]; \[IndentingNewLine]\ \ \ mm = g[\([1, 1]\)]; 
            nn = g[\([1, 2]\)], \[IndentingNewLine]Length[G] === 2, 
            If[Length[loop[\([G[\([1]\)]]\)]] \[GreaterEqual] G[\([2]\)], 
              mm = G[\([1]\)]; nn = G[\([2]\)], 
              Return[{"\<Unknown mm,nn \>", G}]\ ], \[IndentingNewLine]True, 
            mm = Length[loop]]; \[IndentingNewLine]If[
            Sign[\(loop[\([mm, nn]\)]\)[\([2, 1]\)]] \[NotEqual] 1, 
            mx = ms]; \[IndentingNewLine]If[
            mm \[GreaterEqual] 
                Length[loop] || \((l = loop[\([mm]\)])\) == {} || 
              Length[l] < nn, gmn = "\<Unrecognized\>", l = l[\([nn]\)]; 
            gmn = loop[\([mm, nn, 1]\)]]; 
          res = Which[o < 1 && l[\([4]\)] != "\<ca[]\>", 
              ToExpression[
                l[\([4]\)]], \[IndentingNewLine]\((o == 0 || o \[Equal] 1)\) && 
                l[\([5]\)] \[NotEqual] {}, 
              ge[l[\([5]\)], 
                l[\([6]\)]], \[IndentingNewLine]\((o == 0 || o \[Equal] 2)\) && 
                Length[l] > 6 && l[\([7]\)] \[NotEqual] {}, 
              mx[l[\([7]\)], 
                u2], \[IndentingNewLine]\((o == 0 || o \[Equal] 3)\) && 
                Length[l] > 7 && l[\([8]\)] \[NotEqual] {}, 
              mx[l[\([8]\)], 
                u3], \[IndentingNewLine]\((o == 0 || o \[Equal] 4)\) && 
                Length[l] > 8 && l[\([9]\)] \[NotEqual] {}, 
              mx[l[\([9]\)], 
                u4], \[IndentingNewLine]\((o == 0 || o \[Equal] 5)\) && 
                Length[l] > 9, 
              ToExpression[
                l[\([10]\)]], \[IndentingNewLine]\((o == 0 || 
                    o \[Equal] 6)\) && Length[l] > 10, 
              ToExpression[l[\([11]\)]], \[IndentingNewLine]True, 
              Print[{G, "\<No Protoloop\>", o}]; {}]; id[res]; 
          glo = res];\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(gd[] := gd[mm, nn]; gd[{m_Integer, n_Integer}] := gd[m, n]; 
    gd[m_Integer:  mm, n_Integer:  nn] := 
      If[m > 0 && loop[\([m]\)] \[NotEqual] {} && n > 0 && 
          Length[loop[\([m]\)]] \[GreaterEqual] n, {mm = m, nn = n, 
          loop[\([m, n]\)]}, "\<Not a loop index\>"];\), "\n", 
    \(gd[g_] := 
      Module[{i}, 
        Which[\[IndentingNewLine]Head[g] === 
              String && \((i = Position[loop, g, 3, 1])\) \[NotEqual] {}, 
          gd[mm = i[\([1, 1]\)], 
            nn = i[\([1, 2]\)]], \[IndentingNewLine]Head[g] === 
              String && \((i = 
                  Position[loop, g <> "\<?\>", 3, 1])\) \[NotEqual] {}, 
          gd[mm = i[\([1, 1]\)], 
            nn = i[\([1, 2]\)]], \[IndentingNewLine]True, 
          Print["\<Not a loop index or known mnemonic. Try as a string?\>"]]]\
\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".10 Loop identification",
  StyleBox[" id, idc",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\(Unprotect[id, 
        idc]\) \)\(;\)\(\(id =. \) \)\(;\)\(\(idc =. \) \)\(;\)\(\(mm =. \) \
\)\(;\)\(\(nn =  .0\) \)\(;\)\(\(glo =. \) \)\(;\)\( (*for\ extensions*) \)\)\
\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[{
    \(\(idc[G_] := 
        If[conservativeQ[G], 
          id[G], "\<Not conservative.\>"];\)\), "\[IndentingNewLine]", 
    \(\(idc[G_, L_?ListQ] := 
        If[conservativeQ[G], 
          id[G, L], "\<Not conservative.\>"];\)\), "\[IndentingNewLine]", 
    \(\(id[] := id[{mm, nn}, {}];\)\), "\[IndentingNewLine]", 
    \(id[G_: {mm, nn}] := id[G, {}]; 
    id[G_: {mm, nn}, L_?ListQ] := 
      Module[{ln, lg, j, jj, M}, nn = 1; 
        If[Head[G] === TraditionalForm, M = G[\([1]\)], 
          M = G]; \[IndentingNewLine]If[Head[G] === String, M = mp[G]]; 
        Which[Dimensions[M] \[Equal] {2}, mm = M[\([1]\)]; nn = M[\([2]\)]; 
          M = {}, \[IndentingNewLine]MatrixQ[M], 
          M = If[Length[L] > 0, reorder[M, L], M]; 
          mm = Length[M], \[IndentingNewLine]True, mm = Length[loop]; 
          glo =. ; M = {}]; \[IndentingNewLine]lg = 
          Length[M]; \[IndentingNewLine]If[
          lg > 1 && \((j = 
                  Position[\(loop[\([lg]\)]\)[\([All, {2}]\)], dico[M], 3, 
                    1])\) \[NotEqual] {}, nn = j[\([1, 1]\)], 
          mm = Length[loop]]; \[IndentingNewLine]jj = loop[\([mm, nn, 3]\)]; 
        ln = nn; \[IndentingNewLine]Switch[jj, 0, , \[IndentingNewLine]1, 
          Switch[trico[M], {3, 
              3\_2}, "\<C9\>", {9}, \(nn++\); "\<C3C3\>", {6, 3}, 
            nn += 4; "\<Alt9n\>"], \[IndentingNewLine]2, 
          If[Length[fa[M]] \[Equal] 2, "\<Dav\>", 
            nn += 3; "\<C4C2r\>"], \[IndentingNewLine]3, 
          If[subgroups[M, 0] \[Equal] 9, 
            nn += 3; "\<C8C2\>", "\<C4C4\>"], \[IndentingNewLine]4, 
          If[subgroups[M, 0, 5, 5] \[NotEqual] 
              1, "\<C3C25\>", \(nn++\); "\<C75\>"], \[IndentingNewLine]5, 
          If[trico[M] === {3, 3\_5}, "\<C18\>", 
            nn += 3; "\<C3C3C2\>"], \[IndentingNewLine]6, 
          If[trico[M] === {9, 1\_9}, 
            nn += 3; "\<E18\>", "\<D9\>"], \[IndentingNewLine]7, 
          If[Length[fa[M]] \[Equal] 2, "\<C3KJ\>", 
            nn += 5; "\<C4C3j\>"], \[IndentingNewLine]8, 
          Switch[trico[M], {3, 3\_8}, "\<C27\>", {9, 
              9\_2}, \(nn++\); "\<C9C3\>", {27}, 
            nn += 4; "\<C3C3C3\>"], \[IndentingNewLine]9, 
          If[subgroups[M, 0] \[Equal] 
              1, "\<C25\>", \(nn++\); "\<C5C5\>"], \[IndentingNewLine]10, 
          Switch[
            trico[M], {9, 
              9\_2}, \(nn++\); "\<g2704\>", {27}, "\<P27\>"], \
\[IndentingNewLine]11, 
          Switch[subgroups[M, 0, 0, 8], 33, nn += 31; "\<g3233\>", 37, 
            nn += 22; "\<g3224\>", any_, "\<g3202\>"], \[IndentingNewLine]12, 
          If[conservativeQ[M], "\<C4C4r\>", 
            nn += 2; "\<C4Kcn\>"], \[IndentingNewLine]13, 
          If[trico[M] === {1, 1\_13, 
                2}, "\<CL31\>", \(nn++\); "\<CL22\>"], \[IndentingNewLine]14, 
          If[Length[centre[M]] \[Equal] 8, "\<KiC8\>", 
            nn += 6; "\<g3211\>"], \[IndentingNewLine]15, 
          If[trico[M] === {1, 1\_11, 2\_2}, "\<CL4\>", 
            nn += 3; "\<CL13\>"], \[IndentingNewLine]16, 
          Switch[trico[M], {1, 1\_13, 2}, "\<r31r\>", {1, 1\_11, 
              2\_2}, \(nn++\); "\<r31s\>", {1, 1\_15}, 
            nn += 2; "\<r31t\>", {1, 1\_7, 2\_4}, 
            nn += 3; "\<r31u\>"], \[IndentingNewLine]17, 
          If[Length[centre[M]] \[Equal] 8, "\<C4iC4C2\>", 
            nn += 6; "\<KiQ8\>"], \[IndentingNewLine]18, 
          Switch[Max[
              First[Transpose[
                  collect[subgroupTypes[subgroups[M, 1, 16, 16]]]]]], 2, 
            mm = 32; nn = 25; "\<D4C4\>", 3, mm = 32; nn = 30; "\<G3230\>", 
            4, mm = 32; nn = 31; "\<g3231\>"], \[IndentingNewLine]19, 
          If[Length[centre[M]] == 4, 
            nn += 6; "\<Q8C4\>", "\<g3226\>"], \[IndentingNewLine]20, 
          If[conservativeQ[M], "\<QC2c\>", nn += 19; "\<QC2cn\>"], 21, 
          If[Length[centre[M]] \[Equal] 4, "\<g64091\>"; mm = 64; 
            nn = ln + 13, "\<g64078\>"; mm = 64; 
            nn = ln], \[IndentingNewLine]22, 
          If[Position[
                M, \(-\[ImaginaryI]\)] === {}, \(nn++\); "\<C3i\>", \
"\<C12c\>"], \[IndentingNewLine]23, 
          If[subgroups[M, 0, 3, 3] \[Equal] 1, "\<C36\>", 
            nn += 6; "\<C12C3\>"], \[IndentingNewLine]24, 
          If[subgroups[M, 0, 3, 3] \[Equal] 1, "\<C18C2\>", 
            nn += 9; "\<C6C6\>"], \[IndentingNewLine]25, 
          If[subgroups[M, 0, 3, 3] \[Equal] 1, "\<D18\>", 
            nn += 9; "\<E18C2\>"], \[IndentingNewLine]26, 
          If[subgroups[M, 0, 3, 3] \[Equal] 1, "\<Q36\>", 
            nn += 6; "\<C3iQ12\>"], \[IndentingNewLine]27, 
          If[subgroups[M, 0, 3, 3] \[Equal] 1, "\<g3603\>", 
            nn += 8; "\<A4C3\>"], \[IndentingNewLine]28, 
          Switch[allFactorGroups[M, 0, 2, 2, {37, 38}], 37, "\<g64104\>"; 
            mm = 64; nn = ln, 38, "\<g64105\>"; mm = 64; 
            nn = ln + 1], \[IndentingNewLine]29, 
          Switch[trico[M], {3, 3\_20}, "\<C63\>", {9, 
              9\_6}, \(nn++\); "\<C7C3C3\>"], \[IndentingNewLine]30, 
          If[subgroups[M, 0, 3, 3] \[Equal] 
              1, "\<C45\>", \(nn++\); "\<C5C3C3\>"], \[IndentingNewLine]31, 
          Switch[trico[M], {3, 3\_6, 21\_2}, \(nn++\); "\<C6n3\>", {45, 
              3\_6}, "\<g2101C3\>"], \[IndentingNewLine]32, 
          If[subgroups[M, 0, 4, 4] \[Equal] 7, "\<C3C4C4\>", 
            nn += 3; "\<C24C2\>"], \[IndentingNewLine]33, 
          If[Length[centre[M]] \[Equal] 
              4, \(nn++\); "\<g4805\>", "\<C8D3\>"], \[IndentingNewLine]34, 
          Switch[subgroups[M, 0, 32, 
              0, {3, 7, 11, 15, 36, 38, 
                42}], \[IndentingNewLine]36, "\<g64116\>"; mm = 64; 
            nn = 116, \[IndentingNewLine]3, "\<g64117\>"; mm = 64; 
            nn = 117, \[IndentingNewLine]7, "\<g64117\>"; mm = 64; 
            nn = 117, \[IndentingNewLine]_, "\<g64124\>"; mm = 64; 
            nn = 124], \[IndentingNewLine]35, 
          If[subgroups[M, 0, 4, 4] \[Equal] 15, 
            nn += 2; "\<C4D6\>", "\<P48\>"], \[IndentingNewLine]36, 
          If[subgroups[M, 0, 4, 4] \[Equal] 3, 
            If[Length[centre[M]] \[NotEqual] 
                4, "\<C24g17C2\>", \(nn++\); "\<g4810\>"], 
            nn += 2; "\<Q12C4\>"], \[IndentingNewLine]37, 
          Switch[subgroups[M, 0, 4, 4], 11, "\<A4C4\>", 7, 
            nn += 2; "\<g4833\>"], \[IndentingNewLine]38, 
          If[subgrpPerm[M, 0, 7, 7] \[Equal] 
              1, "\<C49\>", \(nn++\); "\<C7C7\>"], \[IndentingNewLine]39, 
          If[subgrpPerm[M, 0, 5, 5] \[Equal] 
              1, "\<C50\>", \(nn++\); "\<C10C5\>"], \[IndentingNewLine]40, 
          If[subgrpPerm[M, 0, 5, 5] \[Equal] 
              1, "\<D25\>", \(nn++\); "\<C5nD5\>"], \[IndentingNewLine]41, 
          If[subgrpPerm[M, 0, 9, 9] \[Equal] 4, "\<P54\>", 
            nn += 5; "\<E18nC3\>"], \[IndentingNewLine]42, 
          If[Length[Position[allFactorGroups[M, 0, 9, 9], "\<D3\>"]] === 3, 
            mm = 54; nn = ln; "\<D9C3a\>", mm = 54; 
            nn = ln + 1; "\<g5406\>"], \[IndentingNewLine]43, 
          Switch[trico[M], {3, 1\_27, 3\_8}, D27, _, 
            nn += 13; "\<D27b\>"], \[IndentingNewLine]44, 
          Switch[allFactorGroups[M, 0, 2, 2, {39, 40}], 39, "\<g64118\>"; 
            mm = 64; nn = ln, 40, "\<g64119\>"; mm = 64; 
            nn = ln + 1], \[IndentingNewLine]45, 
          If[trico[M] === {9, 3\_9, 9\_2}, "\<C9D3\>", 
            nn += 8; "\<D3C3C3\>"], \[IndentingNewLine]46, 
          If[MemberQ[allFactorGroups[M, 0, 2, 2], "\<g3215\>"], "\<g64022\>"; 
            mm = 64; nn = ln + 3, mm = 64; 
            nn = ln; "\<g64019\>"], \[IndentingNewLine]47, 
          If[MemberQ[allFactorGroups[M, 0, 2, 2], "\<D4nC4\>"], "\<g64013\>"; 
            mm = 64; nn = ln, mm = 64; 
            nn = ln + 1; "\<g64014\>"], \[IndentingNewLine]48, 
          If[subgroups[M, 0, 4, 4] \[Equal] 27, "\<g64020\>", 
            nn += 2; "\<g64022\>"], \[IndentingNewLine]49, 
          Switch[subgroups[M, 0, 8, 8], 7, "\<g64026\>", 
            nn += 24, "\<g64050\>"], \[IndentingNewLine]50, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {16, 17}], \[IndentingNewLine]17, "\<g64027\>"; mm = 64; 
            nn = ln, 16, "\<g64051\>"; mm = 64; 
            nn = ln + 24], \[IndentingNewLine]51, 
          If[MemberQ[allFactorGroups[M, 0, 2, 2], "\<g3211\>"], "\<g64020\>"; 
            mm = 64; nn = ln + 2, mm = 64; 
            nn = ln; "\<g64018\>"], \[IndentingNewLine]52, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {2, 9, 14, 40, 42}], \[IndentingNewLine]40, "\<g64106\>"; 
            mm = 64; nn = ln + 85, \[IndentingNewLine]42, "\<g64108\>"; 
            mm = 64; nn = ln + 87, \[IndentingNewLine]_, "\<g64021\>"; 
            mm = 64; nn = ln], \[IndentingNewLine]53, 
          If[subgroups[M, 0, 4, 4] \[Equal] 
              31, "\<g64135\>", "\<g64136\>"; \(nn++\)], \
\[IndentingNewLine]54, 
          If[Length[centre[M]] \[Equal] 4, "\<g64177\>"; nn += 43, 
            If[subgroups[M, 0, 4, 4] \[Equal] 35, "\<g64190\>"; 
              nn += 56, "\<g64134\>"]], \[IndentingNewLine]55, 
          Switch[subgroups[M, 0, 32, 0, {16, 17}], 16, nn = ln; "\<g64044\>", 
            17, nn = ln + 1; "\<g64045\>"], \[IndentingNewLine]56, 
          Switch[subgroups[M, 0, 16, 16], 19, "\<g64057\>"; nn = ln, 
            11, "\<g64064\>"; nn = ln + 7, 7, "\<g64082\>"; 
            nn = ln + 25], \[IndentingNewLine]57, 
          Switch[
            allFactorGroups[M, 0, 2, 
              2, {31, 42}], \[IndentingNewLine]31, "\<g64167\>"; mm = 64; 
            nn = ln, 42, "\<g64176\>"; mm = 64; nn = ln + 9, _, "\<g64173\>"; 
            mm = 64; nn = ln + 6], \[IndentingNewLine]58, 
          Switch[allFactorGroups[M, 0, 2, 2, {22, 43, 28}], 22, "\<g64100\>"; 
            mm = 64; nn = ln, 43, "\<g64109\>"; mm = 64; nn = ln + 9, 
            28, "\<g64151\>"; mm = 64; nn = ln + 51], \[IndentingNewLine]59, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {11, 28, 37, 38, 42}], \[IndentingNewLine]37, "\<g64088\>"; 
            mm = 64; nn = ln, \[IndentingNewLine]38, "\<g64089\>"; mm = 64; 
            nn = ln + 1, \[IndentingNewLine]42, "\<g64097\>"; mm = 64; 
            nn = ln + 9, \[IndentingNewLine]11, "\<g64101\>"; mm = 64; 
            nn = ln + 13, \[IndentingNewLine]28, "\<g64152\>"; mm = 64; 
            nn = ln + 64, \[IndentingNewLine]_, "\<g64102\>"; mm = 64; 
            nn = ln + 14], \[IndentingNewLine]60, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {5, 4, 17, 24}], \[IndentingNewLine]5, "\<g64017\>"; 
            mm = 64; nn = ln, \[IndentingNewLine]4, "\<g64084\>"; mm = 64; 
            nn = ln + 67, \[IndentingNewLine]17, "\<g64184\>"; mm = 64; 
            nn = ln + 167, \[IndentingNewLine]24, 
            Switch[allFactorGroups[M, 0, 2, 
                2, {36, 38}], \[IndentingNewLine]36, "\<g64112\>"; mm = 64; 
              nn = ln + 95, \[IndentingNewLine]38, "\<g64114\>"; mm = 64; 
              nn = ln + 97, \[IndentingNewLine]_, "\<g64113\>"; mm = 64; 
              nn = ln + 96], \[IndentingNewLine]_, 
            Switch[allFactorGroups[M, 0, 2, 
                2, {36, 37, 38}], \[IndentingNewLine]36, "\<g64185\>"; 
              mm = 64; nn = ln + 168, \[IndentingNewLine]37, "\<g64085\>"; 
              mm = 64; nn = ln + 68, \[IndentingNewLine]38, "\<g64086\>"; 
              mm = 64; nn = ln + 69]], \[IndentingNewLine]61, 
          Switch[allFactorGroups[M, 0, 2, 2, {16, 36}], 36, "\<g64083\>"; 
            mm = 64; nn = ln, 16, "\<g64183\>"; mm = 64; 
            nn = ln + 100], \[IndentingNewLine]62, 
          Switch[allFactorGroups[M, 0, 2, 2, {37, 38}], 37, "\<g64113\>"; 
            mm = 64; nn = ln, 38, "\<g64114\>"; mm = 64; 
            nn = ln + 1], \[IndentingNewLine]63, 
          Switch[allFactorGroups[M, 0, 2, 2, {31, 34}], 31, "\<g64074\>"; 
            mm = 64; nn = ln, 34, "\<g64080\>"; mm = 64; 
            nn = ln + 6], \[IndentingNewLine]64, 
          Switch[allFactorGroups[M, 0, 2, 2, {31, 32}], 31, "\<g64071\>"; 
            mm = 64; nn = ln + 4, _, "\<g64067\>"; mm = 64; 
            nn = ln], \[IndentingNewLine]65, 
          Switch[allFactorGroups[M, 0, 2, 2, {23, 25, 26, 28}], 
            26, "\<g64072\>"; mm = 64; nn = ln + 2, _, "\<g64070\>"; mm = 64; 
            nn = ln], \[IndentingNewLine]66, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {25, 26, 30, 31, 33}], \[IndentingNewLine]31, "\<g64063\>"; 
            mm = 64; nn = ln, \[IndentingNewLine]_, "\<g64068\>"; mm = 64; 
            nn = ln + 5], \[IndentingNewLine]67, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {22, 31}], \[IndentingNewLine]22, "\<g64062\>"; mm = 64; 
            nn = ln, \[IndentingNewLine]_, "\<g64069\>"; mm = 64; 
            nn = ln + 7], \[IndentingNewLine]68, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {28, 33}], \[IndentingNewLine]28, "\<g64061\>"; mm = 64; 
            nn = ln, \[IndentingNewLine]33, "\<g64209\>"; mm = 64; 
            nn = ln + 148, \[IndentingNewLine]_, "\<g64210\>"; mm = 64; 
            nn = ln + 149], \[IndentingNewLine]69, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {2, 24}], \[IndentingNewLine]2, "\<g64056\>"; mm = 64; 
            nn = ln, \[IndentingNewLine]24, "\<g64195\>"; mm = 64; 
            nn = ln + 139, \[IndentingNewLine]_, "\<g64198\>"; mm = 64; 
            nn = ln + 142], \[IndentingNewLine]70, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {40, 42}], \[IndentingNewLine]40, "\<g64129\>"; mm = 64; 
            nn = ln, \[IndentingNewLine]42, "\<g64133\>"; mm = 64; 
            nn = ln + 4, \[IndentingNewLine]_, "\<g64161\>"; mm = 64; 
            nn = ln + 32], \[IndentingNewLine]71, 
          Switch[allFactorGroups[M, 0, 2, 
              2, {40, 42}], \[IndentingNewLine]42, "\<g64130\>"; mm = 64; 
            nn = ln, \[IndentingNewLine]40, "\<g64131\>"; mm = 64; 
            nn = ln + 1], \[IndentingNewLine]72, 
          If[conservativeQ[M], "\<C3C2\>", nn += 12; "\<C6an\>"], 73, 
          If[Length[centre[M]] \[Equal] 4, "\<g64178\>"; 
            nn += 41, "\<g64137\>"], \[IndentingNewLine]74, 
          Switch[\(collect[allFactorGroups[M, 0, 8, 8, {16, 16}]]\)[\([1, 
                1]\)], \[IndentingNewLine]11, "\<g64159\>"; mm = 64; 
            nn = ln + 17, \[IndentingNewLine]17, "\<g64157\>"; mm = 64; 
            nn = ln + 15, \[IndentingNewLine]23, "\<g64145\>"; mm = 64; 
            nn = ln + 3, \[IndentingNewLine]_, "\<g64142\>"; mm = 64; 
            nn = ln], \[IndentingNewLine]75, 
          Switch[allFactorGroups[M, 0, 2, 2, {40, 42}], 40, "\<Q8pQ8\>"; 
            mm = 64; nn = ln, 42, "\<g64160\>"; mm = 64; 
            nn = ln + 4], \[IndentingNewLine]76, 
          Switch[allFactorGroups[M, 0, 2, 2, {40, 42}], 40, "\<g54162\>"; 
            mm = 64; nn = ln, 42, "\<g64163\>"; mm = 64; 
            nn = ln + 1], \[IndentingNewLine]77, 
          Switch[allFactorGroups[M, 0, 2, 2, {40, 42}], 40, "\<g54164\>"; 
            mm = 64; nn = ln, 42, "\<g64166\>"; mm = 64; 
            nn = ln + 2], \[IndentingNewLine]78, 
          Switch[allFactorGroups[M, 0, 2, 2, {31, 42}], 31, "\<g54168\>"; 
            mm = 64; nn = ln, 42, "\<g64180\>"; mm = 64; 
            nn = ln + 12, _, "\<g64179\>"; mm = 64; 
            nn = ln + 11], \[IndentingNewLine]79, 
          Switch[allFactorGroups[M, 0, 2, 2, {18, 34}], 18, "\<g54186\>"; 
            mm = 64; nn = ln + 12, 34, "\<g64174\>"; mm = 64; 
            nn = ln], \[IndentingNewLine]80, 
          Switch[allFactorGroups[M, 0, 2, 2, {34, 39}], 34, "\<g54175\>"; 
            mm = 64; nn = ln, 39, "\<g64181\>"; mm = 64; 
            nn = ln + 6], \[IndentingNewLine]81, 
          Switch[allFactorGroups[M, 0, 2, 2, {19}], 19, "\<g64187\>"; 
            mm = 64; nn = ln, _, "\<g64189\>"; mm = 64; nn = ln + 2], 82, 
          Switch[allFactorGroups[M, 0, 2, 2, {27, 34, 39}], 27, "\<g64202\>"; 
            mm = 64; nn = ln, 34, "\<g64211\>"; mm = 64; nn = ln + 9, 
            39, "\<g64250\>"; mm = 64; nn = ln + 48], \[IndentingNewLine]83, 
          Switch[\(collect[allFactorGroups[M, 0, 8, 8, {16, 16}]]\)[\([1, 
                1]\)], \[IndentingNewLine]50, "\<g64205\>"; mm = 64; 
            nn = ln, \[IndentingNewLine]51, "\<g64205\>"; mm = 64; 
            nn = ln, \[IndentingNewLine]59, "\<g64205\>"; mm = 64; 
            nn = ln, \[IndentingNewLine]73, "\<g64206\>"; mm = 64; 
            nn = ln + 1, \[IndentingNewLine]63, "\<g64207\>"; mm = 64; 
            nn = ln + 2, \[IndentingNewLine]49, "\<g64213\>"; mm = 64; 
            nn = ln + 8, \[IndentingNewLine]_, "\<g64205\>"; mm = 64; 
            nn = ln], \[IndentingNewLine]84, 
          If[\(collect[allFactorGroups[M, 0, 4, 4]]\)[\([1, 1]\)] \[Equal] 
              24, "\<g64208\>"; mm = 64; nn = ln, "\<g64214\>"; mm = 64; 
            nn = ln + 6], \[IndentingNewLine]85, 
          If[\(collect[allFactorGroups[M, 0, 4, 4]]\)[\([1, 1]\)] \[Equal] 
              102, "\<g64215\>"; mm = 64; nn = ln, "\<g64216\>"; mm = 64; 
            nn = ln + 1], \[IndentingNewLine]86, 
          If[\(collect[allFactorGroups[M, 0, 4, 4]]\)[\([1, 1]\)] \[Equal] 
              38, "\<g64227\>"; mm = 64; nn = ln, "\<g64231\>"; mm = 64; 
            nn = ln + 4], \[IndentingNewLine]87, 
          If[\(collect[allFactorGroups[M, 0, 4, 4]]\)[\([1, 1]\)] \[Equal] 
              62, "\<g64219\>"; mm = 64; nn = ln, "\<g64221\>"; mm = 64; 
            nn = ln + 2], \[IndentingNewLine]88, 
          If[\(collect[allFactorGroups[M, 0, 4, 4]]\)[\([1, 1]\)] \[Equal] 
              18, "\<g64228\>"; mm = 64; nn = ln, "\<g64229\>"; mm = 64; 
            nn = ln + 1], \[IndentingNewLine]89, 
          Switch[\(collect[allFactorGroups[M, 0, 4, 4]]\)[\([1, 1]\)], 
            58, "\<g64232\>"; mm = 64; nn = ln, 44, "\<g64240\>"; mm = 64; 
            nn = ln + 8, 42, "\<g64234?36\>"; mm = 64; 
            nn = ln + 2], \[IndentingNewLine]90, 
          If[\(collect[allFactorGroups[M, 0, 4, 4]]\)[\([1, 1]\)] \[Equal] 
              71, "\<g64241\>"; mm = 64; nn = ln, "\<g64242\>"; mm = 64; 
            nn = ln + 1], \[IndentingNewLine]91, 
          If[\(collect[allFactorGroups[M, 0, 4, 4]]\)[\([1, 1]\)] \[Equal] 
              33, "\<g64247\>"; mm = 64; nn = ln, "\<g64248\>"; mm = 64; 
            nn = ln + 1], \[IndentingNewLine]92, 
          If[\(collect[allFactorGroups[M, 0, 4, 4]]\)[\([1, 1]\)] \[Equal] 
              35, "\<g64251\>"; mm = 64; nn = ln, "\<g64253\>"; mm = 64; 
            nn = ln + 2], \[IndentingNewLine]93, 
          If[Length[centre[M]] \[Equal] 4, "\<g64254\>"; mm = 64; 
            nn = ln, "\<g64257\>"; mm = 64; 
            nn = ln + 3], \[IndentingNewLine]94, 
          If[Length[centre[M]] \[Equal] 4, "\<g64256\>"; mm = 64; 
            nn = ln, "\<g64258\>"; mm = 64; 
            nn = ln + 2], \[IndentingNewLine]95, 
          If[Length[centre[M]] \[Equal] 4, "\<g64255\>"; mm = 64; 
            nn = ln, "\<g64259\>"; mm = 64; 
            nn = ln + 4], \[IndentingNewLine]96, 
          If[Length[centre[M]] \[Equal] 4, "\<g64???\>"; mm = 64; 
            nn = ln, "\<g64???\>"; mm = 64; 
            nn = ln + 4], \[IndentingNewLine]97, 
          If[Length[fp[M]] \[Equal] 6, 
            nn += 18; "\<O4k\>", "\<O4\>"], \[IndentingNewLine]98, 
          If[\(! conservativeQ[
                M]\), \(nn++\); "\<D4M4n\>", "\<Q8M2\>"], \
\[IndentingNewLine]99, 
          If[\(! associativeQ[M]\), 
            nn += 20; "\<C8pC2M\>", "\<g3238\>"]\[IndentingNewLine]]; \
\[IndentingNewLine]If[mm \[NotEqual] Length[loop], glo = M]; 
        gmn = loop[\([mm, nn, 1]\)]]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".11 Subgroup Routines ",
  StyleBox["subgroups, subgroupTypes, collect, dico, etc",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(subgroups[G_?MatrixQ, o_:  0, i1_:  2, i2_:  49, pp_:  associativeQ] := 
        Module[{d, divs, dl, f = \(-1\), g, i, j, l = Length[G], n = 0, 
            p = pp, r, test = 0, 
            v = Drop[G[\([1]\)], 1]}, \[IndentingNewLine]If[
            i1 \[NotEqual] 2 && GCD[l, i1] \[Equal] 1, 
            Print[i1, "\< is not a factor of \>", l]; \ Abort[]]; 
          i = If[NumberQ[i2], Max[i1, i2], i1]; \[IndentingNewLine]Which[
            o < 0, \ test = {\(-o\)}; i = i1, p \[Equal] {}, 
            p = associativeQ, ListQ[p], test = p]; \[IndentingNewLine]divs = 
            Select[Drop[Drop[Divisors[l], \(-1\)], 1] - 1, 
              i > #1 >= i1 - 1 &]; 
          sg = {}; \[IndentingNewLine]globa = G;  (*\ 
            Now\ find\ all\ potential\ subloops\ in\ the\ range\ \
*) \[IndentingNewLine]d = 
            Flatten[Table[KS[v, divs[\([i]\)]], {i, Length[divs]}], 1]; 
          dl = Length[d]; 
          If[o > 2, \(Print[{dl, "\< cases\>"}];\)]; \[IndentingNewLine]j = 
            0; While[\(j++\); j < dl, 
            r = Flatten[{1, d[\([j]\)]}]; \[IndentingNewLine]If[
              select[r] \[Equal] r,  (*\ quasi - group\ filter\ *) g = 
                reorder[G, 
                  r]; \[IndentingNewLine]Which[\[IndentingNewLine]ListQ[
                  test], If[
                  associativeQ[
                      g] && \((f = id[g])\) \[NotEqual] "\<Unrecognised\>" && 
                    MemberQ[test, f = \(gd[]\)[\([2]\)]], Goto[tag], 
                  globa = G; f = 0], \[IndentingNewLine]p[g], \(n++\); 
                AppendTo[sg, r]]\[IndentingNewLine]]]; 
          Label[tag]; \[IndentingNewLine]Which[f > \(-1\), 
            f,  (*\ target\ \(\(found\)\(?\)\)\ *) \[IndentingNewLine]o \
\[Equal] 0, n, \  (*\ count\ \ *) \[IndentingNewLine]o \[Equal] 1, 
            sg,  (*\ subloop\ list\ *) \[IndentingNewLine]True, 
            Print["\< Number of subloops = \>", n]; sg]];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(KS[l_List, 1, gap_: {}, lef_: {}] := Partition[l, 1]\), "\n", 
    \(KS[l_List, k_Integer?Positive, gap_: {}, 
        lef_: {}] := {l} /; \((k == Length[l])\)\), "\n", 
    \(KS[l_List, k_Integer?Positive, gap_: {}, lef_: {}] := 
      Module[{f = First[l], g, ngap, nlf}, \[IndentingNewLine]nlf = 
          Append[lef, f]; ngap = Append[gap, f]; 
        g = Length[Intersection[select[nlf], gap]]; 
        If[g > 0, 
          KS[Drop[l, 1], k, ngap, lef], \[IndentingNewLine]Join[
            Map[\((Prepend[#, f])\) &, KS[Drop[l, 1], k - 1, gap, nlf]], 
            KS[Drop[l, 1], k, ngap, lef]]]]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(dico[g_] := 
      Module[{gg = 
            If[Length[g] \[Equal] 1, 
              g\[LeftDoubleBracket]1\[RightDoubleBracket], g, gf], o = 1, 
          n = {}}, gf = Sign[Flatten[gg]]; If[abelianQ[gg], o = 1. ]; 
        If[gg === Abs[gg], Null, o = \(-o\); n = {negco[gg]}]; 
        If[MemberQ[gf, \[ImaginaryI]] || MemberQ[gf, \(-\[ImaginaryI]\)], 
          o = \[ImaginaryI]\ o]; 
        If[MemberQ[gf, \[DoubleStruckCapitalJ]] || 
            MemberQ[gf, \[DoubleStruckCapitalJ]\^2], 
          o = \[DoubleStruckCapitalJ]\ o]; 
        If[Length[gg] \[Equal] 32, n = {subgrpPerm[gg, 0, 4, 4]}]; 
        If[Length[gg] \[Equal] 64, n = {Max[orderCount[gg]], nabco[gg]}]; 
        If[Length[gg] \[Equal] 54 || Length[gg] \[Equal] 72, 
          n = {subgrpPerm[gg, 0, 3, 3]}]; 
        abbr[Distribution[
            Table[gg\[LeftDoubleBracket]i, i\[RightDoubleBracket], {i, 
                Length[gg]}]], o, n]]; 
    trico[g_] := 
      abbr[If[Length[g] > 1, 
          Distribution[Table[g[\([i, g[\([i, i]\)]]\)], {i, Length[g]}]], 
          Distribution[
            Table[g[\([1, i, g[\([1, i, i]\)]]\)], {i, 
                Length[g[\([1]\)]]}]]]]\), "\n", 
    \(\(nabco[g_] := 
        If[Length[g] \[Equal] 1, 
          Length[g[\([1]\)]]^2 - 
            Length[Position[g[\([1]\)] - Transpose[g[\([1]\)]], 0]], 
          Length[g]^2 - 
            Length[Position[g - Transpose[g], 
                0]]];\)\), "\[IndentingNewLine]", 
    \(\(negco[g_] := 
        Length[Position[g - Abs[g], a_ /; a \[NotEqual] 0]];\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
subgrpPerm[g_,a_:0]:=Module[{p=Flatten[{1,Map[Last,Sort[Map[({Random[],#})&,\
Range[Length[g]-1]]]]+1}]},subgroups[reorder[g,p],a]];
subgrpPerm[g_,a_,b_,c_]:=Module[{p=Flatten[{1,Map[Last,Sort[Map[({Random[],#})\
&,Range[Length[g]-1]]]]+1}]},subgroups[reorder[g,p],a,b,c]];\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[{
    \(subgroupTypes[sg_:  sg] := 
      Module[{c, l = Length[sg], j, g = globa, m = Length[Last[sg]], n, 
          count, types = {}}, count = Table[0, {i, m}]; 
        Do[\(count[\([Length[sg[\([j]\)]\ ]\ ]\)]++\), {j, l}]; n = 1; 
        Do[c = count[\([i]\)]; 
          If[c > 0, 
            If[PrimeQ[i], n += c; 
              AppendTo[
                types, {c, 
                  StringJoin["\<C\>", ToString[i]]}], \[IndentingNewLine]Do[
                AppendTo[types, {id[g, sg[\([n]\)]]}]; \(n++\), {z, 
                  count[\([i]\)]}]]], \[IndentingNewLine]{i, 2, 
            m}]; \[IndentingNewLine]types]\), "\n", 
    \(collect[sg_:  %] := 
      Module[{l = Length[sg], c = {}, s, s1}, 
        Do[If[Length[s = sg[\([i]\)]] > 1, AppendTo[c, s], 
            s1 = Position[c, s[\([1]\)]]; 
            If[s1 \[Equal] {}, AppendTo[c, {1, s[\([1]\)]}], 
              s1 = s1[\([1, 1]\)]; c[\([s1, 1]\)] = c[\([s1, 1]\)] + 1]], {i, 
            l}]; c]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".12 Generalised Hoop Algebra Routines ",
  StyleBox["toPolar etc, hoopTimes, hoopInverse, hoopP",
    FontSlant->"Italic"],
  "o",
  StyleBox["wer, ",
    FontSlant->"Italic"],
  StyleBox["hoopTest",
    FontSlant->"Italic"],
  StyleBox[", genQuadratic, c2simeq, rotateQOP.",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
toPolar[{a__},g_:gmn]:=toPol[{a},g];
toVector[{a__},g_:gmn]:=toVec[{a},g];
tohyPolar[{a__},g_:gmn]:=tohyPol[{a},g];
tohyVector[{a__},g_:gmn]:=tohyVec[{a},g];\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"hoopTimes", "[", 
        RowBox[{"a_", ",", "b_", ",", "g_", ",", 
          StyleBox[
            RowBox[{
              StyleBox["c",
                FontColor->RGBColor[1, 0, 0]], "_"}]]}], "]"}], ":=", 
      RowBox[{"(*", 
        StyleBox["skeleton",
          FontColor->RGBColor[1, 0, 0]], "*)"}], 
      StyleBox["\[IndentingNewLine]",
        FontColor->RGBColor[1, 0, 0]], \(Module[{m = Length[g], t}, 
        t = Table[0, {m}]; \[IndentingNewLine]Do[
          Do[t\[LeftDoubleBracket]g[\([l, k]\)]\[RightDoubleBracket] += 
              a\[LeftDoubleBracket]
                  l\[RightDoubleBracket]\ b\[LeftDoubleBracket]
                  k\[RightDoubleBracket]\ , {k, m}], {l, m}]; t]\)}]], "Input",\

  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(hoopTimes[a_?VectorQ, b_?VectorQ, g_?MatrixQ] := 
      hoopTimes[glo = g; mm = Length[g]; a, b]\), "\n", 
    \(hoopTimes[a_?VectorQ, b_?VectorQ, g_] /; Head[g] === String := 
      hoopTimes[glo = mp[g]; gmn = g; mm = Length[g]; a, b]\), "\n", 
    \(hoopTimes[a_?VectorQ, b_?VectorQ] := 
      Module[{i, j, p, s, ss, st, t, u}, 
        u = Table[0, {kk, mm = Length[glo]}]; t = u; i = Join[a, t]; 
        j = Join[b, t]; \[IndentingNewLine]Do[
          Do[s = glo\[LeftDoubleBracket]ll, kk\[RightDoubleBracket]; 
            ss = Sign[s]; \[IndentingNewLine]st = 
              If[ss === 0, s, s/ss]; \[IndentingNewLine]t\[LeftDoubleBracket]
                st\[RightDoubleBracket] += 
              i\[LeftDoubleBracket]
                    ll\[RightDoubleBracket]\ j\[LeftDoubleBracket]
                    kk\[RightDoubleBracket]\ ss /. List \[Rule] 0, {kk, 
              mm}], {ll, mm}]; \[IndentingNewLine]Rl = u; Rr = u; 
        If[\((p = Position[shape[t], 0])\) \[NotEqual] {}, 
          If[Complement[p, Position[shape[a], 0]] \[NotEqual] {}, 
            u = hoopInverse[b]; \[IndentingNewLine]Do[
              Do[s = glo\[LeftDoubleBracket]ll, kk\[RightDoubleBracket]; 
                ss = Sign[s]; \[IndentingNewLine]st = 
                  If[ss === 0, s, 
                    s/ss]; \[IndentingNewLine]Rl\[LeftDoubleBracket]
                    st\[RightDoubleBracket] += 
                  u\[LeftDoubleBracket]
                        kk\[RightDoubleBracket]\ t\[LeftDoubleBracket]
                        ll\[RightDoubleBracket]\ ss /. List \[Rule] 0, {kk, 
                  mm}], {ll, mm}]; Rl = Chop[a - Rl]]; \[IndentingNewLine]If[
            Complement[p, Position[shape[b], 0]] \[NotEqual] {}, 
            u = hoopInverse[a]; \[IndentingNewLine]Do[
              Do[s = glo\[LeftDoubleBracket]ll, kk\[RightDoubleBracket]; 
                ss = Sign[s]; \[IndentingNewLine]st = 
                  If[ss === 0, s, 
                    s/ss]; \[IndentingNewLine]Rr\[LeftDoubleBracket]
                    st\[RightDoubleBracket] += 
                  t\[LeftDoubleBracket]kk\[RightDoubleBracket] 
                      u\[LeftDoubleBracket]ll\[RightDoubleBracket]\ \ ss /. 
                    List \[Rule] 0, {kk, mm}], {ll, mm}]; 
            Rr = Chop[b - Rr]]]; \[IndentingNewLine]t]\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(hmin = 4  $MachineEpsilon;\)\), "\n", 
    \(\(hoopInverse[v_?VectorQ] := 
        Module[{arrsz, abcsz, ls, inv, var, vec, s, temp}, 
          inv = Table[0, {ii, mm}]; vec = Take[Flatten[Append[v, inv]], mm]; 
          arrsz = shape[vec]; ls = Length[arrsz]; abcsz = hoopShape[]; 
          Do[s = Sign[gi\[LeftDoubleBracket]ii\[RightDoubleBracket]]; 
            var = alph\[LeftDoubleBracket]
                gi[\([ii]\)]/s\[RightDoubleBracket]; temp = 0; 
            Do[Which[
                Abs[Chop[arrsz\[LeftDoubleBracket]jj\[RightDoubleBracket], 
                      hmin]] === 0, Null, True, 
                temp += s\ gi\[LeftDoubleBracket]
                      mm + jj\[RightDoubleBracket] \[PartialD]\_var 
                          abcsz\[LeftDoubleBracket]jj\[RightDoubleBracket]/
                      abcsz\[LeftDoubleBracket]jj\[RightDoubleBracket]], {jj, 
                ls}]; inv\[LeftDoubleBracket]ii\[RightDoubleBracket] += 
              temp, {ii, mm}]; 
          Chop[Simplify[inv/mm /. fromAlph[vec]]]];\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(hoopInverse[vec_, g_, gi_, gshape_]\), ":=", 
        RowBox[{"(*", 
          StyleBox["skeleton",
            FontColor->RGBColor[1, 0, 0]], "*)"}], 
        "\[IndentingNewLine]", \(Module[{al, inv, ls = Length[gshape], 
            mm = Length[g], var, ss, sub, t}, inv = Table[0, {i, mm}]; 
          al = Take[{a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, 
                t, u, v, w, x, y, 
                z, \[Alpha], \[Beta], \[Gamma], \[Delta], \[Epsilon], \
\[Zeta]}, mm], \[IndentingNewLine]sub = 
            Table[al[\([i]\)] \[Rule] vec[\([i]\)], {i, 
                mm}]; \[IndentingNewLine]Do[ss = Sign[gi[\([ii]\)]]; 
            var = al[\([gi[\([ii]\)]/ss]\)]; t = 0; 
            Do[Which[Abs[Chop[gshape[\([jj]\)]] /. sub, 2^\((\(-48\))\)]] === 
                0, Null, True, 
              temp += ss*
                  gi[\([mm + jj]\)]*\((D[gshape[\([jj]\)], var]/
                      gshape[\([jj]\)])\), {jj, 
                ls}]; \[IndentingNewLine]inv[\([ii]\)] += t, {ii, mm}]; 
          Simplify[inv/mm /. sub]]\)}], ";"}]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  StyleBox["hoopIn",
    FontSlant->"Italic"],
  StyleBox["verse",
    FontSlant->"Italic"],
  " Procedure:- based on Cramer's method, to give Ainv.A={1,0,0...}.\n",
  StyleBox["la",
    FontSlant->"Italic"],
  " is the length of ",
  StyleBox["vec",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["arrsz",
    FontSlant->"Italic"],
  " is the ",
  StyleBox["shape",
    FontSlant->"Italic"],
  " of ",
  StyleBox["vec",
    FontSlant->"Italic"],
  "; finding it also sets ",
  StyleBox["gi",
    FontSlant->"Italic"],
  ". ",
  StyleBox["abcsz",
    FontSlant->"Italic"],
  " becomes ",
  StyleBox["sh[glo]",
    FontSlant->"Italic"],
  ", the symbolic conserved factors. ",
  StyleBox["inv",
    FontSlant->"Italic"],
  " is initialised as a table of zeroes, to be filled in by the ",
  StyleBox["ii",
    FontSlant->"Italic"],
  " loop. For each ",
  StyleBox["ii",
    FontSlant->"Italic"],
  ", the sign is found from ",
  StyleBox["gi",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["var",
    FontSlant->"Italic"],
  " is the ",
  StyleBox["ii",
    FontSlant->"Italic"],
  "'th symbol used in ",
  StyleBox["abcsz",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["jj",
    FontSlant->"Italic"],
  " loop ignores near-zero sizes, and adds to ",
  StyleBox["temp",
    FontSlant->"Italic"],
  " the derivations (wrt the variable ",
  StyleBox["var",
    FontSlant->"Italic"],
  " indicated by ",
  StyleBox["gi",
    FontSlant->"Italic"],
  ") of the size, divided by the size and multiplied by the sign ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and by the multiplicity ",
  StyleBox["gi\[LeftDoubleBracket]la+jj\[RightDoubleBracket]",
    FontSlant->"Italic"],
  " . On completion of this loop, ",
  StyleBox["temp",
    FontSlant->"Italic"],
  " is put into ",
  StyleBox["inv",
    FontSlant->"Italic"],
  ". Finally, ",
  StyleBox["inv",
    FontSlant->"Italic"],
  " is divided by ",
  StyleBox["la",
    FontSlant->"Italic"],
  " and the symbols are replaced by whatever was supplied as ",
  StyleBox["vec",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(hoopPower[A_, r_:  1/2] := 
        Module[{a = {}, lg, l, s = shape[A]}, 
          If[r < 0, hoopPower[hoopInverse[A], \(-r\)], l = toPolar[A]; 
            lg = Length[gp]; 
            Do[AppendTo[a, 
                If[IntegerQ[gp[\([ii]\)]], 
                  If[Head[l[\([ii]\)]] === Complex, 
                    l[\([ii]\)]\^r, \(Abs[l[\([ii]\)]]\^r\) 
                      Sign[l[\([ii]\)]], l[\([ii]\)]\^r], 
                  r  l[\([ii]\)]]], {ii, lg}]; 
            Chop[toVector[a]]]];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[TextData[{
  "hoopPo",
  "wer",
  StyleBox[" procedure:- If the power is negative, calculate the positive \
power of the inverse. Find the polar form; multiply angles by the power; \
replace sizes by the signed power of the absolute size. (Complex numbers are \
raised to the power.) Recover the vector from the new polar data.",
    FontSlant->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[BoxData[{
    \(\(Unprotect[hoopTest];\)\), "\n", 
    \(\(Clear[glo, gmn, mm, nn, hoopTest];\)\)}], "Input",
  PageWidth->WindowWidth,
  FormatType->TraditionalForm],

Cell[BoxData[
    \(hoopTest[x_:  glo, t_:  Real, r_: {\(-1. \), 1. }, o_:  0] := 
      Module[{A, Am, Ap, B, BA, Bi, C, ms, no = "\< No other\>", pa, pb, pab, 
          q = 0, res, result, sx, sz = 2^\(-16\), xq, X}, 
        X = Which[Head[x] === TraditionalForm, x[\([1]\)], 
            Head[x] === String, mp[x], IntegerQ[x] && IntegerQ[T], t = Real; 
            mp[x, T], True, x]; 
        If[MatrixQ[X] === False, X = makeProtoloop[x]]; 
        If[X === glo, , glo = caylindex[X]]; gmn = id[glo]; 
        res = gmn; \[IndentingNewLine]hoopFactor[]; ms = minsign[glo]; 
        If[Head[sh["\<Unrecognized\>"]] === List, 
          sh["\<Unrecognized\>"] =. ]; 
        If[Head[sh[gmn]] === sh, sh[gmn] = hoopShape[]]; 
        If[o > 0, Print[{"\<Hoop =\>", res, X, mm}]]; 
        While[\(\(A = Table[Random[t, r], {i, mm}] // N;\)\[IndentingNewLine]
          
          Position[0, 
              pa = Chop[Expand[shape[A]], sz] /. ms] \[NotEqual] {}\)\(,\)]; 
        While[\(B = Table[Random[t, r], {i, mm}] // N; 
          Position[0, 
              Chop[pb = Expand[shape[B]], sz] /. 
                ms] \[NotEqual] {}\)\(,\)]; \[IndentingNewLine]AB = 
          hoopTimes[A, B]; pba = Chop[Expand[shape[AB]] /. ms, sz]; 
        Am = Chop[\((Expand[pa*pb] - pba)\) /. ms, sz]; 
        Ap = Chop[\((Expand[pa*pb] + pba)\) /. ms, sz]; 
        If[o > 2, 
          Print[{"\<A=\>", A, "\<\nB=\>", B, "\<\nAB=\>", 
              AB, "\<pa,pb,pa pb,pba,pa pb-pba\>", pa, pb, pa\ pb, pba, Am, 
              Union[Am], Ap, Union[Ap]}]]; 
        If[\((Flatten[Union[Am]] === {0})\) || \((Flatten[
                  Union[Ap]] === {0})\), res = "\<Conservative \>" <> res, 
          If[gmn == "\<Unrecognized\>", 
            Print[gmn <> "\< Factors NOT conserved\>"], 
            Print[gmn <> "\< Isomorph. Protoloop factors NOT conserved\>"]]; 
          Goto[exit]]; \[IndentingNewLine]Ai = 
          Chop[Together[Expand[hoopInverse[A]]] /. ms, sz]; 
        pba = Chop[
            Together[Expand[\((AiAB = hoopTimes[Ai, AB])\) - B]] /. ms, sz]; 
        If[o > 0, 
          Print[{"\<A Inverse=\>", Ai, "\<AiAB=\>", AiAB, "\<AiAB-B=\>", 
              pba}]]; If[Union[pba] === {0}, no = "\<\>"; 
          res = res <> "\<, division\>"]; \[IndentingNewLine]If[
          Head[toPol[A, gmn]] === List, 
          If[Union[Chop[toVector[toPolar[A]] - A, sz]] === {0}, no = "\<\>"; 
            res = res <> "\<, polar-vector\>"]; 
          If[Union[Chop[hoopPower[hoopPower[A], 2] - A, sz]] === {0}, 
            no = "\<\>"; res = res <> "\<, +ve Powers\>"]; 
          If[abelianQ[glo], 
            While[q < 10, \(q++\); A = Table[Random[t, r], {i, mm}]; 
              B = Table[Random[t, r], {i, mm}]; 
              xq = Table[Random[t, r], {i, mm}] // N; sx = shape[xq]; 
              C = hoopTimes[A, hoopTimes[xq, xq]] + hoopTimes[B, xq]; 
              result = Chop[genQuadratic[A, B, C]]; 
              If[Union[Chop[sx - shape[result[\([1]\)]]]] === {0} || 
                  Union[Chop[sx - shape[result[\([2]\)]]]] === {0}, 
                res = res <> "\<, quadratic eqn.\>"; q = 10]]]; 
          If[Union[
                Chop[hoopPower[hoopPower[A, \(-1\)/3], \(-3\)] - A]] === {0}, 
            no = "\<\>"; res = res <> "\<, -ve Powers\>"]]; 
        If[Head[tohyPol[A, gmn]] === List, 
          If[Union[Chop[tohyVector[tohyPolar[A]] - A, sz]] === {0}, 
            no = "\<\>"; res = res <> "\<, hyPolar\>"]]; Label[exit]; 
        res <> no <> "\< test(s) passed\>"]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(genQuadratic[A_?VectorQ, B_?VectorQ, C_?VectorQ] := 
        Module[{a, b}, 
          If[Length[gp] \[NotEqual] Length[A], 
            Print["\<Roots unavailable\>"]; 
            Abort[], \[IndentingNewLine]a = hoopInverse[A]; 
            b = hoopRoot[
                hoopTimes[B, B] + 4\ hoopTimes[A, C]]; {hoopTimes[
                  a, \((\(-B\) + b)\)], hoopTimes[a, \((\(-B\) - b)\)]}/2]]\),
       ";", 
      RowBox[{
        StyleBox[\(hoopRoot[A_?VectorQ]\),
          ShowStringCharacters->True,
          NumberMarks->True], 
        StyleBox[" ",
          ShowStringCharacters->True,
          NumberMarks->True], 
        StyleBox[":=",
          ShowStringCharacters->True,
          NumberMarks->True], 
        RowBox[{
          StyleBox["Module",
            ShowStringCharacters->True,
            NumberMarks->True], 
          StyleBox["[",
            ShowStringCharacters->True,
            NumberMarks->True], 
          RowBox[{
            StyleBox[\({a = {}, l = toPolar[A]}\),
              ShowStringCharacters->True,
              NumberMarks->True], 
            StyleBox[",",
              ShowStringCharacters->True,
              NumberMarks->True], 
            StyleBox[\( (*\ gp\ shows\ whether\ radius\ or\ angle\ *) \),
              ShowStringCharacters->True,
              NumberMarks->True], "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{
                StyleBox["Do",
                  ShowStringCharacters->True,
                  NumberMarks->True], 
                StyleBox["[",
                  ShowStringCharacters->True,
                  NumberMarks->True], 
                RowBox[{
                  StyleBox[
                    RowBox[{"AppendTo", "[", 
                      RowBox[{"a", ",", 
                        RowBox[{"If", "[", 
                          RowBox[{\(IntegerQ[gp[\([i]\)]]\), ",", 
                            RowBox[{
                              SuperscriptBox[
                                RowBox[{"Abs", "[", 
                                  RowBox[{
                                    StyleBox["l",
                                      ShowStringCharacters->True,
                                      NumberMarks->True], "[", \([i]\), "]"}],
                                   "]"}], \(1/2\)], \(Sign[l[\([i]\)]]\)}], 
                            ",", \(l[\([i]\)]/2\)}], "]"}]}], "]"}],
                    ShowStringCharacters->True,
                    NumberMarks->True], ",", 
                  "\[IndentingNewLine]", \({i, Length[gp]}\)}], "]"}], ";", 
              RowBox[{
                StyleBox["Chop",
                  ShowStringCharacters->True,
                  NumberMarks->True], 
                StyleBox["[",
                  ShowStringCharacters->True,
                  NumberMarks->True], 
                RowBox[{
                  StyleBox["toVector",
                    ShowStringCharacters->True,
                    NumberMarks->True], 
                  StyleBox["[",
                    ShowStringCharacters->True,
                    NumberMarks->True], "a", 
                  StyleBox["]",
                    ShowStringCharacters->True,
                    NumberMarks->True]}], "]"}]}]}], "]"}]}]}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(c2simeq[a_, b_, c_] := 
        c2simeq[a\[LeftDoubleBracket]1\[RightDoubleBracket], 
          a\[LeftDoubleBracket]2\[RightDoubleBracket], 
          b\[LeftDoubleBracket]1\[RightDoubleBracket], 
          b\[LeftDoubleBracket]2\[RightDoubleBracket], 
          c\[LeftDoubleBracket]1\[RightDoubleBracket], 
          c\[LeftDoubleBracket]2\[RightDoubleBracket], 
          a\[LeftDoubleBracket]3\[RightDoubleBracket], 
          a\[LeftDoubleBracket]4\[RightDoubleBracket], 
          b\[LeftDoubleBracket]3\[RightDoubleBracket], 
          b\[LeftDoubleBracket]4\[RightDoubleBracket], 
          c\[LeftDoubleBracket]3\[RightDoubleBracket], 
          c\[LeftDoubleBracket]4\[RightDoubleBracket]];\)\), "\n", 
    \(c2simeq[a1_, a2_, b1_, b2_, c1_, c2_, a3_, a4_, b3_, b4_, c3_, c4_] := 
      Module[{a1m2b = \((a1 - a2)\)\ \((b3 - b4)\) - \((a3 - a4)\)\ \((b1 - 
                    b2)\), a1p2b = \((a1 + a2)\)\ \((b3 + b4)\) - \((a3 + 
                    a4)\)\ \((b1 + b2)\), 
          a1m2c = \((a1 - a2)\)\ \((c3 - c4)\) - \((a3 - a4)\)\ \((c1 - 
                    c2)\), a1p2c = \((a1 + a2)\)\ \((c3 + c4)\) - \((a3 + 
                    a4)\)\ \((c1 + c2)\), 
          b1m2 = \((b1 - b2)\)\ \((c3 - c4)\) - \((b3 - b4)\)\ \((c1 - c2)\), 
          b1p2 = \((b1 + b2)\)\ \((c3 + c4)\) - \((b3 + b4)\)\ \((c1 + c2)\), 
          x4}, Which[a1p2b == 0 && a1p2c == 0 || a1m2b == 0, 
          Flatten[{Simplify[{c1\ \((a4\ b2 - a1\ b3)\) + 
                      c2\ \((a2\ b3 - a4\ b1)\) + c3\ \((a1\ b1 - a2\ b2)\) + 
                      x4\ \((a4\ \((b1\^2 - b2\^2)\) + \((a1\ b2 - 
                                  a2\ b1)\)\ b3 + \((a2\ b2 - 
                                  a1\ b1)\)\ b4)\), 
                    c1\ \((a2\ b3 - a3\ b2)\) + c2\ \((a3\ b1 - a1\ b3)\) + 
                      c3\ \((a1\ b2 - a2\ b1)\) + 
                      x4\ \((a3\ \((b2\^2 - b1\^2)\) + \((a1\ b1 - 
                                  a2\ b2)\)\ b3 + \((a2\ b1 - 
                                  a1\ b2)\)\ b4)\), \(1\/a2\) \((\((\(-a1\)\ \
a3 + a2\ a4)\)\ \((a1\ \((c2 - b1\ x4)\) - 
                                a2\ \((c1 - b2\ x4)\))\) + \((a1\^2 - 
                                a2\^2)\)\ \((a3\ c2 - a2\ c3 - a3\ b1\ x4 + 
                                a2\ b4\ x4)\))\)}/\((\((a1\ a3 - 
                            a2\ a4)\)\ b1 + \((a1\ a4 - 
                            a2\ a3)\)\ b2 + \((a2\^2 - 
                            a1\^2)\)\ b3)\)], {x4}}], \
\[IndentingNewLine]a1p2b == 
            0, {{0, 0}, {0, 
              0}}, \[IndentingNewLine]True, {\(-b1m2\), b1m2, 
                  a1m2c, \(-a1m2c\)}/
                a1m2b\ 2 + {\(-b1p2\), \(-b1p2\), a1p2c, a1p2c}/
                a1p2b\ 2]]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{10, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  TextJustification->0,
  FontFamily->"Courier New",
  FontSize->12,
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    \(simc2[a_, b_, o_:  0] := 
      Module[{l = Length[a], ai, aijp, aijn, dp, dn, p = {}, n = {}, 
          at = Transpose[a], sp = {}, sn = {}, i = 1, bp = {}, bip, bn = {}, 
          bin, X, x}, x = Unique[]; x = Table[x, {i, l}]; 
        Do[ai = at[\([i]\)]; bip = b[\([i, 1]\)]; 
          bin = b[\([i, 2]\)]; \[IndentingNewLine]AppendTo[bp, bip + bin]; 
          AppendTo[bn, bip - bin]; \[IndentingNewLine]Do[
            aijp = ai[\([j, 1]\)]; 
            aijn = ai[\([j, 2]\)]; \[IndentingNewLine]p = {p, aijp + aijn}; 
            n = {n, aijp - aijn}, {j, l}], {i, l}]; 
        p = Partition[Flatten[p], l]; 
        dp = Chop[2\ Det[p]]; \[IndentingNewLine]n = 
          Partition[Flatten[n], l]; dn = Chop[2\ Det[n]]; 
        If[o === 2, Print[{"\<n\>", n, dn, "\<\np\>", p, dp}]]; 
        While[i \[LessEqual] l, 
          bip = Det[Insert[Drop[p, {i}], bp, i]]; \[IndentingNewLine]bin = 
            Det[Insert[Drop[n, {i}], bn, i]]; \[IndentingNewLine]sp = {sp, 
              bip, bip}; sn = {sn, bin, \(-bin\)}; 
          i += 1]; \[IndentingNewLine]X = 
          If[dp === 0, x, 
              Partition[Flatten[sp], 2]/dp] + \[IndentingNewLine]\ \ If[
              dn === 0, x, 
              Partition[Flatten[sn], 2]/dn]; \[IndentingNewLine]If[o === 1, 
          X, X = Transpose[X]; X[\([1]\)] - X[\([2]\)]]]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  TextAlignment->Left,
  FontFamily->"Courier New",
  FontSize->12,
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
\tRotation using Euler parameters is implemented below for Quaternions, \
Octonions, and Pauli-\[Sigma] algebra. Footnote 16 in Louenesto 2001 \
indicates that it can be generalized via Clifford multiplication. This has \
not been pursued.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[{
    RowBox[{\(\(rotateQOP[v0_, n0_, \[Theta]_, g_:  gmn]\)\(:=\)\), 
      StyleBox[\( (*Not\ initialised*) \),
        FontColor->RGBColor[1, 0, 0]], 
      StyleBox[";",
        FontColor->RGBColor[1, 0, 
        0]]}], "\[IndentingNewLine]", \(Module[{lv = Length[v0], l, n, p = 1, 
        q, r, v}, 
      Which[Depth[v0] \[NotEqual] 3 || Depth[n0] \[NotEqual] 2, 
        Print\ ["\<Wrong bracketing\>"]; Abort[], g == "\<Qr\>", l = 4, 
        g == "\<Octr\>", l = 8, g == "\<P4\>", p = \(-1\); l = 4, True, 
        Print[{g, "\<Wrong\>"}]; \ Abort[]]; gmn = g; 
      v = Table[
          Take[Flatten[{v0\[LeftDoubleBracket]i\[RightDoubleBracket], {0, 0, 
                  0, 0, 0, 0}}], l], {i, lv}]; 
      n = Take[Flatten[{n0, {0, 0, 0, 0, 0}}], l - 1]; 
      q = Flatten[{Cos[\[Theta]/
                2], \(n\ Sin[\[Theta]/2]\)\/\@\(p\ Plus @@ \((n\ n)\)\)}]; 
      r = Flatten[{Cos[\[Theta]/
                2], \(\(-n\)\ Sin[\[Theta]/2]\)\/\@\(p\ Plus @@ \((n\ \
n)\)\)}]; 
      Chop[Table[
          hoopTimes[q, 
            hoopTimes[v\[LeftDoubleBracket]i\[RightDoubleBracket], r, 
              g]], {i, lv}]]]; 
    angls[r_, \[Theta]_, \[Psi]_:  0] := {{r\ Cos[\[Theta]], 
          r\ Sin[\[Theta]], r\ Cos[\[Theta]], 
          r\ Sin[\[Theta]]}, {r*Cos[\[Theta]], r*Cos[\[Theta] + 2*Pi/3], 
          r*Cos[\[Theta] + 4*Pi/3], r*Cos[\[Theta]], 
          r*Cos[\[Theta] + 2*Pi/3], 
          r*Cos[\[Theta] + 4*Pi/3]}, {r*Cos[\[Theta]], 
          r*Cos[\[Theta] + 2*Pi/3], 
          r*Cos[\[Theta] + 4*Pi/3], \(-r\)*Cos[\[Theta]], \(-r\)*
            Cos[\[Theta] + 2*Pi/3], \(-r\)*
            Cos[\[Theta] + 4*Pi/3]}, {}, {}}\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(QPower[{a_, b_, c_, d_}, r_:  .5] := 
        Module[{s, t = ArcTan[a, Sqrt[b^2 + c^2 + d^2]], 
            u = ArcTan[b, Sqrt[c^2 + d^2]], v = ArcTan[c, d]}, 
          s = Sin[r\ t]; \[IndentingNewLine]\((a^2 + b^2 + c^2 + d^2)\)^\((r/
                  2)\) {Cos[r\ t], s\ Cos[u], s\ Sin[u] Cos[v], 
              s\ Sin[u] Sin[v]}];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".13 Substitutions  ",
  StyleBox["fa,  fp, alph, power2, pow2, power3, fromAlph, fromZtoCliff, \
linearFactor, s2, s3, s4, pr1, pr2 .",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(fp[g_, p_:  power2] /; Head[g] === TraditionalForm := 
        fp[g[\([1]\)], p];\)\), "\[IndentingNewLine]", 
    \(fp[g_?indexTableQ, p_:  pow2] := 
      Module[{pp = p, lg = Length[g], lp = Length[p]}, 
        pp = If[lp < lg, Flatten[Append[pp, Table[0, {i, lg - lp}]]], 
            Take[pp, lg]]; pa = Factor[Det[gmap[g, pp]]]; 
        If[Length[fp] > 1 && fp[\([1]\)] \[Equal] \(-1\), \(-pa\), pa, pa]]; 
    fa[g_] /; Head[g] === TraditionalForm := 
      fa[g[\([1]\)]];\), "\[IndentingNewLine]", 
    \(\(fa[g_?indexTableQ] := 
        If[Length[g] < 13, 
          Flatten[If[\((pa = 
                      Factor[Det[
                          gmap[g, 
                            alph]]])\)[\([1]\)] \[Equal] \(-1\), \(-pa\), pa, 
              pa]], Print["\<Too Long for fa\>"]; Abort[]];\)\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(alph = {a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, 
          u, v, w, x, y, 
          z, \[Alpha], \[Beta], \[Gamma], \[Delta], \[CurlyEpsilon], \[Zeta], \
\[Eta], \[Theta], \[CapitalTheta], \[Iota], \[Kappa], \[Lambda], \[Mu], \
\[Nu], \[Xi], \[CapitalXi], \[CurlyPi], \[CapitalPi], \[Rho], \[CurlyRho], \
\[Sigma], \[CapitalSigma], \[Tau], \[Upsilon], \[CapitalUpsilon], \[Phi], \
\[CurlyPhi], \[CapitalPhi], \[Chi], \[Psi], \[CapitalPsi], \[CapitalOmega], \
\[CapitalKoppa], \[Sampi], \[CapitalSampi], \[EmptySet], \[Mho], a, a, b, c, 
          d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y, 
          z, \[Alpha], \[Beta], \[Gamma], \[Delta], \[CurlyEpsilon], \[Zeta], \
\[Eta], \[Theta], \[CapitalTheta], \[Iota], \[Kappa], \[Lambda], \[Mu], \
\[Nu], \[Xi], \[CapitalXi], \[CurlyPi], \[CapitalPi], \[Rho], \[CurlyRho], \
\[Sigma], \[CapitalSigma], \[Tau], \[Upsilon], \[CapitalUpsilon], \[Phi], \
\[CurlyPhi], \[CapitalPhi], \[Chi], \[Psi], \[CapitalPsi], \[Omega], \
\[CapitalOmega], \[CapitalKoppa], \[Sampi], \[CapitalSampi], \[EmptySet], \
\[Mho], \[WeierstrassP], a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, 
          r, s, t, u, v, w, x, y, 
          z, \[Alpha], \[Beta], \[Gamma], \[Delta], \[CurlyEpsilon], \[Zeta], \
\[Eta], \[Theta], \[CapitalTheta], \[Iota], \[Kappa], \[Lambda], \[Mu], \
\[Nu], \[Xi], \[CapitalXi], \[CurlyPi], \[CapitalPi], \[Rho], \[CurlyRho], \
\[Sigma], \[CapitalSigma], \[Tau], \[Upsilon], \[CapitalUpsilon], \[Phi], \
\[CurlyPhi], \[CapitalPhi], \[Chi], \[Psi], \[CapitalPsi], \[Omega], \
\[CapitalOmega], \[CapitalKoppa], \[Sampi], \[CapitalSampi], \[EmptySet], \
\[Mho], a, a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, 
          w, x, y, 
          z, \[Alpha], \[Beta], \[Gamma], \[Delta], \[CurlyEpsilon], \[Zeta], \
\[Eta], \[Theta], \[CapitalTheta], \[Iota], \[Kappa], \[Lambda], \[Mu], \
\[Nu], \[Xi], \[CapitalXi], \[CurlyPi], \[CapitalPi], \[Rho], \[CurlyRho], \
\[Sigma], \[CapitalSigma], \[Tau], \[Upsilon], \[CapitalUpsilon], \[Phi], \
\[CurlyPhi], \[CapitalPhi], \[Chi], \[Psi], \[CapitalPsi], \[Omega], \
\[CapitalOmega], \[CapitalKoppa], \[Sampi], \[CapitalSampi], \[EmptySet], \
\[Mho], a};\)\), "\[IndentingNewLine]", 
    \( (*unique\ Length\ 64, \ useable\ lengths\ 260*) \)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{\(alpha = {"\<a\>", "\<b\>", "\<c\>", "\<d\>", "\<e\>", \
"\<f\>", "\<g\>", "\<h\>", "\<i\>", "\<j\>", "\<k\>", "\<l\>", "\<m\>", \
"\<n\>", "\<o\>", "\<p\>", "\<q\>", "\<r\>", "\<s\>", "\<t\>", "\<u\>", \
"\<v\>", "\<w\>", "\<x\>", "\<y\>", "\<z\>", "\<\[Alpha]\>", "\<\[Beta]\>", "\
\<\[Gamma]\>", "\<\[Delta]\>", "\<\[CurlyEpsilon]\>", "\<\[Zeta]\>", \
"\<\[Eta]\>", "\<\[Theta]\>", "\<\[CapitalTheta]\>", "\<\[Iota]\>", "\<\
\[Kappa]\>", "\<\[Lambda]\>", "\<\[Mu]\>", "\<\[Nu]\>", "\<\[Xi]\>", "\<\
\[CapitalXi]\>", "\<\[CurlyPi]\>", "\<\[CapitalPi]\>", "\<\[Rho]\>", "\<\
\[CurlyRho]\>", "\<\[Sigma]\>", "\<\[CapitalSigma]\>", "\<\[Tau]\>", "\<\
\[Upsilon]\>", "\<\[CapitalUpsilon]\>", "\<\[Phi]\>", "\<\[CurlyPhi]\>", "\<\
\[CapitalPhi]\>", "\<\[Chi]\>", "\<\[Psi]\>", "\<\[CapitalPsi]\>", \
"\<\[Omega]\>", "\<\[CapitalOmega]\>", "\<\[CapitalKoppa]\>", "\<\[Sampi]\>", \
"\<\[CapitalSampi]\>", "\<\[EmptySet]\>", "\<\[Mho]\>", "\<a\>", "\<a\>", \
"\<b\>", "\<c\>", "\<d\>", "\<e\>", "\<f\>", "\<g\>", "\<h\>", "\<i\>", \
"\<j\>", "\<k\>", "\<l\>", "\<m\>", "\<n\>", "\<o\>", "\<p\>", "\<q\>", \
"\<r\>", "\<s\>", "\<t\>", "\<u\>", "\<v\>", "\<w\>", "\<x\>", "\<y\>", \
"\<z\>", "\<\[Alpha]\>", "\<\[Beta]\>", "\<\[Gamma]\>", "\<\[Delta]\>", "\<\
\[CurlyEpsilon]\>"};  (*unique\ Length\ 64, \ 
      useable\ lengths\ 96*) \[IndentingNewLine]pow2 = 
      Flatten[Prepend[Table[2\^i, {i, 0, 50}], {a}]];\), "\n", \(power2 = 
      Flatten[Prepend[Table[2\^i, {i, 0, 50}], {"\<a\>", 3, 7}]]; 
    power3 = Flatten[
        Prepend[Table[3\^i, {i, 0, 32}], {"\<a\>", 2, 
            4}]];\), "\[IndentingNewLine]", \(cliff = {e, a, b, ab, c, ac, 
        bc, abc, d, ad, bd, abd, cd, acd, bcd, abcd, f, af, bf, abf, cf, acf, 
        bcf, abcf, df, adf, bdf, abdf, cdf, acdf, bcdf, abcdf};  (*\ 
      scalar, \ univector, \ bivector, \ trivector, \ 
      etc . \ Clifford\ algebra\ elements\ *) \n
    fromAlph[Null] := {};\), "\[IndentingNewLine]", \(fromAlph[vec_?VectorQ, 
        a_:  alph] := 
      Table[a[\([ii]\)] \[Rule] vec[\([ii]\)], {ii, Length[vec]}]; 
    fromZtoCliff[a_, B_:  cliff, Z_:  Range[32]] := 
      a /. Flatten[
          Table[{Z[\([ii]\)] \[Rule] 
                B[\([ii]\)], \(-Z[\([ii]\)]\) \[Rule] \(-B[\([ii]\)]\)}, {ii, 
              Length[B]}]]; 
    linearFactor[f_, l_:  mm] := 
      Module[{res = Take[alph, l], po = fromAlph[Take[pow2, l]]}, 
        Do[If[Plus @@ \((res /. po)\) - f >= 2  pow2[\([ii]\)], 
            res[\([ii]\)] *= \(-1\)], {ii, l, 0, \(-1\)}]; 
        Plus @@ res]\), "\[IndentingNewLine]", 
    FormBox[\(SetAttributes[linearFactor, Listable]\),
      "TraditionalForm"]}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(\( (*\ 
      Permutation\ Lists\ *) \)\(\[IndentingNewLine]\)\(s3 = {{2, 1, 3}, {3, 
          1, 2}}; s4 = {{2, 1, 3, 4}, {1, 2, 4, 3}, {1, 4, 2, 3}, {3, 4, 1, 
          2}, {2, 3, 4, 1}};\n
    \(s5 = {{2, 1, 3, 4, 5}, {1, 2, 4, 5, 3}, {2, 3, 4, 1, 5}, {1, 4, 5, 2, 
            3}, {3, 4, 5, 1, 2}, {2, 3, 4, 5, 1}, {3, 4, 1, 2, 5}, {1, 2, 4, 
            3, 5}};\)\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(\( (*\ vecs\ pr1, \ 
      pr2\ that\ usually\ give\ good\ factorizations\ *) \)\(\
\[IndentingNewLine]\)\(\(pr1 = {1, 2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 37, 
          41, 43, 47, 61, 67, 53, 73, 79, 83, 59, 31, 103, 107, 109, 113, 
          127, 131, 137, 139, 149, 151, 157, 163, 167, 173, 179, 181, 191, 
          193, 197, 199, 211, 223, 227, 229, 233, 239, 241, 251, 257, 263, 
          269, 271, 277, 281, 283, 293, 307, 311, 313, 317, 331};\)\n
    \(pr2 = {1, 3, 7, 5, 7, 11, 13, 17, 19, 23, 31, 29, 61, 37, 43, 41, 53, 
          47, 61, 59, 73, 67, 79, 71, 83, 89, 97, 101, 103, 107, 109, 113, 
          127, 131, 137, 139, 149, 151, 157, 163, 167, 173, 179, 181, 191, 
          193, 197, 199, 211, 223, 227, 229, 233, 239, 241, 251, 257, 263, 
          269, 271, 277, 281, 283, 293};\)\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".14 Matrix Group Data ",
  StyleBox["u2, u3, u4. ",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[TextData[{
  "These have been moved from Section 4 to prevent them being included in \
function definitions such as ",
  StyleBox["ms ",
    FontSlant->"Italic"],
  "until they are needed. They are unitary monomial matrices that dot \
multiply to give groups."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(u2 = {{{\(-1\), 0}, {0, \(-1\)}}, {{1, 
              0}, {0, \(-1\)}}, {{0, \(-\[ImaginaryI]\)}, {\[ImaginaryI], 
              0}}, {{0, 1}, {1, 
              0}}, {{0, \[DoubleStruckCapitalJ]}, \
{\[DoubleStruckCapitalJ]\^2, 0}}, {{\[DoubleStruckK], 
              0}, {0, \[DoubleStruckK]}}, {{0, \[DoubleStruckN]\^4}, {\
\[DoubleStruckN]\^3, 0}}, {{\[DoubleStruckM], 
              0}, {0, \[DoubleStruckM]}}, {{0, \[DoubleStruckCapitalI]}, {\
\[DoubleStruckCapitalI]\^3, 0}}, {{\[DoubleStruckCapitalJ], 
              0}, {0, \[DoubleStruckCapitalJ]\^2}}, \
{{\[DoubleStruckCapitalY], 
              0}, {0, \[DoubleStruckCapitalY]\^2}}, {{\[ImaginaryI], 
              0}, {0, \[ImaginaryI]}}, {{0, \[ImaginaryI]}, {\[ImaginaryI], 
              0}}, {{0, \(-1\)}, {1, 
              0}}, {{0, \[DoubleStruckCapitalJ]\^2}, {\(-\
\[DoubleStruckCapitalJ]\), 0}}, {{\[DoubleStruckCapitalI], 
              0}, {0, \[DoubleStruckCapitalI]\^3}}, {{0, \
\(-\[DoubleStruckO]\^3\)}, {\[DoubleStruckO]\^5, 0}}, {{\[DoubleStruckP], 
              0}, {0, \[DoubleStruckP]\^4}}, {{\[DoubleStruckH], 
              0}, {0, \[DoubleStruckH]\^5}}, {{\[DoubleStruckCapitalJ]\^2, 
              0}, {0, \(-\[DoubleStruckCapitalJ]\)}}, {{\[DoubleStruckG], 
              0}, {0, \[DoubleStruckG]\^6}}, {{\[DoubleStruckO], 
              0}, {0, \[DoubleStruckO]\^7}}, {{\[DoubleStruckN], 
              0}, {0, \[DoubleStruckN]\^8}}, {{0, 1}, {\(-1\), 
              0}}, {{0, \[DoubleStruckCapitalJ]}, \
{\(-\[DoubleStruckCapitalJ]^2\), 
              0}}, {{0, \[DoubleStruckK]}, {\(-\[DoubleStruckK]\), 
              0}}, {{0, \[DoubleStruckL]}, {\(-\[DoubleStruckL]\), 
              0}}, {{0, \[DoubleStruckM]}, {\(-\[DoubleStruckM]\), 
              0}}, \ {{0, 1}, {\[ImaginaryI], 0}}, {{1, 
              0}, {0, \[DoubleStruckS]}}, {{0, 1}, {\[DoubleStruckS], 
              0}}, {{0, 1}, {\[DoubleStruckCapitalJ], 
              0}}, {{\[DoubleStruckCapitalY], 0}, {0, 1}}, {{\[ImaginaryI], 
              0}, {0, \(-\[ImaginaryI]\)}}, {{0, 
              1}, {\[DoubleStruckCapitalI], 0}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(u3 = {{{\(-1\), 0, 0}, {0, \(-1\), 0}, {0, 0, \(-1\)}}, {{1, 0, 
              0}, {0, 0, 1}, {0, 1, 0}}, {{1, 0, 0}, {0, \[DoubleStruckK], 
              0}, {0, 0, \[DoubleStruckK]}}, {{\(-1\), 0, 
              0}, {0, \(-\[DoubleStruckK]\), 0}, {0, 
              0, \(-\[DoubleStruckK]\)}}, {{0, 1, 0}, {1, 0, 0}, {0, 0, 
              1}}, {{0, \(-1\), 0}, {\(-1\), 0, 0}, {0, 
              0, \(-1\)}}, {{0, \[DoubleStruckCapitalJ], 
              0}, {\[DoubleStruckCapitalJ]\^2, 0, 0}, {0, 0, 1}}, {{1, 0, 
              0}, {0, \[DoubleStruckCapitalJ], 0}, {0, 
              0, \[DoubleStruckCapitalJ]\^2}}, {{0, 
              0, \[DoubleStruckCapitalJ]}, {\[DoubleStruckCapitalJ], 0, 
              0}, {0, \[DoubleStruckCapitalJ], 0}}, {{0, 0, 1}, {1, 0, 
              0}, {0, 1, 0}}, {{0, 0, \[ImaginaryI]}, {\[ImaginaryI], 0, 
              0}, {0, \(-1\), 0}}, {{\[DoubleStruckCapitalJ], 0, 
              0}, {0, \[DoubleStruckCapitalJ], 0}, {0, 
              0, \[DoubleStruckCapitalJ]}}, {{0, 0, 1}, {0, 1, 0}, {\(-1\), 
              0, 0}}, {{0, 0, \[ImaginaryI]}, {0, 1, 0}, {\[ImaginaryI], 0, 
              0}}, {{1, 0, 0}, {0, \[ImaginaryI], 0}, {0, 
              0, \(-\[ImaginaryI]\)}}, {{1, 0, 0}, {0, \[DoubleStruckP]\^2, 
              0}, {0, 0, \[DoubleStruckP]\^3}}, \
{{\(-\[DoubleStruckCapitalJ]\), 0, 0}, {0, \(-\[DoubleStruckCapitalJ]\), 
              0}, {0, 0, \(-\[DoubleStruckCapitalJ]\)}}, {{\(-1\), 0, 
              0}, {0, \(-\[DoubleStruckCapitalJ]\), 0}, {0, 
              0, \(-\[DoubleStruckCapitalJ]\^2\)}}, {{\[DoubleStruckCapitalJ]\
\^2, 0, 0}, {0, 
              0, \[DoubleStruckCapitalJ]\^2}, {0, \[DoubleStruckCapitalJ]\^2, 
              0}}, {{0, 0, \(-\[ImaginaryI]\)}, {\(-\[ImaginaryI]\), 0, 
              0}, {0, 1, 0}}, {{0, 1, 0}, {0, 0, 1}, {\(-1\), 0, 
              0}}, {{\[DoubleStruckCapitalJ], 0, 
              0}, {0, \(-\[DoubleStruckCapitalJ]\), 0}, {0, 
              0, \(-\[DoubleStruckCapitalJ]\)}}, {{0, 
              0, \(-\[DoubleStruckCapitalJ]\)}, \
{\(-\[DoubleStruckCapitalJ]\), 0, 0}, {0, \(-\[DoubleStruckCapitalJ]\), 
              0}}, {{1, 0, 0}, {0, \[DoubleStruckG]\^2, 0}, {0, 
              0, \[DoubleStruckG]\^5}}, {{0, 1, 0}, {\[ImaginaryI], 0, 
              0}, {0, 0, \[ImaginaryI]}}, {{\[ImaginaryI], 0, 0}, {0, 0, 
              1}, {0, \[ImaginaryI], 0}}, {{\[DoubleStruckO], 0, 0}, {0, 1, 
              0}, {0, 0, \[DoubleStruckO]\^7}}, {{1, 0, 
              0}, {0, \[DoubleStruckN]\^4, 0}, {0, 
              0, \[DoubleStruckN]\^5}}, {{\(-1\), 0, 
              0}, {0, \(-\[DoubleStruckP]\^2\), 0}, {0, 
              0, \(-\[DoubleStruckP]\^3\)}}, {{\(-1\), 0, 
              0}, {0, \(-\[DoubleStruckG]\^2\), 0}, {0, 
              0, \(-\[DoubleStruckG]\^5\)}}, {{\(-1\), 0, 
              0}, {0, \(-\[DoubleStruckN]\^4\), 0}, {0, 
              0, \(-\[DoubleStruckN]\^5\)}}, {{1, 0, 
              0}, {0, \[DoubleStruckCapitalY], 0}, {0, 
              0, \[DoubleStruckCapitalY]\^2}}, {{\[DoubleStruckN], 0, 
              0}, {0, \[DoubleStruckN], 0}, {0, 
              0, \[DoubleStruckN]\^7}}, {{0, \(-1\), 0}, {1, 0, 0}, {0, 0, 
              1}}, {{0, \(-1\), 0}, {0, 0, \(-1\)}, {1, 0, 0}}, {{1, 0, 
              0}, {0, 0, \(-1\)}, {0, 1, 0}}, {{0, \[DoubleStruckP], 
              0}, {\[DoubleStruckP]\^3, 0, 0}, {0, 
              0, \[DoubleStruckP]\^2}}, {{\(-1\), 0, 0}, {0, 1, 0}, {0, 
              0, \(-1\)}}, {{0, 0, \(-1\)}, {0, 1, 0}, {1, 0, 0}}, {{1, 0, 
              0}, {0, \(-1\), 0}, {0, 0, 1}}, {{0, 0, 1}, {0, \(-1\), 
              0}, {\(-1\), 0, 0}}, {{0, 0, \(-1\)}, {0, \(-1\), 0}, {1, 0, 
              0}}, {{\[ImaginaryI], 0, 0}, {0, \[ImaginaryI], 0}, {0, 
              0, \[ImaginaryI]}}, \(-{{\[ImaginaryI], 0, 
                0}, {0, \[ImaginaryI], 0}, {0, 0, \[ImaginaryI]}}\), {{0, 1, 
              0}, {0, 0, \[ImaginaryI]}, {1, 0, 0}}, {{0, \[ImaginaryI], 
              0}, {0, 0, \[ImaginaryI]}, {\[ImaginaryI], 0, 
              0}}, {{0, \[DoubleStruckS], 0}, {0, 0, 1}, {1, 0, 
              0}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(u4 = {{{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, \(-1\), 0}, {0, 0, 
              0, \(-1\)}}, {{0, 1, 0, 0}, {1, 0, 0, 0}, {0, 0, \(-1\), 
              0}, {0, 0, 0, \(-1\)}}, {{1, 0, 0, 0}, {0, 0, \(-1\), 
              0}, {0, \(-1\), 0, 0}, {0, 0, 0, 1}}, {{0, 1, 0, 0}, {1, 0, 0, 
              0}, {0, 0, 0, 1}, {0, 0, 1, 0}}, {{\(-1\), 0, 0, 0}, {0, 1, 0, 
              0}, {0, 0, \(-1\), 0}, {0, 0, 0, 1}}, {{1, 0, 0, 
              0}, {0, \(-1\), 0, 0}, {0, 0, \(-1\), 0}, {0, 0, 0, 1}}, {{0, 
              0, 1, 0}, {0, 0, 0, \(-1\)}, {1, 0, 0, 0}, {0, \(-1\), 0, 
              0}}, {{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 
              0, \[DoubleStruckCapitalJ], 0}, {0, 0, 
              0, \[DoubleStruckCapitalJ]\^2}}, {{0, 0, \(-1\), 0}, {1, 0, 0, 
              0}, {0, \(-1\), 0, 0}, {0, 0, 0, 1}}, {{1, 0, 0, 0}, {0, 0, 
              0, \[DoubleStruckCapitalJ]}, {0, \[DoubleStruckCapitalJ], 0, 
              0}, {0, 0, \[DoubleStruckCapitalJ], 0}}, {{1, 0, 0, 
              0}, {0, \[DoubleStruckCapitalJ], 0, 0}, {0, 
              0, \[DoubleStruckCapitalJ], 0}, {0, 0, 
              0, \[DoubleStruckCapitalJ]}}, {{1, 0, 0, 0}, {0, \(-1\), 0, 
              0}, {0, 0, \[ImaginaryI], 0}, {0, 0, 0, \[ImaginaryI]}}, {{0, 
              0, \(-1\), 0}, {0, 0, 0, \(-1\)}, {0, 1, 0, 0}, {1, 0, 0, 
              0}}, {{0, 0, 0, \(-1\)}, {0, 0, 1, 0}, {0, \(-1\), 0, 0}, {1, 
              0, 0, 0}}, {{0, 0, \(-1\), 0}, {0, 0, 0, 1}, {1, 0, 0, 
              0}, {0, \(-1\), 0, 0}}, {{0, \(-1\), 0, 0}, {1, 0, 0, 0}, {0, 
              0, 0, \(-1\)}, {0, 0, 1, 0}}, {{1, 0, 0, 
              0}, {0, \[DoubleStruckP], 0, 0}, {0, 0, \[DoubleStruckP]\^2, 
              0}, {0, 0, 0, \[DoubleStruckP]\^2}}, {{0, 1, 0, 0}, {0, 
              0, \(-1\), 0}, {\(-1\), 0, 0, 0}, {0, 0, 0, \(-1\)}}, {{1, 0, 
              0, 0}, {0, \[DoubleStruckH], 0, 0}, {0, 0, \[DoubleStruckH]\^2, 
              0}, {0, 0, 0, \[DoubleStruckH]\^3}}, {{\[DoubleStruckG], 0, 0, 
              0}, {0, \[DoubleStruckG], 0, 0}, {0, 0, \[DoubleStruckG]\^2, 
              0}, {0, 0, 0, \[DoubleStruckG]\^3}}, {{1, 0, 0, 0}, {0, 
              0, \(-\[ImaginaryI]\), 0}, {0, \(-1\), 0, 0}, {0, 0, 
              0, \[ImaginaryI]}}, {{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 
              0, \[DoubleStruckO]\^3, 0}, {0, 0, 
              0, \[DoubleStruckO]\^5}}, {{1, 0, 0, 0}, {0, \[DoubleStruckN], 
              0, 0}, {0, 0, \[DoubleStruckN]\^4, 0}, {0, 0, 
              0, \[DoubleStruckN]\^4}}, {{1, 0, 0, 0}, {0, 
              0, \(-\[DoubleStruckP]\^2\), 0}, {0, \(-\[DoubleStruckP]\), 0, 
              0}, {0, 0, 0, \[DoubleStruckP]\^2}}, {{\(-1\), 0, 0, 
              0}, {0, \(-\[DoubleStruckP]\), 0, 0}, {0, 
              0, \(-\[DoubleStruckP]\^2\), 0}, {0, 0, 
              0, \(-\[DoubleStruckP]\^2\)}}, {{0, 0, \(-\[ImaginaryI]\), 
              0}, {1, 0, 0, 0}, {0, \(-1\), 0, 0}, {0, 0, 
              0, \[ImaginaryI]}}, {{0, 0, \[DoubleStruckCapitalJ], 0}, {0, 0, 
              0, \[DoubleStruckCapitalJ]\^2}, {\(-1\), 0, 0, 0}, {0, \(-1\), 
              0, 0}}, {{0, 0, \(-\[DoubleStruckP]\^2\), 0}, {1, 0, 0, 
              0}, {0, \(-\[DoubleStruckP]\), 0, 0}, {0, 0, 
              0, \[DoubleStruckP]\^2}}, {{0, 0, 0, 1}, {0, 0, 1, 
              0}, {0, \(-1\), 0, 0}, {\(-1\), 0, 0, 0}}, {{0, 0, 
              0, \(-\[ImaginaryI]\)}, {0, 0, \[ImaginaryI], 
              0}, {0, \[ImaginaryI], 0, 0}, {\(-\[ImaginaryI]\), 0, 0, 
              0}}, {{0, 0, 1, 0}, {0, 0, 0, \(-1\)}, {\(-1\), 0, 0, 0}, {0, 
              1, 0, 0}}, {{0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 0, 0, 
              0}}, {{0, \[DoubleStruckCapitalJ], 0, 
              0}, {\[DoubleStruckCapitalJ], 0, 0, 0}, {0, 0, 0, 1}, {0, 
              0, \[DoubleStruckCapitalJ], 0}}, {{0, 
              0, \[DoubleStruckCapitalJ], 0}, {0, 0, 
              0, \[DoubleStruckCapitalJ]\^2}, {\[DoubleStruckCapitalJ]\^2, 0, 
              0, 0}, {0, \[DoubleStruckCapitalJ], 0, 0}}, {{0, 1, 0, 0}, {1, 
              0, 0, 0}, {0, 0, 0, \(-1\)}, {0, 0, \(-1\), 0}}, {{0, 1, 0, 
              0}, {0, 0, 0, \(-1\)}, {\(-1\), 0, 0, 0}, {0, 0, 1, 
              0}}, \[IndentingNewLine]{{0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 
              1}, {\(-1\), 0, 0, 0}}, {{0, \(-\[ImaginaryI]\), 0, 
              0}, {\[ImaginaryI], 0, 0, 0}, {0, 0, 
              0, \(-\[ImaginaryI]\)}, {0, 0, \[ImaginaryI], 0}}, {{0, 
              0, \(-\[ImaginaryI]\), 0}, {0, 0, 
              0, \(-\[ImaginaryI]\)}, {\[ImaginaryI], 0, 0, 
              0}, {0, \[ImaginaryI], 0, 0}}, {{0, 0, 1, 0}, {0, 0, 0, 1}, {1, 
              0, 0, 0}, {0, 1, 0, 0}}, {{0, 0, \(-1\), 0}, {0, 0, 
              0, \(-1\)}, {1, 0, 0, 0}, {0, 1, 0, 0}}, {{0, 0, 0, 1}, {0, 
              0, \(-1\), 0}, {0, \(-1\), 0, 0}, {1, 0, 0, 0}}, {{0, 1, 0, 
              0}, {\(-1\), 0, 0, 0}, {0, 0, 0, 1}, {0, 0, \(-1\), 0}}, {{0, 
              0, 0, \(-1\)}, {0, 0, \(-1\), 0}, {0, 1, 0, 0}, {1, 0, 0, 
              0}}, {{0, \[DoubleStruckS], 0, 0}, {0, 0, 0, 1}, {1, 0, 0, 
              0}, {0, 0, 1, 0}}};\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9",
    FontFamily->"Times New Roman"],
  ".16 Generalized multi-phase Sinusoids ",
  StyleBox["genCos, genSin.",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(genCos[x_, m_:  4, j_:  0] := 
      Which[m == 0, 
        j \((\[ExponentialE]\^\(\(\ \)\(x\)\) + \[ExponentialE]\^\(-x\))\)/2, 
        m == 2, Re[\[ExponentialE]\^x + \(\((\(-1\))\)\^j\) \[ExponentialE]\^\
\(\(\ \)\(-x\)\)]/2, \[IndentingNewLine]True, 
        Re[\(\((\(-1\))\)\^\(2 \((m - j)\)/
                    m\)\) \[ExponentialE]\^\(\[ImaginaryI]\ Im[\((\(-1\))\)\^\
\(2/m\)]\ x\)]]\), "\[IndentingNewLine]", 
    \(genSin[x_, m_:  4, j_:  0] := 
      Which[m == 
          0, \((\[ExponentialE]\^\(\(\ \)\(x\)\) - \[ExponentialE]\^\(-x\))\)/
          2, m == 2, 
        Re[\(\((\(-1\))\)\^j\) \[ExponentialE]\^\(\(\ \)\(x\)\) - \
\[ExponentialE]\^\(-x\)]/2, \[IndentingNewLine]True, 
        Im[\(\((\(-1\))\)\^\(2 \((m - j)\)/
                    m\)\) \[ExponentialE]\^\(\[ImaginaryI]\ Im[\((\(-1\))\)\^\
\(2/m\)]\ x\)]]\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10. Protect system symbols, end private context. ",
  StyleBox["Unprotect some exported symbols, end package context",
    FontFamily->"Times New Roman"],
  StyleBox[".",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"]
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["Protect[Evaluate[protected]];", "Input",
  PageWidth->WindowWidth],

Cell["End[];", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["Protect[Evaluate[$Context <> \"*\"]];", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(Unprotect[\ a1, a2, a2, a3, a4, ab, aa, abc, abef, agek, ai, ap, ar, 
        as, azx, ayz, A, Ai, AiBA, AiAB, Am, Ap, \ b1, b2, b3, b4, bb, bc, B, 
        AB, BA, c1, c2, c3, c4, cr, d1, da, dab, db, de, dozaltest, e1, e2, 
        ef, f2, fa, ff, fi, fj, fn, fp, G, g1, g2, gf, gg, glo, globa, genel, 
        gi, gmn, gp, h1, hoopList, hh, i1, i2, ii, im, in, jj, kk, l22a, 
        l22b, l3, l4, l4p, l4q, l4r, l4s, la, ll, lm, lp, lr, ls, lt, m1, mi, 
        matel, mm, nn, nb, no, np, nw, nx, ok, o1, o2, o3, o4, oo, p1, p2, 
        p22, p23, p26, pa, pb, pab, papb, pba, pi, po, permel, plex, pp, ps, 
        q22, q23, q24, q26, qq, res, result, \[DoubleStruckR], R1, R2, Rl, 
        Rr, r22, r23, r26, rhs, rr, sab, sh, sg, s1, s2, s5, s22, s23, s24, 
        s26, si, sij, sm, ss, strep, temp, test, tes, tf, ts, uu, var, vec, 
        vf, vv, x2, x4, xy, y2, z, L3, L1a, L1b, L1c, L1d, L22, L23a, L23b, 
        L23c, L23d, L26a, L26b, L26c, L26d, L4, L24Q, L24\[Sigma], L4Q, 
        L4\[Sigma], L49, L49a, L49b, L49c, L4a3, L4b3, L4c3, L4d3, L4a6, 
        L4b6, L4c6, 
        L4d6 (*\(,\)\(\[Alpha]\)\(,\)\(\[Beta]\)\(,\)\(\[Gamma]\)\(,\)\(\
\[Delta]\)\(,\)\(\[Epsilon]\)\(,\)\(\[Zeta]\)\(,\)\(\[Eta]\)\(,\)\(\[Theta]\)\
\(,\)\(\[CurlyTheta]\)\(,\)\(\[Iota]\)\(,\)\(\[Kappa]\)\(,\)\(\[CurlyKappa]\)\
\(,\)\(\[Lambda]\)\(,\)\(\[Mu]\)\(,\)\(\[Nu]\)\(,\)\(\[Xi]\)\(,\)\(\[Rho]\)\(,\
\)\(\[Sigma]\)\(,\)\(\[Tau]\)\(,\)\(\[Phi]\)\(,\)\(\[CurlyPhi]\)\(,\)\(\[Chi]\
\)\(,\)\(\[Psi]\)\(,\)\(\[Omega]\)*) ];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell["EndPackage[];", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{750, 603},
WindowMargins->{{90, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "11/10/6"]], Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 190, 4, 170, "Title"],
Cell[1969, 59, 1058, 26, 229, "Text"],
Cell[3030, 87, 370, 8, 68, "Input",
  InitializationCell->True],
Cell[3403, 97, 156, 3, 68, "Input"],
Cell[3562, 102, 546, 10, 203, "Text"],

Cell[CellGroupData[{
Cell[4133, 116, 174, 3, 68, "Subsection"],
Cell[4310, 121, 607, 18, 125, "Text"],
Cell[4920, 141, 680, 13, 177, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5637, 159, 158, 3, 42, "Subsection"],
Cell[5798, 164, 3952, 92, 957, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9787, 261, 156, 3, 42, "Subsection"],
Cell[9946, 266, 654, 11, 177, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10637, 282, 156, 3, 42, "Subsection"],
Cell[10796, 287, 375, 8, 125, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11208, 300, 159, 3, 42, "Subsection"],
Cell[11370, 305, 1494, 30, 385, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12901, 340, 107, 2, 42, "Subsection"],
Cell[13011, 344, 2433, 60, 515, "Text"],
Cell[15447, 406, 1007, 16, 503, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16491, 427, 262, 9, 42, "Subsection"],

Cell[CellGroupData[{
Cell[16778, 440, 155, 6, 61, "Subsubsection"],
Cell[16936, 448, 271, 11, 41, "Input",
  InitializationCell->True],
Cell[17210, 461, 811, 17, 271, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[18058, 483, 111, 2, 38, "Subsubsection"],
Cell[18172, 487, 1308, 21, 380, "Input",
  InitializationCell->True],
Cell[19483, 510, 3268, 49, 1836, "Input",
  InitializationCell->True],
Cell[22754, 561, 1374, 21, 796, "Input",
  InitializationCell->True],
Cell[24131, 584, 1443, 22, 69, "Input",
  InitializationCell->True],
Cell[25577, 608, 1490, 24, 822, "Input",
  InitializationCell->True],
Cell[27070, 634, 2662, 39, 1368, "Input",
  InitializationCell->True],
Cell[29735, 675, 1876, 30, 1056, "Input",
  InitializationCell->True],
Cell[31614, 707, 1287, 19, 718, "Input",
  InitializationCell->True],
Cell[32904, 728, 1895, 28, 69, "Input",
  InitializationCell->True],
Cell[34802, 758, 316, 6, 69, "Input",
  InitializationCell->True],
Cell[35121, 766, 867, 13, 69, "Input",
  InitializationCell->True],
Cell[35991, 781, 786, 13, 69, "Input",
  InitializationCell->True],
Cell[36780, 796, 1257, 19, 69, "Input",
  InitializationCell->True],
Cell[38040, 817, 4983, 77, 69, "Input",
  InitializationCell->True],
Cell[43026, 896, 1134, 18, 69, "Input",
  InitializationCell->True],
Cell[44163, 916, 1060, 16, 69, "Input",
  InitializationCell->True],
Cell[45226, 934, 376, 6, 69, "Input",
  InitializationCell->True],
Cell[45605, 942, 1627, 24, 69, "Input",
  InitializationCell->True],
Cell[47235, 968, 2304, 37, 69, "Input",
  InitializationCell->True],
Cell[49542, 1007, 1392, 23, 69, "Input",
  InitializationCell->True],
Cell[50937, 1032, 721, 12, 69, "Input",
  InitializationCell->True],
Cell[51661, 1046, 1361, 22, 69, "Input",
  InitializationCell->True],
Cell[53025, 1070, 277, 5, 69, "Input",
  InitializationCell->True],
Cell[53305, 1077, 1652, 26, 69, "Input",
  InitializationCell->True],
Cell[54960, 1105, 1384, 23, 69, "Input",
  InitializationCell->True],
Cell[56347, 1130, 1807, 28, 69, "Input",
  InitializationCell->True],
Cell[58157, 1160, 920, 16, 69, "Input",
  InitializationCell->True],
Cell[59080, 1178, 1152, 18, 69, "Input",
  InitializationCell->True],
Cell[60235, 1198, 1470, 24, 926, "Input",
  InitializationCell->True],
Cell[61708, 1224, 895, 15, 69, "Input",
  InitializationCell->True],
Cell[62606, 1241, 1149, 18, 666, "Input",
  InitializationCell->True],
Cell[63758, 1261, 2012, 32, 742, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[65807, 1298, 98, 1, 38, "Subsubsection"],
Cell[65908, 1301, 1935, 33, 1004, "Input",
  InitializationCell->True],
Cell[67846, 1336, 1160, 20, 614, "Input",
  InitializationCell->True],
Cell[69009, 1358, 676, 14, 354, "Input",
  InitializationCell->True],
Cell[69688, 1374, 1534, 29, 848, "Input",
  InitializationCell->True],
Cell[71225, 1405, 1794, 36, 1212, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[73068, 1447, 176, 3, 68, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[73269, 1454, 198, 6, 61, "Subsubsection"],
Cell[73470, 1462, 321, 9, 110, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[73828, 1476, 296, 9, 39, "Subsubsection"],
Cell[74127, 1487, 164, 4, 73, "Text"],
Cell[74294, 1493, 433, 9, 206, "Input",
  InitializationCell->True],
Cell[74730, 1504, 1128, 28, 224, "Input",
  InitializationCell->True],
Cell[75861, 1534, 1471, 28, 536, "Input",
  InitializationCell->True],
Cell[77335, 1564, 925, 20, 484, "Input",
  InitializationCell->True],
Cell[78263, 1586, 1365, 28, 614, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[79665, 1619, 213, 6, 38, "Subsubsection"],
Cell[79881, 1627, 1235, 24, 281, "Text"],
Cell[81119, 1653, 3905, 80, 276, "Input",
  InitializationCell->True],
Cell[85027, 1735, 3240, 72, 510, "Input",
  InitializationCell->True],
Cell[88270, 1809, 4700, 106, 458, "Input",
  InitializationCell->True],
Cell[92973, 1917, 375, 8, 172, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[93385, 1930, 212, 6, 38, "Subsubsection"],
Cell[93600, 1938, 219, 5, 73, "Text"],
Cell[93822, 1945, 1264, 18, 432, "Input",
  InitializationCell->True],
Cell[95089, 1965, 1804, 31, 406, "Input",
  InitializationCell->True],
Cell[96896, 1998, 380, 7, 120, "Input",
  InitializationCell->True],
Cell[97279, 2007, 1900, 31, 406, "Input",
  InitializationCell->True],
Cell[99182, 2040, 385, 8, 146, "Input",
  InitializationCell->True],
Cell[99570, 2050, 2771, 58, 232, "Input",
  InitializationCell->True],
Cell[102344, 2110, 531, 13, 172, "Input",
  InitializationCell->True],
Cell[102878, 2125, 14557, 220, 1385, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[117472, 2350, 299, 10, 39, "Subsubsection"],
Cell[117774, 2362, 142, 3, 69, "Input"],
Cell[117919, 2367, 175, 4, 69, "Input",
  InitializationCell->True],
Cell[118097, 2373, 1477, 28, 69, "Input",
  InitializationCell->True],
Cell[119577, 2403, 1734, 30, 69, "Input",
  InitializationCell->True],
Cell[121314, 2435, 731, 13, 69, "Input",
  InitializationCell->True],
Cell[122048, 2450, 2222, 40, 69, "Input",
  InitializationCell->True],
Cell[124273, 2492, 4380, 74, 69, "Input",
  InitializationCell->True],
Cell[128656, 2568, 1269, 22, 69, "Input",
  InitializationCell->True],
Cell[129928, 2592, 4630, 81, 69, "Input",
  InitializationCell->True],
Cell[134561, 2675, 4754, 82, 69, "Input",
  InitializationCell->True],
Cell[139318, 2759, 1119, 19, 69, "Input",
  InitializationCell->True],
Cell[140440, 2780, 1595, 30, 69, "Input",
  InitializationCell->True],
Cell[142038, 2812, 3691, 60, 69, "Input",
  InitializationCell->True],
Cell[145732, 2874, 1839, 33, 69, "Input",
  InitializationCell->True],
Cell[147574, 2909, 970, 17, 69, "Input",
  InitializationCell->True],
Cell[148547, 2928, 11548, 189, 69, "Input",
  InitializationCell->True],
Cell[160098, 3119, 641, 13, 69, "Input",
  InitializationCell->True],
Cell[160742, 3134, 2588, 40, 69, "Input",
  InitializationCell->True],
Cell[163333, 3176, 702, 14, 69, "Input",
  InitializationCell->True],
Cell[164038, 3192, 2549, 44, 69, "Input",
  InitializationCell->True],
Cell[166590, 3238, 2554, 47, 69, "Input",
  InitializationCell->True],
Cell[169147, 3287, 11203, 183, 69, "Input",
  InitializationCell->True],
Cell[180353, 3472, 1150, 21, 69, "Input",
  InitializationCell->True],
Cell[181506, 3495, 867, 18, 69, "Input",
  InitializationCell->True],
Cell[182376, 3515, 3274, 56, 69, "Input",
  InitializationCell->True],
Cell[185653, 3573, 2486, 42, 69, "Input",
  InitializationCell->True],
Cell[188142, 3617, 770, 16, 69, "Input",
  InitializationCell->True],
Cell[188915, 3635, 2112, 39, 69, "Input",
  InitializationCell->True],
Cell[191030, 3676, 1166, 22, 69, "Input",
  InitializationCell->True],
Cell[192199, 3700, 39728, 689, 69, "Input",
  InitializationCell->True],
Cell[231930, 4391, 2322, 46, 69, "Input",
  InitializationCell->True],
Cell[234255, 4439, 10264, 170, 69, "Input",
  InitializationCell->True],
Cell[244522, 4611, 2559, 47, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[247118, 4663, 224, 6, 38, "Subsubsection"],
Cell[247345, 4671, 3139, 91, 463, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[250521, 4767, 324, 9, 61, "Subsubsection"],
Cell[250848, 4778, 568, 12, 154, "Input",
  InitializationCell->True],
Cell[251419, 4792, 456, 9, 103, "Input",
  InitializationCell->True],
Cell[251878, 4803, 991, 19, 198, "Input",
  InitializationCell->True],
Cell[252872, 4824, 3765, 71, 666, "Input",
  InitializationCell->True],
Cell[256640, 4897, 1203, 25, 121, "Input",
  InitializationCell->True],
Cell[257846, 4924, 1710, 33, 362, "Input",
  InitializationCell->True],
Cell[259559, 4959, 1375, 25, 231, "Input",
  InitializationCell->True],
Cell[260937, 4986, 2194, 54, 221, "Input",
  InitializationCell->True],
Cell[263134, 5042, 3400, 87, 273, "Input",
  InitializationCell->True],
Cell[266537, 5131, 4257, 107, 241, "Input",
  InitializationCell->True],
Cell[270797, 5240, 2922, 75, 275, "Input",
  InitializationCell->True],
Cell[273722, 5317, 1757, 31, 298, "Input",
  InitializationCell->True],
Cell[275482, 5350, 2195, 56, 154, "Input",
  InitializationCell->True],
Cell[277680, 5408, 4396, 100, 579, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[282113, 5513, 320, 9, 61, "Subsubsection"],
Cell[282436, 5524, 1103, 19, 172, "Input",
  InitializationCell->True],
Cell[283542, 5545, 3712, 70, 665, "Input",
  InitializationCell->True],
Cell[287257, 5617, 2955, 55, 509, "Input",
  InitializationCell->True],
Cell[290215, 5674, 557, 11, 94, "Input",
  InitializationCell->True],
Cell[290775, 5687, 597, 12, 120, "Input",
  InitializationCell->True],
Cell[291375, 5701, 2134, 36, 392, "Input",
  InitializationCell->True],
Cell[293512, 5739, 1862, 34, 418, "Input",
  InitializationCell->True],
Cell[295377, 5775, 2040, 38, 444, "Input",
  InitializationCell->True],
Cell[297420, 5815, 657, 15, 202, "Input",
  InitializationCell->True],
Cell[298080, 5832, 551, 11, 133, "Input",
  InitializationCell->True],
Cell[298634, 5845, 643, 13, 120, "Input",
  InitializationCell->True],
Cell[299280, 5860, 644, 13, 120, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[299961, 5878, 320, 9, 61, "Subsubsection"],
Cell[300284, 5889, 2829, 45, 679, "Input",
  InitializationCell->True],
Cell[303116, 5936, 2285, 37, 626, "Input",
  InitializationCell->True],
Cell[305404, 5975, 3445, 59, 847, "Input",
  InitializationCell->True],
Cell[308852, 6036, 3549, 63, 837, "Input",
  InitializationCell->True],
Cell[312404, 6101, 1062, 19, 340, "Input",
  InitializationCell->True],
Cell[313469, 6122, 2196, 40, 635, "Input",
  InitializationCell->True],
Cell[315668, 6164, 2476, 46, 666, "Input",
  InitializationCell->True],
Cell[318147, 6212, 1066, 18, 276, "Input",
  InitializationCell->True],
Cell[319216, 6232, 2164, 37, 588, "Input",
  InitializationCell->True],
Cell[321383, 6271, 555, 10, 146, "Input",
  InitializationCell->True],
Cell[321941, 6283, 1953, 32, 496, "Input",
  InitializationCell->True],
Cell[323897, 6317, 1899, 33, 444, "Input",
  InitializationCell->True],
Cell[325799, 6352, 1754, 34, 484, "Input",
  InitializationCell->True],
Cell[327556, 6388, 5599, 100, 1462, "Input",
  InitializationCell->True],
Cell[333158, 6490, 1024, 18, 302, "Input",
  InitializationCell->True],
Cell[334185, 6510, 651, 13, 224, "Input",
  InitializationCell->True],
Cell[334839, 6525, 913, 16, 328, "Input",
  InitializationCell->True],
Cell[335755, 6543, 4155, 67, 964, "Input",
  InitializationCell->True],
Cell[339913, 6612, 1724, 29, 640, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[341674, 6646, 318, 9, 61, "Subsubsection"],
Cell[341995, 6657, 1309, 23, 338, "Input",
  InitializationCell->True],
Cell[343307, 6682, 3522, 57, 487, "Input",
  InitializationCell->True],
Cell[346832, 6741, 277, 5, 73, "Text"],
Cell[347112, 6748, 690, 13, 137, "Input"],
Cell[347805, 6763, 139, 3, 47, "Text"],
Cell[347947, 6768, 475, 9, 97, "Input"],
Cell[348425, 6779, 2202, 42, 364, "Input",
  InitializationCell->True],
Cell[350630, 6823, 3246, 59, 631, "Input",
  InitializationCell->True],
Cell[353879, 6884, 2904, 41, 305, "Input",
  InitializationCell->True],
Cell[356786, 6927, 292, 5, 99, "Text"],
Cell[357081, 6934, 1456, 29, 257, "Input"],
Cell[358540, 6965, 2782, 54, 512, "Input",
  InitializationCell->True],
Cell[361325, 7021, 2259, 34, 305, "Input",
  InitializationCell->True],
Cell[363587, 7057, 1137, 22, 201, "Input",
  InitializationCell->True],
Cell[364727, 7081, 1709, 32, 281, "Input",
  InitializationCell->True],
Cell[366439, 7115, 2120, 31, 305, "Input",
  InitializationCell->True],
Cell[368562, 7148, 1158, 20, 195, "Input",
  InitializationCell->True],
Cell[369723, 7170, 1224, 21, 247, "Input",
  InitializationCell->True],
Cell[370950, 7193, 1103, 18, 227, "Input",
  InitializationCell->True],
Cell[372056, 7213, 1339, 23, 307, "Input",
  InitializationCell->True],
Cell[373398, 7238, 2196, 38, 569, "Input",
  InitializationCell->True],
Cell[375597, 7278, 674, 13, 137, "Input",
  Evaluatable->False],
Cell[376274, 7293, 7867, 128, 1577, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[384144, 7423, 137, 4, 37, "Input",
  InitializationCell->True],
Cell[384284, 7429, 568, 10, 117, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[384889, 7444, 310, 9, 61, "Subsubsection"],
Cell[385202, 7455, 5634, 94, 69, "Input",
  InitializationCell->True],
Cell[390839, 7551, 2141, 34, 69, "Input",
  InitializationCell->True],
Cell[392983, 7587, 4114, 62, 69, "Input",
  InitializationCell->True],
Cell[397100, 7651, 5604, 90, 69, "Input",
  InitializationCell->True],
Cell[402707, 7743, 1889, 31, 69, "Input",
  InitializationCell->True],
Cell[404599, 7776, 2129, 35, 69, "Input",
  InitializationCell->True],
Cell[406731, 7813, 1186, 21, 69, "Input",
  InitializationCell->True],
Cell[407920, 7836, 3044, 52, 69, "Input",
  InitializationCell->True],
Cell[410967, 7890, 3138, 54, 69, "Input",
  InitializationCell->True],
Cell[414108, 7946, 5457, 89, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[419602, 8040, 205, 6, 38, "Subsubsection"],
Cell[419810, 8048, 3285, 53, 69, "Input",
  InitializationCell->True],
Cell[423098, 8103, 6476, 98, 69, "Input",
  InitializationCell->True],
Cell[429577, 8203, 6023, 94, 69, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[435649, 8303, 208, 4, 68, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[435882, 8311, 426, 13, 85, "Subsubsection"],
Cell[436311, 8326, 457, 9, 69, "Input",
  InitializationCell->True],
Cell[436771, 8337, 1814, 38, 69, "Input",
  InitializationCell->True],
Cell[438588, 8377, 4425, 83, 69, "Input",
  InitializationCell->True],
Cell[443016, 8462, 823, 17, 69, "Input",
  InitializationCell->True],
Cell[443842, 8481, 7666, 139, 69, "Input",
  InitializationCell->True],
Cell[451511, 8622, 1031, 26, 69, "Text"],
Cell[452545, 8650, 2175, 40, 69, "Input",
  InitializationCell->True],
Cell[454723, 8692, 8018, 156, 69, "Input",
  InitializationCell->True],
Cell[462744, 8850, 2008, 38, 69, "Input",
  InitializationCell->True],
Cell[464755, 8890, 459, 10, 69, "Input",
  InitializationCell->True],
Cell[465217, 8902, 250, 6, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[465504, 8913, 263, 9, 39, "Subsubsection"],
Cell[465770, 8924, 1922, 45, 69, "Input",
  InitializationCell->True],
Cell[467695, 8971, 8149, 134, 69, "Input",
  InitializationCell->True],
Cell[475847, 9107, 3231, 64, 69, "Input",
  InitializationCell->True],
Cell[479081, 9173, 947, 19, 69, "Input",
  InitializationCell->True],
Cell[480031, 9194, 262, 7, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[480330, 9206, 301, 10, 39, "Subsubsection",
  InitializationCell->True],
Cell[480634, 9218, 830, 17, 69, "Input",
  InitializationCell->True],
Cell[481467, 9237, 666, 14, 69, "Input",
  InitializationCell->True],
Cell[482136, 9253, 1476, 30, 69, "Input",
  InitializationCell->True],
Cell[483615, 9285, 1022, 18, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[484674, 9308, 266, 9, 39, "Subsubsection"],
Cell[484943, 9319, 340, 10, 69, "Text"],
Cell[485286, 9331, 2038, 37, 69, "Input",
  InitializationCell->True],
Cell[487327, 9370, 1022, 19, 69, "Input",
  InitializationCell->True],
Cell[488352, 9391, 1434, 24, 69, "Input",
  InitializationCell->True],
Cell[489789, 9417, 1107, 21, 69, "Input",
  InitializationCell->True],
Cell[490899, 9440, 4183, 75, 69, "Input",
  InitializationCell->True],
Cell[495085, 9517, 2661, 48, 69, "Input",
  InitializationCell->True],
Cell[497749, 9567, 1152, 21, 69, "Input",
  InitializationCell->True],
Cell[498904, 9590, 868, 16, 69, "Input",
  InitializationCell->True],
Cell[499775, 9608, 1403, 28, 69, "Input",
  InitializationCell->True],
Cell[501181, 9638, 1448, 27, 69, "Input",
  InitializationCell->True],
Cell[502632, 9667, 1038, 21, 69, "Input",
  InitializationCell->True],
Cell[503673, 9690, 353, 8, 69, "Input",
  InitializationCell->True],
Cell[504029, 9700, 555, 12, 69, "Input",
  InitializationCell->True],
Cell[504587, 9714, 2536, 49, 69, "Input",
  InitializationCell->True],
Cell[507126, 9765, 3067, 55, 69, "Input",
  InitializationCell->True],
Cell[510196, 9822, 3258, 59, 69, "Input",
  InitializationCell->True],
Cell[513457, 9883, 3152, 58, 69, "Input",
  InitializationCell->True],
Cell[516612, 9943, 2497, 46, 69, "Input",
  InitializationCell->True],
Cell[519112, 9991, 2493, 46, 69, "Input",
  InitializationCell->True],
Cell[521608, 10039, 754, 15, 69, "Input",
  InitializationCell->True],
Cell[522365, 10056, 2628, 52, 69, "Input",
  InitializationCell->True],
Cell[524996, 10110, 287, 6, 69, "Input",
  InitializationCell->True],
Cell[525286, 10118, 303, 7, 69, "Input",
  InitializationCell->True],
Cell[525592, 10127, 3223, 61, 69, "Input",
  InitializationCell->True],
Cell[528818, 10190, 3133, 57, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[531988, 10252, 294, 9, 39, "Subsubsection"],
Cell[532285, 10263, 1020, 20, 69, "Input",
  InitializationCell->True],
Cell[533308, 10285, 938, 20, 69, "Input",
  InitializationCell->True],
Cell[534249, 10307, 1352, 26, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[535638, 10338, 449, 17, 62, "Subsubsection"],
Cell[536090, 10357, 1601, 34, 69, "Input",
  InitializationCell->True],
Cell[537694, 10393, 848, 16, 69, "Input",
  InitializationCell->True],
Cell[538545, 10411, 11273, 206, 69, "Input",
  InitializationCell->True],
Cell[549821, 10619, 11361, 207, 69, "Input"],
Cell[561185, 10828, 2108, 41, 69, "Input",
  InitializationCell->True],
Cell[563296, 10871, 5657, 104, 69, "Input",
  InitializationCell->True],
Cell[568956, 10977, 3764, 70, 69, "Text"],
Cell[572723, 11049, 1780, 34, 69, "Input",
  InitializationCell->True],
Cell[574506, 11085, 2762, 50, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[577305, 11140, 231, 7, 39, "Subsubsection"],
Cell[577539, 11149, 1991, 39, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[579567, 11193, 305, 10, 39, "Subsubsection"],
Cell[579875, 11205, 1119, 21, 69, "Input",
  InitializationCell->True],
Cell[580997, 11228, 2012, 43, 69, "Input",
  InitializationCell->True],
Cell[583012, 11273, 3524, 67, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[586573, 11345, 261, 8, 39, "Subsubsection"],
Cell[586837, 11355, 3148, 56, 69, "Input",
  InitializationCell->True],
Cell[589988, 11413, 976, 20, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[591001, 11438, 255, 9, 39, "Subsubsection"],
Cell[591259, 11449, 237, 5, 69, "Input"],
Cell[591499, 11456, 19859, 333, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[611395, 11794, 283, 8, 39, "Subsubsection"],
Cell[611681, 11804, 2087, 36, 69, "Input",
  InitializationCell->True],
Cell[613771, 11842, 750, 14, 69, "Input",
  InitializationCell->True],
Cell[614524, 11858, 1636, 35, 69, "Input",
  InitializationCell->True],
Cell[616163, 11895, 409, 8, 69, "Input",
  InitializationCell->True],
Cell[616575, 11905, 1117, 23, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[617729, 11933, 418, 14, 62, "Subsubsection"],
Cell[618150, 11949, 236, 7, 69, "Input",
  InitializationCell->True],
Cell[618389, 11958, 815, 20, 69, "Input",
  InitializationCell->True],
Cell[619207, 11980, 2410, 41, 69, "Input",
  InitializationCell->True],
Cell[621620, 12023, 1133, 20, 69, "Input",
  InitializationCell->True],
Cell[622756, 12045, 1174, 23, 69, "Input",
  Evaluatable->False],
Cell[623933, 12070, 2116, 85, 69, "Text"],
Cell[626052, 12157, 593, 13, 69, "Input",
  InitializationCell->True],
Cell[626648, 12172, 419, 10, 69, "Text"],
Cell[627070, 12184, 171, 4, 69, "Input"],
Cell[627244, 12190, 3591, 64, 69, "Input",
  InitializationCell->True],
Cell[630838, 12256, 3353, 81, 69, "Input",
  InitializationCell->True],
Cell[634194, 12339, 3125, 59, 69, "Input",
  InitializationCell->True],
Cell[637322, 12400, 1678, 36, 69, "Input",
  InitializationCell->True],
Cell[639003, 12438, 289, 6, 69, "Text"],
Cell[639295, 12446, 1716, 35, 69, "Input"],
Cell[641014, 12483, 427, 8, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[641478, 12496, 335, 9, 62, "Subsubsection"],
Cell[641816, 12507, 899, 18, 69, "Input",
  InitializationCell->True],
Cell[642718, 12527, 2394, 35, 69, "Input",
  InitializationCell->True],
Cell[645115, 12564, 2782, 45, 69, "Input",
  InitializationCell->True],
Cell[647900, 12611, 520, 10, 69, "Input",
  InitializationCell->True],
Cell[648423, 12623, 954, 15, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[649414, 12643, 251, 8, 39, "Subsubsection"],
Cell[649668, 12653, 303, 8, 69, "Text"],
Cell[649974, 12663, 2241, 38, 69, "Input",
  InitializationCell->True],
Cell[652218, 12703, 4227, 67, 69, "Input",
  InitializationCell->True],
Cell[656448, 12772, 5218, 77, 69, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[661703, 12854, 277, 9, 39, "Subsubsection"],
Cell[661983, 12865, 985, 20, 197, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[663017, 12891, 326, 9, 94, "Subsection"],
Cell[663346, 12902, 72, 1, 69, "Input"],
Cell[663421, 12905, 77, 2, 69, "Input",
  InitializationCell->True],
Cell[663501, 12909, 165, 3, 69, "Input",
  InitializationCell->True],
Cell[663669, 12914, 1665, 24, 69, "Input",
  InitializationCell->True],
Cell[665337, 12940, 141, 3, 69, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

