(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    490298,      11618]*)
(*NotebookOutlinePosition[    491733,      11662]*)
(*  CellTagsIndexPosition[    491597,      11655]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Hoop Algebra Demonstration.", "Title",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
Conservative Division Algebras - Data, Procedures, Demonstrations, Physics. \
\
\>", "Subtitle",
  PageWidth->WindowWidth],

Cell["R.H.Beresford. 2004-5, revised 12/10/2006. ", "Subsubtitle",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell["\<\
\".. we must be willing to question basic, seemingly self-evident, elements \
of reality.\" (Brian Greene, The Fabric of the Cosmos\" 2004, p426.)\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["1. Foreword.", "Section"],

Cell["\<\
Symmetry-conserving partial-fraction-division \"Hoop Algebras\" are closely \
related to Groups and Moufang Loops. They multiply, divide, add and split \
vectors with generalized signs and employ many new or neglected mathematical \
concepts to re-define physical mathematics.\
\>", "Text"],

Cell[TextData[{
  "A shorter and simpler account of Hoop Algebras (using a much smaller \
package) is available at ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/6198/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/6198/"], None},
    ButtonStyle->"Hyperlink"],
  "; it should be studied first. This notebook goes into much greater detail.\
\nThe demonstrations can be followed by non-",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users, by downloading the free ",
  StyleBox["MathReader ",
    FontSlant->"Italic"],
  "from the same ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  " page.\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users can save (in ",
  StyleBox["addons/ExtraPackages",
    FontSlant->"Italic"],
  ") & initialize the ",
  StyleBox["GrouploopHoop.nb",
    FontSlant->"Italic"],
  " from ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/4894/"], None},
    ButtonStyle->"Hyperlink"],
  ".",
  " to set up the package and investigate the demonstrations.\n",
  StyleBox["HoopDemo",
    FontSlant->"Italic"],
  " is a simplified version of ",
  StyleBox["GroupLoopDemo",
    FontSlant->"Italic"],
  ", omitting material on the creation, identification, and manipulation of \
Groups & Loops. Activate the following cell if you have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and wish to test the examples with different data.\nPlease send any \
comments to me at ",
  StyleBox["rhberesford@btinternet.com",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(<< GroupLoopHoop`\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Illustrated Introduction.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->16],

Cell[CellGroupData[{

Cell["2.1 Hoops.", "Subsection"],

Cell[TextData[{
  "\tHoops are \"symmetry-conserving partial-fraction-division algebras\" \
that unify many physically significant algebras (including \
\[DoubleStruckCapitalR], \[DoubleStruckCapitalC], Clifford, Davenport, Dirac-\
\[Gamma], graded, \[DoubleStruckCapitalH], Lie, noncommutative, \
non-associative, \[DoubleStruckCapitalO], Pauli-\[Sigma], and Wedge etc., \
algebras). Hoops act on \"vecs\" (generalized vectors) - indexed lists of \
operators or coefficients {",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_1\)\(,\)\)\)]],
  "...",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  "}, equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_i\( a\_i\) d\_i\ where\ d\_i\)]],
  " is a sign or a dimension - using a Cayley index multiplication table G:",
  StyleBox["i j\[RightArrow] k",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["i, j & k",
    FontSlant->"Italic"],
  " are indices though ",
  StyleBox["k",
    FontSlant->"Italic"],
  " may be signed",
  " (see Figure 1)",
  ".",
  " Generalized procedures multiply, divide and (in some cases) provide \
cartesian/polar interconversions that lead to powers and roots. Hoops have \
the Moufang division property, ensuring that vectors have multiplicative \
inverses. Consequently, division employs the same procedure, ",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  ", as multiplication; AB=",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_k\( a\_i\) \(b\_j\) g\_k\)]],
  ". Warning - this multiplication MUST NOT be confused with matrix \
multiplication (transformations of coordinates for a single vector); it \
represents interactions between two vectors to give a product and two \
(possibly null) remainder vectors.\n\tThe defining feature of a hoop is \
\"Frobenius conservation\", Det[AB]=\[PlusMinus]Det[A] Det[B]; each algebra \
has conserved \"sizes\" or symmetries that may (by Noether's theoren) define \
particles and forces. These sizes are the factors of the determinant of the \
multiplication table inverse mapped with the vectors. The sizes are also \
denominators of the partial-fraction formulation of the inverse. Hoops \
comprise all groups, a few non-associative Moufang Loops (including \
Octonions), and the \"signed tables\" obtained by \"folding\" conservative \
unsigned tables. Hoops combine the \"conservative\" property with the Moufang \
division property, so they describe conservative division algebras. Most \
tables lack both properties."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 New Concepts.", "Subsection"],

Cell[TextData[{
  "\tNew concepts, transcending the limitations of \"real algebras without \
divisors of zero\", are introduced. The most important of these are unsigned \
continuous \"primal numbers\", \"generalized signs\", \"folding\", conserved \
\"sizes\" (symmetries), conservative multiplication-division with \
\"remainders\", degenerate \"monosized\" algebras, \"polar-duals\" with \
\"offsets\", \"plex-conjugates\", and \"unital hoop algebras\" with \
continuous \"orbits\" that provide analogies with deBroglie waves and Planck \
areas. Real numbers are \"folded\" (equivalenced) from a pair of \"primal\" \
(unsigned continuous, half-line) numbers via an equivalence relationship ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontSlant->"Plain"], "i"], TraditionalForm]]],
  " ~ {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)]],
  "} ~ {",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  "} iff ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)]],
  "; reals do not exist in some algebras. Other types of number are folded \
from larger sets of primal numbers by the introduction of generalized signs.\n\
\tHoop multiplication tables are, or are \"folded\" from, algebraic loops. An \
unsigned ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " loop with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry can be folded to an ",
  StyleBox["(m/r)",
    FontSlant->"Italic"],
  StyleBox["\[Times]",
    FontSlant->"Italic"],
  StyleBox["(m/r) ",
    FontSlant->"Italic"],
  "table whose elements are \"",
  StyleBox["r-signed",
    FontSlant->"Italic"],
  "\". The tables inherit the Moufang division properties, including \
zx.yz=(z.xy)z. This ensures that there are multiplicative inverses for each \
group element and for each vector, so division (multiplication by a \
multiplicative inverse) is always possible. Groups are associative Moufang \
loops, so all groups define hoop algebras. Only a few of the many \
non-associative Moufang loops [4] are conservative (i.e. hoops). (Those with \
up to 32 elements are in the database as D4M, Oct, OctC2, P4M, KiC4M, C8pC2M, \
C4iC4M.)"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tFig.1 shows three small Moufang loops (the C4C2, quaternion, and C9 \
groups) as index tables; the boldface top left squares are the folded \
versions. These, because of a loop symmetry, occur with or without offsets in \
the other squares of the same size. The folded tables are interpreted as \
algebraic multiplication tables with signed products. The minus sign is a \
square root of +1, the sign \[DoubleStruckCapitalJ] is a cube root of +1, and \
\[ImaginaryI], i, j are fourth roots of +1. The first and folded second \
tables define the complex and quaternion algebras; the third is a new algebra \
\"C9J\" developed to investigate ternary symmetry and \"3-folding\". \n\tThe \
last table is the symbolic form of the C9j table; {a,b,c} has been mapped \
onto the signed elements. This mapping allows the evaluation of the table \
determinant, Det. (Hoops are defined as having the Frobenius property, \
conservation of conjugate factors of the determinant Det[AB].) The conserved \
factors (omitting the voluminous C9 case) are shown. In all but the C9J case \
(where the determinant is -",
  Cell[BoxData[
      \(TraditionalForm\`a\^3\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`b\^3\)]],
  "\[DoubleStruckCapitalJ]+3",
  StyleBox["abc",
    FontSlant->"Italic"],
  "\[DoubleStruckCapitalJ]-",
  Cell[BoxData[
      \(TraditionalForm\`c\^3\)]],
  ") conjugation has had no effect as the determinants are real. "
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 1.",
    FontWeight->"Bold"],
  " Two-fold and three-fold ",
  StyleBox["Folding ",
    FontWeight->"Bold"],
  "of Moufang Loops, the\nresulting signed algebras, and their conserved \
shapes.."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "   C4C2 group          Quaternion group       C9 Group\n\n",
  Cell[BoxData[
      TagBox[
        FormBox[
          RowBox[{GridBox[{
                {
                  StyleBox["1",
                    FontWeight->"Bold"], 
                  StyleBox["2",
                    FontWeight->"Bold"], 
                  StyleBox["3",
                    FontWeight->"Bold"], 
                  StyleBox["4",
                    FontWeight->"Bold"], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["2",
                    FontWeight->"Bold"], 
                  StyleBox["3",
                    FontWeight->"Bold"], 
                  StyleBox["4",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontWeight->"Bold"], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["3",
                    FontWeight->"Bold"], 
                  StyleBox["4",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontWeight->"Bold"], 
                  StyleBox["2",
                    FontWeight->"Bold"], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["4",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontWeight->"Bold"], 
                  StyleBox["2",
                    FontWeight->"Bold"], 
                  StyleBox["3",
                    FontWeight->"Bold"], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["1",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["2",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["3",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["2",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["3",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["1",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["3",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["1",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["2",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["8",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["5",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["6",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["7",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["1",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["2",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["3",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]"}],
          "TraditionalForm"],
        TraditionalForm,
        Editable->True]],
    PageWidth->PaperWidth,
    Evaluatable->False,
    FontSize->9],
  ", ",
  Cell[BoxData[
      RowBox[{
        TagBox[
          FormBox[
            RowBox[{"\[NoBreak]", GridBox[{
                  {
                    StyleBox["1",
                      FontWeight->"Bold"], 
                    StyleBox["2",
                      FontWeight->"Bold"], 
                    StyleBox["3",
                      FontWeight->"Bold"], 
                    StyleBox["4",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["2",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Bold"], 
                    StyleBox["8",
                      FontWeight->"Bold"], 
                    StyleBox["3",
                      FontWeight->"Bold"], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["3",
                      FontWeight->"Bold"], 
                    StyleBox["4",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Bold"], 
                    StyleBox["6",
                      FontWeight->"Bold"], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["4",
                      FontWeight->"Bold"], 
                    StyleBox["7",
                      FontWeight->"Bold"], 
                    StyleBox["2",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Bold"], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["5",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["5",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["5",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]},
                  {
                    StyleBox["8",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["3",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["6",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["1",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["4",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["7",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["2",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}], 
                    StyleBox["5",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontTracking->"Plain",
                      FontVariations->{"Underline"->False,
                      "Outline"->False,
                      "Shadow"->False,
                      "StrikeThrough"->False,
                      "Masked"->False,
                      "CompatibilityType"->0,
                      "RotationAngle"->0}]}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak] "}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ","}]],
    PageWidth->PaperWidth,
    Evaluatable->False,
    FontSize->9],
  " ",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox["1",
                FontWeight->"Bold"], 
              StyleBox["2",
                FontWeight->"Bold"], 
              StyleBox["3",
                FontWeight->"Bold"], 
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["2",
                FontWeight->"Bold"], 
              StyleBox["3",
                FontWeight->"Bold"], 
              StyleBox["4",
                FontWeight->"Bold"], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["3",
                FontWeight->"Bold"], 
              StyleBox["4",
                FontWeight->"Bold"], 
              StyleBox["5",
                FontWeight->"Bold"], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]},
            {
              StyleBox["9",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["2",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["3",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["4",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["5",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["6",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["7",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["8",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]}
            },
          ColumnAlignments->{Decimal}], 
        TagBox[
          FormBox["\[NoBreak]",
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], " "}]]],
  "\n\n  C4 & Complex    Quaternion        C9J      Symbolic\n    algebra     \
   algebra         algebra     C9J  \n",
  Cell[BoxData[{
      RowBox[{
        TagBox[
          FormBox[
            RowBox[{"\[NoBreak]", GridBox[{
                  {
                    StyleBox["1",
                      FontWeight->"Bold"], 
                    StyleBox["\[ImaginaryI]",
                      FontWeight->"Bold"], \(-1\), \(-\[ImaginaryI]\)},
                  {
                    StyleBox["\[ImaginaryI]",
                      FontWeight->"Bold"], 
                    StyleBox[\(-1\),
                      FontWeight->"Bold"], \(-\[ImaginaryI]\), "1"},
                  {\(-1\), \(-\[ImaginaryI]\), "1", "\[ImaginaryI]"},
                  {\(-\[ImaginaryI]\), "1", "\[ImaginaryI]", \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", " ", 
        TagBox[
          FormBox[
            RowBox[{"\[NoBreak]", GridBox[{
                  {"1", 
                    StyleBox["i",
                      FontSlant->"Plain"], 
                    StyleBox["j",
                      FontSlant->"Plain"], "ij"},
                  {
                    StyleBox["i",
                      FontSlant->"Plain"], \(-1\), \(-ij\), 
                    StyleBox["j",
                      FontSlant->"Plain"]},
                  {
                    StyleBox["j",
                      FontSlant->"Plain"], "ij", \(-1\), 
                    RowBox[{"-", 
                      StyleBox["i",
                        FontSlant->"Plain"]}]},
                  {"ij", 
                    RowBox[{"-", 
                      StyleBox["j",
                        FontSlant->"Plain"]}], 
                    StyleBox["i",
                      FontSlant->"Plain"], \(-1\)}
                  },
                ColumnAlignments->{Decimal}]}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "     ", 
        RowBox[{
          TagBox[
            FormBox[
              RowBox[{"\[NoBreak]", 
                RowBox[{GridBox[{
                      {"1", "2", "3"},
                      {"2", \(\(3\)\(\ \)\), "\[DoubleStruckCapitalJ]1"},
                      {"3", "\[DoubleStruckCapitalJ]1", 
                        "\[DoubleStruckCapitalJ]2"}
                      }], ",", "\[NoBreak]"}]}],
              "TraditionalForm"],
            TraditionalForm,
            Editable->True], GridBox[{
              {"a", "b", "c"},
              {"b", "c", \(\(\[DoubleStruckCapitalJ]a\)\(\ \)\)},
              {"c", "\[DoubleStruckCapitalJ]a", "\[DoubleStruckCapitalJ]b"}
              }]}]}], "\[IndentingNewLine]", 
      RowBox[{"   "}]}], "Input",
    PageWidth->PaperWidth,
    FontSize->9,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  PageWidth->WindowWidth,
  FontFamily->"Courier New",
  FontSize->9],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`shape[{a, b, c, d, e, f, g, h}, "\<C4C2\>"]\)], "Input",\

  FontSize->9],

Cell[BoxData[
    \({a + b + c + d - e - f - g - h, a - b + c - d + e - f + g - h, 
      a - b + c - d - e + f - g + h, 
      a + b + c + d + e + f + g + 
        h, \((a - c - e + g)\)\^2 + \((b - d - f + h)\)\^2, \((a - c + e - g)\
\)\^2 + \((b - d + f - h)\)\^2}\)], "Output",
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(shape[{a, b, c, d}, "\<C4\>"]\)\(\ \)\)\)], "Input",\

  FontSize->9],

Cell[BoxData[
    \({a + b + c + d, 
      a - b + c - d, \((a - c)\)\^2 + \((b - d)\)\^2}\)], "Output",
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(shape[{a, b, c, d, e, f, g, 
        h}, "\<Q8\>"]\)\(\ \)\)\)], "Input",
  FontSize->9],

Cell[BoxData[
    \({a + b - c - d + e + f - g - h, a - b + c - d + e - f + g - h, 
      a - b - c + d + e - f - g + h, 
      a + b + c + d + e + f + g + 
        h, \((a - e)\)\^2 + \((b - f)\)\^2 + \((c - g)\)\^2 + \((d - h)\)\^2}\
\)], "Output",
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(shape[{a, b, c, d}, "\<Qr\>"]\)\(\ \)\)\)], "Input",\

  FontSize->9],

Cell[BoxData[
    \({a\^2 + b\^2 + c\^2 + d\^2}\)], "Output",
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(shape[{a, b, c}, "\<C9J\>"]\)\(\ \)\)\)], "Input",
  FontSize->9],

Cell[BoxData[
    \({a\^3 + b\^3\ \[DoubleStruckCapitalJ] - 
        3\ a\ b\ c\ \[DoubleStruckCapitalJ] + 
        c\^3\ \[DoubleStruckCapitalJ]\^2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tLoops can be expressed as Cayley tables in many isomorphic ways. The \
Hoops database provides a preferred isomorph or \"protoloop\" for each table. \
The basic properties are unchanged if an isomorph is used - the elements are \
re-labelled in isomorphisms. However, different isomorphs can fold to \
different hoops (see Figures 2 and 24).\n\tFig. 2 folds a different C4C2 \
isomorph to the Davenport algebra, by 5\[RightArrow]-1, 6\[RightArrow]-2, 7\
\[RightArrow]-3. The symbolic table ({a,b,c,d} mapped onto {1,2,3,4}),  is \
also shown. The determinant of this table factorises into ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          StyleBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  StyleBox["(",
                    FontSlant->"Plain"], 
                  RowBox[{
                    StyleBox["b",
                      FontSlant->"Italic"], 
                    StyleBox["+",
                      FontSlant->"Plain"], 
                    StyleBox["c",
                      FontSlant->"Italic"]}], ")"}], "2"], 
              "+", \(\((a - d)\)\^2\)}],
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "* ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox[
            RowBox[{"(", " ", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    StyleBox["(",
                      FontSlant->"Plain"], 
                    StyleBox[\(b - c\),
                      FontSlant->"Italic"], 
                    StyleBox[")",
                      FontSlant->"Plain"]}], "2"], "+", \(\((a + d)\)\^2\)}], 
              ")"}],
            FontSlant->"Plain"]}], TraditionalForm]], "Text"],
  ", and these two factors are conserved on multiplication."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 2. ",
    FontWeight->"Bold"],
  "Davenport algebra is folded from a C4C2 Isomorph."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[{\(C4C2\ \
Isomorph\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Dave\
nport\ Algebra\), "\[IndentingNewLine]", GridBox[{
        {GridBox[{
              {"1", "2", "3", "4", 
                StyleBox["5",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["6",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["7",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["8",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]},
              {"2", "5", "4", "7", 
                StyleBox["6",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["1",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["8",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["3",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]},
              {"3", "4", "5", "6", 
                StyleBox["7",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["8",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["1",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["2",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]},
              {"4", "7", "6", "1", 
                StyleBox["8",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["3",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["2",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["5",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]},
              {
                StyleBox["5",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["6",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["7",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["8",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["1",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["2",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["3",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["4",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]},
              {
                StyleBox["6",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["1",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["8",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["3",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["2",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["5",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["4",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["7",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]},
              {
                StyleBox["7",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["8",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["1",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["2",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["3",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["4",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["5",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["6",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]},
              {
                StyleBox["8",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["3",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["2",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["5",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["4",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["7",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["6",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox["1",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]}
              },
            ColumnAlignments->{Decimal}], 
          RowBox[{GridBox[{
                {
                  StyleBox[\(\(\ \ \ \ \ \)\(1\)\),
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["2",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["3",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["2",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox[\(-1\),
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox[\(-3\),
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["3",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["4",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox[\(-1\),
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox[\(-2\),
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]},
                {
                  StyleBox["4",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox[\(-3\),
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox[\(-2\),
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}], 
                  StyleBox["1",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]}
                },
              ColumnAlignments->{Decimal}], "     "}], GridBox[{
              {
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox[\(\(\ \ \ \)\(b\)\),
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                RowBox[{"  ", 
                  StyleBox["c",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]}], 
                RowBox[{"  ", 
                  StyleBox["d",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]}]},
              {
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox[\(-a\),
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                RowBox[{"  ", 
                  StyleBox["d",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]}], 
                StyleBox[\(-c\),
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]},
              {
                StyleBox["c",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                RowBox[{"  ", 
                  StyleBox["d",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]}], 
                StyleBox[\(-a\),
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox[\(-b\),
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}]},
              {
                StyleBox["d",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox[\(-c\),
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                StyleBox[\(-b\),
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False,
                  "StrikeThrough"->False,
                  "Masked"->False,
                  "CompatibilityType"->0,
                  "RotationAngle"->0}], 
                RowBox[{"  ", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False,
                    "StrikeThrough"->False,
                    "Masked"->False,
                    "CompatibilityType"->0,
                    "RotationAngle"->0}]}]}
              }]}
        }]}], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell["\<\
\tMost hoop determinants have more than one factor. I call the determinant \
factors \"sizes\" and the list of symbolic sizes the \"shape\" for the hoop. \
Sizes are conserved properties or symmetries for the algebra, size[AB]=\
\[PlusMinus]size[A] size[B]. Hoops are so-named because they conserve their \
shape and come between groups and loops.\
\>", "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3 Primal numbers, generalized signs.", "Subsection"],

Cell[TextData[{
  "\tLoops are defined without introducing negation, so they multiply sets of \
essentially unsigned elements (numbers or operators). Unsigned continuous \
\"Primal\" numbers (the half-line) can be defined from set theory, via \
Natural numbers, unsigned rational numbers, and an axiom of continuity. Other \
numbers can then be defined via equivalence relations that \"folds\" a set of \
",
  StyleBox["r",
    FontSlant->"Italic"],
  " primal numbers to a single ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-signed number. ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " Moufang loops with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry can be folded to (",
  StyleBox["m/r)\[Times]",
    FontSlant->"Italic"],
  "(",
  StyleBox["m/r) ",
    FontSlant->"Italic"],
  "Hoop tables; at the same time the sets of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " unsigned elements are folded to vectors with ",
  StyleBox["m/r ",
    FontSlant->"Italic"],
  "\"",
  StyleBox["r",
    FontSlant->"Italic"],
  "-signed\" elements. Signs introduce the second operation that converts a \
loop into an algebra. The standard cases are r=2 and 4, creating numbers in \
real or complex fields and the signs \"+\", \"",
  StyleBox["\[DoubleStruckI]",
    FontSlant->"Italic"],
  "\", \"-\", and \"-",
  StyleBox["\[DoubleStruckI]",
    FontSlant->"Italic"],
  "\"."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tMost mathematical texts wrongly assume that negative numbers are \
fundamental; only a few define them as equivalence relations on pairs of \
unsigned numbers; even fewer include \"Minus 1 exists\" and \"Minus 1 is \
unique\" as axioms. The effect is that much of mathematics has been \
restricted to \"fields\" where \"ordinary negation\" and \"subtraction\" are \
conflated, the only \"signs\" are \"+\", \"\[ImaginaryI]\", \"-\", & \"-\
\[ImaginaryI]\", and other possibilities are excluded. Hoops transcend this \
artificial limitation.\
\>", "Text"],

Cell[TextData[{
  "\tGeneralized signs ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^j\)]],
  " (with ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^r\)]],
  " = 1) are introduced as distinct ",
  StyleBox["j",
    FontSlant->"Italic"],
  "'th powers of ",
  StyleBox["r",
    FontSlant->"Italic"],
  "'th roots of unity. They include, when ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^0\)]],
  "=\"+\", ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^1\)]],
  "=\"\[ImaginaryI]\", ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^2\)]],
  "=\"-\", & ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^3\)]],
  "=\"-\[ImaginaryI]\". Projecting other roots of unity onto the complex \
plane as \"cyclotomic numbers\" is a distortion and restriction of their \
properties. In many hoops, \"Minus 1\" is not unique; the standard proof that \
it is unique is based on the usually unstated axiom (assumption) that \
integers are equivalence relations on ",
  StyleBox["pairs",
    FontSlant->"Italic"],
  " rather than ",
  StyleBox["indexed sets",
    FontSlant->"Italic"],
  " of natural numbers. \"Study numbers\" have ",
  Cell[BoxData[
      \(TraditionalForm\`k\^2\)]],
  "=1,  ",
  StyleBox["k",
    FontSlant->"Italic"],
  "\[NotEqual]-1. \"Minus 1\" need not exist; ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=3 gives \"Terplex algebra\", with signs \"+\", \
\"\[DoubleStruckCapitalJ]\", \"",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^2\)]],
  "\", where \[DoubleStruckCapitalJ]\[DoubleStruckCapitalJ]\
\[DoubleStruckCapitalJ]=1, and there is no entity that squares to 1. (The \
standard proof that all 3-element algebras are equivalent to complex algebra \
is only valid for fields with a single -1.)\n\tComplex functions are special \
cases of functions involving generalized signs. In particular, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_r\%\(\[DoubleStruckS]\^j\ x\)\)]],
  "defines multiphase symmetric sinusoids that fold to the asymmetric ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ x\)\)]],
  "= Cos[x] +\[ImaginaryI] Sin[x] when ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=2."
}], "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["2.4 Vector Division, Remainders.", "Subsection"],

Cell[TextData[{
  "\tThe Moufang division property ensures that a multiplicative inverse ",
  StyleBox["Ainv",
    FontSlant->"Italic"],
  " exists for all hoop vectors ",
  StyleBox["A",
    FontSlant->"Italic"],
  ", with ",
  StyleBox["Aiinv.A ",
    FontSlant->"Italic"],
  "= {1,0,..} (the unit vector). Vector division is multiplication by the \
inverse. (In non-abelian algebras ",
  StyleBox["Ai",
    FontSlant->"Italic"],
  " is a left inverse; a right inverse can be created.)  Inverses can be \
found via Cramer's rule, and so have the conjugate determinant as a \
denominator. In most hoops (excluding degenerate monosized \
\[DoubleStruckCapitalR], \[DoubleStruckCapitalC], \[DoubleStruckCapitalH], \
\[DoubleStruckCapitalO], Pauli-\[Sigma], C9j, C9J, some Clifford algebras, \
etc.) the determinant has more than one distinct factor, and the inverse \
splits into partial fractions with each distinct real factor providing a \
partial-fraction denominator (repeated factors occur in non-abelian hoops, \
but only provide one size.)"
}], "Text"],

Cell[TextData[{
  "\t Vectors give a zero determinant if any sizes are zero, even though some \
sizes are still finite. Such \"zero-vectors\" (with one or more size \
evaluating to zero) can still have conservative hoop multiplication and \
division. Division projects the results onto sub-algebras (constrained to \
have these sizes zero) and is defined so that it ejects left & right \
\"remainders\"; A/B=C+Rl+Rr, with C*B+Rl=A & A/C+Rr=B. The remainders Rl & Rr \
have the sizes of A or B that would be infinite in 1/B & 1/A respectively; \
i.e. 0\[LessSlantEqual]size[Rl]<size[1/B], just as integer division has \
I/J=K+R, 0\[LessEqual]R<J. Conservation is maintained by the creation of \
remainders wherever a size would otherwise be lost by becoming zero or \
infinity. Division-by-zero is eliminated by \"projection\" into sub-algebras. \
In effect, the zeroes and infinities are factored out of the result.\n\t\
Multiplication behaves in the same way (multiplication and division are one \
operation, using inverse vectors). In Fig. 3, multiplying A={2,1,-1,2} by \
B={1,3,5,2} in the Davenport algebra gives AB={8,-1,1,8} and a right \
remainder {-.5,4,4,.5} because the shape of A is {0,20}. The shape of B is \
{65,13}, so the shapes of AB and Rr are {0,13} and {65,0}.\n\t (Most figures \
are the output from a set of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " input instructions, which are usually hidden in a \"closed cell\" because \
they are probably meaningless to non-users of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". If desired, the instructions can be inspected by clicking on the tiny \
cell bracket, then on ",
  StyleBox["Cell,",
    FontSlant->"Italic"],
  " ",
  StyleBox["Cell Properties ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["Cell Open.",
    FontSlant->"Italic"],
  ")"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 3.",
    FontWeight->"Bold"],
  " Remainders in Dav multiplication and division."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \({"\<A= \>", A = {2, 1, \(-1\), 2}, "\<B= \>", 
      B = {1, 3, 5, 2}, "\<\nUsing Davenport Algebra, AB=\>", 
      AB = hoopTimes[A, B, "\<Dav\>"], "\<\nRl is\>", 
      Rl, "\< with shape[Rl]=\>", shape[Rl], "\<\nRr is\>", 
      rr = Rr, "\< with shape[Rr]=\>", shape[Rr], "\<\nAinverse=\>", 
      Ai = hoopInverse[A], "\<\nAinverse.AB = \>", 
      B0 = hoopTimes[\ Ai, 
          AB], "\<which only recovers B when Rr is added to give \>", 
      B0 + rr}\), "\[IndentingNewLine]", 
    \(A =. ; AB =. ; B0 =. ; rr =. \)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A= ", {2, 1, \(-1\), 2}, "B= ", {1, 3, 5, 2}, 
      "\nUsing Davenport Algebra, AB=", {8, \(-1\), 1, 8}, 
      "\nRl is", {0, 0, 0, 0}, " with shape[Rl]=", {0, 0}, 
      "\nRr is", {\(-\(1\/2\)\), 4, 4, 1\/2}, " with shape[Rr]=", {65, 0}, 
      "\nAinverse=", {1\/10, \(-\(1\/20\)\), 1\/20, 1\/10}, 
      "\nAinverse.AB = ", {3\/2, \(-1\), 1, 3\/2}, 
      "which only recovers B when Rr is added to give ", {1, 3, 5, 
        2}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5 Polar Duals, Orbits.", "Subsection"],

Cell["\<\
\tMany hoops have quadratic sizes that can be expressed as sums or \
differences of squares. These lead to polar-dual forms (generalizations of \
the polar description of the complex plane) that involve multiphase sinusoids \
with angles; the quadratic sizes are squared radii. Because angles add on \
abelian multiplication, polar-duals provide abelian hoops with roots, powers, \
logarithms, and continuous multi-phase sinusoidal \"orbits\" that are are \
related to the discrete orbits of loops. Whilst complex-conjugate \
factor-pairs are not conserved, their real products are conserved sizes that \
define the squared radii of orbits.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 4.",
    FontWeight->"Bold"],
  " The polar form of \"Terplex\" C3 is given by \"",
  StyleBox["toPol[{a,b,c}]",
    FontSlant->"Italic"],
  "\". The Orbit has an offset ",
  StyleBox["d",
    FontSlant->"Italic"],
  "=",
  StyleBox["a+b+c",
    FontSlant->"Italic"],
  ", a squared radius ",
  StyleBox["r2",
    FontSlant->"Italic"],
  ", and an angle \[Sigma]. The function \"",
  StyleBox["toVec[{d,r2,\[Sigma]}]",
    FontSlant->"Italic"],
  "\" recovers the Cartesian form."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \({"\<The Terplex Polar form of {a,b,c} is\>", 
      toPol[{a, b, 
          c}, "\<C3\>"], "\<\nThe general toVec[{d,r2,\[Sigma]},C3] \
expression is\>", 
      toVec[{d, 
          r2, \[Sigma]}, "\<C3\>"], "\<\nThe Polar form of {1.,2.,5.} is\>", 
      p3 = toPol[{1. , 2. , 
            5. }, "\<C3\>"], \[IndentingNewLine]"\<\ntoVec recovers  \>", 
      toVec[p3, "\<C3\>"]}\), "\[IndentingNewLine]", 
    \(p3 =. \)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"The Terplex Polar form of {a,b,c} is", {a + b + c, 
        1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2)\), 
        ArcTan[2\ a - b - c, \(-\@3\)\ \((b - c)\)]}, 
      "\nThe general toVec[{d,r2,\[Sigma]},C3] expression is", {1\/3\ \((d + 
              2\ \@r2\ Cos[\[Sigma]])\), 
        1\/3\ \((d + 2\ \@r2\ Cos[\(2\ \[Pi]\)\/3 + \[Sigma]])\), 
        1\/3\ \((d + 2\ \@r2\ Cos[\(2\ \[Pi]\)\/3 - \[Sigma]])\)}, 
      "\nThe Polar form of {1.,2.,5.} is", {8.`, 13.`, 2.3369589764886807`}, 
      "\ntoVec recovers  ", {1.`, 1.9999999999999993`, 5.`}}\)], "Output"]
}, Open  ]],

Cell["\<\
\tSome unitary algebras, in which the determinant is constrained to be 1 \
(apart from any zero sizes), have 3, 4, 6, & 12-phase de-Broglie-wave-like \
orbits, stable Planck-area-like sizes, and reciprocal-radius pairs. \
12-element hoops provide \"half-spin\" quantum operators related to 6-element \
\"unit-spin\" operators; there are fewer 6-element \"supersymmetric\" \
elements because they result from a fold that frees them from the Pauli \
exclusion principle. Note that, whilst algebras are usually taken to have \
vector elements that are \"coefficients\", elements can also be operators.
\tSizes are symmetries that may (via Noether's theorem) account for forces \
and particles. They may determine the different families and the limited \
number of fundamental particles. They may also lead to the \"law of large \
numbers\" and three size regimes, R = the radius of universe, \[Rho] = a \
Planck-size , and r = \[Rho]/R = the radius of \"pseudopoint\" particles. \
Hoops may provide a new basis for symmetry in mathematical physics, based on \
finite hoops rather than infinite groups.\
\>", "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "2.6 The ",
  StyleBox["GroupLoopHoop.m ",
    FontSlant->"Italic"],
  "package."
}], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox["GroupLoopHoop.m ",
    FontSlant->"Italic"],
  "is a package that includes data on over 90 hoop algebras (including some \
isomorphs). Most of these have under 16 elements; large symbolic determinant \
factors are difficult to find. The package provides the generalized \
procedures ",
  StyleBox["hoopTimes, hoopInverse, hoopPower",
    FontSlant->"Italic"],
  ". In addition to the hoops, it provides a database of all groups with up \
to 73 elements, and some other tables, and includes procedures to generate, \
manipulate, and identify tables. ",
  StyleBox["GroupLoopTest.nb",
    FontSlant->"Italic"],
  " validates the package.\n\t",
  StyleBox["HoopGlossary.nb",
    FontSlant->"Italic"],
  " gives brief explanations of the relevant concepts. ",
  StyleBox["GroupLoopDemo.nb",
    FontSlant->"Italic"],
  " demonstrates the database and procedures. This notebook, ",
  StyleBox["HoopDemo.nb",
    FontSlant->"Italic"],
  ", is a shortened version concerned only with hoops. ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  " /6198 gives a simplified account of hoops, with a database restricted to \
hoops."
}], "Text",
  PageWidth->WindowWidth]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Hoop Tutorial.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Arial",
  FontSize->16,
  FontVariations->{"CompatibilityType"->0}],

Cell[CellGroupData[{

Cell["3.1. \"Hoops\", Hoop Names.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary. ",
  StyleBox["Conservative division algebras (Hoops) are created by \"folding\" \
Moufang loops (groups and some alternative loops such as octonions) by the \
introduction of generalized signs. Hoops multiply and divide vectors whilst \
conserving \"symmetries\" or \"sizes\" (factors of the symbolic inverse table \
determinant). A database provides named tables and sizes for over 90 hoops, \
together with much more material on small loops and groups.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tHoops are \"conservative division algebras\" that unify most algebras \
(including the Cayley-Dickson algebras {\[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], \[DoubleStruckCapitalO]}, \
Clifford, Davenport, Dirac-\[Gamma], Lie, non-commutative, non-associative, \
Pauli-\[Sigma], Terplex & Wedge algebras, etc) by employing generalized \
procedures for multiplication, division, and (where appropriate) conversion \
to and from the polar-dual forms that provide powers and roots. They act on \
generalized vectors - indexed lists of coefficients {",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_1\)\(,\)\)\)]],
  "...",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  "}, equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_i\( a\_i\) d\_i\ where\ d\_i\)]],
  " is a sign, a direction, or a dimension.\n\tHoops are division algebras \
because their multiplication tables have the Moufang division property, \
zx.yz=(z.xy)z. This ensures that each element in the table, and each vector, \
has a multiplicative inverse. Division is multiplication by the inverse \
vector.\n\tHoops are conservative algebras because (by definition) they have \
the Frobenius determinant conservation property, Det[AB] = \
\[PlusMinus]Det[A]Det[B] where Det is evaluated from the inverted \
multiplication table mapped with the vector. The factors of the determinant \
are conserved properties (\"symmetries\" or \"sizes\") and the list of \
distinct factors is the \"shape\" for a vector in a specified algebra.\n\t\
Hoops are algebras because they have another operation (apart from \
multiplication/division), addition with generalized negation and \
\"generalized signs\". This operation is obtained by an equivalence \
relationship on sets of coefficients,  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["h",
            FontSlant->"Plain"], "i"], TraditionalForm]]],
  "~ {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/r\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + 2  m/r\)\)]],
  ",..} ~ {",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/r\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + 2  m/r\)\)]],
  "...}. The commonest case is ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=2, giving half as many real coefficients, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontSlant->"Plain"], "i"], TraditionalForm]]],
  "~ {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  " ,",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  "} ~ {",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/2\)\)]],
  "} iff ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/2\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  ". Equivalencing an ",
  StyleBox["m\[Cross]m",
    FontSlant->"Italic"],
  " table with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry \"folds\" it to an ",
  StyleBox["(m/r)\[Cross](m/r)",
    FontSlant->"Italic"],
  " table. This may be a smaller unsigned Moufang loop (e.g. in Fig.1 the \
C4C2 isomorph folds to C4) but in many cases it is a signed table in which \
some products are signed; e.g. C4 2-folds to C4c (complex algebra) with \
elements {1,\[ImaginaryI]} and the signed product \[ImaginaryI].\[ImaginaryI] \
is -1; the C4C2 isomorph in Fig.2 2-folds to the signed Davenport \
multiplication table."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe database in ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " includes multiplication tables and properties for over 90 loops with \
known determinant factors. Each has a string as a name. The names without the \
quotation marks define Cayley tables, providing the \"preferred isomorph\" \
for hoop multiplication tables. The procedure ",
  StyleBox["hoopShape[name]",
    FontSlant->"Italic"],
  " selects a \"target algebra\" for further operations. The names, in order \
of increasing vector size, (apart from 4 non-conservative loops, moved to the \
end) are:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`hoopList\)], "Input"],

Cell[BoxData[
    \({"C2", "C4c", "C3", "C3C2c", "C12c", "C3i", "C4C3c", "C3C3j", "C9j", 
      "C9J", "C4", "K", "Qr", "P4", "Dav", "O2", "C8r", "C3C4j", "CL2", 
      "C4C2r", "P16c", "C8c", "C5", "C3C2", "D3", "C3C4c", "Q12c", "Q12r", 
      "Q12r", "g2401c", "D6r", "D3C2c", "KC3c", "C3Kr", "Cl3r", "Clm3r", 
      "C8", "KC2", "C4C2", "D4", "Q8", "Octr", "KiC4c", "O4", "O4a", "O4b", 
      "C4C4c", "C4C4r", "Q8C2r", "C2D4r", "P8", "CL3", "C4iC4c", "QC2r", 
      "KiC4r", "CL21", "CL03", "Octi", "C3C3", "C9", "C6C3c", "C3C4", "C3K", 
      "Q12", "D3C2", "A4", "C3Qr", "C3P4", "C6Kr", "C3KC2r", "Q12C2c", "D8", 
      "Q16", "D4C2", "C4C4", "Q8C2", "KK", "C4K", "KiC4", "C4iC4", "P16", 
      "Oct", "Q8M2", "CL4", "CL13", "CL22", "CL31", "r31r", "CL04", "O8", 
      "C3C4C2", "CL31C2", "CL4C2", "Q4n", "C6n", "Q8n", "D3Mn"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe names are based on the names of loops used in ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  ". Thus C2, C3, etc. are cyclic groups, D3, D4, etc. are dihedral groups, \
Q8, Q12 are quaternionic groups (Q12 is called T in Mathworld ",
  StyleBox["Groups",
    FontSlant->"Italic"],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(Dic\_3\)\)\)]],
  "in Wikipedia). C3C2 is the direct composition of C3 with C2; C4iC4 is the \
indirect composition of C4 with C4; K=C2C2 is the Klein 4-group. P4, P8, P16 \
have Pauli-\[Sigma] matrices as generators. CLmn is Clifford(m,n). Names \
ending in r, j, J, or i are signed tables that compose with C2, C3, or C4 to \
Moufang loops. Oct is the 16-element Octonion loop, which folds to the \
8-element octonion hoop Octr. O4, O4a, O4b are hoops with polar",
  StyleBox["-duals",
    FontSlant->"Plain"],
  " having four {angle,radius} pairs. Dav is the Davenport (hypercomplex) \
algebra. An M indicates a non-associative Moufang loop, obtained by doubling \
a non-abelian group, so Q8M2 is the non-associative but conservative Moufang \
loop obtained from Q8. The last four, with names ending in n, are not \
conservative; they are included as non-hoop counter-examples with known \
determinant factors that do not define inverses."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["\tAll these hoops have been tested, using a routine in ",
    FontSlant->"Plain"],
  "GroupLoopTest.nb",
  StyleBox[". This shows them to be conservative division algebras by tests \
with random real or complex vectors. Polar-duals, positive powers, roots, and \
quadratic equation solution have also been tested successfully wherever duals \
are known.",
    FontSlant->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell["\<\
\tConservative Moufang loops are a small subset of quasi-groups and \
semi-groups. Most tables have neither the Moufang nor the Frobenius property, \
so they lack inverses and conserved sizes.\
\>", "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2. Multiplication, Conserved \"sizes\".", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary. ",
  StyleBox["hoopShape selects an algebra & ",
    FontSlant->"Italic"],
  StyleBox["hoopTi",
    FontSlant->"Italic"],
  StyleBox["mes defines multiplication in it. Conservation of determinant \
factors is demonstrated for C3 algebra.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe ",
  StyleBox["GroupLoopHoop.m ",
    FontSlant->"Italic"],
  "database contains a multiplication table and a \"shape\" for each hoop \
algebra. A \"target hoop\" is selected by a ",
  StyleBox["hoopShape[name]",
    FontSlant->"Italic"],
  " instruction (or by specifying the loop in a multiplication operation)",
  StyleBox[".",
    FontSlant->"Italic"],
  " ",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  " uses the selected multiplication table to multiply two vectors. The \
result is a vector ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)]],
  " = \[CapitalSigma]",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  " where ",
  StyleBox["i\[Cross] j = k",
    FontSlant->"Italic"],
  " in the table. Do not confuse hoop multiplication (which creates a vector \
and remainders from two vectors) with matrix multiplication (which transforms \
a single vector to new coordinates) or the Dot product, which creates a \
scalar from two vectors."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 6.",
    FontWeight->"Bold"],
  " Multiplication. The C3 algebra is selected by ",
  StyleBox["hoopShape[\"C3\"];",
    FontSlant->"Italic"],
  " and two 3-element vectors are set up and multiplied:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Figure\ 6. *) \)\(hoopShape["\<C3\>"]; {"\<If A=\>", 
      A = {3. , 1. , 4. }, "\<& B=\>", 
      B = {1. , 2. , \(-4. \)}, "\<AB in C3 algebra =\>", 
      AB = hoopTimes[A, B], "\<\nThis is not the Dot product, which is\>"\ , 
      A . B, "\<\nbut a vector. The general product {a,b,c}\[Times]{d,e,f} is \
\>", hoopTimes[{a, b, c}, {d, e, f}]}\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"If A=", {3.`, 1.`, 4.`}, "& B=", {1.`, 2.`, \(-4.`\)}, 
      "AB in C3 algebra =", {7.`, \(-9.`\), \(-6.`\)}, 
      "\nThis is not the Dot product, which is", \(-11.`\), 
      "\nbut a vector. The general product {a,b,c}\[Times]{d,e,f} is ", {a\ d \
+ c\ e + b\ f, b\ d + a\ e + c\ f, c\ d + b\ e + a\ f}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThree variables, the hoop name ",
  StyleBox["gmn,",
    FontSlant->"Italic"],
  " the multiplication table ",
  StyleBox["glo,",
    FontSlant->"Italic"],
  " and the length ",
  StyleBox["mm",
    FontSlant->"Italic"],
  ", are automatically set when an algebra is selected by ",
  StyleBox["hoopShape",
    FontSlant->"Italic"],
  ". \n\tThe multiplication index-table can be shown in \"TraditionalForm\" \
by appending ",
  StyleBox["//tf ",
    FontSlant->"Italic"],
  ", the symbolic form by ",
  StyleBox["gmap[glo,{a,b,c}]//tf",
    FontSlant->"Italic"],
  ", (which puts ",
  StyleBox["a,b...",
    FontSlant->"Italic"],
  " in place of ",
  StyleBox["1,2..",
    FontSlant->"Italic"],
  ", etc.) and the shape is given by ",
  StyleBox["sh[gmn]\n\t",
    FontSlant->"Italic"],
  "\n",
  StyleBox["Figure 7. ",
    FontWeight->"Bold"],
  "C3 Index table, Symbolic table, and Shape."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Figure\ 7. *) \)\({gmn, "\<Index Table\>", 
      glo // tf, "\<Symbolic Form\>", 
      gmap[glo, {a, b, c}] // tf, "\<\nhas shape=\>", 
      shape[{a, b, c}, "\<C3\>"]}\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"C3\"\>", ",", "\<\"Index Table\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "3", "1"},
                  {"3", "1", "2"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"Symbolic Form\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b", "c"},
                  {"b", "c", "a"},
                  {"c", "a", "b"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nhas shape=\"\>", 
        ",", \({a + b + c, 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + \
c)\)\^2)\)}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Figure 8.",
    FontWeight->"Bold"],
  " Size Conservation in Multiplication. The shapes of A, B, and AB (from \
Fig. 6.) are shown; conservation is demonstrated in the last line by \
subtracting to give {0,0}:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({{"\<\>", sh1, sh2}, Flatten[Join[{shA\ }, sA = shape[A]]], 
        Flatten[Join[{shB\ }, sB = shape[B]]], 
        Flatten[Join[{shAB}, sAB = shape[AB]]], 
        Flatten[Join[{shA*shB - shAB}, sA*sB - sAB]]} // tf\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"\"\>", "sh1", "sh2"},
            {"shA", "8.`", "7.`"},
            {"shB", \(-1.`\), "31.`"},
            {"shAB", \(-8.`\), "217.`"},
            {\(shA\ shB - shAB\), "0.`", "0.`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3. Multiplicative Inverses, Division.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary.",
  StyleBox[" Division is multiplication by a multiplicative inverse that can \
be found by Cramer's method and so has the determinant as denominator.  ",
    FontSlant->"Italic"],
  StyleBox["hoopIn",
    FontSlant->"Italic"],
  StyleBox["verse creates the left inverse Ainv. This is demonstrated for \
abelian C3 and non-abelian D3, where Ainv.AB recovers B and AB.Binv recovers \
A (because B is the left inverse of Binv), provided that A & B have the same \
zero-sizes.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["\t",
    FontSlant->"Italic"],
  StyleBox["hoopIn",
    FontSlant->"Italic"],
  StyleBox["verse[A]",
    FontSlant->"Italic"],
  " gives the multiplicative left inverse Ainv (which is also a right inverse \
for abelian hoops). The inverses have been found by Cramer's method, solving \
Ainv.A= I, where I is the hoop unit vector, {1,0....0}. (Again, do not \
confuse this with matrix inversion, where I is the unit diagonal matrix.) \
Cramer's method makes the table determinant the denominator for every element \
of the inverse.\n",
  StyleBox["Figure 9. ",
    FontWeight->"Bold"],
  "C3 Division using ",
  StyleBox["hoopIn",
    FontSlant->"Italic"],
  StyleBox["verse",
    FontSlant->"Italic"],
  ". Ainv.AB recovers B:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Example\ 2  a*) \)\({"\<Ainv\>", 
      Ainv = hoopInverse[A], "\<\nDeterminant \>", 
      Det[gmap[C3, A]], "\<\nShape Ainv\>", 
      shape[Ainv], "\<\nAinv.AB recovers B\>", 
      hoopTimes[Ainv, AB]}\)\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"Ainv", {0.08928571428571429`, 
        0.23214285714285712`, \(-0.1964285714285714`\)}, 
      "\nDeterminant ", \(-56.`\), 
      "\nShape Ainv", {0.125`, 0.14285714285714282`}, 
      "\nAinv.AB recovers B", {0.9999999999999998`, 
        1.9999999999999996`, \(-3.999999999999999`\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tNon-abelian (noncommutative) algebra determinants have repeated roots, \
as shown by the third line of Figure 10., where {a,b,c,d,e,f} is mapped onto \
the index table of D3 (the smallest non-abelian group), and the determinant \
is factorised. (The repeated factor \"fragments\" into (",
  Cell[BoxData[
      \(TraditionalForm\`\((a - c)\)\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\((c - e)\)\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\((e - a)\)\^2\)]],
  ")/2-(",
  Cell[BoxData[
      \(TraditionalForm\`\((b - d)\)\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\((d - f)\)\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\((f - b)\)\^2\)]],
  ")/2 ). The D3 products AB and BA differ. Inverses are \"left inverses\", \
so both Ainv.AB & BA.Ainv recover B, but AB.Ainv gives rubbish.\n\n",
  StyleBox["Figure 10.",
    FontWeight->"Bold"],
  " Noncommutative Multiplication & Division using D3."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Example\ 2  b*) \)\(hoopShape["\<D3\>"]; {"\<A=\>", 
      A = {3, 1, 4, 2, 6, 5}, "\<B=\>", 
      B = {1, 2, 1, 3, 3, 4}, "\<\nD3 Determinant \>", 
      Factor[Det[gmap[D3, {a, b, c, d, e, f}]]], "\<\nAB in D3 algebra =\>", 
      AB = hoopTimes[A, B], "\<\nBA in D3 algebra =\>", 
      BA = hoopTimes[B, A], "\<\nAinv\>", 
      Ainv = hoopInverse[A], "\<\nShapes of A & Ainv\>", shape[A], 
      shape[Ainv], "\<\nAinv.AB recovers B\>", 
      hoopTimes[Ainv, AB], "\<\nBA.Ainv recovers B\>", 
      hoopTimes[BA, Ainv], "\<\nAB.Ainv is rubbish\>", 
      hoopTimes[AB, Ainv], "\<\nBinv\>", 
      Binv = hoopInverse[B], "\<\nShapes of B & Binv\>", shape[B], 
      shape[Binv], "\<\nAB.Binv recovers A\>", 
      hoopTimes[AB, Binv], "\<\nBinv.BA recovers A\>", 
      hoopTimes[Binv, BA]}\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A=", {3, 1, 4, 2, 6, 5}, "B=", {1, 2, 1, 3, 3, 4}, 
      "\nD3 Determinant ", \(-\((a - b + c - d + e - f)\)\)\ \((a + b + c + 
            d + e + f)\)\ \((a\^2 - b\^2 - a\ c + c\^2 + b\ d - d\^2 - a\ e - \
c\ e + e\^2 + b\ f + d\ f - f\^2)\)\^2, 
      "\nAB in D3 algebra =", {49, 58, 48, 51, 40, 48}, 
      "\nBA in D3 algebra =", {49, 54, 46, 55, 42, 48}, 
      "\nAinv", {83\/315, \(-\(191\/630\)\), \(-\(149\/630\)\), \
\(-\(43\/315\)\), 61\/630, 229\/630}, 
      "\nShapes of A & Ainv", {21, 5, \(-6\)}, {1\/21, 1\/5, \(-\(1\/6\)\)}, 
      "\nAinv.AB recovers B", {1, 2, 1, 3, 3, 4}, 
      "\nBA.Ainv recovers B", {1, 2, 1, 3, 3, 4}, 
      "\nAB.Ainv is rubbish", {1, 5, 4, 1, 0, 3}, 
      "\nBinv", {\(-\(39\/56\)\), 59\/56, 73\/56, 
        3\/56, \(-\(39\/56\)\), \(-\(53\/56\)\)}, 
      "\nShapes of B & Binv", {14, \(-4\), 1}, {1\/14, \(-\(1\/4\)\), 1}, 
      "\nAB.Binv recovers A", {3, 1, 4, 2, 6, 5}, 
      "\nBinv.BA recovers A", {3, 1, 4, 2, 6, 5}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe database contains a few hoops that are non-associative, with \
Octonions being best known. \"Octr\" is the 8-element octonion algebra, and \
\"Oct\" is its parent 16-element unsigned table, the third nonassociative \
Moufang loop with 16 elements. \"Q8M2\" is the second, and is parent to \
another 8-element signed table \"Octi\" (split-octonions in Wikipedia); both \
have a size consisting of four positive and four negated squares, giving the \
signature (4,4). Left and right multiplication of two 16-element vectors is \
demonstrated for \"Q8M2\" in Figure 10a:-\n\n",
  StyleBox["Figure 10a",
    FontWeight->"Bold"],
  ". Noncommutative Nonassociative Multiplication & Division Q8M2."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<A=\>", 
      A = {3, 1, 4, 2, 6, 5, 0, 7, 1, 0, 4, 2, 3, 
          0, \(-1\), \(-4\)}, "\<B=\>", 
      B = {1, 2, 1, 3, 3, 4, 5, 0, 2, 6, 5, 0, 7, 1, 0, 
          4}, "\<\nQ8M2 Determinant Factors\n \>", 
      hoopShape["\<Q8M2\>"], "\<\nAB in Q8M2 algebra =\>", 
      AB = hoopTimes[A, B], "\<\nBA in Q8M2 algebra =\>", 
      BA = hoopTimes[B, A], "\<\nAinv\>", 
      Ainv = hoopInverse[A], "\<\nShapes of A & Ainv\>", shape[A], 
      shape[Ainv], "\<\nAinv.AB recovers B\>", 
      hoopTimes[Ainv, AB], "\<\nBA.Ainv recovers B\>", 
      hoopTimes[BA, Ainv], "\<\nAB.Ainv is rubbish\>", 
      hoopTimes[AB, Ainv], "\<\nBinv\>", 
      Binv = hoopInverse[B], "\<\nShapes of B & Binv\>", shape[B], 
      shape[Binv], "\<\nAB.Binv recovers A\>", 
      hoopTimes[AB, Binv], "\<\nBinv.BA recovers A\>", 
      hoopTimes[Binv, BA]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A=", {3, 1, 4, 2, 6, 5, 0, 7, 1, 0, 4, 2, 3, 0, \(-1\), \(-4\)}, 
      "B=", {1, 2, 1, 3, 3, 4, 5, 0, 2, 6, 5, 0, 7, 1, 0, 4}, 
      "\nQ8M2 Determinant Factors\n ", {a + b + c + d + e + f + g + h - i - 
          j - k - l - m - n - o - p, 
        a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
        a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
        a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p, 
        a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
        a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p, 
        a + b - c - d + e + f - g - h - i - j + k + l - m - n + o + p, 
        a + b + c + d + e + f + g + h + i + j + k + l + m + n + o + 
          p, \((a - e)\)\^2 + \((b - f)\)\^2 + \((c - g)\)\^2 + \((d - \
h)\)\^2 - \((i - m)\)\^2 - \((j - n)\)\^2 - \((k - o)\)\^2 - \((l - p)\)\^2}, 
      "\nAB in Q8M2 algebra =", {103, 128, 56, 53, 63, 46, 119, 89, 102, 124, 
        43, 99, 105, 75, 149, 98}, 
      "\nBA in Q8M2 algebra =", {103, 60, 123, 90, 63, 114, 52, 52, 124, 60, 
        124, 98, 83, 139, 68, 99}, 
      "\nAinv", {\(-\(121636\/79695\)\), 
        154249\/79695, \(-\(22292\/11385\)\), 29228\/11385, 
        117449\/79695, \(-\(164531\/79695\)\), 
        23248\/11385, \(-\(27697\/11385\)\), 86929\/79695, 
        4589\/79695, \(-\(29182\/11385\)\), \(-\(35162\/11385\)\), \(-\(72461\
\/79695\)\), 4589\/79695, 27743\/11385, 33148\/11385}, 
      "\nShapes of A & Ainv", {23, 5, 7, 9, 7, \(-11\), \(-1\), 33, 
        1}, {1\/23, 1\/5, 1\/7, 1\/9, 1\/7, \(-\(1\/11\)\), \(-1\), 1\/33, 
        1}, "\nAinv.AB recovers B", {1, 2, 1, 3, 3, 4, 5, 0, 2, 6, 5, 0, 7, 
        1, 0, 4}, 
      "\nBA.Ainv recovers B", {1, 2, 1, 3, 3, 4, 5, 0, 2, 6, 5, 0, 7, 1, 0, 
        4}, "\nAB.Ainv is rubbish", {1, \(-82\), 34, 308, 3, 
        88, \(-28\), \(-305\), 96, \(-146\), 118, \(-239\), \(-87\), 
        153, \(-113\), 243}, 
      "\nBinv", {\(-\(1471\/40832\)\), 1571\/122496, \(-\(3731\/122496\)\), 
        1109\/122496, \(-\(2879\/40832\)\), 5795\/122496, 
        4717\/122496, \(-\(5227\/122496\)\), 1169\/40832, 3859\/122496, 
        10877\/122496, \(-\(11387\/122496\)\), 
        4689\/40832, \(-\(6701\/122496\)\), 
        317\/122496, \(-\(2939\/122496\)\)}, 
      "\nShapes of B & Binv", {\(-6\), 8, 4, \(-6\), \(-4\), \(-2\), \(-6\), 
        44, \(-58\)}, {\(-\(1\/6\)\), 1\/8, 
        1\/4, \(-\(1\/6\)\), \(-\(1\/4\)\), \(-\(1\/2\)\), \(-\(1\/6\)\), 
        1\/44, \(-\(1\/58\)\)}, 
      "\nAB.Binv recovers A", {3, 1, 4, 2, 6, 5, 0, 7, 1, 0, 4, 2, 3, 
        0, \(-1\), \(-4\)}, 
      "\nBinv.BA recovers A", {3, 1, 4, 2, 6, 5, 0, 7, 1, 0, 4, 2, 3, 
        0, \(-1\), \(-4\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
Recovery fails unless A & B have the same zero-sizes; disparate zeroes are \
handled in the next sections.\
\>", "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4. \"Zero sizes\" & Remainders.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary. ",
  StyleBox["Vectors B with zero-sizes are given an inverse Binv with the same \
zeroes, so these sizes are lost in the dividend. A/B (= Binv*A) is \
\"projected\" onto a sub-algebra. Conservation is maintained by \"ejecting\" \
a remainder. The analogy with integer division, A/B = C, C*B+R=A with R<B, is \
that the ejected remainder contains those sizes of A that are less than the \
(infinite) sizes omitted from Binv. ",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tMost hoop determinants have more than one factor, so most inverses split \
into partial fractions with the factors (sizes) as denominators. (A \
mathematical quirk makes repeated factors give a single partial fraction, \
weighted by the multiplicity, rather than the general partial fractions.)\n\t\
",
  StyleBox["hoopIn",
    FontSlant->"Italic"],
  StyleBox["verse",
    FontSlant->"Italic"],
  " creates the required partial fractions, but omits any in which the \
denominator is effectively zero (to within an arbitrary ",
  StyleBox["hmin",
    FontSlant->"Italic"],
  "). Consequently, Ainv has the same zeroes as A and dividends have the same \
zeroed sizes. The dividends are \"projected\" onto a sub-algebra in which \
these sizes are constrained to be zero. By analogy with natural number \
division, where A/B = C with remainder R (with 0\[LessSlantEqual]R<B) such \
that C*B+R=A, there is a dividend C and a remainder R, into which any \
unconserved sizes are \"ejected\". This is implemented by ",
  StyleBox["hoopTi",
    FontSlant->"Italic"],
  StyleBox["mes[A,Binv]",
    FontSlant->"Italic"],
  "; it is demonstrated here and discussed in the next section.\n\t\n",
  StyleBox["Figure 11.",
    FontWeight->"Bold"],
  "  B is altered to have a zero D3 size. Dividing A by B splits A into the \
dividend A0, with the same size zero, and the (left) remainder Rl, with the \
other sizes zero:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Example\ 3*) \)\(hoopShape["\<D3\>"]; {"\<A=\>", 
      A = {3, 1, 4, 2, 6, 5}, "\<B=\>", 
      B = {1, 2, 1, 3, 7, 4}, "\<\nAB in D3 algebra =\>", 
      AB = hoopTimes[A, B], "\<\nBinv\>", 
      Binv = hoopInverse[B], "\<\nwith remainders Rl, Rr\>", R1 = Rl, 
      Rr, "\<\nShapes A,B    \>", shape[A], shape[B], "\<\nShapes Rl,Binv\>", 
      shape[Rl], shape[Binv], "\<\nAB/B+Rl=A\>", 
      hoopTimes[AB, Binv] + R1}\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A=", {3, 1, 4, 2, 6, 5}, "B=", {1, 2, 1, 3, 7, 4}, 
      "\nAB in D3 algebra =", {65, 78, 72, 55, 52, 56}, 
      "\nBinv", {\(-\(61\/1188\)\), 47\/1188, 155\/1188, 
        1\/108, \(-\(61\/1188\)\), \(-\(25\/1188\)\)}, 
      "\nwith remainders Rl, Rr", {5\/6, \(-\(5\/6\)\), 5\/6, \(-\(5\/6\)\), 
        5\/6, \(-\(5\/6\)\)}, {0, 0, 0, 0, 0, 0}, 
      "\nShapes A,B    ", {21, 5, \(-6\)}, {18, 0, 33}, 
      "\nShapes Rl,Binv", {0, 5, 0}, {1\/18, 0, 1\/33}, 
      "\nAB/B+Rl=A", {3, 1, 4, 2, 6, 5}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.5. Multiplication and Remainders.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary. ",
  StyleBox["Multiplication by a vector Z with zero-sizes gives a product with \
the same zeroes, losing any corresponding sizes in the other multiplicand, so \
that ZB/Z does not recover B. The product ZB has been \"projected\" onto a \
sub-algebra, just as in division. Conservation is maintained by \"ejecting\" \
left and right remainders so that ZB/B+Rl = Z & ZB/Z + Rr = B. Abelian, \
non-abelian, and monosized algebra remainders are demonstrated.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tDivision needs remainders to maintain conservation. As division is \
multiplication by an inverse, using ",
  StyleBox["hoopTi",
    FontSlant->"Italic"],
  StyleBox["mes",
    FontSlant->"Italic"],
  ", remainders must also be involved in multiplication. If different sizes \
of A & B are zero, these sizes will be zero in the product AB. To maintain \
conservation, the \"missing sizes\" have to be \"ejected\" as remainders when \
AB is \"projected\" onto a sub-algebra. Rl is the remainder for the left \
multiplicand A, and Rr for the right multiplicand B. They ensure that \
AB/B+Rl=A and AB/A+Rr=B. The procedure ",
  StyleBox["hoopTi",
    FontSlant->"Italic"],
  StyleBox["mes",
    FontSlant->"Italic"],
  " creates the product and both remainders, which are {0,0..} if different \
zeroes are not involved.\nA general function ",
  StyleBox["muldiv",
    FontSlant->"Italic"],
  " is set up to demonstrate remainders. (The details are irrelevant to \
non-users of Mathematica):-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(muldiv[Ao_, Bo_, H_] := 
        Module[{s = Length[sh[H]], z = Table[0, {i, 32}]}, gmn = H; 
          glo = ToExpression[H]; mm = Length[glo]; 
          s = Take[Flatten[{"\<shape no.\>", Range[s]}]]; 
          A = Take[Flatten[Append[Ao, z]], mm]; 
          B = Take[Flatten[Append[Bo, z]], mm]; 
          Print[{Flatten[Append[{"\<A  =\>"}, A]], 
                Flatten[Append[{"\<B  =\>"}, B]], \[IndentingNewLine]Flatten[
                  Append[{"\<AB =\>"}, 
                    AB = hoopTimes[A, B]]], \[IndentingNewLine]Flatten[
                  Append[{"\<Rl =\>"}, R1 = Rl]], \[IndentingNewLine]Flatten[
                  Append[{"\<Rr =\>"}, R2 = Rr]]} // 
              tf]; \[IndentingNewLine]Print[{s, 
                Flatten[Append[{"\<shA  =\>"}, shape[A]]], 
                Flatten[Append[{"\<shB  =\>"}, shape[B]]], 
                Flatten[Append[{"\<shAB =\>"}, shape[AB]]], 
                Flatten[Append[{"\<shRl =\>"}, shape[Rl]]], 
                Flatten[Append[{"\<shRr =\>"}, shape[Rr]]]} // 
              tf]; {Print["\<AB/B+Rl=A  \>", 
              hoopTimes[AB, hoopInverse[B]] + R1, "\<\nAB/A+Rr=B  \>", 
              hoopTimes[hoopInverse[A], AB] + R2]};];\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[TextData[{
  StyleBox["Figure 12.",
    FontWeight->"Bold"],
  " The C3C2 algebra is used. A is chosen to have the first size zero, B to \
have the second and fourth zero, so AB has only the third size non-zero. Rl & \
Rr have the shapes that are missing from AB:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Figure\ 12*) \)\(muldiv[{2, 1, \(-2\), \(-2\), 3, \(-2\)}, {3, 
          1, 1, 3, 1, 1}, "\<C3C2\>"];\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"A  =\"\>", "2", "1", \(-2\), \(-2\), "3", \(-2\)},
              {"\<\"B  =\"\>", "3", "1", "1", "3", "1", "1"},
              {"\<\"AB =\"\>", "0", "8", \(-8\), "0", "8", \(-8\)},
              {"\<\"Rl =\"\>", "2", \(-1\), "0", \(-2\), "1", "0"},
              {"\<\"Rr =\"\>", \(5\/3\), \(5\/3\), \(5\/3\), \(5\/3\), \(5\/3\
\), \(5\/3\)}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print"],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"shape no.\"\>", "1", "2", "3", "4"},
              {"\<\"shA  =\"\>", "0", "2", "48", "28"},
              {"\<\"shB  =\"\>", "10", "0", "16", "0"},
              {"\<\"shAB =\"\>", "0", "0", "768", "0"},
              {"\<\"shRl =\"\>", "0", "2", "0", "28"},
              {"\<\"shRr =\"\>", "10", "0", "0", "0"}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print"],

Cell[BoxData[
    InterpretationBox[\("AB/B+Rl=A  "\[InvisibleSpace]{2, 1, \(-2\), \(-2\), 
          3, \(-2\)}\[InvisibleSpace]"\nAB/A+Rr=B  "\[InvisibleSpace]{3, 1, 
          1, 3, 1, 1}\),
      SequenceForm[ 
      "AB/B+Rl=A  ", {2, 1, -2, -2, 3, -2}, "\nAB/A+Rr=B  ", {3, 1, 1, 3, 1, 
        1}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Figure 13.",
    FontWeight->"Bold"],
  " Non-abelian D3 is used; two of the sizes of B are zero and Rl contains \
the sizes ejected from A:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Figure\ 13. *) \)\(muldiv[{2, 1, \(-2\), 2, 3, \(-2\)}, {3, 1, 
          1, 3, 1, 1}, "\<D3\>"];\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"A  =\"\>", "2", "1", \(-2\), "2", "3", \(-2\)},
              {"\<\"B  =\"\>", "3", "1", "1", "3", "1", "1"},
              {"\<\"AB =\"\>", "12", "12", \(-4\), "12", "12", \(-4\)},
              {"\<\"Rl =\"\>", \(4\/3\), \(1\/3\), \(-\(8\/3\)\), \(4\/3\), \
\(7\/3\), \(-\(8\/3\)\)},
              {"\<\"Rr =\"\>", "0", "0", "0", "0", "0", "0"}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print"],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"shape no.\"\>", "1", "2", "3"},
              {"\<\"shA  =\"\>", "4", "2", "8"},
              {"\<\"shB  =\"\>", "10", "0", "0"},
              {"\<\"shAB =\"\>", "40", "0", "0"},
              {"\<\"shRl =\"\>", "0", "2", "8"},
              {"\<\"shRr =\"\>", "0", "0", "0"}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print"],

Cell[BoxData[
    InterpretationBox[\("AB/B+Rl=A  "\[InvisibleSpace]{2, 1, \(-2\), 2, 
          3, \(-2\)}\[InvisibleSpace]"\nAB/A+Rr=B  "\[InvisibleSpace]{3, 1, 
          1, 3, 1, 1}\),
      SequenceForm[ 
      "AB/B+Rl=A  ", {2, 1, -2, 2, 3, -2}, "\nAB/A+Rr=B  ", {3, 1, 1, 3, 1, 
        1}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Figure 14.",
    FontWeight->"Bold"],
  " P4 is a non-abelian group with one size; the Pauli-\[Sigma] matrices \
provide a representation. It gives a complex product from real vectors. As \
the size is ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`c\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`d\^2\)]],
  ", real vectors can have a size of zero (the \"light-cone\" of relativity.) \
A is chosen to have size 0, so the remainder for B is all of B:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Figure\ 14. *) \)\(muldiv[{5, 4, 0, 3}, {2, 1, 4, 
          3}, "\<P4\>"];\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"A  =\"\>", "5", "4", "0", "3"},
              {"\<\"B  =\"\>", "2", "1", "4", "3"},
              {"\<\"AB =\"\>", 
                "23", \(13 + 12\ \[ImaginaryI]\), \(20 + 
                  9\ \[ImaginaryI]\), \(21 - 16\ \[ImaginaryI]\)},
              {"\<\"Rl =\"\>", "0", "0", "0", "0"},
              {"\<\"Rr =\"\>", "2", "1", "4", "3"}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print"],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"shape no.\"\>", "1"},
              {"\<\"shA  =\"\>", "0"},
              {"\<\"shB  =\"\>", \(-22\)},
              {"\<\"shAB =\"\>", "0"},
              {"\<\"shRl =\"\>", "0"},
              {"\<\"shRr =\"\>", \(-22\)}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print"],

Cell[BoxData[
    InterpretationBox[\("AB/B+Rl=A  "\[InvisibleSpace]{5, 4, 0, 
          3}\[InvisibleSpace]"\nAB/A+Rr=B  "\[InvisibleSpace]{2, 1, 4, 3}\),
      SequenceForm[ 
      "AB/B+Rl=A  ", {5, 4, 0, 3}, "\nAB/A+Rr=B  ", {2, 1, 4, 3}],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.6. Polar and Hyperbolic Duals.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary. ",
  StyleBox["Some hoops have quadratic sizes that can be written as sums or \
differences of squared terms. In many cases, their cartesian forms can be \
converted to polar-duals or hyperbolic-duals in which each quadratic size is \
a squared radius (or \"ulna\" in the hyperbolic case) associated with an \
angle that can be calculated by an ArcTan (or ArcTanh) function. These duals \
generalize the complex plane; angles add on abelian multiplication.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tMany hoops have Polar, as well as Cartesian, forms because they have \
quadratic sizes that \"fragment\" into sums of squares. The polar form (here \
called ",
  StyleBox["pA",
    FontSlant->"Italic"],
  ") is given by ",
  StyleBox["toPolar[A]",
    FontSlant->"Italic"],
  ", and the cartesian form is recovered by ",
  StyleBox["toVector[pA]",
    FontSlant->"Italic"],
  ". The polar forms have squared radii and angles, and often involve linear \
\"offsets\" such as ",
  StyleBox["a+b+c, a+b+c+d, a-b+c-d",
    FontSlant->"Italic"],
  " that are conserved on addition as well as on multiplication The forms for \
the radii and angles are exemplified by those of C3 & C4:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 15.",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "Typical Polar-duals."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(toPolar[{a, b, c}, "\<C3\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + 
        c, \(1\/2\) \((\((a - b)\)\^2 + \((a - c)\)\^2 + \((b - c)\)\^2)\), 
      ArcTan[2  a - b - 
          c, \(\(-\)\(\ \)\) \(\(3\^\(1\/2\)\) \((b - c)\)\)]}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(toPolar[{a, b, c, d}, "\<C4\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c + d, a - b + c - d, \((a - c)\)\^2 + \((b - d)\)\^2, 
      ArcTan[a - c, b - d]}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tIn Figure 16, the C4 algebra is used to multiply arbitrary real A & B; the \
polar form pA=toPolar[A] is found; toVector[pA] is shown to recover A. The \
two linear offsets, the squared radii and the angles are tabulated for A, B, \
and AB. The zeroes in the last two lines show that sizes multiply and angles \
add:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 16.",
    FontWeight->"Bold"],
  " Interconversion between C4 vector & polar"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(hoopShape["\<C4\>"]; {Flatten[
            Append[{"\<A =\>"}, A = {2. , 0.5, 1. , 0.1}]], 
          Flatten[Append[{"\<B =\>"}, B = {3. ,  .7, 2.5,  .5}]], 
          Flatten[Append[{"\<AB=\>"}, AB = hoopTimes[A, B]]]} // tf\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Chop", "[", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\"\<\>\"", " ", ",", "\"\<\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",\nFontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",\nFontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"(\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\()\^2\),\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\()\^2\),\nFontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"angle\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"or\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",\nFontSlant->\"Italic\"]\)\>\""}], "}"}], 
            ",", \(Flatten[Append[{"\<pA=\>"}, pA = toPolar[A]]]\), 
            ",", \(Flatten[Append[{"\<toVector[pA]\>"}, toVector[pA]]]\), 
            ",", \(Flatten[Append[{"\<pB=\>"}, pB = toPolar[B]]]\), 
            ",", \(Flatten[Append[{"\<pAB=\>"}, pAB = toPolar[AB]]]\), 
            ",", \(Flatten[Append[{"\<pA pB-pAB\>"}, pA\ pB - pAB]]\), 
            ",", \(Flatten[Append[{"\<pA+pB-pAB\>"}, pA + pB - pAB]]\)}], 
          "}"}], "]"}], "//", "tf"}]}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"A =\"\>", "2.`", "0.5`", "1.`", "0.1`"},
            {"\<\"B =\"\>", "3.`", "0.7`", "2.5`", "0.5`"},
            {"\<\"AB=\"\>", "8.82`", "3.65`", "8.4`", "3.25`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"\"\>", "\<\"\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"+\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"b\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"+\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"c\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"+\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"d\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "\<\"\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"-\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"b\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"+\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"c\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"-\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"d\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "\<\"\\!\\(\\* \
StyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"a\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"c\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\()\\^2\\),\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"+\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"b\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"d\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\()\\^2\\),\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "\<\"\\!\\(\\* \
StyleBox[\\\"angle\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"or\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"d\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>"},
            {"\<\"pA=\"\>", "3.6`", "2.4`", "1.1600000000000001`", 
              "0.3805063771123649`"},
            {"\<\"toVector[pA]\"\>", "2.`", "0.5000000000000001`", 
              "0.9999999999999999`", "0.1`"},
            {"\<\"pB=\"\>", "6.7`", "4.3`", "0.29`", "0.3805063771123648`"},
            {"\<\"pAB=\"\>", "24.12`", "10.32`", "0.33639999999999987`", 
              "0.7610127542247297`"},
            {"\<\"pA pB-pAB\"\>", "0", "0", "0", \(-0.6162276512015525`\)},
            {"\<\"pA+pB-pAB\"\>", \(-13.82`\), \(-3.620000000000001`\), 
              "1.1136000000000004`", "0"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tSome algebras, with sizes expressible as differences of squares, have \
hyperbolic dual formulations with hyperbolic angles and squared \"ulnae\" \
(named by analogy with radii). Thus the ",
  StyleBox["(a+b+c+d)",
    FontSlant->"Italic"],
  " and ",
  StyleBox["(a-b+c-d)",
    FontSlant->"Italic"],
  " sizes of the C4 algebra lead to conservation of ",
  Cell[BoxData[
      \(TraditionalForm\`\((a + c)\)\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`\((b + d)\)\^2\)]],
  " and a hyperbolic angle ArcTanh[a+c, b+d]. This has to be written in the \
logarithmic form for full generality, and the infinite case has to be allowed \
for in the calculation.\n\tExample 17 shows the hyperbolic form of Example \
16. (It has to use \"local variables\" b$, x$ and y$ to handle special \
cases.) The polar components are unchanged, and the two linear sizes are \
replaced by an {ulna, hyperbolic angle} pair. The hyperbolic angles add on \
multiplication."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 17.",
    FontWeight->"Bold"],
  " Interconversion between vector & \"hypolar\". Hyperbolic angle addition. \
"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\({"\<tohyPolar[{a,b,c,d},C4] =\>", 
        tohyPolar[{a, b, c, d}, "\<C4\>"]}\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Chop", "[", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\"\<\>\"", " ", ",", "\"\<\!\(\*
StyleBox[\"(\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\()\^2\),\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\()\^2\),\nFontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"hyperangle\",\nFontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"(\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\()\^2\),\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\()\^2\),\nFontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"angle\",\nFontSlant->\"Italic\"]\)\>\""}], "}"}], 
            ",", \(Flatten[Append[{"\<hA=\>"}, hA = tohyPolar[A]]]\), 
            ",", \(Flatten[Append[{"\<Reverts to A\>"}, tohyVector[hA]]]\), 
            ",", \(Flatten[Append[{"\<hB=\>"}, hB = tohyPolar[B]]]\), 
            ",", \(Flatten[Append[{"\<hAB=\>"}, hAB = tohyPolar[AB]]]\), 
            ",", \(Flatten[Append[{"\<hA hB-hAB\>"}, hA\ hB - hAB]]\), 
            ",", \(Flatten[Append[{"\<hA+hB-hAB\>"}, hA + hB - hAB]]\)}], 
          "}"}], "]"}], "//", "tf"}]}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"tohyPolar[{a,b,c,d},C4] =", {\((a + c)\)\^2 - \((b + d)\)\^2, 
        If[a + c \[Equal] b + d || a + c \[Equal] \(\(-\)\(\ \)\) b - d, 
          If[x$7563 \[NotEqual] 
              0, \[Infinity] \(\( sgn \((y$7563)\)\) Sign[x$7563]\^\(-1\)\), 
            0, 0], b$7563 = 
            Log[N[\((x$7563 + 
                      y$7563)\) \((\((\((x$7563)\)\^2 - \
\((y$7563)\)\^2)\)\^\(1\/2\))\)\^\(-1\)]]; 
          Chop[Re[b$7563] + \((\[ImaginaryI])\) 
                Chop[Im[b$7563]]]], \((a - c)\)\^2 + \((b - d)\)\^2, 
        ArcTan[a - c, b - d]}}\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"\"\>", "\<\"\\!\\(\\* \
StyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"a\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"+\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"c\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\()\\^2\\),\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"-\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"b\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"+\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"d\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\()\\^2\\),\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "\<\"\\!\\(\\* \
StyleBox[\\\"hyperangle\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"\\!\\(\\* StyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"-\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"c\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\()\\^2\\),\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"+\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"b\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"d\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\()\\^2\\),\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "\<\"\\!\\(\\* \
StyleBox[\\\"angle\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>"},
            {"\<\"hA=\"\>", "8.64`", "0.20273255405408228`", 
              "1.1600000000000001`", "0.3805063771123649`"},
            {"\<\"Reverts to A\"\>", "2.0000000000000004`", 
              "0.5000000000000002`", "1.`", "0.10000000000000012`"},
            {"\<\"hB=\"\>", "28.81`", "0.22174625184870195`", "0.29`", 
              "0.3805063771123648`"},
            {"\<\"hAB=\"\>", "248.91839999999996`", "0.4244788059027839`", 
              "0.33639999999999987`", "0.7610127542247297`"},
            {"\<\"hA hB-hAB\"\>", "0", \(-0.3795236219135768`\), 
              "0", \(-0.6162276512015525`\)},
            {"\<\"hA+hB-hAB\"\>", \(-211.46839999999997`\), "0", 
              "1.1136000000000004`", "0"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tMany non-abelian hoops have \"pseudo-polar-duals\" that revert correctly to \
the cartesian form, but do not have additive angles. This is because they \
have repeated determinant factors, and the pseudo-polar-duals are created by \
splitting a repeated quadratic into two sections that are not conserved \
independently. Figure 18 shows this for D3, the smallest non-abelian loop. \
The third size contains six squared fragments, 3 positive and 3 negative. \
These are used to create two {squared radius, angle} pairs that allow \
reversion but give neither conserved radii nor additive angles. (Nor do the \
angles subtract, as I once thought.) Further analysis might resolve this \
problem - I have failed to do so. Non-abelian multiplication appears to \
introduce uncertainty into the polar angles.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 18.",
    FontWeight->"Bold"],
  " D3 has polar reversion without {radius,angle} conservation."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Figure\ 17. *) \)\({"\<Shape of D3 is\>", 
      hoopShape["\<D3\>"], "\<\n\ntoPolar D3 is\>", \
\[IndentingNewLine]toPolar[{a, b, c, d, e, f}]}\[IndentingNewLine]
    \(({Flatten[Append[{"\<A=\>"}, A = {3. , 2. ,  .1, 2. , 1. ,  .4}]], 
          Flatten[Append[{"\<B=\>"}, 
              B = {1. , 3. , \(- .1\),  .2, \(-1. \), 1. }]], 
          Flatten[Append[{"\<AB=\>"}, 
              AB = hoopTimes[A, B]]], \[IndentingNewLine]Flatten[
            Append[{"\<pA\>"}, pA = toPolar[A]]], \[IndentingNewLine]Flatten[
            Append[{"\<Revert pA\>"}, toVector[pA]]], 
          Flatten[Append[{"\<pB\>"}, 
              pB = toPolar[B]]], \[IndentingNewLine]Flatten[
            Append[{"\<Revert pB\>"}, toVector[pB]]], 
          Flatten[Append[{"\<pAB\>"}, pAB = toPolar[AB]]], 
          Flatten[Append[{"\<pA+pB-pAB\>"}, pA + pB - pAB]], 
          Flatten[Append[{"\<pA*pB-pAB\>"}, Chop[pA*pB - pAB]]], 
          Flatten[Append[{"\<pA+pB+pAB\>"}, Chop[pA + pB + pAB]]]} // 
        tf)\)\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Shape of D3 is", {a + b + c + d + e + f, a - b + c - d + e - f, 
        1\/2\ \((\((a - c)\)\^2 - \((b - d)\)\^2 + \((c - e)\)\^2 + \((\(-a\) \
+ e)\)\^2 - \((d - f)\)\^2 - \((\(-b\) + f)\)\^2)\)}, 
      "\n\ntoPolar D3 is", {a + b + c + d + e + f, a - b + c - d + e - f, 
        1\/2\ \((\((a - c)\)\^2 + \((c - e)\)\^2 + \((\(-a\) + e)\)\^2)\) + 
          1\/2\ \((\(-\((b - d)\)\^2\) - \((d - f)\)\^2 - \((\(-b\) + \
f)\)\^2)\), ArcTan[2\ a - c - e, \@3\ \((\(-c\) + e)\)], 
        1\/2\ \((\((a - c)\)\^2 + \((c - e)\)\^2 + \((\(-a\) + e)\)\^2)\), 
        ArcTan[2\ b - d - f, \@3\ \((\(-d\) + f)\)]}}\)], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"A=\"\>", "3.`", "2.`", "0.1`", "2.`", "1.`", "0.4`"},
            {"\<\"B=\"\>", "1.`", "3.`", \(-0.1`\), "0.2`", \(-1.`\), "1.`"},
            {"\<\"AB=\"\>", "9.600000000000001`", "10.7`", "6.88`", "1.86`", 
              "1.5900000000000003`", "4.22`"},
            {"\<\"pA\"\>", "8.5`", \(-0.29999999999999993`\), "4.05`", 
              "0.30800734320987755`", "6.61`", \(-1.0471975511965976`\)},
            {"\<\"Revert pA\"\>", "3.`", "2.0000000000000004`", 
              "0.09999999999999994`", "2.0000000000000004`", 
              "1.0000000000000002`", "0.4000000000000001`"},
            {"\<\"pB\"\>", 
              "4.1`", \(-4.300000000000001`\), \(-3.229999999999999`\), \
\(-0.4659277707138729`\), "3.0100000000000002`", "0.2810349015028136`"},
            {"\<\"Revert pB\"\>", "0.9999999999999999`", 
              "3.`", \(-0.09999999999999994`\), 
              "0.20000000000000018`", \(-1.`\), "1.0000000000000007`"},
            {"\<\"pAB\"\>", "34.85`", 
              "1.2900000000000018`", \(-13.081499999999984`\), \
\(-0.7067647371985014`\), "49.77130000000001`", "0.26074295038658724`"},
            {"\<\"pA+pB-pAB\"\>", \(-22.25`\), \(-5.890000000000002`\), 
              "13.901499999999984`", 
              "0.548844309694506`", \(-40.151300000000006`\), \
\(-1.0269056000803714`\)},
            {"\<\"pA*pB-pAB\"\>", "0", "0", "0", 
              "0.5632555624132204`", \(-29.875200000000007`\), \
\(-0.5550420110411107`\)},
            {"\<\"pA+pB+pAB\"\>", 
              "47.45`", \(-3.3099999999999987`\), \(-12.261499999999984`\), \
\(-0.8646851647024968`\), "59.391300000000015`", \(-0.5054196993071968`\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Figure 19.",
    FontWeight->"Bold"],
  " Clifford(2) Algebra has pseudo-polar reversion but angles do not add."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Figure\ 19. *) \)\({"\<Clifford(2) Shape is \>", 
      hoopShape["\<CL2\>"]}\[IndentingNewLine]
    {Flatten[Append[{"\<A=\>"}, A = {3. , 2. ,  .1,  .3}]], 
        Flatten[Append[{"\<B=\>"}, B = {1. , 3. , \(- .1\),  .7}]], 
        Flatten[Append[{"\<AB=\>"}, 
            AB = hoopTimes[A, B]]], \[IndentingNewLine]Flatten[
          Append[{"\<pA\>"}, pA = toPolar[A]]], \[IndentingNewLine]Flatten[
          Append[{"\<Revert pA\>"}, Chop[toVector[pA]]]], 
        Flatten[Append[{"\<pB\>"}, 
            pB = toPolar[B]]], \[IndentingNewLine]Flatten[
          Append[{"\<Revert pB\>"}, Chop[toVector[pB]]]], 
        Flatten[Append[{"\<pAB\>"}, pAB = toPolar[AB]]], 
        Flatten[Append[{"\<pA+pB-pAB\>"}, pA + pB - pAB]], 
        Flatten[Append[{"\<pA+pB+pAB\>"}, Chop[pA + pB + pAB]]], 
        Flatten[Append[{"\<BA=\>"}, BA = hoopTimes[B, A]]], 
        Flatten[Append[{"\<pBA\>"}, pBA = toPolar[BA]]], 
        Flatten[Append[{"\<pA+pB-pBA\>"}, pA + pB - pBA]], 
        Flatten[Append[{"\<pA+pB+pBA\>"}, Chop[pA + pB + pBA]]]} // 
      tf\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Clifford(2) Shape is ", {a\^2 - b\^2 + c\^2 - d\^2}}\)], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"A=\"\>", "3.`", "2.`", "0.1`", "0.3`"},
            {"\<\"B=\"\>", "1.`", "3.`", \(-0.1`\), "0.7`"},
            {"\<\"AB=\"\>", "9.22`", "11.1`", "0.30000000000000004`", 
              "1.8999999999999997`"},
            {"\<\"pA\"\>", "4.92`", "0.033320995878247196`", "4.09`", 
              "0.14888994760949725`"},
            {"\<\"Revert pA\"\>", "3.`", "2.`", "0.09999999999999998`", 
              "0.30000000000000004`"},
            {"\<\"pB\"\>", \(-8.48`\), \(-0.09966865249116204`\), "9.49`", 
              "0.22923193327699531`"},
            {"\<\"Revert pB\"\>", "0.9999999999999999`", "3.`", \(-0.1`\), 
              "0.7`"},
            {"\<\"pAB\"\>", \(-41.72159999999998`\), "0.03252648539175909`", 
              "126.82`", "0.16952821145792177`"},
            {"\<\"pA+pB-pAB\"\>", 
              "38.16159999999998`", \(-0.09887414200467393`\), \(-113.24`\), 
              "0.2085936694285708`"},
            {"\<\"pA+pB+pAB\"\>", \(-45.28159999999998`\), \
\(-0.033821171221155744`\), "140.4`", "0.5476500923444143`"},
            {"\<\"BA=\"\>", "9.22`", "10.9`", \(-0.7000000000000001`\), 
              "2.8999999999999995`"},
            {"\<\"pBA\"\>", \(-41.721599999999995`\), \(-0.07577653658853419`\
\), "127.22`", "0.26003128958213206`"},
            {"\<\"pA+pB-pBA\"\>", "38.16159999999999`", 
              "0.00942887997561935`", \(-113.64`\), "0.1180905913043605`"},
            {"\<\"pA+pB+pBA\"\>", \(-45.2816`\), \(-0.14212419320144903`\), 
              "140.8`", "0.6381531704686246`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
\tSection 12 returns to duals, showing them to create \"orbits\".\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.7. Powers, Roots, Quadratic equations.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary. ",
  StyleBox["Multiplication of polar-duals multiplies sizes and (if abelian) \
adds angles. This generalizes to powers and roots, in which the sizes are \
raised to the exponent and angles are multiplied by the exponent. Quadratic \
equations can be solved via square roots. If angles exceed 2\[Pi] the results \
are rotated vectors.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["\tAbelian Hoops with polar-duals or hyperbolic-duals have powers \
and roots. (The others may have higher analogues using",
    FontSlant->"Plain"],
  StyleBox[" pseudo",
    FontSlant->"Plain"],
  "-",
  StyleBox["polar-duals, but I have not found them.)  ",
    FontSlant->"Plain"],
  "hoopPower[A,p]",
  StyleBox[" raises A to the power ",
    FontSlant->"Plain"],
  "p",
  StyleBox[", giving the square root if no power is specified. A dual of the \
algebra must be known, because powers involve the multiplication of the \
angle(s) by the exponent. If the result exceeds 2\[Pi], recovering a root \
will give a rotated value with the same sizes.\n",
    FontSlant->"Plain"],
  StyleBox["Figure 20.",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  StyleBox[" Squaring the C3 square root recovers the original. :-",
    FontSlant->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hoopShape["\<C3\>"]; {"\<A=\>", 
      A = {3, 1, 4. }, \*"\"\<\\nIn C3, \!\(\@A\) =\>\"", 
      RootA = hoopPower[A], \*"\"\<\\n(\!\(\@A\)\!\(\()\^2\)\) =\>\"", 
      hoopPower[RootA, 2]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A=", {3, 1, 4.`}, 
      "\nIn C3, \!\(\@A\) =", {1.7789046383311689`, \
\(-0.07325649775906366`\), 1.1227789841740856`}, 
      "\n(\!\(\@A\)\!\(\()\^2\)\) =", {3.0000000000000013`, 
        1.0000000000000007`, 4.000000000000002`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Figure 21.",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  StyleBox[" ",
    FontSlant->"Plain"],
  " High angle Powers give rotated roots,"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\( (*Example\ 7 \( \(b\)\(.\)\)\ *) \), 
      RowBox[{\(hoopShape["\<C4\>"]\), ";", 
        RowBox[{"{", 
          RowBox[{
          "\"\<A=\>\"", ",", \(A = {1.6, 1, 1.4, 0}\), ",", 
            "\"\<\\nIn C4, shape[\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\) is \>\"", ",", \(shape[A]\), ",", 
            "\"\<\\n     and polar A is\>\"", ",", " ", \(toPolar[A]\), ",", 
            "\"\<\\n     with angle             1.3734 \[UpArrow]\\n\!\(\*
StyleBox[\(A\^2\),\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)is \>\"", 
            ",", \(SquareA = hoopPower[A, 2]\), ",", 
            "\"\<\\nwith Polar-dual\>\"", ",", \(toPolar[SquareA]\), ",", 
            "\"\<\\nwith squared sizes & doubled angle \[UpArrow].\\nThe \
square root recovers \!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(hoopPower[SquareA]\), 
            ",", "\"\<\\n\!\(\*
StyleBox[\(A\^3\),\nFontSlant->\"Italic\"]\) takes the angle beyond 2\[Pi] \
\\n\!\(\*
StyleBox[\(A\^3\),\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)is \>\"", 
            ",", \(CubeA = hoopPower[A, 3]\), ",", 
            "\"\<\\nWith Polar-dual\>\"", ",", \(toPolar[CubeA]\), ",", 
            "\"\<\\nNow the cube root of \!\(\*
StyleBox[\(A\^3\),\nFontSlant->\"Italic\"]\)\>\"", 
            ",", \(A3 = hoopPower[CubeA, 1/3]\), ",", 
            "\"\<has the same sizes but a rotated angle\>\"", 
            ",", \(Chop[toPolar[A3]]\)}], "}"}]}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"A=\"\>", ",", \({1.6`, 1, 1.4`, 0}\), 
        ",", "\<\"\\nIn C4, shape[\\!\\(\\* StyleBox[\\\"A\\\",\\nFontSlant->\
\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) is \"\>", 
        ",", \({4.`, 2.`, 1.04`}\), ",", "\<\"\\n     and polar A is\"\>", 
        ",", \({4.`, 2.`, 1.04`, 1.3734007669450157`}\), 
        ",", "\<\"\\n     with angle             1.3734 \
\[UpArrow]\\n\\!\\(\\* \
StyleBox[\\(A\\^2\\),\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)is \"\>", 
        ",", \({4.5200000000000005`, 3.2`, 5.4799999999999995`, 2.8`}\), 
        ",", "\<\"\\nwith Polar-dual\"\>", 
        ",", \({16.`, 4.`, 1.0815999999999986`, 2.746801533890031`}\), 
        ",", "\<\"\\nwith squared sizes & doubled angle \[UpArrow].\\nThe \
square root recovers \\!\\(\\* \
StyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({1.6`, 0.9999999999999998`, 1.4`, 0}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\(A\\^3\\),\\nFontSlant->\\\"Italic\\\"]\\) takes the angle beyond \
2\[Pi] \\n\\!\\(\\* \
StyleBox[\\(A\\^3\\),\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)is \"\>", 
        ",", \({17.704`, 13.56`, 18.296`, 14.44`}\), 
        ",", "\<\"\\nWith Polar-dual\"\>", 
        ",", \({64.`, 7.999999999999998`, 
          1.1248639999999968`, \(-2.1629830063445383`\)}\), 
        ",", "\<\"\\nNow the cube root of \\!\\(\\* \
StyleBox[\\(A\\^3\\),\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({1.8830127018922191`, 0.16339745962155638`, 
          1.1169872981077809`, 0.8366025403784436`}\), 
        ",", "\<\"has the same sizes but a rotated angle\"\>", 
        ",", \({4.`, 1.9999999999999998`, 
          1.0399999999999987`, \(-0.7209943354481795`\)}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tQPower calculates powers in the quaternion algebra (28/1/05), and \
handles complex (biquaternion) elements. It multiplies the angle ",
  StyleBox["t",
    FontSlant->"Italic"],
  " by the power ",
  StyleBox["n",
    FontSlant->"Italic"],
  ". It may lead to better ",
  StyleBox["topolar & toVector",
    FontSlant->"Italic"],
  " formulations for quaternion & other non-abelian hoops; the current \
formulations do not have angle addition."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 22.",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " QPower works with biquaternions (quaternions over the complex field)."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<A =       \>", 
      A = {\  .6 -  .1  \[ImaginaryI],  .5,  .3, \(- .2\) \[ImaginaryI]}, "\<\
\nrootA = \>", 
      rA = QPower[A, 
          1/2], \[IndentingNewLine]\*"\"\<\\n(rootA\!\(\()\^2\)\) = \>\"", 
      Chop[QPower[rA, 
          2]], \[IndentingNewLine]\*"\"\<\\n\!\(A\^2\)     =   \>\"", 
      AA = Chop[QPower[A, 2]], \*"\"\<\\n\!\(\@A\^2\)   =   \>\"", 
      Chop[QPower[AA, 1/2]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A =       ", {\(\(0.6`\)\(\[InvisibleSpace]\)\) - 
          0.1`\ \[ImaginaryI], 0.5`, 0.3`, \(-0.2`\)\ \[ImaginaryI]}, 
      "\nrootA = ", {\(\(0.8411243957355753`\)\(\[InvisibleSpace]\)\) - 
          0.051748712010671424`\ \[ImaginaryI], \(\(0.29610042432253175`\)\(\
\[InvisibleSpace]\)\) + 
          0.018217062377681104`\ \[ImaginaryI], \(\(0.17766025459351903`\)\(\
\[InvisibleSpace]\)\) + 
          0.010930237426608659`\ \[ImaginaryI], \(\(0.007286824951072442`\)\(\
\[InvisibleSpace]\)\) - 0.11844016972901267`\ \[ImaginaryI]}, 
      "\n(rootA\!\(\()\^2\)\) = ", {\(\(0.6`\)\(\[InvisibleSpace]\)\) - 
          0.09999999999999999`\ \[ImaginaryI], 0.5000000000000001`, 
        0.3000000000000001`, \(-0.19999999999999998`\)\ \[ImaginaryI]}, 
      "\n\!\(A\^2\)     =   ", {\(\(0.05000000000000004`\)\(\[InvisibleSpace]\
\)\) - 0.11999999999999997`\ \[ImaginaryI], \(\(0.6`\)\(\[InvisibleSpace]\)\) \
- 0.1`\ \[ImaginaryI], \(\(0.3599999999999999`\)\(\[InvisibleSpace]\)\) - 
          0.05999999999999999`\ \[ImaginaryI], \(-0.039999999999999994`\) - 
          0.23999999999999994`\ \[ImaginaryI]}, 
      "\n\!\(\@A\^2\)   =   ", \
{\(\(0.6000000000000001`\)\(\[InvisibleSpace]\)\) - 0.1`\ \[ImaginaryI], 
        0.5000000000000001`, 
        0.29999999999999993`, \(-0.19999999999999998`\)\ \[ImaginaryI]}}\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "\tQuadratics can be solved in algebras that have powers. ",
  StyleBox["Figure",
    FontSlant->"Plain"],
  " 23 sets up three random C4 vectors A, B, C. Then ",
  StyleBox["genQuadratic",
    FontSlant->"Italic"],
  " is used to solve A ",
  Cell[BoxData[
      \(TraditionalForm\`X\^2\)]],
  "+B ",
  StyleBox["X ",
    FontSlant->"Italic"],
  "== C. Substituting the two results into A ",
  Cell[BoxData[
      \(TraditionalForm\`X\^2\)]],
  "+B ",
  StyleBox["X",
    FontSlant->"Italic"],
  " shows that they are both solutions. Calculating C from  A ",
  Cell[BoxData[
      \(TraditionalForm\`Xo\^2\)]],
  "+B Xo = C and solving for X often does not give Xo as one of the solutions \
because negative sizes and large angles can result in many different \
solutions. The next example uses random coefficients in the range [0.,1.] for \
A, B, & C. Two solutions are found, and validated by recovering C."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 23.",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " Solving a random quadratic equation in C4.  "
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(genShape["\<C4\>"]; 
    Print[{"\<A=\>", 
        A = Table[Random[Real, {\(- .1\), 1. }], {i, mm}], "\<\n B=\>", 
        B = Table[
            Random[Real, {\(- .1\), 1. }], {i, 
              mm}], \[IndentingNewLine]"\<\n C=\>", 
        Cc = Table[
            Random[Real, {\(- .1\), 1. }], {i, 
              mm}], \[IndentingNewLine]\*"\"\<\\nSolutions for x if A \
\!\(x\^2\)+B x=C:-\\n\>\"", 
        result = 
          genQuadratic[A, B, 
            Cc]}]; \*"\"\<A \!\(x\^2\)+B x recovers C in both cases:-\>\""\), \
"\[IndentingNewLine]", 
    \(Chop[
      hoopTimes[result[\([1]\)], 
        B + hoopTimes[A, result[\([1]\)]]]]\), "\[IndentingNewLine]", 
    \(Chop[
      hoopTimes[result[\([2]\)], 
        B + hoopTimes[A, result[\([2]\)]]]]\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"A=", {0.4271149339129312`, 
        0.787609277880221`, \(-0.08221229697021755`\), 0.9800759079133609`}, 
      "\n B=", {0.824270297020966`, 0.7016908311354538`, 
        0.6644551650483096`, \(-0.03420828194168146`\)}, 
      "\n C=", {0.10535315341072343`, 0.3516856349363612`, 
        0.9119650182331155`, 0.5005817268493185`}, 
      "\nSolutions for x if A \!\(x\^2\)+B x=C:-\n", {{0.13978424377953402`, 
          0.3625190201079137`, 
          0.374907744444526`, \(-0.317299129405597`\)}, \
{\(-0.14904792029085084`\), \(-1.4460144084205107`\), \
\(-0.5873634364646417`\), 0.6018661346828986`}}}\)], "Print"],

Cell[BoxData[
    \("A \!\(x\^2\)+B x recovers C in both cases:-"\)], "Output"],

Cell[BoxData[
    \({0.08208135003278766`, 0.37495743831429706`, 0.8886932148551798`, 
      0.5238535302272544`}\)], "Output"],

Cell[BoxData[
    \({0.08208135003278821`, 0.3749574383142975`, 0.8886932148551805`, 
      0.5238535302272549`}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.8. Many Moufang Loops \"Collapse\"  to Hoops.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary.",
  StyleBox[" Hoops are obtained from Moufang loops. These act on sets of \
unsigned coefficients; Algebras operate on signed vectors, usually sets of \
real or complex numbers. Real numbers are obtained from pairs of unsigned \
numbers via a \"folding\" equivalence relationship, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontSlant->"Italic"], "i"], TraditionalForm]]],
  StyleBox["~ {",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)],
    FontSlant->"Italic"],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)],
    FontSlant->"Italic"],
  StyleBox["}; this halves the number of coefficients, and halves the number \
of elements in Moufang loops with 2-fold symmetry - it \"folds\" the loop to \
an algebra. The result may be either smaller Moufang loops, or signed \
multiplication tables such as those for Complex & Quaternion algebras. Most \
of the non-associative Moufang loops [4] are not conservative; only a few \
describe hoops (all associative loops describe hoops).",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tHoops are obtained from Moufang Loops, inheriting vector multiplication \
and division from them. The definition of Moufang loops does not involve \
signs, so they multiply (and divide) sets of unsigned coefficients, but they \
are not algebras because they lack a second operation. They only become \
algebras (hoops) if generalized signs are introduced, as equivalence \
relations on sets of coefficients,  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["h",
            FontSlant->"Plain"], "i"], TraditionalForm]]],
  "~ {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/r\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + 2  m/r\)\)]],
  ", ..} ~ {",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/r\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + 2  m/r\)\)]],
  ", ...}. The general case is discussed in Section 9, but the commonest \
cases, ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=2 or 4, are developed here. ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=2 gives half the number of real coefficients, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontSlant->"Plain"], "i"], " "}], TraditionalForm]]],
  "~ {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  "} ~ {",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/2\)\)]],
  "} iff ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(a\_i\)\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/2\)\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  ". The ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " table \"folds\" to an ",
  StyleBox["(m/r\[Times]m/r)",
    FontSlant->"Italic"],
  " table, which may a smaller (unsigned) Moufang loop or a signed table in \
which some products are signed. Thus C4 is a hoop over the real field because \
it can be regarded as the folded version of C4C2; the highlights in the \
illustration of C4C2 (figure 24) give the C4 table. C4 is also a loop that \
fold to complex algebra, \[DoubleStruckCapitalC]. This is shown by mapping \
{1,\[ImaginaryI],-1,-\[ImaginaryI]} onto the C4 table, and highlighting the \
complex multiplication table that results from folding. This matches the \
signed C4c table, which is complex multiplication.\n\n",
  StyleBox["Figure 24.",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " Collapsing Moufang Tables to Hoops."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[GridBox[{
        {"C4C2", "1", "2", "3", "4", 
          StyleBox["5",
            FontWeight->"Plain"], 
          StyleBox["6",
            FontWeight->"Plain"], 
          StyleBox["7",
            FontWeight->"Plain"], 
          StyleBox["8",
            FontWeight->"Plain"]},
        {" ", "2", "3", "4", "1", 
          StyleBox["6",
            FontWeight->"Plain"], 
          StyleBox["7",
            FontWeight->"Plain"], 
          StyleBox["8",
            FontWeight->"Plain"], 
          StyleBox["5",
            FontWeight->"Plain"]},
        {" ", "3", "4", "1", "2", 
          StyleBox["7",
            FontWeight->"Plain"], 
          StyleBox["8",
            FontWeight->"Plain"], 
          StyleBox["5",
            FontWeight->"Plain"], 
          StyleBox["6",
            FontWeight->"Plain"]},
        {" ", "4", "1", "2", "3", 
          StyleBox["8",
            FontWeight->"Plain"], 
          StyleBox["5",
            FontWeight->"Plain"], 
          StyleBox["6",
            FontWeight->"Plain"], 
          StyleBox["7",
            FontWeight->"Plain"]},
        {" ", 
          StyleBox["5",
            FontWeight->"Plain"], 
          StyleBox["6",
            FontWeight->"Plain"], 
          StyleBox["7",
            FontWeight->"Plain"], 
          StyleBox["8",
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], 
          StyleBox["2",
            FontWeight->"Plain"], 
          StyleBox["3",
            FontWeight->"Plain"], 
          StyleBox["4",
            FontWeight->"Plain"]},
        {" ", 
          StyleBox["6",
            FontWeight->"Plain"], 
          StyleBox["7",
            FontWeight->"Plain"], 
          StyleBox["8",
            FontWeight->"Plain"], 
          StyleBox["5",
            FontWeight->"Plain"], 
          StyleBox["2",
            FontWeight->"Plain"], 
          StyleBox["3",
            FontWeight->"Plain"], 
          StyleBox["4",
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"]},
        {" ", 
          StyleBox["7",
            FontWeight->"Plain"], 
          StyleBox["8",
            FontWeight->"Plain"], 
          StyleBox["5",
            FontWeight->"Plain"], 
          StyleBox["6",
            FontWeight->"Plain"], 
          StyleBox["3",
            FontWeight->"Plain"], 
          StyleBox["4",
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], 
          StyleBox["2",
            FontWeight->"Plain"]},
        {" ", 
          StyleBox["8",
            FontWeight->"Plain"], 
          StyleBox["5",
            FontWeight->"Plain"], 
          StyleBox["6",
            FontWeight->"Plain"], 
          StyleBox["7",
            FontWeight->"Plain"], 
          StyleBox["4",
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], 
          StyleBox["2",
            FontWeight->"Plain"], 
          StyleBox["3",
            FontWeight->"Plain"]}
        }]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[GridBox[{
        {"C4", "1", "\[ImaginaryI]", 
          StyleBox[\(-1\),
            FontWeight->"Plain"], 
          StyleBox[\(-\[ImaginaryI]\),
            FontWeight->"Plain"], " ", "C4c", "1", "2", " ", 
          "\[DoubleStruckCapitalC]", "1", "\[ImaginaryI]"},
        {" ", "\[ImaginaryI]", \(-1\), 
          StyleBox[\(-\[ImaginaryI]\),
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], " ", " ", "2", \(-1\), " ", " ", 
          "\[ImaginaryI]", \(-1\)},
        {" ", 
          StyleBox[\(-1\),
            FontWeight->"Plain"], 
          StyleBox[\(-\[ImaginaryI]\),
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], 
          StyleBox["\[ImaginaryI]",
            FontWeight->"Plain"], " ", " ", " ", "  ", " ", " ", " ", " "},
        {" ", 
          StyleBox[\(-\[ImaginaryI]\),
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], 
          StyleBox["\[ImaginaryI]",
            FontWeight->"Plain"], 
          StyleBox[\(-1\),
            FontWeight->"Plain"], " ", " ", " ", " ", " ", " ", " ", " "}
        }]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"A =\"\>", "2.`", "0.5`", "1.`", "0.1`"},
            {"\<\"B =\"\>", "3.`", "0.7`", "2.5`", "0.5`"},
            {"\<\"AB=\"\>", "8.82`", "3.65`", "8.4`", "3.25`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth]
}, Closed]],

Cell[TextData[{
  "The C4 multiplication of {2., 0.5, 1., 0.1} and {3., .7, 2.5, .5} (in Fig. \
16) gave {8.82, 3.65, 8.4, 3.25}. These vectors fold to complex numbers \
(2-1)+(.5-.1)\[ImaginaryI] and (3-2.5)+(.7-.5)\[ImaginaryI], with product \
(8.82-8.4)+(3.65-3.25)\[ImaginaryI]; i.e. (1+.4\[ImaginaryI])(.5+.2\
\[ImaginaryI]) = .42+.4\[ImaginaryI]. \nThis is confirmed in ",
  StyleBox["Figure 25:-",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", 
        RowBox[{
          StyleBox["Figure",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontSlant->"Plain"], 
          StyleBox["25.",
            FontSlant->"Plain"], " ", "C4", " ", "example", " ", "folds", " ",
           "to", " ", "C4c"}], 
        "*)"}], \({"\< {(2-1),(.5-.1)}*{(3-2.5),(.7-.5)}\n\
~.42+.4\[ImaginaryI]\>", "\<\nC4c product folds to (1+.4\[ImaginaryI])(.5+.2\
\[ImaginaryI]) & gives\>", 
        hoopTimes[{\((2 - 1)\), \(( .5 -  .1)\)}, {\((3 - 
                2.5)\), \(( .7 -  .5)\)}, "\<C4c\>"]}\)}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({" {(2-1),(.5-.1)}*{(3-2.5),(.7-.5)}\n~.42+.4\[ImaginaryI]", 
      "\nC4c product folds to (1+.4\[ImaginaryI])(.5+.2\[ImaginaryI]) & \
gives", {0.42000000000000004`, 0.39999999999999997`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  "The properties of complex algebra result from the Moufang & Frobenius \
properties of C4. The rules for quaternion and octonion algebras arise \
similarly, from the Q8 and Oct tables. As their determinant factors are \
(repeated) sums of the squares of their elements, they are \"real algebras \
without divisors of zero\".\n\tAfter finding several conservative tables \
related to Octonions, I conjectured that all non-associative Moufang Loops \
might be conservative. This was comprehensively disproved by the examples in \
[4]; on testing the 88 with up to 36 elements, only 7 were hoops. Figure 24a \
shows these, together with the non-hoop 12 & 20 element cases, and 4 larger \
nonassociative hoops composed from Oct."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 24a.",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " A few nonassociative Moufang Tables are conservative."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({conservativeQ[mp["\<D3Mn\>"]], conservativeQ[mp["\<Q8M2\>"]], 
      conservativeQ[Oct], conservativeQ[mp["\<D5Mn\>"]], 
      conservativeQ[mp["\<P16M\>"]], conservativeQ[mp["\<OctC2\>"]], 
      conservativeQ[mp["\<C8pC2M\>"]], conservativeQ[mp["\<KiC4M\>"]], 
      conservativeQ[C4iC4M], conservativeQ[co[Oct, C3]], 
      conservativeQ[co[Oct, C4]], conservativeQ[co[Oct, K]], 
      conservativeQ[co[Oct, C5]]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({False, True, True, False, True, True, True, True, True, True, True, 
      True, True}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tOct and Q8M2 are the two 16 element non-associative Moufang loops. They \
each have 8 linear and one quadratic size, and fold to the signed tables for \
the \"Octr\" Octonion and the \"Octi\" (\"Split-Octonion\" in Wikipedia) \
algebras. Q8M2 operations were demonstrated in Figure 10a. Figure 24b gives \
the shapes of these algebras\n\tOcti is an algebra with divisors of zero and \
signature {4,4} as it conserves {",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`c\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`d\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`e\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`f\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`g\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`h\^2\)]],
  "}. Oct and Q8M2 have one quadratic and 8 linear sizes and the linear sizes \
produce divisors of zero."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 24b.",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " Conservative nonassociative Octonion and \"Split-octonion\" Algebras."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Q8M2 shape\>", sh["\<Q8M2\>"], "\<\nOct shape\>", 
      sh["\<Oct\>"], "\<\nOcti shape\>", sh["\<Octi\>"], "\<\nOctr shape\>", 
      sh["\<Octr\>"]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Q8M2 shape", {a + b + c + d + e + f + g + h - i - j - k - l - m - n - 
          o - p, a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - 
          p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
        a - b - c + d + e - f - g + h - i + j + k - l - m + n + o - p, 
        a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + p, 
        a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p, 
        a + b - c - d + e + f - g - h - i - j + k + l - m - n + o + p, 
        a + b + c + d + e + f + g + h + i + j + k + l + m + n + o + 
          p, \((a - e)\)\^2 + \((b - f)\)\^2 + \((c - g)\)\^2 + \((d - \
h)\)\^2 - \((i - m)\)\^2 - \((j - n)\)\^2 - \((k - o)\)\^2 - \((l - p)\)\^2}, 
      "\nOct shape", {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
          o + p, a - b - c + d + e - f - g + h + i - j - k + l + m - n - o + 
          p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
        a + b - c - d + e + f - g - h + i + j - k - l + m + n - o - p, 
        a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p, 
        a + b - c - d - e - f + g + h + i + j - k - l - m - n + o + p, 
        a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - p, 
        a - b - c + d - e + f + g - h + i - j - k + l - m + n + o - 
          p, \((a - i)\)\^2 + \((b - j)\)\^2 + \((c - k)\)\^2 + \((d - \
l)\)\^2 + \((e - m)\)\^2 + \((f - n)\)\^2 + \((g - o)\)\^2 + \((h - p)\)\^2}, 
      "\nOcti shape", {a\^2 - b\^2 + c\^2 - d\^2 + e\^2 - f\^2 + g\^2 - 
          h\^2}, "\nOctr shape", {a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + 
          g\^2 + h\^2}}\)], "Output"]
}, Open  ]],

Cell["\<\
\tOf the 88 non-associative Moufang loops with up to 36 elements in [4], only \
M1602 (Q8M2), M1603 (Oct), M3202 (Q8C2M), M3216 (OctC2), M3221 (P16M), M3235 \
(C8pC2M), M3254 (KiC4M), and M3265 (C4iC4M) are conservative. They are all \
hoops, becase their compositions with C2, C3, C4, K, etc. are conservative. \
Figure 24c gives some examples. I have not found (folded) signed tables for \
P16M, C8pC2M, KiC4M or C4iC4M; these are related to the corresponding groups \
(without M) via a \"Moufang modification\". Unlike D3Mn, their diagonals do \
not preclude a folded version.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Figure 24c.",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " Composition of conservative nonassociative Moufang Loops with C2, C3, C4 \
& K gives conservative hoops."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({conservativeQ[co[mp["\<P16M\>"], C2]], 
      conservativeQ[co[mp["\<C8pC2M\>"], C3]], 
      conservativeQ[co[mp["\<KiC4M\>"], K]], 
      conservativeQ[co[mp["\<C4iC4M\>"], C4]]}\)], "Input"],

Cell[BoxData[
    \({True, True, True, True}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.9. \"Generalized signs\" fold unsigned numbers and Moufang loops.\
\>", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary.",
  StyleBox[" The signs {1,\[ImaginaryI],-1,-\[ImaginaryI]} or {",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^\(\(\ \)\(0\)\)\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^\(\(\ \)\(1\)\)\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^\(\(\ \)\(2\)\)\)]],
  StyleBox[",",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^\(\(\ \)\(3\)\)\)]],
  StyleBox["} are the r=4 (complex) case of generalised signs ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^j\)]],
  StyleBox["where ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^r\)]],
  StyleBox["=+1 & 0\[LessEqual]j<r. Other algebras use other r values, e.g. \
r=3 gives Terplex algebra. m\[Times] m Moufang loops operate on sets of m \
unsigned coefficients, but if they have r-fold symmetry they can be folded to \
(m/r)\[Cross](m/r) hoop tables that  multiply vectors with m/r \"r-signed\" \
coefficients. These tables inherit the Moufang and Frobenius properties, but \
some sizes are destroyed by folding.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tSection 8 demonstrated the folding of Moufang loops with 2-fold symmetry \
to introduce the traditional \"-\" sign. Many hoops in the database involve \
\"generalized signs\", (\"-\", \[DoubleStruckCapitalJ], \[ImaginaryI]), that \
are primitive roots of unity - e.g. ",
  Cell[BoxData[
      \("-"\^2\)], "Output"],
  "=+1, ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^3\)]],
  "=+1, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^4\)]],
  "=+1. (They should not be confused with the cyclotomic numbers, which are \
points in the complex plane). The package defines \[DoubleStruckCapitalJ] and \
some other signs (e.g. ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckK]\^2\)]],
  "=1, \[DoubleStruckK] distinct from \"-\") as extensions to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". (Only \[ImaginaryI] & \[DoubleStruckCapitalJ] are used in this notebook, \
but the generalization is explained for completeness). These numbers resemble \
\[ImaginaryI] but are not real, not (apart from \[ImaginaryI]) complex, not \
positive, not negative; they are their own sign and have an absolute value \
(magnitude) of 1. The general case \[DoubleStruckS] is set up as the ",
  StyleBox["r",
    FontSlant->"Italic"],
  "'th root of unity, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^r\)]],
  "=1. A ",
  StyleBox["minSign",
    FontSlant->"Italic"],
  " function is provided to reduce the powers of any signs in an expression \
to the minimum range ",
  StyleBox["0\[LessEqual]j<r",
    FontSlant->"Italic"],
  ". \n\tEach signed table has been obtained from a larger Moufang table that \
(because negation is not required in the definition of Moufang loops) \
consists of unsigned indices. Moufang coefficients may be operators, but if \
they are numbers they are therefore fundamentally \"unsigned\", i.e. natural \
numbers, unsigned rational numbers, or unsigned (non-negative) continuous \
numbers (for which I propose the name Primal numbers.) Signed numbers are \
equivalence relations on sets of unsigned numbers. Thus, Real coefficients \
are equivalence relations on pairs of primal numbers, ",
  Cell[BoxData[
      \(TraditionalForm\`r\_i\)]],
  "~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  "}~ {",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/2\)\)]],
  "}, -",
  Cell[BoxData[
      \(TraditionalForm\`r\_i\)]],
  "~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "}, 0~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "} with the relationship ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/2\)\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ". Complex coefficients are equivalence relations on quads of real numbers, \
",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  "~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/4\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + 3  m/4\)\)]],
  "}, -",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  "~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + 3  m/4\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/4\)\)]],
  "} with the relationships ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/2\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/4\)\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + 3  m/4\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + 3  m/4\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/4\)\)]],
  ". Terplex coefficients, with signs {1,\[DoubleStruckCapitalJ], ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^2\)]],
  "} are equivalence relations on triples of primal numbers, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\_i\)\(\ \)\)\)]],
  "~ {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/3\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + 2  m/3\)\)]],
  "}, \[DoubleStruckCapitalJ]",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\_i\)\(\ \)\)\)]],
  "~ {",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/3\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + 2  m/3\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "}, ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\_i\)\(\ \)\)\)]],
  "~ {",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/3\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + 2  m/3\)\)]],
  "} with the relationship ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i + m/3\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/3\)\)]],
  "+",
  Cell[BoxData[
      FormBox[
        RowBox[{\(b\_i\), "=", 
          RowBox[{
            FormBox[\(a\_\(i + 2  m/2\)\),
              "TraditionalForm"], "+", 
            FormBox[\(b\_i\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". I call the equivalencing of 2, 3, 4 or more primal coefficients to a \
single real, terplex, complex or hypercomplex (etc) number \"folding\". \n\t\
Signed tables are produced by folding Moufang Loops that have suitable \
symmetry. A Moufang table of size ",
  StyleBox["m\[Times]m ",
    FontSlant->"Italic"],
  "can be folded to a signed table of size ",
  StyleBox["(m/r)\[Times](m/r)",
    FontSlant->"Italic"],
  " if it has ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry. The unsigned tables consist of ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " blocks (of size ",
  StyleBox["(m/r)\[Times](m/r)",
    FontSlant->"Italic"],
  ") that are repeated with offsets. Twofold folding gives the top left ",
  StyleBox["(m/2)\[Cross](m/2)",
    FontSlant->"Italic"],
  " table; indices greater than r become negated smaller indices. Threefold \
folding gives a ",
  StyleBox["(m/3)\[Cross](m/3)",
    FontSlant->"Italic"],
  " table that may involve \[DoubleStruckCapitalJ]."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 26.",
    FontWeight->"Bold"],
  " Collapsing the unsigned C6, Quaternion (Q8) and C9 tables to signed Hoop \
tables."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[GridBox[{
        {
          RowBox[{
            RowBox[{"C6", "=", 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "2", "3", " ", 
                      StyleBox["4",
                        FontWeight->"Plain"], 
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"]},
                    {"2", "3", "4", " ", 
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"]},
                    {"3", "4", "5", " ", 
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"], 
                      StyleBox["2",
                        FontWeight->"Plain"]},
                    {" ", " ", " ", " ", 
                      StyleBox[" ",
                        FontWeight->"Plain"], 
                      StyleBox[" ",
                        FontWeight->"Plain"], 
                      StyleBox[" ",
                        FontWeight->"Plain"]},
                    {
                      StyleBox["4",
                        FontWeight->"Plain"], 
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"], " ", "1", "2", "3"},
                    {
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"], " ", "2", "3", "4"},
                    {
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"], 
                      StyleBox["2",
                        FontWeight->"Plain"], " ", "3", "4", "5"}
                    },
                  ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
            "\[IndentingNewLine]"}], 
          RowBox[{
            RowBox[{"C3C2c", "=", 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "2", "3"},
                    {"2", "3", \(-1\)},
                    {"3", \(-1\), \(-2\)}
                    },
                  ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
            "\[IndentingNewLine]", \(\(\(4\  &\)\ 5\ \ become\  - 1\  &\)\  - 
              2\)}]},
        {
          RowBox[{"Q8", "=", 
            RowBox[{"(", GridBox[{
                  {"1", "2", "3", "4", " ", 
                    StyleBox["5",
                      FontWeight->"Plain"], 
                    StyleBox["6",
                      FontWeight->"Plain"], 
                    StyleBox["7",
                      FontWeight->"Plain"], 
                    StyleBox["8",
                      FontWeight->"Plain"]},
                  {"2", "5", "8", "3", " ", 
                    StyleBox["6",
                      FontWeight->"Plain"], 
                    StyleBox["1",
                      FontWeight->"Plain"], 
                    StyleBox["4",
                      FontWeight->"Plain"], 
                    StyleBox["7",
                      FontWeight->"Plain"]},
                  {"3", "4", "5", "6", " ", 
                    StyleBox["7",
                      FontWeight->"Plain"], 
                    StyleBox["8",
                      FontWeight->"Plain"], 
                    StyleBox["1",
                      FontWeight->"Plain"], 
                    StyleBox["2",
                      FontWeight->"Plain"]},
                  {"4", "7", "2", "5", " ", 
                    StyleBox["8",
                      FontWeight->"Plain"], 
                    StyleBox["3",
                      FontWeight->"Plain"], 
                    StyleBox["6",
                      FontWeight->"Plain"], 
                    StyleBox["1",
                      FontWeight->"Plain"]},
                  {
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], " ", 
                    StyleBox[" ",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontWeight->"Bold"]},
                  {
                    StyleBox["5",
                      FontWeight->"Plain"], 
                    StyleBox["6",
                      FontWeight->"Plain"], 
                    StyleBox["7",
                      FontWeight->"Plain"], 
                    StyleBox["8",
                      FontWeight->"Plain"], " ", 
                    StyleBox["1",
                      FontWeight->"Bold"], 
                    StyleBox["2",
                      FontWeight->"Bold"], 
                    StyleBox["3",
                      FontWeight->"Bold"], 
                    StyleBox["4",
                      FontWeight->"Bold"]},
                  {
                    StyleBox["6",
                      FontWeight->"Plain"], 
                    StyleBox["1",
                      FontWeight->"Plain"], 
                    StyleBox["4",
                      FontWeight->"Plain"], 
                    StyleBox["7",
                      FontWeight->"Plain"], " ", 
                    StyleBox["2",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Bold"], 
                    StyleBox["8",
                      FontWeight->"Bold"], 
                    StyleBox["3",
                      FontWeight->"Bold"]},
                  {
                    StyleBox["7",
                      FontWeight->"Plain"], 
                    StyleBox["8",
                      FontWeight->"Plain"], 
                    StyleBox["1",
                      FontWeight->"Plain"], 
                    StyleBox["2",
                      FontWeight->"Plain"], " ", 
                    StyleBox["3",
                      FontWeight->"Bold"], 
                    StyleBox["4",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Bold"], 
                    StyleBox["6",
                      FontWeight->"Bold"]},
                  {
                    StyleBox["8",
                      FontWeight->"Plain"], 
                    StyleBox["3",
                      FontWeight->"Plain"], 
                    StyleBox["6",
                      FontWeight->"Plain"], 
                    StyleBox["1",
                      FontWeight->"Plain"], " ", 
                    StyleBox["4",
                      FontWeight->"Bold"], 
                    StyleBox["7",
                      FontWeight->"Bold"], 
                    StyleBox["2",
                      FontWeight->"Bold"], 
                    StyleBox["5",
                      FontWeight->"Bold"]}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
          RowBox[{
            RowBox[{"Qr", "=", 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "2", "3", "4"},
                    {"2", \(-1\), \(-4\), "3"},
                    {"3", "4", \(-1\), \(-2\)},
                    {"4", \(-3\), "2", \(-1\)}
                    },
                  ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
            "\[IndentingNewLine]", 
            StyleBox[\({5, 6, 7, 8}\ \ becomes\),
              "Text"], 
            StyleBox["\[IndentingNewLine]",
              "Text"], 
            StyleBox[\({\(-1\), \(-2\), \(-3\), \(-4\)}\),
              "Text"], 
            StyleBox["\[IndentingNewLine]",
              "Text"]}]},
        {
          RowBox[{"C9", "=", 
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "2", "3", "  ", 
                      StyleBox["4",
                        FontWeight->"Plain"], 
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"], " ", 
                      StyleBox["7",
                        FontWeight->"Plain"], 
                      StyleBox["8",
                        FontWeight->"Plain"], 
                      StyleBox["9",
                        FontWeight->"Plain"]},
                    {"2", "3", "4", " ", 
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["7",
                        FontWeight->"Plain"], " ", 
                      StyleBox["8",
                        FontWeight->"Plain"], 
                      StyleBox["9",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"]},
                    {"3", "4", "5", " ", 
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["7",
                        FontWeight->"Plain"], 
                      StyleBox["8",
                        FontWeight->"Plain"], " ", 
                      StyleBox["9",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"], 
                      StyleBox["2",
                        FontWeight->"Plain"]},
                    {" ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " "},
                    {
                      StyleBox["4",
                        FontWeight->"Plain"], 
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"], " ", 
                      StyleBox["7",
                        FontWeight->"Plain"], 
                      StyleBox["8",
                        FontWeight->"Plain"], 
                      StyleBox["9",
                        FontWeight->"Plain"], " ", "1", "2", "3"},
                    {
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["7",
                        FontWeight->"Plain"], " ", 
                      StyleBox["8",
                        FontWeight->"Plain"], 
                      StyleBox["9",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"], " ", "2", "3", "4"},
                    {
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["7",
                        FontWeight->"Plain"], 
                      StyleBox["8",
                        FontWeight->"Plain"], " ", 
                      StyleBox["9",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"], 
                      StyleBox["2",
                        FontWeight->"Plain"], " ", "3", "4", "5"},
                    {" ", " ", " ", " ", " ", " ", " ", "  ", " ", " ", " "},
                    {
                      StyleBox["7",
                        FontWeight->"Plain"], 
                      StyleBox["8",
                        FontWeight->"Plain"], 
                      StyleBox["9",
                        FontWeight->"Plain"], " ", "1", "2", "3", " ", 
                      StyleBox["4",
                        FontWeight->"Plain"], 
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"]},
                    {
                      StyleBox["8",
                        FontWeight->"Plain"], 
                      StyleBox["9",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"], " ", "2", "3", "4", " ", 
                      StyleBox["5",
                        FontWeight->"Plain"], 
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["7",
                        FontWeight->"Plain"]},
                    {
                      StyleBox["9",
                        FontWeight->"Plain"], 
                      StyleBox["1",
                        FontWeight->"Plain"], 
                      StyleBox["2",
                        FontWeight->"Plain"], " ", "3", "4", "5", " ", 
                      StyleBox["6",
                        FontWeight->"Plain"], 
                      StyleBox["7",
                        FontWeight->"Plain"], 
                      StyleBox["8",
                        FontWeight->"Plain"]}
                    },
                  ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"C9J", "=", 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "2", "3"},
                    {"2", "3", "\[DoubleStruckCapitalJ]"},
                    {"3", 
                      "\[DoubleStruckCapitalJ]", \(2\ \[DoubleStruckCapitalJ]\
\)}
                    }], "\[NoBreak]", ")"}]}], "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{
                RowBox[{\(4\  &\), " ", 
                  StyleBox["5",
                    "Text"], 
                  StyleBox[" ",
                    "Text"], 
                  StyleBox["become",
                    "Text"], 
                  StyleBox[" ",
                    "Text"], 
                  StyleBox["\[DoubleStruckCapitalJ]",
                    "Text"]}], 
                StyleBox[" ",
                  "Text"], 
                StyleBox["&",
                  "Text"]}], "2", 
              StyleBox["\[DoubleStruckCapitalJ]",
                "Text"]}]}]}
        }]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  "Figure 27. shows that C9J is a division algebra. It was developed to show \
that hoops were not restricted to \"traditional\" signs. After finding and \
applying the appropriate ",
  StyleBox["minsign",
    FontSlant->"Italic"],
  ", the shapes are seen to be conserved. Then multiplying Ainverse by AB \
recovers B, showing that C9J is a division algebra over the real field, \
though its products involve \[DoubleStruckCapitalJ]. The C9 conjugate \
determinant has one linear, one quadratic, and one 6th order factor; folding \
reduces these to a single cubic factor, the size for C9J."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 27",
    FontWeight->"Bold"],
  ". Using the C9J multiplication table to multiply and divide:- "
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "\"\<hoopShape[C9J] ={\!\(a\^3\)+\!\(b\^3\) \[DoubleStruckCapitalJ]-3 a \
b c \[DoubleStruckCapitalJ]+\!\(c\^3\) \!\(\[DoubleStruckCapitalJ]\^2\)}\\nA=\
\>\"", ",", \(A = {2, 1, 3}\), ",", "\"\<\\nB=\>\"", 
        ",", \(B = {4, \(-2\), 5}\), ",", "\"\<\\nAB=\>\"", 
        ",", \(AB = hoopTimes[A, B, "\<C9J\>"]\), ",", "\"\<\\nshape[A] \>\"",
         ",", \(sa = shape[A]\), " ", ",", "\"\<\\nshape[B]\>\"", 
        ",", \(sb = shape[B]\), ",", "\"\<\\nshape[AB]\>\"", 
        ",", \(sab = Expand[shape[AB]]\), ",", 
        RowBox[{"\"\<\\nApplying \!\(\*
StyleBox[\"minsign\",\nFontSlant->\"Italic\"]\)= {\!\(\[DoubleStruckCapitalJ]\
\^3\)\[RightArrow]1,\!\(\[DoubleStruckCapitalJ]\^any_\)\>\"", 
          "\[RightArrow]", \(\[DoubleStruckCapitalJ]\^mod[any, 3]\)}], 
        ",", \(mins = minsign[AB]; "\<\nshAB gives\>"\), 
        ",", \(Expand[shape[AB]] /. mins\), ",", "\"\<\\nshA shB = \>\"", 
        ",", \(Expand[sa\ sb] /. mins\), ",", "\"\<\\n\!\(\*
StyleBox[\"Ai\",\nFontSlant->\"Italic\"]\)=\>\"", 
        ",", \(Ai = hoopInverse[A]\), ",", "\[IndentingNewLine]", 
        "\"\<\\n\!\(\*
StyleBox[\"AiAB\",\nFontSlant->\"Italic\"]\)=\>\"", 
        ",", \(AiAB = hoopTimes[Ai, AB]\), ",", "\"\<\\n\!\(\*
StyleBox[\"minsign\",\nFontSlant->\"Italic\"]\) simplifies this to \!\(\*
StyleBox[\"B\",\nFontSlant->\"Italic\"]\) \>\"", 
        ",", \(Simplify[Expand[AiAB] /. mins]\)}], "}"}]], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"hoopShape[C9J] ={\\!\\(a\\^3\\)+\\!\\(b\\^3\\) \
\[DoubleStruckCapitalJ]-3 a b c \[DoubleStruckCapitalJ]+\\!\\(c\\^3\\) \\!\\(\
\[DoubleStruckCapitalJ]\\^2\\)}\\nA=\"\>", ",", \({2, 1, 3}\), 
        ",", "\<\"\\nB=\"\>", ",", \({4, \(-2\), 5}\), ",", "\<\"\\nAB=\"\>", 
        ",", \({8 - \[DoubleStruckCapitalJ], 15\ \[DoubleStruckCapitalJ], 
          20}\), ",", "\<\"\\nshape[A] \"\>", 
        ",", \({8 - 17\ \[DoubleStruckCapitalJ] + 
            27\ \[DoubleStruckCapitalJ]\^2}\), ",", "\<\"\\nshape[B]\"\>", 
        ",", \({64 + 112\ \[DoubleStruckCapitalJ] + 
            125\ \[DoubleStruckCapitalJ]\^2}\), ",", "\<\"\\nshape[AB]\"\>", 
        ",", \({512 - 192\ \[DoubleStruckCapitalJ] + 
            824\ \[DoubleStruckCapitalJ]\^2 + 
            899\ \[DoubleStruckCapitalJ]\^3 + 
            3375\ \[DoubleStruckCapitalJ]\^4}\), ",", 
        RowBox[{"\<\"\\nApplying \\!\\(\\* \
StyleBox[\\\"minsign\\\",\\nFontSlant->\\\"Italic\\\"]\\)= {\\!\\(\
\[DoubleStruckCapitalJ]\\^3\\)\[RightArrow]1,\\!\\(\[DoubleStruckCapitalJ]\\^\
any_\\)\"\>", "\[RightArrow]", \(\[DoubleStruckCapitalJ]\^mod[any, 3]\)}], 
        ",", "\<\"\\nshAB gives\"\>", 
        ",", \({1411 + 3183\ \[DoubleStruckCapitalJ] + 
            824\ \[DoubleStruckCapitalJ]\^2}\), ",", "\<\"\\nshA shB = \"\>", 
        ",", \({1411 + 3183\ \[DoubleStruckCapitalJ] + 
            824\ \[DoubleStruckCapitalJ]\^2}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"Ai\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)=\"\>", 
        ",", \({\(4 - 3\ \[DoubleStruckCapitalJ]\)\/\(8 - 17\ \
\[DoubleStruckCapitalJ] + 27\ \[DoubleStruckCapitalJ]\^2\), \(\
\[DoubleStruckCapitalJ]\^3\ \((\(-2\) + 9\ \[DoubleStruckCapitalJ])\)\)\/\(8 \
- 17\ \[DoubleStruckCapitalJ] + 27\ \[DoubleStruckCapitalJ]\^2\), \(-\(\(5\ \
\[DoubleStruckCapitalJ]\^3\)\/\(8 - 17\ \[DoubleStruckCapitalJ] + 
                  27\ \[DoubleStruckCapitalJ]\^2\)\)\)}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"AiAB\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)=\"\>", 
        ",", \({\(\((4 - 3\ \[DoubleStruckCapitalJ])\)\ \((8 - \
\[DoubleStruckCapitalJ])\)\)\/\(8 - 17\ \[DoubleStruckCapitalJ] + 27\ \
\[DoubleStruckCapitalJ]\^2\) - \(75\ \[DoubleStruckCapitalJ]\^5\)\/\(8 - 17\ \
\[DoubleStruckCapitalJ] + 27\ \[DoubleStruckCapitalJ]\^2\) + \(20\ \
\[DoubleStruckCapitalJ]\^4\ \((\(-2\) + 9\ \[DoubleStruckCapitalJ])\)\)\/\(8 \
- 17\ \[DoubleStruckCapitalJ] + 27\ \[DoubleStruckCapitalJ]\^2\), \(15\ \((4 \
- 3\ \[DoubleStruckCapitalJ])\)\ \[DoubleStruckCapitalJ]\)\/\(8 - 17\ \
\[DoubleStruckCapitalJ] + 27\ \[DoubleStruckCapitalJ]\^2\) - \(100\ \
\[DoubleStruckCapitalJ]\^4\)\/\(8 - 17\ \[DoubleStruckCapitalJ] + 27\ \
\[DoubleStruckCapitalJ]\^2\) + \(\((8 - \[DoubleStruckCapitalJ])\)\ \
\[DoubleStruckCapitalJ]\^3\ \((\(-2\) + 9\ \[DoubleStruckCapitalJ])\)\)\/\(8 \
- 17\ \[DoubleStruckCapitalJ] + 27\ \[DoubleStruckCapitalJ]\^2\), \(20\ \((4 \
- 3\ \[DoubleStruckCapitalJ])\)\)\/\(8 - 17\ \[DoubleStruckCapitalJ] + 27\ \
\[DoubleStruckCapitalJ]\^2\) - \(5\ \((8 - \[DoubleStruckCapitalJ])\)\ \
\[DoubleStruckCapitalJ]\^3\)\/\(8 - 17\ \[DoubleStruckCapitalJ] + 27\ \
\[DoubleStruckCapitalJ]\^2\) + \(15\ \[DoubleStruckCapitalJ]\^4\ \((\(-2\) + \
9\ \[DoubleStruckCapitalJ])\)\)\/\(8 - 17\ \[DoubleStruckCapitalJ] + 27\ \
\[DoubleStruckCapitalJ]\^2\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"minsign\\\",\\nFontSlant->\\\"Italic\\\"]\\) simplifies this to \
\\!\\(\\* StyleBox[\\\"B\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({4, \(-2\), 5}\)}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.10. Exponent of Generalized Signs, Multiphase Sinusoids.", \
"Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman",
  FontSize->12],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". An important property of generalized signs is that their exponents give \
generalized symmetric multiphase sinusoids, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_r\%\(\(\(\(\[DoubleStruckS]\)\(\ \)\
\)\^j\) x\)\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_j\)]],
  " 2",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^j\)]],
  "/r Sin[p(x+2\[Pi] j/r)], with period p= Sin[2\[Pi] /r]. ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_r\)]],
  " is a normalizing extrapolation of \[ExponentialE]  to r phases, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_r\)]],
  "=",
  Cell[BoxData[
      \(Re[\[ExponentialE]\^\(\(\ \)\(Im[\((\(-1\))\)\^\(2/r\)]\)\)]\)]],
  ". The traditional ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(-\[ImaginaryI]x\)\)]],
  "=Cos[x]+\[ImaginaryI] Sin[x] is an asymmetric folded case with r=4."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[TextData[{
  "\tExtended signs \[DoubleStruckS] are a significant generalization of \
complex mathematics. One important property is that their exponents \
generalize the sinusoids Cos[x] = Re[",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ x\)\)]],
  "], Sin[x] = Im[",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ x\)\)]],
  "] to multi-phase sinusoids ",
  StyleBox["genCos[x,r,j] ",
    FontSlant->"Italic"],
  "= Re[",
  StyleBox["j ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_r\%\(\(\(\(\[DoubleStruckS]\)\(\ \)\
\)\^j\) x\)\)]],
  "] where ",
  StyleBox["j",
    FontSlant->"Italic"],
  " is a phase & ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_r\)]],
  " is a (normalizing) modification of \[ExponentialE] that depends on ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", the number of phases, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_3\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_6\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\@3/2\)\)]],
  "\[TildeEqual]2.3774, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_12\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\@\[ExponentialE]\)]],
  "\[TildeEqual]1.6487. The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " implementation of the normalising element is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_r\)]],
  "= Re[",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^Im[\((\(-1\))\)\^\(2/r\)]\)]],
  "]. The generation of these sinusoids as solutions to banded differential \
equations is described in ",
  StyleBox["GroupLoopDemo",
    FontSlant->"Italic"],
  " Appendix E",
  StyleBox[" ",
    FontSlant->"Italic"],
  "[1]."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 28 & Figure",
    FontWeight->"Bold"],
  " 29 demonstrate ",
  StyleBox["genCos",
    FontSlant->"Italic"],
  " & ",
  StyleBox["genSin ",
    FontSlant->"Italic"],
  "by plotting three phases of the 3-phase & 12-phase sinusoids over their \
periods 2\[Pi]/Sin[2\[Pi]/3]=7.2552 & 4\[Pi]=12.5664. "
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\(Figs\ 28\  &\)\ 9. \ Multiphase\ sinusoids*) \)\(Unprotect[m]; 
    m = 3; Plot[{2/3 
           Re[\((\(-1\))\)\^\(\(2\ \((m - 0)\)\)\/m\)\ \[ExponentialE]\^\(\
\[ImaginaryI]\ Im[\((\(-1\))\)\^\(2/m\)]\ x\)], 
        2/3  Re[\((\(-1\))\)\^\(\(2\ \((m - 1)\)\)\/m\)\ \[ExponentialE]\^\(\
\[ImaginaryI]\ Im[\((\(-1\))\)\^\(2/m\)]\ x\)], 
        2/3  Re[\((\(-1\))\)\^\(\(2\ \((m - 2)\)\)\/m\)\ \[ExponentialE]\^\(\
\[ImaginaryI]\ Im[\((\(-1\))\)\^\(2/m\)]\ x\)]}, {x, 0, 
        2  \[Pi]/Sin[2  \[Pi]/3]}, 
      PlotLabel -> "\<Fig.28. genCos. Phases 0,1,2 for m = 3\>"]; m = 12; 
    Plot[{Im[\((\(-1\))\)\^\(\(2\ \((m - 0)\)\)\/m\)\ \[ExponentialE]\^\(\
\[ImaginaryI]\ Im[\((\(-1\))\)\^\(2/m\)]\ x\)]/6, 
        Im[\((\(-1\))\)\^\(\(2\ \((m - 1)\)\)\/m\)\ \[ExponentialE]\^\(\
\[ImaginaryI]\ Im[\((\(-1\))\)\^\(2/m\)]\ x\)]/6, 
        Im[\((\(-1\))\)\^\(\(2\ \((m - 2)\)\)\/m\)\ \[ExponentialE]\^\(\
\[ImaginaryI]\ Im[\((\(-1\))\)\^\(2/m\)]\ x\)]/6}, {x, 0, 
        2  \[Pi]/Sin[2  \[Pi]/12]}, 
      PlotLabel -> "\<Fig.29. genSin. Phases 0,1,2 for m = 12\>"];\)\)\)], \
"Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.131269 0.309017 0.441453 [
[.15508 .29652 -3 -9 ]
[.15508 .29652 3 0 ]
[.28635 .29652 -3 -9 ]
[.28635 .29652 3 0 ]
[.41762 .29652 -3 -9 ]
[.41762 .29652 3 0 ]
[.54888 .29652 -3 -9 ]
[.54888 .29652 3 0 ]
[.68015 .29652 -3 -9 ]
[.68015 .29652 3 0 ]
[.81142 .29652 -3 -9 ]
[.81142 .29652 3 0 ]
[.94269 .29652 -3 -9 ]
[.94269 .29652 3 0 ]
[.01131 .04415 -24 -4.5 ]
[.01131 .04415 0 4.5 ]
[.01131 .13244 -24 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .22073 -24 -4.5 ]
[.01131 .22073 0 4.5 ]
[.01131 .39731 -18 -4.5 ]
[.01131 .39731 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .57389 -18 -4.5 ]
[.01131 .57389 0 4.5 ]
[.5 .63053 -116 0 ]
[.5 .63053 116 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15508 .30902 m
.15508 .31527 L
s
[(1)] .15508 .29652 0 1 Mshowa
.28635 .30902 m
.28635 .31527 L
s
[(2)] .28635 .29652 0 1 Mshowa
.41762 .30902 m
.41762 .31527 L
s
[(3)] .41762 .29652 0 1 Mshowa
.54888 .30902 m
.54888 .31527 L
s
[(4)] .54888 .29652 0 1 Mshowa
.68015 .30902 m
.68015 .31527 L
s
[(5)] .68015 .29652 0 1 Mshowa
.81142 .30902 m
.81142 .31527 L
s
[(6)] .81142 .29652 0 1 Mshowa
.94269 .30902 m
.94269 .31527 L
s
[(7)] .94269 .29652 0 1 Mshowa
.125 Mabswid
.05006 .30902 m
.05006 .31277 L
s
.07632 .30902 m
.07632 .31277 L
s
.10257 .30902 m
.10257 .31277 L
s
.12882 .30902 m
.12882 .31277 L
s
.18133 .30902 m
.18133 .31277 L
s
.20759 .30902 m
.20759 .31277 L
s
.23384 .30902 m
.23384 .31277 L
s
.26009 .30902 m
.26009 .31277 L
s
.3126 .30902 m
.3126 .31277 L
s
.33885 .30902 m
.33885 .31277 L
s
.36511 .30902 m
.36511 .31277 L
s
.39136 .30902 m
.39136 .31277 L
s
.44387 .30902 m
.44387 .31277 L
s
.47012 .30902 m
.47012 .31277 L
s
.49638 .30902 m
.49638 .31277 L
s
.52263 .30902 m
.52263 .31277 L
s
.57514 .30902 m
.57514 .31277 L
s
.60139 .30902 m
.60139 .31277 L
s
.62765 .30902 m
.62765 .31277 L
s
.6539 .30902 m
.6539 .31277 L
s
.70641 .30902 m
.70641 .31277 L
s
.73266 .30902 m
.73266 .31277 L
s
.75891 .30902 m
.75891 .31277 L
s
.78517 .30902 m
.78517 .31277 L
s
.83768 .30902 m
.83768 .31277 L
s
.86393 .30902 m
.86393 .31277 L
s
.89018 .30902 m
.89018 .31277 L
s
.91644 .30902 m
.91644 .31277 L
s
.96894 .30902 m
.96894 .31277 L
s
.9952 .30902 m
.9952 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .04415 m
.03006 .04415 L
s
[(-0.6)] .01131 .04415 1 0 Mshowa
.02381 .13244 m
.03006 .13244 L
s
[(-0.4)] .01131 .13244 1 0 Mshowa
.02381 .22073 m
.03006 .22073 L
s
[(-0.2)] .01131 .22073 1 0 Mshowa
.02381 .39731 m
.03006 .39731 L
s
[(0.2)] .01131 .39731 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.4)] .01131 .4856 1 0 Mshowa
.02381 .57389 m
.03006 .57389 L
s
[(0.6)] .01131 .57389 1 0 Mshowa
.125 Mabswid
.02381 .06622 m
.02756 .06622 L
s
.02381 .08829 m
.02756 .08829 L
s
.02381 .11036 m
.02756 .11036 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .17658 m
.02756 .17658 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .26487 m
.02756 .26487 L
s
.02381 .28694 m
.02756 .28694 L
s
.02381 .33109 m
.02756 .33109 L
s
.02381 .35316 m
.02756 .35316 L
s
.02381 .37523 m
.02756 .37523 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .44145 m
.02756 .44145 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .50767 m
.02756 .50767 L
s
.02381 .52974 m
.02756 .52974 L
s
.02381 .55182 m
.02756 .55182 L
s
.02381 .02207 m
.02756 .02207 L
s
.02381 .59596 m
.02756 .59596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -177 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.28) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(genCos) show
147.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
159.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phases) show
201.000 12.750 moveto
(0) show
207.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
213.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
219.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
225.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
237.000 12.750 moveto
(for) show
261.000 12.750 moveto
(m) show
273.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
285.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
291.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01924 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01565 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38344 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .16187 m
.06244 .23088 L
.10458 .31175 L
.14415 .38761 L
.18221 .45561 L
.22272 .5178 L
.26171 .5637 L
.28302 .58185 L
.29279 .58839 L
.30316 .59406 L
.31266 .59809 L
.31807 .59988 L
.32313 .60121 L
.32777 .60215 L
.33201 .60277 L
.33436 .60301 L
.33568 .60312 L
.33691 .6032 L
.33809 .60325 L
.33917 .60329 L
.3404 .60331 L
.34157 .60332 L
.34273 .60331 L
.34398 .60327 L
.34515 .60322 L
.34622 .60316 L
.34885 .60295 L
.35133 .60267 L
.35627 .60188 L
.36165 .60066 L
.37124 .59758 L
.38012 .5937 L
.39878 .58239 L
.41939 .56509 L
.45959 .51812 L
.49828 .45906 L
.53942 .38569 L
.57904 .30965 L
.61715 .23641 L
.65771 .16358 L
.69676 .1032 L
.71667 .07742 L
.73825 .05399 L
.75906 .03629 L
.76896 .02965 L
.77824 .02451 L
.78728 .02053 L
.79193 .01888 L
.797 .01739 L
.79987 .01669 L
Mistroke
.80253 .01614 L
.80529 .01566 L
.80778 .01531 L
.81024 .01505 L
.81256 .01487 L
.81383 .0148 L
.815 .01475 L
.81628 .01472 L
.81693 .01472 L
.81764 .01472 L
.81895 .01473 L
.82016 .01476 L
.82079 .01479 L
.82149 .01482 L
.8229 .0149 L
.82546 .01512 L
.82787 .01541 L
.83236 .01613 L
.83719 .0172 L
.84251 .01873 L
.84811 .02071 L
.85811 .02524 L
.8779 .0378 L
.89628 .05361 L
.93537 .09936 L
.97619 .16187 L
Mfstroke
.02381 .16187 m
.06244 .10236 L
.08255 .07646 L
.10458 .05279 L
.12507 .03562 L
.13422 .02954 L
.14415 .0241 L
.14961 .02163 L
.15465 .01968 L
.15937 .01815 L
.16457 .01678 L
.16922 .01585 L
.17146 .0155 L
.17359 .01523 L
.17474 .0151 L
.17599 .01499 L
.17714 .0149 L
.17819 .01484 L
.17943 .01478 L
.18012 .01475 L
.18076 .01474 L
.18191 .01472 L
.18314 .01472 L
.18439 .01474 L
.18552 .01477 L
.18682 .01483 L
.18806 .01491 L
.19026 .0151 L
.19265 .01537 L
.19528 .01575 L
.19807 .01626 L
.20308 .01741 L
.2131 .02067 L
.22415 .02573 L
.2435 .03819 L
.26435 .05655 L
.30549 .10634 L
.34512 .16838 L
.38322 .23711 L
.42378 .31513 L
.46283 .38989 L
.50433 .46338 L
.54431 .52337 L
.58278 .56714 L
.60265 .58341 L
.61267 .58984 L
.62369 .59549 L
.62891 .59764 L
.63386 .59937 L
.63835 .60066 L
Mistroke
.64314 .60176 L
.64586 .60226 L
.64833 .60263 L
.65081 .60292 L
.65314 .60312 L
.65447 .6032 L
.65519 .60324 L
.65587 .60327 L
.65706 .6033 L
.65838 .60332 L
.65911 .60332 L
.65981 .60331 L
.66111 .60328 L
.66184 .60326 L
.66251 .60323 L
.66403 .60314 L
.66522 .60305 L
.66646 .60294 L
.66868 .60268 L
.67369 .60189 L
.67801 .60094 L
.68274 .59964 L
.69342 .59564 L
.70335 .59066 L
.72385 .57657 L
.74245 .55956 L
.78248 .51056 L
.821 .45017 L
.86197 .37609 L
.90143 .30008 L
.93937 .22749 L
.97619 .16187 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->12,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003o;03oool0
0`000000oooo0?ooo`3o0?oooh80oooo000/0?ooo`030000003oool0oooo0?l0ooooPP3oool002`0
oooo00<000000?ooo`3oool0o`3ooon20?ooo`00;03oool00`000000oooo0?ooo`3o0?oooh80oooo
000/0?ooo`030000003oool0oooo0?l0ooooPP3oool002`0oooo00<000000?ooo`3oool0>@3oool6
000007L0oooo1@00001g0?ooo`D00000BP3oool002`0oooo00<000000?ooo`3oool0=03oool50000
00D0oooo1P00001]0?ooo`D000001@3oool4000006d0oooo1P0000050?ooo`H00000A03oool002`0
oooo00<000000?ooo`3oool0<03oool400000100oooo0P00001W0?ooo`@000003P3oool3000006P0
oooo0P00000A0?ooo`800000@P3oool002`0oooo0`00000^0?ooo`8000005P3oool300000680oooo
0P00000E0?ooo`@00000H@3oool3000001D0oooo0P0000100?ooo`00;03oool00`000000oooo0?oo
o`0/0?ooo`8000006`3oool2000005h0oooo0P00000K0?ooo`<00000G03oool2000001X0oooo0P00
000n0?ooo`00;03oool00`000000oooo0?ooo`0Z0?ooo`8000007`3oool2000005X0oooo0P00000P
0?ooo`030000003oool0oooo05L0oooo0P00000N0?ooo`800000?03oool002`0oooo00<000000?oo
o`3oool0:03oool2000002<0oooo0P00001F0?ooo`8000008`3oool2000005D0oooo0P00000R0?oo
o`800000>P3oool002`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0540oooo0P00000W0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0903oool2000003P0oooo000>0?ooo`@000001P3oool2000000L0oooo100000070?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0CP3oool2000002T0oooo0P00000f0?ooo`003@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02T0oooo0P00001>0?ooo`030000003oool0oooo02X0oooo0P00001=0?ooo`030000003o
ool0oooo02/0oooo0P00000d0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0340oooo000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool20000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`800000<03oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00040?ooo`H000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000000P0000070?ooo`@0
0000803oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04D0oooo0P00000c0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0_0?ooo`00
3@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0d0?ooo`800000@`3oool2000003H0oooo00<000000?ooo`3oool0
;P3oool000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool07P3oool2000003L0oooo0P0000120?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo02d0oooo000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02`0oooo000>0?ooo`@000004@3oool30000
00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0:`3oool002`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0:P3oool002`0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool0:@3oool002`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0:@3oool002`0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0:03oool002`0oooo0`00000H0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0W0?ooo`00;03oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0V0?ooo`00
;03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0U0?ooo`00;03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0T0?ooo`00;03oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0T0?ooo`00;03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0S0?ooo`00;03oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`0R0?ooo`00;03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool300000140oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0200oooo000/
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo01l0oooo000/0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01l0oooo000/0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01h0oooo000/0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01d0oooo000/0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo01`0oooo000/0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01/0oooo000/0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
01/0oooo000/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1M0?ooo`030000003oool0oooo01X0oooo000/0?ooo`<000002P3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool06@3oool002`0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool05`3oool002`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool05`3oool000h0oooo100000060?ooo`800000
1`3oool4000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool05P3oool000d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1W0?ooo`030000003o
ool0oooo01D0oooo000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01D0oooo000=0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool6000000L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0503oool000@0
oooo1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`0000080?ooo`@000000`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool04`3oool000d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool04`3oool000d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool04P3oool000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool04@3oool000h0oooo1000
000@0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0K`3oool00`000000oooo0?ooo`0A0?ooo`00;03oool01@000000oooo0?ooo`3o
ool0000007@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0@0?ooo`00;03oool0
10000000oooo0?ooo`00001e0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool03`3o
ool002`0oooo00@000000?ooo`3oool00000MP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo00l0oooo000/0?ooo`<00000M`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo07D0oooo00D000000?ooo`3oool0oooo0000001g0?ooo`030000003oool0oooo00h0oooo000/
0?ooo`800000N@3oool010000000oooo0?ooo`00001i0?ooo`040000003oool0oooo000007P0oooo
00<000000?ooo`3oool03@3oool002`0oooo0P00001j0?ooo`800000NP3oool00`000000oooo0000
001i0?ooo`030000003oool0oooo00d0oooo000/0?ooo`030000003oool0oooo07T0oooo0P00001k
0?ooo`800000NP3oool00`000000oooo0?ooo`0<0?ooo`00;03oool2000007X0oooo0P00001k0?oo
o`800000N@3oool00`000000oooo0?ooo`0=0?ooo`00;03oool2000007X0oooo0P00001j0?ooo`03
0000003oool0000007T0oooo00<000000?ooo`3oool03@3oool002`0oooo00<000000?ooo`000000
N03oool010000000oooo0?ooo`00001i0?ooo`040000003oool0oooo000007L0oooo00<000000?oo
o`3oool03P3oool002`0oooo00<000000?ooo`000000N03oool01@000000oooo0?ooo`3oool00000
07L0oooo00D000000?ooo`3oool0oooo0000001g0?ooo`030000003oool0oooo00h0oooo000/0?oo
o`040000003oool0oooo000007H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0?
0?ooo`00;03oool4000007D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0?0?oo
o`00;03oool01@000000oooo0?ooo`3oool0000007@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`0@0?ooo`00;03oool01@000000oooo0?ooo`3oool0000007<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`0@0?ooo`00;03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0A0?ooo`00
;03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`0A0?ooo`00;03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0B0?ooo`00;03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`0B0?ooo`00;03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0C0?ooo`00;03oool3000000D0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo01@0
oooo000/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo01@0oooo000/0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01D0oooo000/
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo01D0oooo000/0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01H0oooo000/0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo01H0oooo000>0?ooo`@000001P3oool2000000D0oooo1P0000070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo01L0oooo000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo01L0oooo000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01P0oooo000=0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`@000002@3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0603oool000@0
oooo1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo01T0oooo000=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01T0oooo
000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool06P3oool000d0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0K0?ooo`003P3oool4000000h0oooo100000080?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo01/0oooo000/0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01`0oooo000/0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01`0oooo000/0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01d0oooo000/0?ooo`<000003`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool07@3oool0
02`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool07P3oool002`0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool07P3oool002`0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool07`3oool002`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07`3oool002`0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool0803oool002`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool0803oool002`0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool08@3oool002`0oooo0`00000C0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0R0?ooo`00;03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01L0oooo1`00000]0?ooo`H00000:@3oool00`000000oooo0?ooo`020?ooo`@00000<03o
ool4000001<0oooo00<000000?ooo`3oool06@3oool4000000`0oooo00<000000?ooo`3oool08@3o
ool4000002P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`00;03oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo000000020?ooo`030000003oool0oooo02L0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo02l0oooo0P00000]0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0:`3oool600000140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01h0oooo0P0000030?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000]0?oo
o`030000003oool0oooo0080oooo0P00000_0?ooo`040000003oool0oooo00000180oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`0000000P00000V0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0603oool0
02`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
02h0oooo00D000000?ooo`3oool0oooo0000000]0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0;03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01`0oooo1000
000?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`800000103oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0000000A
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G
0?ooo`00;03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo0`00000_0?oo
o`800000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo000/0?ooo`<0
0000603oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool01000000^0?ooo`D00000<@3oool200000100oooo00<000000?ooo`3oool07@3oool5000000l0
oooo00<000000?ooo`3oool07`3oool3000002<0oooo00<000000?ooo`3oool01`3oool6000001T0
oooo000/0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo02L0oooo000/0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02L0oooo000/
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo02P0oooo000/0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02P0oooo000/0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo02T0oooo000/0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02X0oooo000/0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo02X0oooo000/0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02/0oooo000S0?ooool00000RP0000040?oo
o`00;03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool2000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`80
00002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo0P0000080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo000/0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0<03oool010000000oooo0?ooo`00000`0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01T0oooo000/0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo02d0oooo000/0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0oooo000/0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo02h0oooo000/0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02h0oooo000/0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
02l0oooo000/0?ooo`<00000803oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0;`3oool002`0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<03oool002`0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0<03oool002`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<@3oool002`0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0<@3oool002`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0<P3oool002`0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
<P3oool002`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0<`3oool002`0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0<`3oool0
02`0oooo0`00000U0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0d0?ooo`00;03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0d0?ooo`00;03oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0e0?ooo`00;03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0e0?ooo`00;03oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0f
0?ooo`00;03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0f0?ooo`00;03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0g0?ooo`00
;03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0g0?ooo`00;03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0h0?ooo`00;03oool3
000002T0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo03P0oooo000/0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo03T0oooo000/0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03T0
oooo000/0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03X0oooo000/0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03X0oooo000>
0?ooo`@000001P3oool2000000D0oooo1P0000070?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03/0oooo000=0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03/0oooo000=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo03`0oooo000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`080?ooo`@00000;@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0?03oool000d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?@3o
ool000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0?P3oool000d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0n0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03l0
oooo000>0?ooo`@000003P3oool4000000P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool002`0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0@03oool002`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@03oool002`0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06P0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0@@3oool002`0oooo0`00000c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`110?ooo`00;03oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`120?ooo`00;03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`120?ooo`00;03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`130?ooo`00;03oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`140?ooo`00;03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`140?ooo`00;03oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`150?ooo`00;03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`150?ooo`00;03oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`16
0?ooo`00;03oool3000003P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo04H0oooo000/0?ooo`030000003oool0oooo03T0oooo00D000000?ooo`3o
ool0oooo0000001g0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo04L0oooo000/0?ooo`030000003oool0oooo03T0
oooo00D000000?ooo`3oool0oooo0000001h0?ooo`050000003oool0oooo0?ooo`000000M`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04L0oooo000/0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`000000N@3oool010000000oooo0?ooo`00001i0?ooo`040000003oool0
oooo000004X0oooo000/0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`000000NP3oool0
0`000000oooo0000001i0?ooo`030000003oool0000004/0oooo000/0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0N@3oool2000007/0oooo0P00001;0?ooo`00;03oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0000007/0oooo00<000000?ooo`3oool0N@3oool2000004/0
oooo000/0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`000000NP3oool2000007X0oooo
00<000000?ooo`000000B`3oool002`0oooo0`00000i0?ooo`050000003oool0oooo0?ooo`000000
N03oool010000000oooo0?ooo`00001i0?ooo`040000003oool0oooo000004X0oooo000/0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1e0?ooo`05
0000003oool0oooo0?ooo`000000M`3oool01@000000oooo0?ooo`3oool0000004X0oooo000/0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04L0oooo000/0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo000/0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo04H0oooo000>0?ooo`@000001P3oool2000000L0oooo100000070?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo04D0oooo000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`140?ooo`003@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`140?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo1P0000070?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo04<0oooo000=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`@00000<P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@`3oool000d0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0@P3oool000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool000d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0@@3oool000h0oooo1000000@0?ooo`800000203oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`10
0?ooo`00;03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0o0?ooo`00;03oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0o0?ooo`00
;03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0n0?ooo`00;03oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0n0?ooo`00;03oool3
000002h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo03d0oooo000/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo03`0oooo000/0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03`0
oooo000/0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo03/0oooo000/0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo000/
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo03T0oooo000/0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03T0oooo000/0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo03P0oooo000/0?ooo`<00000:03oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0=`3oool002`0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=P3o
ool002`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0=@3oool002`0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0=@3oool002`0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0=03oool002`0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0<`3oool002`0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0<P3oool002`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<@3oool002`0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0<03oool002`0oooo0`00000P0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0_0?ooo`00;03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0^0?ooo`00;03o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0]0?ooo`00;03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0/0?ooo`00;03oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0[0?ooo`003P3oool4000000H0oooo0P0000070?ooo`@000001`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0Z0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
0P0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0J0?ooo`800000?`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02T0oooo
000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`100?ooo`800000>03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0X0?ooo`003@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0@P3oool2000003H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0W
0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`0000000P0000070?ooo`@000005@3oool2000004L0oooo00<000000?ooo`3oool0<@3oool20000
04L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`140?ooo`8000009`3oool000d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`180?ooo`800000<03oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0T0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1:0?ooo`800000;P3oool2000004/0oooo
00<000000?ooo`3oool08`3oool000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0Y0?ooo`800000CP3oool00`000000oooo0?ooo`0R0?ooo`003P3oool400000140oooo0`000006
0?ooo`030000003oool0oooo0140oooo0P00001A0?ooo`800000:03oool200000540oooo00<00000
0?ooo`3oool09P3oool200000540oooo0P00000R0?ooo`00;03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo05<0oooo0P00000T0?ooo`800000E03oool2000002@0oooo0P00001E0?oo
o`800000803oool002`0oooo00<000000?ooo`3oool03P3oool2000005P0oooo0P00000P0?ooo`80
0000F03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05L0oooo0P00000N0?ooo`00
;03oool00`000000oooo0?ooo`0<0?ooo`800000G03oool2000001d0oooo00<000000?ooo`3oool0
F@3oool2000001h0oooo0P00001L0?ooo`030000003oool0oooo01/0oooo000/0?ooo`<000002P3o
ool200000600oooo0P00000I0?ooo`800000GP3oool2000001X0oooo0P00001O0?ooo`8000006`3o
ool002`0oooo00<000000?ooo`3oool0203oool2000006@0oooo00<000000?ooo`3oool04`3oool3
00000680oooo0P00000F0?ooo`800000H`3oool3000001P0oooo000/0?ooo`030000003oool0oooo
00D0oooo0`00001W0?ooo`@000003P3oool3000006L0oooo1P00000=0?ooo`<00000J03oool30000
01D0oooo000/0?ooo`P00000KP3oool>00000700oooo3@00001^0?ooo`L000003P3oool002`0oooo
00<000000?ooo`3oool0o`3ooon20?ooo`00;03oool00`000000oooo0?ooo`3o0?oooh80oooo000/
0?ooo`030000003oool0oooo0?l0ooooPP3oool002`0oooo00<000000?ooo`3oool0o`3ooon20?oo
o`00;03oool00`000000oooo0?ooo`3o0?oooh80oooo000/0?ooo`030000003oool0oooo0?l0oooo
PP3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00500oooo1000000b0?ooo`@00000o`3ooolW0?oo
o`00E03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`250?ooo`00E03oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo08T0oooo0P00000@0?ooo`800000QP3oool003d0oooo100000050?ooo`L000000`3o
ool3000000030?ooo`000000oooo00@0oooo0P0000050?ooo`H00000103oool4000000H0oooo0P00
000?0?ooo`<0000000<0oooo0000003oool0103oool4000000<0oooo0`0000020?ooo`<000000`3o
ool4000000D0oooo100000040?ooo`D000001@3oool2000000h0oooo1@0000040?ooo`<000000P3o
ool3000000<0oooo1@0000030?ooo`D000001@3oool4000000@0oooo1@00000=0?ooo`@000001P3o
ool00`000000oooo0?ooo`040?ooo`L00000103oool00`000000oooo0?ooo`040?ooo`H000003P3o
ool5000000@0oooo100000040?ooo`D000002`3oool3000000040?ooo`00000000000?ooo`800000
7@3oool400000240oooo000n0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`3oool2000000D0oooo0P0000050?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo0P00000>0?ooo`04
0000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`80
00003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000203o
ool00`000000oooo0?ooo`050?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00X0oooo1P00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
7P3oool003h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?oo
o`0000003@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool07P3oool003h0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo1P0000030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo1000
000F0?ooo`D00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo1000
00050?ooo`@00000103oool6000000@0oooo1000000<0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool07P3oool003h0oooo100000070?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool0oooo0P00000?0?ooo`030000003oool0oooo00@0oooo1000000F0?ooo`040000
003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?oo
o`8000000`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool2000000h0oooo0P0000001@3oool000000000003oool0000000`0oooo1P00
000>0?ooo`8000008@3oool003h0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`<00000
1P3oool3000000030?ooo`000000000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01@0oooo0`0000000`3oool00000000000040?ooo`@00000
0`3oool2000000040?ooo`0000000000000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`@000001@3oool5000001D0oooo00<000000?ooo`3oool00P3oool01P000000
oooo0?ooo`3oool000000?ooo`<000001@3oool3000000H0oooo1@0000040?ooo`@000001@3oool5
000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0303oool6000000@0oooo100000040?ooo`80000000@0oooo
00000000000000002P3oool2000000050?ooo`000000oooo0?ooo`0000008`3oool00`000000oooo
0?ooo`0N0?ooo`00?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
;`3oool010000000oooo0?ooo`3oool2000002L0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000003@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool07P3oool003d0oooo1`00000M0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0300oooo0`0000000`3oool000000?ooo`0U0?ooo`H00000103oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool3000000h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`00B@3oool00`000000oooo0?ooo`0F0?ooo`@0
00001@3oool4000006L0oooo0P00000e0?ooo`@00000403oool00`000000oooo0?ooo`0=0?ooo`@0
00004@3oool300000480oooo1000000Q0?ooo`00B@3oool00`000000oooo0?ooo`3o0?ooofD0oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 1149.25}, {709, 0}} -> {-0.867888, -0.700007, \
0.0291556, 0.00866962}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0757881 0.309017 1.76581 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.93327 .29652 -6 -9 ]
[.93327 .29652 6 0 ]
[.01131 .04415 -30 -4.5 ]
[.01131 .04415 0 4.5 ]
[.01131 .13244 -24 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .22073 -30 -4.5 ]
[.01131 .22073 0 4.5 ]
[.01131 .39731 -24 -4.5 ]
[.01131 .39731 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .57389 -24 -4.5 ]
[.01131 .57389 0 4.5 ]
[.5 .63053 -119 0 ]
[.5 .63053 119 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(2)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(4)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(6)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(8)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(10)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(12)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.0617 .30902 m
.0617 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.13749 .30902 m
.13749 .31277 L
s
.21328 .30902 m
.21328 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.28907 .30902 m
.28907 .31277 L
s
.36486 .30902 m
.36486 .31277 L
s
.40275 .30902 m
.40275 .31277 L
s
.44064 .30902 m
.44064 .31277 L
s
.51643 .30902 m
.51643 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.59222 .30902 m
.59222 .31277 L
s
.66801 .30902 m
.66801 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.7438 .30902 m
.7438 .31277 L
s
.81958 .30902 m
.81958 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.89537 .30902 m
.89537 .31277 L
s
.97116 .30902 m
.97116 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .04415 m
.03006 .04415 L
s
[(-0.15)] .01131 .04415 1 0 Mshowa
.02381 .13244 m
.03006 .13244 L
s
[(-0.1)] .01131 .13244 1 0 Mshowa
.02381 .22073 m
.03006 .22073 L
s
[(-0.05)] .01131 .22073 1 0 Mshowa
.02381 .39731 m
.03006 .39731 L
s
[(0.05)] .01131 .39731 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.1)] .01131 .4856 1 0 Mshowa
.02381 .57389 m
.03006 .57389 L
s
[(0.15)] .01131 .57389 1 0 Mshowa
.125 Mabswid
.02381 .0618 m
.02756 .0618 L
s
.02381 .07946 m
.02756 .07946 L
s
.02381 .09712 m
.02756 .09712 L
s
.02381 .11478 m
.02756 .11478 L
s
.02381 .15009 m
.02756 .15009 L
s
.02381 .16775 m
.02756 .16775 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .23838 m
.02756 .23838 L
s
.02381 .25604 m
.02756 .25604 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29136 m
.02756 .29136 L
s
.02381 .32668 m
.02756 .32668 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .36199 m
.02756 .36199 L
s
.02381 .37965 m
.02756 .37965 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45028 m
.02756 .45028 L
s
.02381 .46794 m
.02756 .46794 L
s
.02381 .50326 m
.02756 .50326 L
s
.02381 .52091 m
.02756 .52091 L
s
.02381 .53857 m
.02756 .53857 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .02649 m
.02756 .02649 L
s
.02381 .00883 m
.02756 .00883 L
s
.02381 .59155 m
.02756 .59155 L
s
.02381 .6092 m
.02756 .6092 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -180 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.29) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(genSin) show
147.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
159.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phases) show
201.000 12.750 moveto
(0) show
207.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
213.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
219.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
225.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
237.000 12.750 moveto
(for) show
261.000 12.750 moveto
(m) show
273.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
285.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
297.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02474 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .015 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
.02381 .16187 m
.06244 .23088 L
.10458 .31175 L
.14415 .38761 L
.18221 .45561 L
.22272 .5178 L
.26171 .5637 L
.28302 .58185 L
.29279 .58839 L
.30316 .59406 L
.31266 .59809 L
.31807 .59988 L
.32313 .60121 L
.32777 .60215 L
.33201 .60277 L
.33436 .60301 L
.33568 .60312 L
.33691 .6032 L
.33809 .60325 L
.33917 .60329 L
.3404 .60331 L
.34157 .60332 L
.34273 .60331 L
.34398 .60327 L
.34515 .60322 L
.34622 .60316 L
.34885 .60295 L
.35133 .60267 L
.35627 .60188 L
.36165 .60066 L
.37124 .59758 L
.38012 .5937 L
.39878 .58239 L
.41939 .56509 L
.45959 .51812 L
.49828 .45906 L
.53942 .38569 L
.57904 .30965 L
.61715 .23641 L
.65771 .16358 L
.69676 .1032 L
.71667 .07742 L
.73825 .05399 L
.75906 .03629 L
.76896 .02965 L
.77824 .02451 L
.78728 .02053 L
.79193 .01888 L
.797 .01739 L
.79987 .01669 L
Mistroke
.80253 .01614 L
.80529 .01566 L
.80778 .01531 L
.81024 .01505 L
.81256 .01487 L
.81383 .0148 L
.815 .01475 L
.81628 .01472 L
.81693 .01472 L
.81764 .01472 L
.81895 .01473 L
.82016 .01476 L
.82079 .01479 L
.82149 .01482 L
.8229 .0149 L
.82546 .01512 L
.82787 .01541 L
.83236 .01613 L
.83719 .0172 L
.84251 .01873 L
.84811 .02071 L
.85811 .02524 L
.8779 .0378 L
.89628 .05361 L
.93537 .09936 L
.97619 .16187 L
Mfstroke
.02381 .05414 m
.06244 .09948 L
.10458 .16424 L
.14415 .23528 L
.18221 .30837 L
.22272 .38611 L
.26171 .45584 L
.30316 .51926 L
.32392 .54541 L
.34309 .56563 L
.36173 .58138 L
.37125 .58784 L
.3815 .59356 L
.3917 .59797 L
.40103 .60086 L
.40552 .60186 L
.40789 .60228 L
.41042 .60265 L
.41284 .60293 L
.41504 .60312 L
.4161 .60319 L
.41725 .60325 L
.41834 .60329 L
.41933 .60331 L
.4206 .60332 L
.42179 .60331 L
.42287 .60329 L
.42403 .60324 L
.4253 .60318 L
.42665 .60309 L
.42907 .60286 L
.4313 .60259 L
.43339 .60228 L
.43816 .60135 L
.44335 .60002 L
.4481 .5985 L
.45882 .59403 L
.46862 .58869 L
.47775 .58268 L
.49845 .56539 L
.53749 .52011 L
.57899 .4568 L
.61897 .38533 L
.65744 .31153 L
.69836 .23295 L
.73776 .16243 L
.77565 .10386 L
.79673 .07659 L
.81599 .05559 L
.8359 .03817 L
Mistroke
.85481 .02595 L
.86442 .02141 L
.86969 .01942 L
.87466 .01786 L
.8793 .01668 L
.88174 .01617 L
.88431 .01572 L
.88649 .0154 L
.88887 .01512 L
.88991 .01502 L
.89103 .01493 L
.89208 .01486 L
.89306 .01481 L
.89428 .01476 L
.89493 .01474 L
.89563 .01472 L
.89632 .01472 L
.89705 .01472 L
.89836 .01473 L
.89957 .01476 L
.9007 .01481 L
.90193 .01488 L
.90325 .01498 L
.90625 .01528 L
.90906 .01567 L
.91434 .01668 L
.91937 .01796 L
.924 .01943 L
.93447 .02374 L
.94419 .02897 L
.95327 .03489 L
.97392 .05197 L
.97619 .05414 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->12,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003o<@3oool0
0`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340
oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo
000a0?ooo`<00000o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?oo
o`030000003oool0oooo0?l0oooo3`3oool=00000180oooo3@00000B0?ooo``00000903oool00340
oooo00<000000?ooo`3oool0o`3oool<0?ooo`<000003@3oool4000000X0oooo1000000=0?ooo`@0
0000303oool2000000`0oooo1000000P0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
0P00000D0?ooo`8000001P3oool2000001D0oooo0P0000060?ooo`@000004P3oool3000001d0oooo
000a0?ooo`030000003oool0oooo0?l0oooo203oool2000001P0oooo0P0000020?ooo`8000006@3o
ool200000080oooo0P00000I0?ooo`<000006P3oool00340oooo0`00003o0?ooo`H0oooo0P00000L
0?ooo`8000007@3oool2000001h0oooo0P00000H0?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
o`@0oooo0P00000M0?ooo`80000000<0oooo0000000000006@3oool200000080oooo0P00000N0?oo
o`8000005P3oool00340oooo00<000000?ooo`3oool0o`3oool20?ooo`8000007@3oool2000000D0
oooo0P00000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0C0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooo`8000007@3oool2000000T0oooo
00<000000?ooo`3oool04@3oool2000000P0oooo0P00000N0?ooo`030000003oool0oooo0180oooo
000;0?ooo`@000001P3oool2000000D0oooo1`0000030?ooo`@000001`3oool00`000000oooo0?oo
o`3m0?ooo`8000007@3oool2000000`0oooo0P00000?0?ooo`800000303oool2000001d0oooo00<0
00000?ooo`3oool04@3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`800000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0@0?ooo`002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0K0?oo
o`800000403oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool400000?T0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo00000`3oool00000
00000004000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3h0?ooo`800000
7@3oool2000001H0oooo0P0000060?ooo`030000003oool0oooo01@0oooo0P00000M0?ooo`030000
003oool0oooo00`0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`040?ooo`@000001`3oool00`000000oooo0?ooo`3g0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool06`3oool2000000`0oooo000:0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01X0oooo00@000000?ooo`3oool000006`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool3
000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3e0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0703oool2000001d0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`080?ooo`002`3oool400000100oooo00<000000?ooo`3oool0103oool50000
00H0oooo0P00003e0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool20000
01h0oooo00<000000?ooo`3oool09P3oool00340oooo00<000000?ooo`000000l`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool000007P3oool00`00
0000oooo0?ooo`0U0?ooo`00<@3oool300000?80oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`0000007P3oool00`000000oooo0?ooo`0U0?oo
o`00<@3oool010000000oooo0?ooo`00003`0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0903oool00340oooo00D000000?ooo`3oool0oooo0000003_0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool08`3oool00340oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3[0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool08P3oool00340oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool08@3oool00340oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3W0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0803oool00340oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0803oool00340oooo0`0000050?ooo`030000003oool0oooo0>@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0O0?ooo`00<@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0>80oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0N0?ooo`00
<@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0M0?ooo`00<@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0=l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`00<@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`00<@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0=`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`00<@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0J0?ooo`00<@3oool3000000/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01T0oooo000a0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0e`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo000a
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01L0oooo000a0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0e03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo000a0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01H0oooo000a0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
d@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo000a0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01D0oooo000a0?ooo`<00000403oool00`000000oooo0?ooo`3?0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0503oool00340oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`3=0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool00340
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool04`3oool001@0oooo100000060?ooo`8000001@3oool7000000D0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool04P3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0b@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo000C
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0100oooo000:0?ooo`H0
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01P3oool4000001@0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00l0oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00l0oooo000C0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00h0oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool3
000000P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`310?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool03@3oool001@0oooo1000000@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool03@3oool00340oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`2o0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool00340oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool02`3oool00340oooo0`00000J0?ooo`030000003oool0oooo0;`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`00<@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:
0?ooo`00<@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0;T0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`090?ooo`00<@3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0;P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`090?ooo`00
<@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`080?ooo`00<@3oool2000001h0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0V0?ooo`00<@3oool2000001l0oooo00<000000?ooo`3oool0]03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0V0?ooo`00<@3oool3000001h0oooo00<000000?ooo`3oool0/`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0U0?ooo`00<@3oool00`000000oooo0000000O0?ooo`030000003oool0oooo0;80
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool09@3oool00340oooo00@000000?ooo`3oool000007P3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo02@0oooo000a0?ooo`040000003oool0oooo000001l0
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0T0?ooo`00<@3oool01@000000oooo
0?ooo`3oool0000001h0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0S0?ooo`00
<@3oool01@000000oooo0?ooo`3oool0000001l0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0S0?ooo`00<@3oool300000080oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0240oooo000a
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2[
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo0240oooo000a0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0200oooo000a0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2Y0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0200oooo000a0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01l0oooo000a0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo01l0oooo000a0?ooo`<000001P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0:D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool07P3oool00340oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool07P3oool00340
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool07@3oool00340oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0703oool000/0oooo1000
00060?ooo`8000001P3oool4000000D0oooo100000070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01`0oooo000:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0X03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0K0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool06`3oool000X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`@000002@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
09h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool06P3oool000030?ooo`000000000000@000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool06P3oool000X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool4000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool06@3oool000X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01T0oooo000:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0H
0?ooo`002`3oool4000000h0oooo100000050?ooo`D000001P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0G0?oo
o`00<@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0G0?ooo`00<@3oool3000000h0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01H0oooo000a0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo01H0oooo000a0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01D0oooo000a0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
01D0oooo000a0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo01@0oooo000a0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01@0oooo
000a0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo01<0oooo000a0?ooo`<000004@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool04`3oool00340oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool04P3oool00340oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool04P3oool00340oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
4@3oool00340oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00H00000=`3oool4000003L0oooo1000000?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool400000180oooo00<000000?ooo`3oool0703oool7000000<0oooo1000
000]0?ooo`L000000P3oool6000000030?ooo`000000oooo0180oooo000a0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0703oool00`000000oooo000000040?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000B0?ooo`00<@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01`0oooo00@000000?ooo`3oool00000?@3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo000a0?ooo`<000005@3oool0
0`000000oooo0?ooo`0L0?ooo`040000003oool0oooo000003P0oooo1P00000f0?ooo`8000000`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3o
ool00340oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0L0?ooo`040000003oool0
oooo000003P0oooo00@000000?ooo`3oool00000=`3oool00`000000oooo00000002000000d0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`@00000403oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0?0?ooo`00<@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01`0oooo00D0
00000?ooo`3oool0oooo0000000g0?ooo`040000003oool0oooo000003L0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo000a0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool06`3oool2000000<0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0000000h0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000a0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool06`3oool2000000<0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0000000i0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0P0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02/0oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0=0?ooo`00<@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01/0oooo1000000i0?ooo`800000>P3oool3000000X0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0:0?ooo`@000003P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00@0oooo1000000`0?ooo`030000003oool0oooo00@0oooo100000060?ooo`030000003oool0
oooo00d0oooo000a0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`220?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo00`0oooo000a0?ooo`<000006@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0303oool00340oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0800oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool02`3oool00340oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool00340oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool02P3oool00340oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool02P3oool00340oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool02@3oool00340oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool02@3oool002P0ooooo`00002900000000<@3oool2
000000d0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000<0?ooo`030000003oool0
oooo00`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02P3oool00340oooo0P00000O0?ooo`030000003oool0oooo01P0oooo00D0
00000?ooo`3oool0oooo0000000f0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
6@3oool00340oooo00<000000?ooo`0000007P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo08D0oooo000a0?ooo`030000003oool0000001l0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`260?ooo`00<@3oool010000000oooo0?ooo`00000N0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0QP3oool00340oooo00@000000?ooo`3oool000007`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08L0oooo000a0?ooo`<0000000<0oooo0000
003oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0780oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo08L0oooo000a0?ooo`05
0000003oool0oooo0?ooo`0000007`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
08P0oooo000a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo08P0oooo000a0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08T0oooo
000a0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo08T0oooo000a0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08X0oooo000a0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo08X0oooo000a0?ooo`<00000103oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0R`3oool00340oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
R`3oool00340oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0S03oool00340oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0S03oool0
0340oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0S@3oool00340oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0S@3oool00340oooo
0`0000070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`2>0?ooo`00<@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`2>0?ooo`00<@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1Q
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2?
0?ooo`00<@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`2?0?ooo`00<@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2@0?ooo`00
<@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`2@0?ooo`00<@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2A0?ooo`00<@3oool3
000000/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0940oooo000a0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0980oooo000a0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0980
oooo000a0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo09<0oooo000;0?ooo`@000001P3oool2000000H0oooo1000
00050?ooo`@000001`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`2D0?ooo`002P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0U03o
ool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo09D0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool40000
00h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
09D0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`2F0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`@000001`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`2G0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0U`3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo09P0oooo000;0?ooo`@000003P3oool4000000D0oooo1@0000060?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo09P0oooo000a0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo09T0oooo000a0?ooo`<00000
4`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
VP3oool00340oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0VP3oool00340oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0V`3oool0
0340oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0V`3oool00340oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0W03oool00340oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0W03oool00340oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0W@3oool00340oooo0`00000G
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2N
0?ooo`00<@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`2N0?ooo`00<@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2O0?ooo`00
<@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`2O0?ooo`00<@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2P0?ooo`00<@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`2Q0?ooo`00<@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2Q0?ooo`00<@3oool3000001/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0:80
oooo000a0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0:80oooo000a0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0:<0oooo000a
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0:@0oooo000a0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0:@0oooo000a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0:D0oooo000a0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0:H0oooo000a0?ooo`<000007`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0YP3o
ool00340oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0Y`3oool00340oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0Y`3oool001@0
oooo100000060?ooo`8000001@3oool7000000D0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0Z03oool001<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0:T0oooo000C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0:T0oooo000C
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0:X0oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`060?ooo`@000008`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0Z`3oool001<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0Z`3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0[03oool001<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`<00000203oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2]0?ooo`00503oool4
00000100oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2]0?ooo`00<@3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`2^0?ooo`00<@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2_0?ooo`00<@3oool3000002P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0:l0oooo
000a0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0;00oooo000a0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;00oooo000a0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0;40oooo000a0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0;80oooo000a0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0;80oooo000a0?ooo`<00000;03oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0/`3oool00340oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0]03oool0
0340oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0]@3oool00340oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0]P3oool00340oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0]P3oool00340oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0]`3oool00340oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0^03oool00340oooo0`00000b0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`2i0?ooo`00<@3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2j0?ooo`00
<@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`2k0?ooo`00<@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2k0?ooo`00<@3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`2l0?ooo`00<@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2m0?ooo`00<@3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`2n0?ooo`00<@3oool3000003P0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0;l0oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`000000
7`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0<00oooo000a0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0000001l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`300?ooo`00<@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0`@3oool0
00/0oooo100000060?ooo`8000001@3oool7000000<0oooo100000070?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000003oool00000
01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`320?ooo`002P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0703oool2000001T0oooo00D000000?ooo`3oool0oooo0000000K0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0``3oool000X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo0P00000N0?ooo`03
0000003oool0oooo0<@0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo1000000n0?ooo`800000
7P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo0P00000E0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0a@3oool000X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01`0oooo0P00000B0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0L0?ooo`800000b03o
ool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00@0oooo100000070?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool2
000001h0oooo00<000000?ooo`3oool0b03oool000X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`390?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo0`0000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo0P00000@0?ooo`030000003oool0oooo00T0
oooo0P00000O0?ooo`030000003oool0oooo0<X0oooo000;0?ooo`@00000403oool00`000000oooo
0?ooo`040?ooo`D000001P3oool00`000000oooo0?ooo`150?ooo`8000007P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0140oooo0P0000080?ooo`030000003oool0oooo01d0oooo
0P00003=0?ooo`00<@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0103oool2000001H0oooo00<000000?ooo`3oool00`3oool2000001h0oooo0P00
003?0?ooo`00<@3oool3000004P0oooo0P00000M0?ooo`8000000P3oool2000001T0oooo0P000000
0`3oool000000000000N0?ooo`800000d@3oool00340oooo00<000000?ooo`3oool0BP3oool20000
01d0oooo0P00000L0?ooo`<000007@3oool200000=<0oooo000a0?ooo`030000003oool0oooo04`0
oooo0P00000H0?ooo`<000000P3oool2000001P0oooo0P0000030?ooo`8000006@3oool200000=D0
oooo000a0?ooo`030000003oool0oooo04h0oooo1000000A0?ooo`<000001`3oool400000180oooo
0P0000070?ooo`<000004P3oool400000=L0oooo000a0?ooo`030000003oool0oooo0580oooo1P00
00060?ooo`D000003P3oool6000000H0oooo1P00000<0?ooo`L000001P3oool500000=/0oooo000a
0?ooo`030000003oool0oooo05P0oooo1P00000I0?ooo`H000006@3oool600000>00oooo000a0?oo
o`030000003oool0oooo0?l0ooooO@3oool00340oooo0`00003o0?ooogd0oooo000a0?ooo`030000
003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?ooogd0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
001@0?ooo`@00000<P3oool400000?l0oooo9`3oool005@0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0Q@3oool0
05@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`290?ooo`800000403oool20000
08H0oooo000m0?ooo`@000001@3oool7000000<0oooo0`0000000`3oool000000?ooo`040?ooo`80
00001@3oool6000000@0oooo0`0000070?ooo`8000003`3oool3000000030?ooo`000000oooo00@0
oooo100000030?ooo`<000000P3oool300000080oooo00<000000?ooo`0000000P0000030?ooo`L0
00000P3oool300000080oooo0`0000030?ooo`8000003P3oool5000000@0oooo0`0000020?ooo`<0
00000`3oool5000000<0oooo1@0000050?ooo`@00000103oool5000000d0oooo100000060?ooo`03
0000003oool0oooo00@0oooo1`0000040?ooo`030000003oool0oooo00@0oooo1P00000>0?ooo`D0
0000103oool4000000@0oooo1@00000;0?ooo`<0000000@0oooo000000000000oooo0P00000L0?oo
o`L000000P3oool6000001L0oooo000n0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`3oool2000000D0oooo0P0000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`8000003P3oool01000
0000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0P00000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P000008
0?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02P3oool6000000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01D0oooo000n0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`070?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?oo
o`00?P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo1P0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?oo
o`D00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo100000050?oo
o`@00000103oool6000000@0oooo1000000<0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`00?P3oool4000000L0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`3oool2000000l0oooo00<000000?ooo`3oool01@3oool5
000001@0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo100000060?ooo`030000
003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`3oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool2000000h0oooo0P0000001@3oool000000000003oool0000000`0oooo
1P00000>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05`3oool003h0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`<000001P3oool3000000030?ooo`000000000000l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0
oooo0`0000000`3oool00000000000040?ooo`@000000`3oool2000000040?ooo`00000000000000
00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000D0oooo0P000000
103oool0000000000000000F0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0oooo
0000003oool3000000D0oooo0`0000060?ooo`D00000103oool4000000D0oooo1@00000;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00`0oooo1P0000040?ooo`@00000103oool2000000040?ooo`00000000000000
00X0oooo0P0000001@3oool000000?ooo`3oool000000240oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0F0?ooo`00?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`3oool2000002L0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000003@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo000m0?ooo`L000007@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`<0000000<0oooo0000003oool09@3oool6000000@0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo0`00000>
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`13
0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00190?oo
o`030000003oool0oooo01H0oooo100000060?ooo`@00000?03oool00`000000oooo0?ooo`0W0?oo
o`800000=@3oool400000100oooo00<000000?ooo`3oool03@3oool400000140oooo0`0000140?oo
o`030000003oool0oooo00@0oooo1000000H0?ooo`00B@3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0?l0oooo0P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 1149.25}, {709, 0}} -> {-1.68585, -0.175695, \
0.0506953, 0.00217583}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "\n\tMulti-phase sinusoids have an exponential series formulation that \
simplifies, when ",
  StyleBox["m",
    FontSlant->"Italic"],
  " = 4, to half the standard Cos and Sin series, with alternate terms \
becoming zero. ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ x\)\)]],
  " = {Cos[x]/2, Sin[x]/2, -Cos[x]/2, -Sin[x]/2}. This is traditionally \
folded and mis-interpreted as two asymmetrical phases, {Cos[x], Sin[x]} \
instead of four symmetrical phases.\n\tIt is convenient to include a phase \
parameter \"j\" in the generalised sinusoid procedures ",
  StyleBox["genCos[x,m,j]",
    FontSlant->"Italic"],
  " & ",
  StyleBox["genSin[x,m,j],",
    FontSlant->"Italic"],
  " and to normalize the amplitude to 1. Cosh and Sinh functions are included \
via ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=0 and ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=2, which do not give sinusoids."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[TextData[{
  StyleBox["Figure 30.",
    FontWeight->"Bold"],
  "  genCos, genSin."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?genCos\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData["\<\"genCos[x_,m_:4,j_:0] creates the \!\(\*   \
StyleBox[\\\"j\\\",\\nFontSlant->\\\"Italic\\\"]\)'th phase of the \
generalized antisymmetric sinusoid or helix with \!\(\*   StyleBox[\\\"m\\\",\
\\nFontSlant->\\\"Italic\\\"]\) phases; generalised Cosh and Sinh functions \
are generated if \!\(\*   \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*   \
StyleBox[\\\"=\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   StyleBox[\\\"0\\\",\
\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   \
StyleBox[\\\"or\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   StyleBox[\\\"2\\\",\\nFontSlant->\
\\\"Plain\\\"]\).\"\>"], "Print",
  PageWidth->WindowWidth,
  CellTags->"Info3353843803-4044115"]
}, Closed]],

Cell[BoxData[
    \(genCos[x_, m_:  4, j_:  0] := 
      Which[m == 0, 
        j \((\[ExponentialE]\^\(\(\ \)\(x\)\) + \[ExponentialE]\^\(-x\))\)/2, 
        m == 2, Re[\[ExponentialE]\^x + \(\((\(-1\))\)\^j\) \[ExponentialE]\^\
\(\(\ \)\(-x\)\)]/2, \[IndentingNewLine]True, 
        Re[\(\((\(-1\))\)\^\(2 \((m - j)\)/
                    m\)\) \[ExponentialE]\^\(\[ImaginaryI]\ Im[\((\(-1\))\)\^\
\(2/m\)]\ x\)]]\)], "Input",
  PageWidth->WindowWidth,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?genSin\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData["\<\"genSin[x_,m_:4,j_:0] creates the \!\(\* StyleBox[\\\"j\\\",\
\\nFontSlant->\\\"Italic\\\"]\)'th phase of the generalized symmetric \
sinusoid or helix with \!\(\* \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]\) phases; generalised Cosh \
and Sinh functions are generated if \!\(\* \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* \
StyleBox[\\\"=\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"0\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"or\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\"2\\\",\\nFontSlant->\\\
\"Plain\\\"]\).\"\>"], "Print",
  PageWidth->WindowWidth,
  CellTags->"Info3353241802-8811303"]
}, Closed]],

Cell[BoxData[
    \(genSin[x_, m_:  4, j_:  0] := 
      Which[m == 
          0, \((\[ExponentialE]\^\(\(\ \)\(x\)\) - \[ExponentialE]\^\(-x\))\)/
          2, m == 2, 
        Re[\(\((\(-1\))\)\^j\) \[ExponentialE]\^\(\(\ \)\(x\)\) - \
\[ExponentialE]\^\(-x\)]/2, \[IndentingNewLine]True, 
        Im[\(\((\(-1\))\)\^\(2 \((m - j)\)/
                    m\)\) \[ExponentialE]\^\(\[ImaginaryI]\ Im[\((\(-1\))\)\^\
\(2/m\)]\ x\)]]\)], "Input",
  PageWidth->WindowWidth,
  FontWeight->"Plain"],

Cell[TextData[{
  "\tNote that neither the phasality ",
  StyleBox["m",
    FontSlant->"Italic"],
  " nor the phase ",
  StyleBox["j",
    FontSlant->"Italic"],
  " need be an integer. Also ",
  StyleBox["genCos[x,m,m/4] \[Congruent] genSin[x,m]",
    FontSlant->"Italic"],
  ", so one of the series is redundant. Both are included for compatibility \
with normal mathematics, with ",
  StyleBox["genSin",
    FontSlant->"Italic"],
  " as the antisymmetric sinusoid. ",
  StyleBox["genSin",
    FontSlant->"Italic"],
  " is preferable to ",
  StyleBox["genCos",
    FontSlant->"Italic"],
  " in some situations such as Direction Sines, as ",
  StyleBox["genSin[x,m,0]\[ShortRightArrow] x",
    FontSlant->"Italic"],
  " for small ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and the value tends to zero with ",
  StyleBox["x",
    FontSlant->"Italic"],
  ". When x = 0, terms involving ",
  StyleBox["genSin[x,m,0]",
    FontSlant->"Italic"],
  " drop out of expressions, making them compatible with renormalization."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.11. Generalizing Complex maths.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". Equations and functions containing \[ImaginaryI]  are often special \
cases of  more generalized functions containing the generalized sign \
\[DoubleStruckS]."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[TextData[{
  "\tJust as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ x\)\)]],
  " is a special case of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\_r\%\(\(\(\(\[DoubleStruckS]\)\(\ \)\
\)\^j\) x\)\)]],
  "and Cos[x]+\[ImaginaryI] Sin[x] generalizes to multi-phase sinusoids, many \
other complex functions appear to be special cases of more general functions \
involving \[DoubleStruckS]. Others may be unique to the r=4 case, giving \
complex maths a unique central position in mathematics. The author has \
neither the time nor the ability to explore this vast topic, but makes the \
following observations.\n(1). Generalized signs act as relators for most \
groups. Only a subset have \[ImaginaryI] as a relator, and many of this \
subset have additional relators that are different fourth roots of unity. \
E.g. C4C4, C4iC4, Pauli-\[Sigma] algebra.\n(2). A lot of group theory is \
concerned with unitary complex matrices that dot-multiply to provide the \
elements of particular classes of groups. The Pauli-\[Sigma] algebra is \
archetypical, as it has a representation as \[Sigma]-matrices, which involve \
\[ImaginaryI]. Many other groups have representations via small matrices \
involving other signs. These are widely used in ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  "\n(3). \[ImaginaryI] is an intrinsic feature of both Schroedinger's \
equation and Fourier analysis. Together [3] they lead to dispersive Gaussian \
wave packets that describe \"information about particles\". But particles do \
not disperse, and it is an article of the physicist's creed that mathematics \
is the language in which existence is written. Therefore there should be a \
mathematical formulation for particles, possibly as a version of \
Schroedinger's equation involving \[DoubleStruckS]. Hoop algebras provide \
tantalizing glimpses of possibilities for physical mathematics using \
generalized signs."
}], "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["3.12. Unital \"Orbits\" & sub-algebras. Orbits with \"Offsets\".", \
"Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  StyleBox["Summary",
    FontSlant->"Plain"],
  ". Polar-duals become continuous \"Orbits\" when the non-zero offsets and \
squared radii (or their product) are constrained to be one, defining \"unital\
\" sub-algebras. Many orbits appear to be unstable and have zero size. The \
implications of the few cases with finite sizes are discussed later."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["C3, K & C4 Orbits have fixed amplitudes.", "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tFinite groups have finite \"orbits\", sets of points. These become \
continuous orbits (continuous multi-phase sinusoids) in algebras with \
polar-duals - the duals form an equivalence class if offsets and squared \
radii (or ulnae) are constrained to values of 0 or 1 whilst angles are \
allowed to vary. They constitute continuous closed unitary sub-algebras; \
group multiplication of two orbits gives another orbit.\n\tOnce a hoop is \
specified, Orbit vector values are given by ",
  StyleBox["toVector[P]",
    FontSlant->"Italic"],
  " using arbitrary or symbolic angles, all other parameters in P being 0 or \
1. The three C3 and four C4 orbits are set up in Figure 31; the names \
correspond to the sizes. Note that ",
  StyleBox["shape[\"C3\"]",
    FontSlant->"Italic"],
  " has one L1 (linear) and one L2 (quadratic) size whilst a C3 vector has 3 \
degrees of freedom. Similarly, ",
  StyleBox["shape[\"C4\"]",
    FontSlant->"Italic"],
  " has three size parameters to describe a 4-element vector. Each squared \
radius releases a degree of freedom. This is taken up by the angle parameter, \
which is a \"hidden variable\" for the cartesian form. Each polar-dual \
includes an angle for each quadratic size in the shape. The linear sizes \
become offsets from zero for the centre of rotation, providing conserved \
properties that are not present in the \"standard model\" of particles.\n\t\
Figure 31 also sets up and multiplies the C3 orbits, showing the product to \
be an orbit with the angles added. Then four C4 orbit pairs are set up and \
multiplied; the products have the correct sizes for orbits:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Figure 31. ",
  StyleBox["C3 & C4 Orbit Multiplication.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<C3 Orbits\>", 
      hoopShape["\<C3\>"]; "\<\nOC301 is {0,1,a} with vector form\>", 
      OC301 = toVector[{0, 1, a}], "\<\nOC311 is {1,1,b} with vector form\>", 
      OC311 = toVector[{1, 1, 
            b}], "\<\nProducts are orbits with added angles; the polar form \
of the product is\>", 
      Simplify[toPolar[
          hoopTimes[OC301, OC311, 
            C3]]], "\<\n\nC4 Orbits\>", \
\[IndentingNewLine]\(hoopShape["\<C4\>"];\); "\<\nOC4001 is {0,0,1,a} with \
vector form\>", 
      OC4001 = toVector[{0, 0, 1, 
            a}], "\<\nOC4011 is {0,1,1,b} with vector form\>", 
      OC4011 = toVector[{0, 1, 1, 
            b}], "\<\nOC4101 = {1,0,1,c} with vector form\>", 
      OC4101 = toVector[{1, 0, 1, 
            c}], "\<\nOC4111 is {1,1,1,d} with vector form\>", 
      OC4111 = toVector[{1, 1, 1, 
            d}], "\<\n\n\>", \
\[IndentingNewLine]Simplify[{"\<OC4001\[Times]OC4001 has the 001 shape\>", 
          shape[hoopTimes[OC4001, OC4001, 
              C4]], "\<\nOC4101\[Times]OC4011 also has the 001 shape\nas the \
two offsets disappear   \>", 
          shape[hoopTimes[OC4101, 
              OC4011]], "\<\nOC4101\[Times]OC4111 has the 101 shape\>", 
          shape[hoopTimes[OC4101, 
              OC4111]], "\<\nOC4111\[Times]OC4111 has the 111 shape\>", 
          shape[hoopTimes[OC4111, OC4111]]}]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"C3 Orbits", 
      "\nOC301 is {0,1,a} with vector form", {\(2\ Cos[a]\)\/3, 
        2\/3\ Cos[a + \(2\ \[Pi]\)\/3], 2\/3\ Cos[a - \(2\ \[Pi]\)\/3]}, 
      "\nOC311 is {1,1,b} with vector form", {1\/3\ \((1 + 2\ Cos[b])\), 
        1\/3\ \((1 + 2\ Cos[b + \(2\ \[Pi]\)\/3])\), 
        1\/3\ \((1 + 2\ Cos[b - \(2\ \[Pi]\)\/3])\)}, 
      "\nProducts are orbits with added angles; the polar form of the product \
is", {0, 1, ArcTan[Cos[a + b], Sin[a + b]]}, "\n\nC4 Orbits", 
      "\nOC4001 is {0,0,1,a} with vector form", {Cos[a]\/2, 
        Sin[a]\/2, \(-\(Cos[a]\/2\)\), \(-\(Sin[a]\/2\)\)}, 
      "\nOC4011 is {0,1,1,b} with vector form", {1\/4\ \((1 + 2\ Cos[b])\), 
        1\/4\ \((\(-1\) + 2\ Sin[b])\), 1\/4\ \((1 - 2\ Cos[b])\), 
        1\/4\ \((\(-1\) - 2\ Sin[b])\)}, 
      "\nOC4101 = {1,0,1,c} with vector form", {1\/4\ \((1 + 2\ Cos[c])\), 
        1\/4\ \((1 + 2\ Sin[c])\), 1\/4\ \((1 - 2\ Cos[c])\), 
        1\/4\ \((1 - 2\ Sin[c])\)}, 
      "\nOC4111 is {1,1,1,d} with vector form", {1\/4\ \((2 + 2\ Cos[d])\), 
        Sin[d]\/2, 1\/4\ \((2 - 2\ Cos[d])\), \(-\(Sin[d]\/2\)\)}, 
      "\n\n", {"OC4001\[Times]OC4001 has the 001 shape", {0, 0, 1}, 
        "\nOC4101\[Times]OC4011 also has the 001 shape\nas the two offsets \
disappear   ", {0, 0, 1}, 
        "\nOC4101\[Times]OC4111 has the 101 shape", {1, 0, 1}, 
        "\nOC4111\[Times]OC4111 has the 111 shape", {1, 1, 1}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe group K (C2C2) cannot have a polar orbit as it has no L2 size, but \
the four L1 sizes can be combined in six ways to give paired \
difference-of-squares formulations. Hyperbolic orbits can be defined using \
any of these as (adjacent",
  Cell[BoxData[
      \(TraditionalForm\`\^2\)]],
  ", opposite",
  Cell[BoxData[
      \(TraditionalForm\`\^2\)]],
  ") pairs. Two orbits are set up in Figure 32 and multiplied. The product is \
shown to be an orbit with unit sizes; its \"angles\" appear in complex form \
but numeric substitutions show that they are the sums of those in the \
multiplicands."
}], "Text",
  PageWidth->WindowWidth],

Cell["Figure 32. Klein Group Hyperbolic Orbit Multiplication.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \({hoopShape["\<K\>"]; "\<OKh11a is {1,\[Alpha],1,a} with vector form\n\
\>", OKh11a = 
        tohyVector[{1, \[Alpha], 1, 
            a}], "\<\nOKh11b is {1,\[Beta],1,b} with vector form\>", 
      OKh11b = tohyVector[{1, \[Beta], 1, 
            b}], "\<\nTheir product Polar form is\n\>", 
      Simplify[tohyPolar[
          hoopTimes[OKh11a, 
            OKh11b]]], "\<\nSubstituting \[Alpha]\[Rule].1, \[Beta]\[Rule].3, \
a\[Rule].22, b\[Rule].28 shows that the angles have added; the product angles \
are {\[Alpha]+\[Beta], a+b}:-\n{Log[(Cosh[\[Alpha]+\[Beta]]+Sinh[\[Alpha]+\
\[Beta]])],Log[(Cosh[a+b]+Sinh[a+b])]} = \>", {Log[\((Cosh[\[Alpha] + \
\[Beta]] + Sinh[\[Alpha] + \[Beta]])\)], 
          Log[\((Cosh[a + b] + Sinh[a + b])\)]} /. {\[Alpha] \[Rule]  .1, 
          a \[Rule]  .22, \[Beta] \[Rule]  .3, b \[Rule]  .28}}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"OKh11a is {1,\[Alpha],1,a} with vector form\n", {Cosh[a]\/2 + 
          Cosh[\[Alpha]]\/2, 
        Sinh[a]\/2 + Sinh[\[Alpha]]\/2, \(-\(Cosh[a]\/2\)\) + 
          Cosh[\[Alpha]]\/2, \(-\(Sinh[a]\/2\)\) + Sinh[\[Alpha]]\/2}, 
      "\nOKh11b is {1,\[Beta],1,b} with vector form", {Cosh[b]\/2 + 
          Cosh[\[Beta]]\/2, 
        Sinh[b]\/2 + Sinh[\[Beta]]\/2, \(-\(Cosh[b]\/2\)\) + 
          Cosh[\[Beta]]\/2, \(-\(Sinh[b]\/2\)\) + Sinh[\[Beta]]\/2}, 
      "\nTheir product Polar form is\n", {1, 
        If[Cosh[\[Alpha] + \[Beta]] == Sinh[\[Alpha] + \[Beta]] || 
            Cosh[\[Alpha] + \[Beta]] + Sinh[\[Alpha] + \[Beta]] == 0, 
          If[x$3959 \[NotEqual] 
              0, \(\[Infinity]\ Sign[y$3959]\)\/Sign[x$3959], 0, 0], 
          b$3959 = Log[N[\(x$3959 + y$3959\)\/\@\(x$3959\^2 - y$3959\^2\)]]; 
          Chop[Re[b$3959] + \[ImaginaryI]\ Chop[Im[b$3959]]]], 1, 
        If[Cosh[a + b] == Sinh[a + b] || Cosh[a + b] + Sinh[a + b] == 0, 
          If[x$3960 \[NotEqual] 
              0, \(\[Infinity]\ Sign[y$3960]\)\/Sign[x$3960], 0, 0], 
          b$3960 = Log[N[\(x$3960 + y$3960\)\/\@\(x$3960\^2 - y$3960\^2\)]]; 
          Chop[Re[b$3960] + \[ImaginaryI]\ Chop[Im[b$3960]]]]}, 
      "\nSubstituting \[Alpha]\[Rule].1, \[Beta]\[Rule].3, a\[Rule].22, b\
\[Rule].28 shows that the angles have added; the product angles are \
{\[Alpha]+\[Beta], a+b}:-\n\
{Log[(Cosh[\[Alpha]+\[Beta]]+Sinh[\[Alpha]+\[Beta]])],Log[(Cosh[a+b]+Sinh[a+b]\
)]} = ", {0.4`, 0.5`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C5, C7 & C8 Orbits have unstable amplitudes.", "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThe orbits of C3 are of fixed squared radius 2/3 and offsets {0,0,0} or \
{1/3, 1/3, 1/3).  Those of C4 are of fixed squared radii or ulnae of \
magnitude 1/2, and offsets {0,..} or {\[PlusMinus]1/4,..}. For C2 there is \
only one, hyperbolic, orbit with a unit ulna. Orbits of C5, C7, Cp (p \
prime>3) etc can be developed, with p sinusoidal phases, but their radii are \
unconstrained, though their offsets are 0 or 1/p. Examples in [1] shows that \
OC51r, a five-phase orbit with radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", has a quartic size of zero and so is unconstrained. The angle, linear L1 \
and quartic parameters only use 3 of the 5 degrees of freedom. Similarly, a \
seven-phase orbit with radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  " has a zero size in C7 (I have not found a polar expression for this \
group) and an eight-phase orbit in C8 has a zero size. These orbits also \
appear to be unstable - numerical integration of the relevant \
differential-equation sets is unstable."
}], "Text",
  PageWidth->WindowWidth],

Cell["Figure 33.  Zero-sized C5 orbit.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{genShape[\"C5\"];\"OC51r is\",OC51r = 
    toVector[{d, r, \[Sigma]}], 
  \"\\nThe radius disappears from the shape\", 
  Simplify[shape[OC51r]]}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier"],

Cell[BoxData[
    \({"OC51r is", {\(1\/5\) \((d + r  Sin[\[Sigma]])\), \(1\/5\) \((d + 
              r  Sin[\(2\/5\) \[Pi] + \[Sigma]])\), \(1\/5\) \((d + 
              r  Sin[\(4\/5\) \[Pi] + \[Sigma]])\), \(1\/5\) \((d + 
              r  Sin[\(6\/5\) \[Pi] + \[Sigma]])\), \(1\/5\) \((d + 
              r  Sin[\(8\/5\) \[Pi] + \[Sigma]])\)}, 
      "\nThe radius disappears from the shape", {\(1\/5\) \((5  d + 
              r  Sin[\[Sigma]] + r  Sin[\(2\/5\) \[Pi] + \[Sigma]] + 
              r  Sin[\(4\/5\) \[Pi] + \[Sigma]] + 
              r  Sin[\(6\/5\) \[Pi] + \[Sigma]] + 
              r  Sin[\(8\/5\) \[Pi] + \[Sigma]])\), 0}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\t Stable, finite amplitude, orbits with 3, 4, 6, 9, and 12 phases have been \
found, some of which have polarization and chirality (Section 13).\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.13. Dozal Orbits, Analogies with Particles & Forces.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary. ",
  StyleBox["Dozal (the algebra of vectors with 12 elements) has elements that \
act as half-spin and unit-spin quantum operators, and stable orbits (some \
with polarization and chirality) that match the families of fundamental \
particles. Dozal is in a real subsymmetric relationship with Hexal (6 \
elements), and a ternal subsymmetric relationship with Tetral (4 elements). \
Multiplication with remainders may correspond to particle interactions, with \
fission and fusion. Instead of being \"point particles\", quarks may be \
multi-phase wave packets with ternary symmetry, and leptons may be wave \
packets with 4-fold symmetry. ",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tThe Appendix shows that the C3K algebra can be interpreted as having \
elements that act as half-spin quantum operators. They cannot be expressed in \
real or complex terms; they combine C3 (terplex numbers) and K (Study \
numbers, or the hyperbolic plane). Section 10. showed that 12-phase systems \
have a natural period of 4\[Pi] - i.e. they have \"half-spin\".\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\t Stable, finite amplitude, orbits with 3, 4, 6, and 12 phases have been \
found for \"Dozal\", the unitary algebra of 12 elements with several \
multiplication rules. Some of these orbits have polarization and chirality. \
In the following examples, the vector form is expressed as \
{a,b,c,d,e,f,g,h,i,j,k,l} and its polar-dual as {\[Alpha], \[Beta], \[Gamma], \
\[Delta], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \
\[Chi], ",
  StyleBox["\[CurlyKappa]\[CurlyKappa]",
    FontWeight->"Bold"],
  ", \[Psi]} for C3K & D3C2, or {\[Alpha], \[Beta], \[Epsilon]\[Epsilon], \
\[Sigma], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \
\[Chi], ",
  StyleBox["\[CurlyKappa]\[CurlyKappa]",
    FontWeight->"Bold"],
  ", \[Psi]} for C3C4 or Q12. The latter have a 4-phase \
{\[Epsilon]\[Epsilon], \[Sigma]} pair in place of the two linear sizes {\
\[Gamma] ,\[Delta]} of C3K and D3C2. Note that {\[Alpha], \[Beta]} and {\
\[Gamma], \[Delta]} can be replaced by hyperbolic orbits. The following \
expressions are edited to emphasise the inter-relationships between the \
vector and polar forms. In particular, square roots of quadratic polar \
elements such as \[Zeta]\[Zeta] become radii such as \[Zeta], and 2\[Pi]/3 is \
written as \[Omega]:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Figure 34. ",
  StyleBox["C3K Cartesian & Polar-Dual interconversions.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(toPolar[{a, b, c, d, e, f, g, h, i, j, k, 
          l}, "\<C3K\>"];\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({\[Alpha] = a + b + c + d + e + f + g + h + i + j + k + l, \[Beta] = 
        a + b + c - d - e - f + g + h + i - j - k - 
          l, \[IndentingNewLine]\[Gamma] = 
        a + b + c + d + e + f - g - h - i - j - k - l, \[Delta] = 
        a + b + c - d - e - f - g - h - i + j + k + 
          l, \[IndentingNewLine]\[Zeta]\[Zeta] = \((\((a - b + d - e + g - h \
+ j - k)\)\^2 + \((b - c + e - f + h - i + k - l)\)\^2 + \((\(-a\) + c - d + \
f - g + i - j + l)\)\^2)\)/2, \[IndentingNewLine]\[Tau] = 
        ArcTan[2\ a - b - c + 2\ d - e - f + 2\ g - h - i + 2\ j - k - 
            l, \(-\@3\)\ \((b - c + e - f + h - i + k - 
                l)\)], \[IndentingNewLine]\[Lambda]\[Lambda] = \((\((a - b - \
d + e + g - h - j + k)\)\^2 + \((\(-a\) + c + d - f - g + i + j - l)\)\^2 + \
\((b - c - e + f + h - i - k + l)\)\^2)\)/2, \[IndentingNewLine]\[Phi] = 
        ArcTan[2\ a - b - c - 2\ d + e + f + 2\ g - h - i - 2\ j + k + 
            l, \(-\@3\)\ \((b - c - e + f + h - i - k + 
                l)\)], \[IndentingNewLine]\[Eta]\[Eta] = \((\((a - b + d - e \
- g + h - j + k)\)\^2 + \((\(-a\) + c - d + f + g - i + j - l)\)\^2 + \((b - \
c + e - f - h + i - k + l)\)\^2)\)/2, \[IndentingNewLine]\[Chi] = 
        ArcTan[2\ a - b - c + 2\ d - e - f - 2\ g + h + i - 2\ j + k + 
            l, \(-\@3\)\ \((b - c + e - f - h + i - k + 
                l)\)], \[IndentingNewLine]\[CurlyKappa]\[CurlyKappa] = \
\((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - c - e + f - h + i + k - l)\
\)\^2 + \((\(-a\) + c + d - f + g - i - j + l)\)\^2)\)/
          2, \[IndentingNewLine]\[Psi] = 
        ArcTan[2\ a - b - c - 2\ d + e + f - 2\ g + h + i + 2\ j - k - 
            l, \(-\@3\)\ \((b - c - e + f - h + i + k - l)\)]}\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \(C3Kv = 
      toVector[{\[Alpha], \[Beta], \[Gamma], \[Delta], \[Zeta]\[Zeta], \
\[Tau], \[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \[Chi], \[CurlyKappa]\
\[CurlyKappa], \[Psi]}, "\<C3K\>"] /. {2  \[Pi]/3 \[Rule] \[Omega], \ 
          4  \[Pi]/3 \[Rule] 
            2  \[Omega], \@\[Zeta]\[Zeta] \[Rule] \[Zeta], \@\[Lambda]\
\[Lambda] \[Rule] \[Lambda], \@\[Eta]\[Eta] \[Rule] \[Eta], \@\[CurlyKappa]\
\[CurlyKappa] \[Rule] \[CurlyKappa]}\)], "Input",
  PageWidth->WindowWidth],

Cell[TextData[{
  "The above expression is not shown directly, but it tidies up to give\n",
  StyleBox["Figure 35",
    FontWeight->"Bold"],
  ":-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \ \ \ \ \ \)\(C3K\[Alpha]\[Beta]\[Gamma]\[Delta]\[Zeta]\
\[Tau]\[Lambda]\[Phi]\[Eta]\[Chi]\[Kappa]\[Psi]\  . \[IndentingNewLine]{\
\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + 
            2\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + 
            2\ \[Eta]\ Cos[\[Chi]]\ \ \ \ \  + 
            2\ \[CurlyKappa]\ Cos[\[Psi]], \ \[Alpha] + \[Beta] + \[Gamma] + \
\[Delta] + 2\ \[Zeta]\ Cos[\[Tau] + \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + 
            2\ \[Eta]\ Cos[\[Chi] + \[Omega]] + 
            2\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]], \ \[Alpha] + \[Beta] + \
\[Gamma] + \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] - \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]] + 
            2\ \[Eta]\ Cos[\[Chi] - \[Omega]] + 
            2\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]], \ \[Alpha] - \[Beta] + \
\[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  + 
            2\ \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - 
            2\ \[CurlyKappa]\ Cos[\[Psi]], \ \[Alpha] - \[Beta] + \[Gamma] - \
\[Delta] + 2\ \[Zeta]\ Cos[\[Tau] + \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + 
            2\ \[Eta]\ Cos[\[Chi] + \[Omega]] - 
            2\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]], \ \[Alpha] - \[Beta] + \
\[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] - \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]] + 
            2\ \[Eta]\ Cos[\[Chi] - \[Omega]] - 
            2\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]], \ \[Alpha] + \[Beta] - \
\[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  - 
            2\ \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - 
            2\ \[CurlyKappa]\ Cos[\[Psi]], \ \[Alpha] + \[Beta] - \[Gamma] - \
\[Delta] + 2\ \[Zeta]\ Cos[\[Tau] + \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - 
            2\ \[Eta]\ Cos[\[Chi] + \[Omega]] - 
            2\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]], \ \[Alpha] + \[Beta] - \
\[Gamma] - \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] - \[Omega]] + 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]] - 
            2\ \[Eta]\ Cos[\[Chi] - \[Omega]] - 
            
            2\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]], \ \[Alpha] - \[Beta] - \
\[Gamma] + \[Delta] + 2\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - 
            2\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  - 
            2\ \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  + 
            2\ \[CurlyKappa]\ Cos[\[Psi]], \ \[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] + 2\ \[Zeta]\ Cos[\[Tau] + \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - 
            2\ \[Eta]\ Cos[\[Chi] + \[Omega]] + 
            2\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]], \ \[Alpha] - \[Beta] - \
\[Gamma] + \[Delta] + 2\ \[Zeta]\ Cos[\[Tau] - \[Omega]] - 
            2\ \[Lambda]\ Cos[\[Phi] - \[Omega]] - 
            2\ \[Eta]\ Cos[\[Chi] - \[Omega]] + 
            2\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]]}/12\)\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell["\<\
Here, \[Tau] occurs in four copies of a 3-phase system, \[Lambda], \[Eta], & \
\[Psi] each occur in two copies of different 6-phase systems. 12-phase \
systems can be obtained by making two of these systems have the same radii \
and period, but with a phase shift of \[Pi]/6. I conjecture that these are \
related to the three families of quarks.
\tThe C3C4 orbits duplicate the {\[Tau], \[Lambda]} orbits and replace the {\
\[Gamma], \[Delta]} linear sizes by a 4-phase {\[Epsilon], \[Sigma]} \
sinusoid. I conjecture that this is related to the leptons. The {\[Eta], \
\[Kappa]} orbits are more complicated in C3C4 than in C3K:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(Figure\ 36. \ \ General\ C3C4\ \(\(orbit\)\(.\)\)\)], "Input",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, 
            l_}, "\<C3C4\>"] := \[IndentingNewLine]Module[{r = \(-Sqrt[3]\), 
            e1 = a + b + c - g - h - i, 
            e2 = d + e + f - j - k - l, \[IndentingNewLine]a1 = 
              a - b + d - e + g - h + j - k, 
            a2 = a - b - d + e + g - h - j + k, \[IndentingNewLine]b1 = 
              b - c + e - f + h - i + k - l, 
            b2 = b - c - e + f + h - i - k + l, \[IndentingNewLine]c1 = 
              c - a + f - d + i - g + l - j, 
            c2 = c - a - f + d + i - g - l + j, 
            f1 = a - b - g + 
                h + \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f2 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 - d + e + j - 
                k, \[IndentingNewLine]f3 = 
              a - b - g + 
                h - \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f4 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 + d - e - j + 
                k}, \[IndentingNewLine]{ (*\[Alpha]*) a + b + c + d + e + f + 
              g + h + i + j + k + l,  (*\[Beta]*) a + b + c - d - e - f + g + 
              h + i - j - k - l, \[IndentingNewLine] (*\[Epsilon]*) e1\^2 + 
              e2\^2,  (*\[Sigma]*) ArcTan[e1, 
              e2], \[IndentingNewLine] (*\[Zeta]*) \((a1\^2 + b1\^2 + 
                  c1\^2)\)/2,  (*\[Tau]*) ArcTan[a1 - c1, 
              r\ b1], \[IndentingNewLine] (*\[Lambda]*) \((a2\^2 + b2\^2 + 
                  c2\^2)\)/2,  (*\[Phi]*) ArcTan[a2 - c2, 
              r\ b2], \[IndentingNewLine] (*\[Eta]*) \((f1\^2 + f2\^2)\) 
              3/4,  (*x*) 
              ArcTan[f1, f2] - \[Pi]/
                6, \[IndentingNewLine] (*\[Kappa]*) \((f3\^2 + f4\^2)\) 
              3/4,  (*y*) ArcTan[f3, f4] - \[Pi]/6}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  FontSize->9],

Cell[BoxData[
    \({\ \ a = \((\[Alpha] + \[Beta] + \[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ \
Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  + \
\[Eta]\ \ \ \ \ \ Cos[x] + \[Eta]\ r3\ Sin[x] + \[Kappa]\ Cos[
                  y] + \[Kappa]\ r3\ Sin[
                  y])\), \[IndentingNewLine]b = \((\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]] - \[Eta]\ \ \ \ \ \ Cos[x] + \[Eta]\ r3\ Sin[
                  x] - \[Kappa]\ Cos[y] + \[Kappa]\ r3\ Sin[
                  y])\), \ \[IndentingNewLine]c = \((\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  - \
\[Eta]\ r6\ Sin[x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  - \[Kappa]\ r6\ Sin[
                  y])\), \[IndentingNewLine]d = \((\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \  + \[Eta]\ r3\ Cos[x]\ \ \ \  - \[Eta]\ Sin[
                  x] - \[Kappa]\ r3\ Cos[y]\  + \[Kappa]\ Sin[
                  y])\), \[IndentingNewLine]e = \((\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ \
Cos[\[Phi] + \[Omega]] + \[Eta]\ r3\ Cos[x]\ \ \ \  + \[Eta]\ Sin[
                  x] - \[Kappa]\ r3\ Cos[y]\  - \[Kappa]\ Sin[
                  y])\), \[IndentingNewLine]f = \((\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] - \[Eta]\ r6\ Cos[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\
\ r6\ Cos[
                  y]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ )\), \
\[IndentingNewLine]g = \((\[Alpha] + \[Beta] - \[Epsilon]\ \ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau]]\ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - \
\[Eta]\ \ \ \ \ \ Cos[x] - \[Eta]\ r3\ Sin[x] - \[Kappa]\ Cos[
                  y] - \[Kappa]\ r3\ Sin[
                  y])\), \[IndentingNewLine]h = \((\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]] + \[Eta]\ \ \ \ \ \ Cos[x] - \[Eta]\ r3\ Sin[
                  x] + \[Kappa]\ Cos[y] - \[Kappa]\ r3\ Sin[
                  y])\), \ \[IndentingNewLine]i = \((\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \
\[Eta]\ r6\ Sin[x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\ r6\ Sin[
                  y])\), \[IndentingNewLine]j = \((\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \  - \[Eta]\ r3\ Cos[x]\ \ \ \  + \[Eta]\ Sin[
                  x] + \[Kappa]\ r3\ Cos[y]\ \  - \[Kappa]\ Sin[
                  y])\), \[IndentingNewLine]k = \((\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ \
Cos[\[Phi] + \[Omega]] - \[Eta]\ r3\ Cos[x]\ \ \ \  - \[Eta]\ Sin[
                  x] + \[Kappa]\ r3\ Cos[y]\ \  + \[Kappa]\ Sin[
                  y])\), \[IndentingNewLine]l = \((\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] + \[Eta]\ r6\ Cos[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\
\ r6\ Cos[y]\ \ \ \ \ \ \ \ \ \ \ )\)}/12\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  FontSize->9],

Cell["\<\
\tThe non-abelian groups D3C2 and Q12 are very closely related to C3K and \
C3C4 respectively - their shapes include some shared sizes.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["Figure 37. General D3C2 orbit..", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \)\(D3C2\[Alpha]\[Beta]\[Gamma]\[Delta]\[Zeta]\[Tau]\
\[Lambda]\[Phi]\[Eta]\[Chi]\[CurlyKappa]\[Psi]\[IndentingNewLine]
    {\((\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + 
          4\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + 
          4\ \[Eta]\ Cos[\[Chi]])\), \[IndentingNewLine]\((\[Alpha] + \[Beta] \
+ \[Gamma] + \[Delta] + 4\ \[Zeta]\ Cos[\[Tau] + \[Omega]] + 
          4\ \[Eta]\ Cos[\[Chi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + 
          4\ \[Zeta]\ Cos[\[Tau] - \[Omega]] + 
          4\ \[Eta]\ Cos[\[Chi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - 
          4\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - 
          4\ \[CurlyKappa]\ Cos[\[Psi]])\), \[IndentingNewLine]\((\[Alpha] - \
\[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - 
          4\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - 
          4\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - 
          4\ \[Lambda]\ Cos[\[Phi] - \[Omega]] - 
          4\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + 
          4\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - 
          4\ \[Eta]\ Cos[\[Chi]])\), \[IndentingNewLine]\((\[Alpha] + \[Beta] \
- \[Gamma] - \[Delta] + 4\ \[Zeta]\ Cos[\[Tau] + \[Omega]] - 
          4\ \[Eta]\ Cos[\[Chi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + 
          4\ \[Zeta]\ Cos[\[Tau] - \[Omega]] - 
          4\ \[Eta]\ Cos[\[Chi] + 
                2\ \[Omega]])\), \[IndentingNewLine]\((\[Alpha] - \[Beta] - \
\[Gamma] + \[Delta]\ \ \ \ \ \  - 4\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + 
          4\ \[CurlyKappa]\ Cos[\[Psi]])\), \[IndentingNewLine]\((\[Alpha] - \
\[Beta] - \[Gamma] + \[Delta]\ \ \ \ \ \  - 
          4\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + 
          4\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \[IndentingNewLine]\((\
\[Alpha] - \[Beta] - \[Gamma] + \[Delta]\ \ \ \ \ \  - 
          4\ \[Lambda]\ Cos[\[Phi] - \[Omega]] + 
          4\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\)}\)\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \(toVec[{\[Alpha]_, \[Beta]_, \[Gamma]_, \[Delta]_, \[Zeta]\[Zeta]_, \
\[Tau]_, \[Lambda]\[Lambda]_, \[Phi]_, \[Eta]\[Eta]_, \[Chi]_, \[Kappa]\
\[Kappa]_, \[Psi]_}, "\<D3C2\>"] := \[IndentingNewLine]Module[{\[Zeta] = 
            4 \@ \[Zeta]\[Zeta], \[Lambda] = 
            4 \@ \[Lambda]\[Lambda], \[Eta] = 4 \@ \[Eta]\[Eta], \[Kappa] = 
            4 \@ \[Kappa]\[Kappa]}, {\ \ \ \ \ \ \[IndentingNewLine]\[Alpha] \
+ \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Eta]\ \
Cos[\[Chi]], \[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]], \ \
\[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\
\[Tau] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]], \[IndentingNewLine]\
\[Alpha] - \[Beta] + \[Gamma] - \[Delta] - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  \
- \[Kappa]\ Cos[\[Psi]]\ , \[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \
\[Delta] - \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Kappa]\ Cos[\[Psi] + \
\[Omega]], \[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \[Delta] - \
\[Lambda]\ Cos[\[Phi] - \[Omega]] - \[Kappa]\ Cos[\[Psi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\
\[Tau]]\ \ \ \ \ \  - \[Eta]\ Cos[\[Chi]]\ , \[IndentingNewLine]\[Alpha] + \
\[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Eta]\ \
Cos[\[Chi] + \[Omega]], \[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \
\[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] - \[Gamma] + \[Delta] - \[Lambda]\ Cos[\
\[Phi]]\ \ \ \ \ \  + \[Kappa]\ Cos[\[Psi]]\ , \[IndentingNewLine]\[Alpha] - \
\[Beta] - \[Gamma] + \[Delta] - \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[Kappa]\ \
Cos[\[Psi] + \[Omega]], \[IndentingNewLine]\[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] - \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[Kappa]\ Cos[\[Psi] - \
\[Omega]]}/12]\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  FontSize->9],

Cell["Figure 38. Q12 Cartesian & Polar-Dual interconversions.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(Q12p[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_}] := {\[Alpha] = 
            a + b + c + d + e + f + g + h + i + j + k + 
              l, \[IndentingNewLine]\[Beta] = 
            a + b + c - d - e - f + g + h + i - j - k - 
              l, \[IndentingNewLine]\[Epsilon]\[Epsilon] = \((a + b + c - g - \
h - i)\)\^2 + \((d + e + f - j - k - l)\)\^2, \[IndentingNewLine]\[Sigma] = 
            ArcTan[a + b + c - g - h - i, 
              d + e + f - j - k - 
                l], \[IndentingNewLine]\[Zeta]\[Zeta] = \((\((a - b + g - \
h)\)\^2 + \((b - c + h - i)\)\^2 + \((\(-a\) + c - g + i)\)\^2)\)/
              2, \[IndentingNewLine]\[Tau] = 
            ArcTan[2\ a - b - c + 2\ g - h - 
                i, \(-\@3\)\ \((b - c + h - 
                    i)\)], \[IndentingNewLine]\[Lambda]\[Lambda] = \((\((d - \
e + j - k)\)\^2 + \((e - f + k - l)\)\^2 + \((\(-d\) + f - j + l)\)\^2)\)/
              2, \[IndentingNewLine]\[Phi] = 
            ArcTan[2\ d - e - f + 2\ j - k - 
                l, \(-\@3\)\ \((e - f + k - 
                    l)\)], \[IndentingNewLine]\[Eta]\[Eta] = \((\((a - b - g \
+ h)\)\^2 + \((\(-a\) + c + g - i)\)\^2 + \((b - c - h + i)\)\^2)\)/
              2, \[IndentingNewLine]\[Chi] = 
            ArcTan[2\ a - b - c - 2\ g + h + 
                i, \(-\@3\)\ \((b - c - h + 
                    i)\)], \[IndentingNewLine]\[CurlyKappa]\[CurlyKappa] = \
\((\((d - e - j + k)\)\^2 + \((\(-d\) + f + j - l)\)\^2 + \((e - f - k + l)\)\
\^2)\)/2, \[IndentingNewLine]\[Psi] = 
            ArcTan[2\ d - e - f - 2\ j + k + 
                l, \(-\@3\)\ \((e - f - k + l)\)]};\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[{
    \(The\ Q12\ polar\ reversion\ has\ been\ tidied\ up\ by\ the\ \
substitutions\), "\[IndentingNewLine]", 
    \(\[Epsilon] -> \@\[Epsilon]\[Epsilon], \[Zeta] -> \@\[Zeta]\[Zeta], \ \
\[Lambda] -> \@\[Lambda]\[Lambda], \[Eta]\  -> \@\(\(\[Eta]\[Eta]\)\(\ \)\), \
\[CurlyKappa]\ \  -> \@\[CurlyKappa]\[CurlyKappa], \[Omega] \[Rule] 
      2  \[Pi]/3 : \(-\[IndentingNewLine]{\[Alpha] + \[Beta] + 
                2\ \[Epsilon]\ Cos[\[Sigma]] + 
                4\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + 
                4\ \[Eta]\ Cos[\[Chi]], \[IndentingNewLine]\[Alpha] + \[Beta] \
+ 2\ \[Epsilon]\ Cos[\[Sigma]] + 4\ \[Zeta]\ Cos[\[Tau] + \[Omega]] + 
                4\ \[Eta]\ Cos[\[Chi] + \[Omega]], \
\[IndentingNewLine]\[Alpha] + \[Beta] + 2\ \[Epsilon]\ Cos[\[Sigma]] + 
                4\ \[Zeta]\ Cos[\[Tau] - \[Omega]] + 
                4\ \[Eta]\ Cos[\[Chi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] + 
                2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \  + 
                4\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + 
                4\ \[CurlyKappa]\ Cos[\[Psi]], \[IndentingNewLine]\[Alpha] - \
\[Beta] + 2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \  + 
                4\ \[Lambda]\ Cos[\[Phi] + \[Omega]] + 
                4\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]], \[IndentingNewLine]\
\[Alpha] - \[Beta] + 2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \  + 
                4\ \[Lambda]\ Cos[\[Phi] - \[Omega]] + 
                4\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]], \[IndentingNewLine]\
\[Alpha] + \[Beta] - 2\ \[Epsilon]\ Cos[\[Sigma]] + 
                4\ \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - 
                4\ \[Eta]\ Cos[\[Chi]], \[IndentingNewLine]\[Alpha] + \[Beta] \
- 2\ \[Epsilon]\ Cos[\[Sigma]] + 4\ \[Zeta]\ Cos[\[Tau] + \[Omega]] - 
                4\ \[Eta]\ Cos[\[Chi] + \[Omega]], \
\[IndentingNewLine]\[Alpha] + \[Beta] - 2\ \[Epsilon]\ Cos[\[Sigma]] + 
                4\ \[Zeta]\ Cos[\[Tau] - \[Omega]] - 
                4\ \[Eta]\ Cos[\[Chi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] - 
                2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \  + 
                4\ \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - 
                4\ \[CurlyKappa]\ Cos[\[Psi]], \[IndentingNewLine]\[Alpha] - \
\[Beta] - 2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \  + 
                4\ \[Lambda]\ Cos[\[Phi] + \[Omega]] - 
                4\ \[CurlyKappa]\ Cos[\[Psi] + \[Omega]], \[IndentingNewLine]\
\[Alpha] - \[Beta] - 2\ \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \  + 
                4\ \[Lambda]\ Cos[\[Phi] - \[Omega]] - 
                4\ \[CurlyKappa]\ Cos[\[Psi] - \[Omega]]}\)/12\)}], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[TextData[{
  "\tIn all cases, orbits are created by conversion to unital sub-algebras, \
with arbitrary angles and with the other components \
(\[Alpha],\[Beta],\[Gamma],\[Delta],\[Epsilon],\[Zeta],\[Eta],\[Lambda],\[Xi],\
",
  StyleBox["\[CurlyKappa]) ",
    FontWeight->"Bold"],
  "all being either 0 or 1. They can be identified by appending names of the \
non-zero parameteres to that of the algebra, as in Figure 39:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"Figure", " ", "39.", "  ", 
      StyleBox["Some",
        FontWeight->"Plain"], 
      StyleBox[" ",
        FontWeight->"Plain"], 
      StyleBox["C3K",
        FontWeight->"Plain"], 
      StyleBox[" ",
        FontWeight->"Plain"], 
      StyleBox[\(\(orbits\)\(.\)\),
        FontWeight->"Plain"]}]], "Input",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[BoxData[GridBox[{
        {\(\(\ \ \ \ \ \)\(C3K\[Tau]\[Phi]\[IndentingNewLine]
          {\ \ \((Cos[\[Tau]]\ \ \ \ \ \ \ \ \  + 
                  Cos[\[Phi]])\), \ \ \ \ \ \ \ \[IndentingNewLine]\((Cos[\
\[Tau] + \ \ \ \[Omega]] + 
                  Cos[\[Phi] + \[Omega]])\), \[IndentingNewLine]\((Cos[\[Tau] \
+ 2\ \[Omega]] + 
                  Cos[\[Phi] + 
                      2  \[Omega]])\), \[IndentingNewLine]\((Cos[\[Tau]\ ]\ \ \
\ \ \ \ \ \  - 
                  Cos[\[Phi]])\), \[IndentingNewLine]\((Cos[\[Tau] + \ \ \ \
\[Omega]] - 
                  Cos[\[Phi] + \ \ \ \[Omega]])\), \[IndentingNewLine]\((Cos[\
\[Tau] + 2\ \[Omega]] - 
                  Cos[\[Phi] + 
                      2\ \[Omega]])\), \[IndentingNewLine]\((Cos[\[Tau]]\ \ \ \
\ \ \ \ \ \  + 
                  Cos[\[Phi]])\), \[IndentingNewLine]\((Cos[\[Tau] + \ \ \ \
\[Omega]] + Cos[\[Phi] + \[Omega]])\), \[IndentingNewLine]\((Cos[\[Tau] + 
                      2\ \[Omega]] + 
                  Cos[\[Phi] + 
                      2\ \[Omega]])\), \[IndentingNewLine]\((Cos[\[Tau]]\ \ \ \
\ \ \ \ \ \ \  - 
                  Cos[\[Phi]])\), \[IndentingNewLine]\((Cos[\[Tau] + \ \ \ \
\[Omega]]\  - Cos[\[Phi] + \[Omega]])\), \[IndentingNewLine]\((Cos[\[Tau] + 
                      2\ \[Omega]] - Cos[\[Phi] + 2\ \[Omega]])\)}/
            6\)\), \(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\)\(C3K\[Alpha]\[Tau]\[Chi]\[IndentingNewLine]
          {\ \ \((1/2 + Cos[\[Tau]]\ \ \ \ \ \ \ \ \  + 
                  Cos[\[Chi]])\), \ \ \ \ \ \ \ \[IndentingNewLine]\((1/2 + 
                  Cos[\[Tau] + \ \ \ \[Omega]] + 
                  Cos[\[Chi] + \ \[Omega]])\), \[IndentingNewLine]\((1/2 + 
                  Cos[\[Tau] + 2\ \[Omega]] + 
                  Cos[\[Chi] + 2\ \[Omega]])\), \[IndentingNewLine]\((1/2 + 
                  Cos[\[Tau]\ ]\ \ \ \ \ \ \ \  + 
                  Cos[\[Chi]])\), \[IndentingNewLine]\((1/2 + 
                  Cos[\[Tau] + \ \ \ \[Omega]] + 
                  Cos[\[Chi] + \ \ \ \[Omega]])\), \[IndentingNewLine]\((1/
                    2 + Cos[\[Tau] + 2\ \[Omega]] + 
                  Cos[\[Chi] + 2  \[Omega]])\), \[IndentingNewLine]\((1/2 + 
                  Cos[\[Tau]]\ \ \ \ \ \ \ \ \  - 
                  Cos[\[Chi]])\), \[IndentingNewLine]\((1/2 + 
                  Cos[\[Tau] + \ \ \ \[Omega]] - 
                  Cos[\[Chi] + \ \ \[Omega]])\), \[IndentingNewLine]\((1/2 + 
                  Cos[\[Tau] + 2\ \[Omega]] - 
                  Cos[\[Chi] + 2\ \[Omega]])\), \[IndentingNewLine]\((1/2 + 
                  Cos[\[Tau]]\ \ \ \ \ \ \ \ \  - 
                  Cos[\[Chi]])\), \[IndentingNewLine]\((1/2 + 
                  Cos[\[Tau] + \[Omega]]\ \ \  - 
                  Cos[\[Chi] + \ \ \ \[Omega]])\), \[IndentingNewLine]\((1/
                    2 + Cos[\[Tau] + 2  \[Omega]] - 
                  Cos[\[Chi] + 2\ \[Omega]])\)}/6\)\)},
        {\(\(\ \ \)\(\[IndentingNewLine]\)\(\ \ \ \ \ \ \)\(C3K\[Alpha]\
\[Delta]\[Chi]\[Psi]\ \[IndentingNewLine]
          {\ \ \((1 + Cos[\[Chi]]\ \ \ \ \ \ \ \ \  + 
                  Cos[\[Psi]])\), \[IndentingNewLine]\((1 + \ 
                  Cos[\[Chi] + \ \ \[Omega]] + 
                  Cos[\[Psi] + \ \ \ \[Omega]])\), \[IndentingNewLine]\((1 + \
\ Cos[\[Chi] + 2\ \[Omega]] + 
                  Cos[\[Psi] + 
                      2\ \[Omega]])\), \[IndentingNewLine]\((\ \ \ \ \ \ \ \
Cos[\[Chi]]\ \ \ \ \ \ \ \ \  - 
                  Cos[\[Psi]])\), \[IndentingNewLine]\((\ \ \ \ \ \ \ Cos[\
\[Chi] + \ \ \ \[Omega]] - 
                  Cos[\[Psi] + \ \ \ \[Omega]])\), \[IndentingNewLine]\((\ \ \
\ \ \ \ \ Cos[\[Chi] + 2\ \[Omega]] - 
                  Cos[\[Psi] + 
                      2\ \[Omega]])\), \[IndentingNewLine]\((\ \ \ \ \ \
\(-Cos[\[Chi]]\)\ \ \ \ \ \ \ \ \  - 
                  Cos[\[Psi]])\), \[IndentingNewLine]\((\ \ \ \ \ \(-Cos[\
\[Chi] + \ \ \ \[Omega]]\) - 
                  Cos[\[Psi] + \ \ \ \[Omega]])\), \[IndentingNewLine]\((\ \ \
\ \ \ \(-Cos[\[Chi] + 2\ \[Omega]]\) - 
                  Cos[\[Psi] + 
                      2\ \[Omega]])\), \[IndentingNewLine]\((\(-1\) - 
                  Cos[\[Chi]]\ \ \ \ \ \ \ \  + 
                  Cos[\[Psi]])\), \[IndentingNewLine]\((\(-1\) - 
                  Cos[\[Chi] + \ \ \ \[Omega]] + 
                  Cos[\[Psi] + \ \ \ \[Omega]])\), \[IndentingNewLine]\((\(-1\
\) - Cos[\[Chi] + 2  \[Omega]] + Cos[\[Psi] + 2\ \[Omega]])\)}/
            6\)\), \(\(\[IndentingNewLine]\)\(\ \ \ \ \ \ \ \ \ \ \ \)\(C3K\
\[Beta]\[Gamma]\[Delta]\[Phi]\[Chi]\[Psi]\[IndentingNewLine]
          {\ \ \ \((1.5 + Cos[\[Phi]]\ \ \ \ \ \ \ \ \  + 
                  Cos[\[Chi]]\ \ \ \ \ \ \ \ \ \  + 
                  Cos[\[Psi]])\), \[IndentingNewLine]\ \((1.5 + 
                  Cos[\[Phi] + \ \ \ \[Omega]] + 
                  Cos[\[Chi] + \ \ \ \[Omega]] + 
                  Cos[\[Psi] + \ \ \[Omega]])\), \[IndentingNewLine]\ \((1.5 \
+ Cos[\[Phi] + 2\ \[Omega]] + Cos[\[Chi] + 2\ \[Omega]] + 
                  Cos[\[Psi] + 
                      2\ \[Omega]])\), \[IndentingNewLine]\ \((\(- .5\) - 
                  Cos[\[Phi]]\ \ \ \ \ \ \ \ \  + 
                  Cos[\[Chi]]\ \ \ \ \ \ \ \ \  - 
                  Cos[\[Psi]])\), \[IndentingNewLine]\ \((\(- .5\) - 
                  Cos[\[Phi] + \ \ \ \[Omega]] + 
                  Cos[\[Chi] + \ \ \ \[Omega]] - 
                  Cos[\[Psi] + \ \ \ \[Omega]])\), \[IndentingNewLine]\ \
\((\(- .5\) - Cos[\[Phi] + 2\ \[Omega]] + Cos[\[Chi] + 2\ \[Omega]] - 
                  Cos[\[Psi] + 
                      2\ \[Omega]])\), \[IndentingNewLine]\ \((\(- .5\) + 
                  Cos[\[Phi]]\ \ \ \ \ \ \ \ \  - 
                  Cos[\[Chi]]\ \ \ \ \ \ \ \ \ \  - 
                  Cos[\[Psi]])\), \[IndentingNewLine]\ \((\(- .5\) + 
                  Cos[\[Phi] + \ \ \ \[Omega]] - 
                  Cos[\[Chi] + \ \ \ \ \[Omega]] - 
                  Cos[\[Psi] + \ \ \ \[Omega]])\), \[IndentingNewLine]\ \
\((\(- .5\) + Cos[\[Phi] + 2  \[Omega]] - Cos[\[Chi] + 2\ \[Omega]] - 
                  Cos[\[Psi] + 
                      2  \[Omega]])\), \[IndentingNewLine]\ \((\(- .5\) - 
                  Cos[\[Phi]]\ \ \ \ \ \ \ \ \  - 
                  Cos[\[Chi]]\ \ \ \ \ \ \ \ \ \  + 
                  Cos[\[Psi]])\), \[IndentingNewLine]\ \((\(- .5\) - 
                  Cos[\[Phi] + \ \ \ \[Omega]] - 
                  Cos[\[Chi] + \ \ \ \ \[Omega]] + 
                  Cos[\[Psi] + \ \ \[Omega]])\), \[IndentingNewLine]\ \((\(- \
.5\) - Cos[\[Phi] + 2  \[Omega]] - Cos[\[Chi] + 2  \[Omega]] + 
                  Cos[\[Psi] + 2\ \[Omega]])\)}/6\)\)}
        }]], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell["\<\
\tThese orbits may be related to deBroglie waves. Elements of the generating \
algebras (e.g. C3K) act as unit-spin and half-spin quantum operators. This \
leads to the surmise that quarks are wave packets with ternary symmetry, and \
leptons are wave packets with 4-fold symmetry. The orbit magnitudes may be \
related to the Planck size of \"extended\" particles; the number of types of \
particles may be related to the number of stable orbits. The 12-element \
algebras are in a \"subsymmetric\" relation to the algebras with 6 elements, \
\"Hexal\". (This respects the convention that unit-spin is supersymmetric to \
half spin. It also suggest that supersymmetry involves fewer, rather than the \
same number of, partners.) The symmetry is shown in Figure 40, where the \
elements of C3K are folded by replacing a & g by a/2 & -a/2, etc. The polar \
form loses 6 elements whilst the other elements match those of C3C2:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"Figure", " ", "40.", "  ", 
      StyleBox["C3K",
        FontWeight->"Plain"], 
      StyleBox[" ",
        FontWeight->"Plain"], 
      StyleBox["is",
        FontWeight->"Plain"], 
      StyleBox[" ",
        FontWeight->"Plain"], 
      StyleBox["Subsymmetric",
        FontWeight->"Plain"], 
      StyleBox[" ",
        FontWeight->"Plain"], 
      StyleBox["to",
        FontWeight->"Plain"], 
      StyleBox["  ",
        FontWeight->"Plain"], 
      StyleBox[\(\(C3C2\)\(.\)\),
        FontWeight->"Plain"]}]], "Input",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(toPolar[{a, b, c, d, e, 
          f, \(-a\), \(-b\), \(-c\), \(-d\), \(-e\), \(-f\)}/
        2, "\<C3K\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({0, 0, a + b + c + d + e + f, a + b + c - d - e - f, 0, 0, 0, 
      0, \[IndentingNewLine]\((\((a - b + d - e)\)\^2 + \((b - c + e - \
f)\)\^2 + \((\(-a\) + c - d + f)\)\^2)\)/2, 
      ArcTan[2\ a - b - c + 2\ d - e - 
          f, \(-\@3\)\ \((b - c + e - 
              f)\)], \[IndentingNewLine]\((\((a - b - d + e)\)\^2 + \((\(-a\) \
+ c + d - f)\)\^2 + \((b - c - e + f)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
        2\ a - b - c - 2\ d + e + 
          f, \(-\@3\)\ \((b - c - e + f)\)]}\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell[BoxData[
    \(toPolar[{a, b, c, d, e, f}, "\<C3C2\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({a + b + c + d + e + f, 
      a + b + c - d - e - 
        f, \[IndentingNewLine]\((\((a - b + d - e)\)\^2 + \((b - c + e - f)\)\
\^2 + \((\(-a\) + c - d + f)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
        2\ a - b - c + 2\ d - e - 
          f, \@3\ \((\(-b\) + c - e + 
              f)\)], \[IndentingNewLine]\ \((\((a - b - d + e)\)\^2 + \((\(-a\
\) + c + d - f)\)\^2 + \((b - c - e + f)\)\^2)\)/2, \[IndentingNewLine]ArcTan[
        2\ a - b - c - 2\ d + e + 
          f, \@3\ \((\(-b\) + c + e - f)\)]}\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell["3.14. Time as a parameter.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Inherent in my conjecture that orbits relate to particles is the concept \
that angles change with \"time\" in some way. C3C4 has the following angles:-\
\nArcTan[a+b+c-g-h-i,d+e+f-j-k-l]\nArcTan[2a-b-c+2d-e-f+ 2g-h-i+ 2j-k-l, -",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "(b-c+e-f+h-i+k-l)]\nArcTan[2a-b-c-2d+e+f+2g-h-i-2j+k+l, -",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "(b-c-e+f+h-i-k+l)]\nArcTan[2a-b-c+2d-e-f-2g+h+i-2j+k+l, -",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "(b-c+e-f-h+i-k+l)]\nArcTan[2a-b-c-2d+e+f-2g+h+i+2j-k-l, -",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "(b-c-e+f-h+i+k-l)].\n\nC3K has the same last four angles It folds to C3C2 \
with\nArcTan[2a-b-c+2d-e-f, -",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "(b-c+e-f)]\nArcTan[2a-b-c-2d+e+f, -",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  "(b-c-e+f)]\n\nC3C4 3-folds to C4, with these and \nArcTan[a-c,b-d]\nAll \
these angles increase with -a/b, so put t=-a/b, in the form b=-a t"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{
          RowBox[{"ArcTan", "[", 
            RowBox[{\(2  a - b - c + 2  d - e - f\), ",", 
              RowBox[{
                FormBox[\(\@3\),
                  "TraditionalForm"], \((c - e + f - b)\)}]}], "]"}], 
          ",", \(ArcTan[a - c, b - d]\)}], "}"}], 
      "/.", \(b \[Rule] \(-a\)\ t\)}]], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({ArcTan[2\ a - c + 2\ d - e - f + a\ t, \@3\ \((c - e + f + a\ t)\)], 
      ArcTan[a - c, \(-d\) - a\ t]}\)], "Output",
  PageWidth->WindowWidth]
}, Closed]],

Cell[TextData[{
  "But there are the constant size constraints to maintain, such as ",
  Cell[BoxData[
      StyleBox[\(\((a - c)\)\^2 + \((b - d)\)\^2\),
        FontFamily->"Times New Roman"]], "Text"],
  "=1. More work (and inspiration!) is needed here"
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tThe l22a & l22b sizes of C3C4 are factors of the L4s size, which is a \
6-Vector, the sum of six squared terms with a seventh squared term \
subtracted:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell["\<\
L4s=l22a*l22b=(3((a-b+(d+e-2*f)/Sqrt[3])^2+((a+b-2*c)/Sqrt[3]-d+e)^2)/4)*(3((\
a-b-(d+e-2*f)/Sqrt[3])^2+((a+b-2*c)/Sqrt[3]+d-e)^2)/4).\
\>", "Text"],

Cell[BoxData[
    \(l22a =. ; l22b =. ;\)], "Input"],

Cell[BoxData[
    \(\(sh = sh12[{a, b, c, d, e, f, g, h, i, j, k, l}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(sh[\([5]\)]\), "\[IndentingNewLine]", 
    \(sh[\([6]\)]\)}], "Input"],

Cell[BoxData[
    \(\(3\/4\) \((\((d - e - \(3\^\(-\(1\/2\)\)\) \((a + b - 2  c - g - h + 2 \
 i)\) - j + k)\)\^2 + \((a - b - g + h + \(3\^\(-\(1\/2\)\)\) \((d + e - 2  f \
- j - k + 2  l)\))\)\^2)\)\)], "Output"],

Cell[BoxData[
    \(\(3\/4\) \((\((d - e + \(3\^\(-\(1\/2\)\)\) \((a + b - 2  c - g - h + 2 \
 i)\) - j + k)\)\^2 + \((a - b - g + h - \(3\^\(-\(1\/2\)\)\) \((d + e - 2  f \
- j - k + 2  l)\))\)\^2)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(toPol[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, 
            l_}, "\<C3C4\>"] := \[IndentingNewLine]Module[{r = \(-Sqrt[3]\), 
            e1 = a + b + c - g - h - i, 
            e2 = d + e + f - j - k - l, \[IndentingNewLine]a1 = 
              a - b + d - e + g - h + j - k, 
            a2 = a - b - d + e + g - h - j + k, \[IndentingNewLine]b1 = 
              b - c + e - f + h - i + k - l, 
            b2 = b - c - e + f + h - i - k + l, \[IndentingNewLine]c1 = 
              c - a + f - d + i - g + l - j, 
            c2 = c - a - f + d + i - g - l + j, 
            f1 = a - b - g + 
                h + \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f2 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 - d + e + j - 
                k, \[IndentingNewLine]f3 = 
              a - b - g + 
                h - \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f4 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 + d - e - j + 
                k}, \[IndentingNewLine]{ (*\[Alpha]*) a + b + c + d + e + f + 
              g + h + i + j + k + l,  (*\[Beta]*) a + b + c - d - e - f + g + 
              h + i - j - k - l, \[IndentingNewLine] (*\[Epsilon]*) e1\^2 + 
              e2\^2,  (*\[Sigma]*) ArcTan[e1, 
              e2], \[IndentingNewLine] (*\[Zeta]*) \((a1\^2 + b1\^2 + 
                  c1\^2)\)/2,  (*\[Tau]*) ArcTan[a1 - c1, 
              r\ b1], \[IndentingNewLine] (*\[Lambda]*) \((a2\^2 + b2\^2 + 
                  c2\^2)\)/2,  (*\[Phi]*) ArcTan[a2 - c2, 
              r\ b2], \[IndentingNewLine] (*\[Eta]*) \((f1\^2 + f2\^2)\) 
              3/4,  (*x*) 
              ArcTan[f1, f2] - \[Pi]/
                6, \[IndentingNewLine] (*\[Kappa]*) \((f3\^2 + f4\^2)\) 
              3/4,  (*y*) ArcTan[f3, f4] - \[Pi]/6}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  FontSize->9],

Cell[BoxData[
    \({\ \ a = \((\[Alpha] + \[Beta] + \[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ \
Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  + \
\[Eta]\ \ \ \ \ \ Cos[x] + \[Eta]\ r3\ Sin[x] + \[Kappa]\ Cos[
                  y] + \[Kappa]\ r3\ Sin[
                  y])\), \[IndentingNewLine]b = \((\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]] - \[Eta]\ \ \ \ \ \ Cos[x] + \[Eta]\ r3\ Sin[
                  x] - \[Kappa]\ Cos[y] + \[Kappa]\ r3\ Sin[
                  y])\), \ \[IndentingNewLine]c = \((\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  - \
\[Eta]\ r6\ Sin[x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  - \[Kappa]\ r6\ Sin[
                  y])\), \[IndentingNewLine]d = \((\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \  + \[Eta]\ r3\ Cos[x]\ \ \ \  - \[Eta]\ Sin[
                  x] - \[Kappa]\ r3\ Cos[y]\  + \[Kappa]\ Sin[
                  y])\), \[IndentingNewLine]e = \((\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ \
Cos[\[Phi] + \[Omega]] + \[Eta]\ r3\ Cos[x]\ \ \ \  + \[Eta]\ Sin[
                  x] - \[Kappa]\ r3\ Cos[y]\  - \[Kappa]\ Sin[
                  y])\), \[IndentingNewLine]f = \((\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] - \[Eta]\ r6\ Cos[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\
\ r6\ Cos[
                  y]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ )\), \
\[IndentingNewLine]g = \((\[Alpha] + \[Beta] - \[Epsilon]\ \ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau]]\ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - \
\[Eta]\ \ \ \ \ \ Cos[x] - \[Eta]\ r3\ Sin[x] - \[Kappa]\ Cos[
                  y] - \[Kappa]\ r3\ Sin[
                  y])\), \[IndentingNewLine]h = \((\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]] + \[Eta]\ \ \ \ \ \ Cos[x] - \[Eta]\ r3\ Sin[
                  x] + \[Kappa]\ Cos[y] - \[Kappa]\ r3\ Sin[
                  y])\), \ \[IndentingNewLine]i = \((\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \
\[Eta]\ r6\ Sin[x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\ r6\ Sin[
                  y])\), \[IndentingNewLine]j = \((\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \  - \[Eta]\ r3\ Cos[x]\ \ \ \  + \[Eta]\ Sin[
                  x] + \[Kappa]\ r3\ Cos[y]\ \  - \[Kappa]\ Sin[
                  y])\), \[IndentingNewLine]k = \((\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ \
Cos[\[Phi] + \[Omega]] - \[Eta]\ r3\ Cos[x]\ \ \ \  - \[Eta]\ Sin[
                  x] + \[Kappa]\ r3\ Cos[y]\ \  + \[Kappa]\ Sin[
                  y])\), \[IndentingNewLine]l = \((\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] + \[Eta]\ r6\ Cos[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\
\ r6\ Cos[y]\ \ \ \ \ \ \ \ \ \ \ )\)}/12\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.15. Noncommutative Features. (Needs OPScalar. Inconclusive!)\
\>", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "\tMost loops (but only a few hoops, including octonions) are \
noncommutative (NC). The ",
  StyleBox["ge",
    FontSlant->"Italic"],
  " procedure employs the explicit NC features of the relators to create the \
protoloop as a table of lex-ordered-string elements, but converts this to an \
index-table for output. I conjecture that the repeated factors of NC loop \
determinants may split when the determinant is found by applying the NC \
rules.\n\tOPScalar` (from Mathsource/4271) extends the functionality of the \
operation NonCommutativeMultiply \"**\" as a \"Diamond\" operation \"\
\[Diamond]\". I modified ",
  StyleBox["det",
    FontSlant->"Italic"],
  " and ",
  StyleBox["ge ",
    FontSlant->"Italic"],
  "to use NC multiplication when the option ",
  StyleBox["o",
    FontSlant->"Italic"],
  " is negative, which can be used after Mathsource/4271 has been placed in \
",
  StyleBox["ExtraPackages",
    FontSlant->"Italic"],
  ". Unfortunately it has several awkward side effects, and this \
investigation has been suspended.",
  "\n",
  StyleBox["I cannot see where to go next with this approach, as \
non-commutative factorization is needed to test my speculation that NC hoop \
repeated factors can be split.",
    FontSlant->"Plain"]
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["17. Particle interactions.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary. ",
  StyleBox["Basic ",
    FontSlant->"Italic"],
  StyleBox["Conjecture. Dozal describes the different particle families as \
Fermions, with Hexal describing Bosons as equivalence relations on Dozal \
elements, freed from the Pauli exclusion principle. ",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[" Lepton interactions. Incomplete.", "Subsubsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "Summary. ",
  StyleBox["Conjecture. The electron family is described by the C3C4 and Q12 \
\[Alpha], \[Beta], \[Epsilon], & \[Sigma]  parameters; their lower analogs \
are photons. ",
    FontSlant->"Italic"]
}], "Text"],

Cell["\<\
\tElectrons have spin, charge, and mass; they are associated with neutrinos, \
muons and tauons; all have anti-particles. The Dozal 4-phase system {\
\[Epsilon] Cos[\[Sigma]], \[Epsilon] Sin[\[Sigma]], -\[Epsilon] \
Cos[\[Sigma]], -\[Epsilon] Sin[\[Sigma]]} wave system, together with the \
\[Alpha] and \[Beta] parameters, provides a possible description.
If mass is related to velocity relative to an origin, perhaps the low-mass \
neutrinos have \[Alpha]=\[Beta]=0; the electron has \[Alpha]=0, \[Beta]=1 and \
the phases are displaced by \[PlusMinus]1; \[Alpha]=1, \[Beta]=1 displaces \
half of them by 2; \[Alpha]=1, \[Beta]=0 displaces all of them by 1\
\>", "Text"],

Cell[BoxData[
    \({\ \ a = \((\[Alpha] + \[Beta] + \[Epsilon]\ \ Cos[\[Sigma]])\), 
        b = \((\[Alpha] + \[Beta] + \[Epsilon]\ \ Cos[\[Sigma]])\), 
        c = \((\[Alpha] + \[Beta] + \[Epsilon]\ \ Cos[\[Sigma]])\), \
\[IndentingNewLine]d = \((\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]])\), 
        e = \((\[Alpha] - \[Beta] + \[Epsilon]\ \ Sin[\[Sigma]])\), 
        f = \((\[Alpha] - \[Beta] + \[Epsilon]\ \ Sin[\[Sigma]])\), \
\[IndentingNewLine]g = \((\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]])\), 
        h = \((\[Alpha] + \[Beta] - \[Epsilon]\ \ Cos[\[Sigma]])\), 
        i = \((\[Alpha] + \[Beta] - \[Epsilon]\ \ Cos[\[Sigma]])\), \
\[IndentingNewLine]j = \((\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]])\), 
        k = \((\[Alpha] - \[Beta] - \[Epsilon]\ \ Sin[\[Sigma]])\), 
        l = \((\[Alpha] - \[Beta] - \[Epsilon]\ \ Sin[\[Sigma]])\)}/
      12\)], "Input",
  FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[{
    \(id[C3C2]; shape[{a, b, c, d, e, f}]\), "\[IndentingNewLine]", 
    \(toPolar[{a, b, c, d, e, f}]\)}], "Input"],

Cell[BoxData[
    \({a + b + c + d + e + f, 
      a + b + c - d - e - 
        f, \(1\/2\) \((\((a - b + d - e)\)\^2 + \((a - c + d - f)\)\^2 + \((b \
- c + e - f)\)\^2)\), \(1\/2\) \((\((a - b - d + e)\)\^2 + \((a - c - d + \
f)\)\^2 + \((b - c - e + f)\)\^2)\)}\)], "Output"],

Cell[BoxData[
    \({a + b + c + d + e + f, 
      a + b + c - d - e - 
        f, \(1\/2\) \((\((a - b + d - e)\)\^2 + \((a - c + d - f)\)\^2 + \((b \
- c + e - f)\)\^2)\), 
      ArcTan[2  a - b - c + 2  d - e - 
          f, \(3\^\(1\/2\)\) \((\(\(-\)\(\ \)\) b + c - e + 
              f)\)], \(1\/2\) \((\((a - b - d + e)\)\^2 + \((a - c - d + f)\)\
\^2 + \((b - c - e + f)\)\^2)\), 
      ArcTan[2  a - b - c - 2  d + e + 
          f, \(3\^\(1\/2\)\) \((\(\(-\)\(\ \)\) b + c + e - 
              f)\)]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(id[D3]; shape[{a, b, c, d, e, f}]\), "\[IndentingNewLine]", 
    \(toPolar[{a, b, c, d, e, f}]\)}], "Input"],

Cell[BoxData[
    \({a + b + c + d + e + f, 
      a - b + c - d + e - 
        f, \(1\/2\) \((\((a - c)\)\^2 - \((b - d)\)\^2 + \((a - e)\)\^2 + \
\((c - e)\)\^2 - \((b - f)\)\^2 - \((d - f)\)\^2)\)}\)], "Output"],

Cell[BoxData[
    \({a + b + c + d + e + f, 
      a - b + c - d + e - 
        f, \(1\/2\) \((\((a - c)\)\^2 + \((a - e)\)\^2 + \((c - e)\)\^2)\) + \
\(1\/2\) \((\(\(-\)\(\ \)\) \((b - d)\)\^2 - \((b - f)\)\^2 - \((d - f)\)\^2)\
\), ArcTan[
        2  a - c - 
          e, \(3\^\(1\/2\)\) \((\(\(-\)\(\ \)\) c + 
              e)\)], \(1\/2\) \((\((a - c)\)\^2 + \((a - e)\)\^2 + \((c - \
e)\)\^2)\), 
      ArcTan[2  b - d - 
          f, \(3\^\(1\/2\)\) \((\(\(-\)\(\ \)\) d + f)\)]}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hadron Interactions. Incomplete.", "Subsubsection",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[CellGroupData[{

Cell[BoxData[{
    \(id[C3C4]; 
    shape[A12 = {a, b, c, d, e, f, g, h, i, j, k, 
          l}]\), "\[IndentingNewLine]", 
    \(toPolar[A12]\)}], "Input"],

Cell[BoxData[
    \({a + b + c + d + e + f + g + h + i + j + k + l, 
      a + b + c - d - e - f + g + h + i - j - k - 
        l, \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - l)\)\^2, 
      1\/2\ \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f + h \
- i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\), 
      1\/2\ \((\((a - b - d + e + g - h - j + k)\)\^2 + \((\(-a\) + c + d - f \
- g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\), 
      3\/4\ \((\((\(-d\) + e + \(a + b - 2\ c - g - h + 2\ i\)\/\@3 + j - \
k)\)\^2 + \((a - b - g + h + \(d + e - 2\ f - j - k + 2\ l\)\/\@3)\)\^2)\), 
      3\/4\ \((\((d - e + \(a + b - 2\ c - g - h + 2\ i\)\/\@3 - j + k)\)\^2 \
+ \((a - b - g + h - \(d + e - 2\ f - j - k + 2\ l\)\/\@3)\)\^2)\)}\)], \
"Output"]
}, Open  ]],

Cell[BoxData[
    \(V12 = 
      toVector[P12 = {1, 1, 0. , 0. , 1, \[Tau], 1, \[Phi], 1, \[Chi], 
            1, \[Psi]}]\)], "Input"],

Cell[BoxData[
    \(Chop[Simplify[toPolar[V12]]]\)], "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix. J.J.Hamilton's Half Spin operators.", "Section",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "\tJ.J.Hamilton published [2] a \"hypercomplex arithmetic\" with half-spin \
\"non-real, non-complex\" quantum operators as well as integer-spin complex \
quantum operators. He generalised complex conjugation, in which the conjugate \
of a conjugate is the original, ",
  StyleBox["i:(i*)*=+i",
    FontSlant->"Italic"],
  ", to include elements ",
  StyleBox["{a,b,a*,b*}",
    FontSlant->"Italic"],
  " demonstrating \"biconjugation\" (my term) in which the conjugate of a \
conjugate is the negated original, ",
  StyleBox["a:a** =-a, (a*)** =-a*,  b:b** =-b, (b*)** =-b*.",
    FontSlant->"Italic"],
  "  He demonstrated that ",
  StyleBox["{a,b,a*,b*}",
    FontSlant->"Italic"],
  "  are fundamental half-integral spin quantum operators with properties \
that cannot be expressed as real or complex numbers. (This is because they \
exist in the hyperbolic plane rather than the complex plane. They are \
different square roots of unity whilst the full-spin operators ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "& ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "are different fourth roots.) His multiplication table (Table II, \
reproduced below) uses the eight elements ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_\(\(n\)\(\ \)\)\)\(=\)\)\)]],
  " {",
  StyleBox["1, i, h, k, a, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(b\^*\)\)]],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(a\^*\)\)]],
  StyleBox[", b",
    FontSlant->"Italic"],
  "}. However, he has several distinct \"-1\" elements (",
  Cell[BoxData[
      \(TraditionalForm\`h\^2, \ a\^2\ and\ a\^\(\(*\)\(2\)\)\)]],
  " all equal +1); he also introduces several other elements and many \
aliases. Example 12a reproduces his Table II."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
Example 12a. J.J.Hamiltons's Hypercomplex Multiplication Table.  (His Table \
II.)\
\>", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    RowBox[{"     ", 
      FormBox[GridBox[{
            {
              " ", \(E\_0\), \(E\_1\), \(E\_2\), \(E\_3\), \(E\_4\), \
\(E\_5\), \(E\_6\), \(E\_7\)},
            {\(E\_0\), "1", "i", "h", "k", "a", \(b\^*\), \(a\^*\), "b"},
            {\(E\_1\), "i", \(-1\), "k", \(-h\), \(b\^*\), \(-a\), 
              "b", \(-\(a\^*\)\)},
            {\(E\_2\), "h", "k", "1", "i", \(a\^*\), "b", "a", \(b\^*\)},
            {\(E\_3\), "k", \(-h\), "i", \(-1\), 
              "b", \(-\(a\^*\)\), \(b\^*\), \(-a\)},
            {\(E\_4\), "a", \(b\^*\), \(a\^*\), "b", "1", "i", "h", "k"},
            {\(E\_5\), \(b\^*\), \(-a\), "b", \(-\(a\^*\)\), "i", \(-1\), 
              "k", \(-h\)},
            {\(E\_6\), \(a\^*\), "b", "a", \(b\^*\), "h", "k", "1", "i"},
            {\(E\_7\), "b", \(-\(a\^*\)\), \(b\^*\), \(-a\), "k", \(-h\), 
              "i", \(-1\)}
            }],
        "TraditionalForm"]}]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  "Example 12b shows that Table II is embedded in C3K. Completing an \
\"extended table\" using Hamilton's definitions for -",
  StyleBox["1,-h,-a",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["-a*",
    FontSlant->"Italic"],
  ", and for their products, gives a 12\[Times]12 table. Choosing generators  \
",
  Cell[BoxData[
      \(TraditionalForm\`i\^3\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`h\^2\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "=1 (to match Hamilton's nomenclature) gives the elements that are shown \
above the table in Example 12b. If the supplementary and ill-defined \"-1\" \
term is converted to an arbitrary variable ",
  StyleBox["ii",
    FontSlant->"Italic"],
  " (it is ",
  Cell[BoxData[
      \(TraditionalForm\`i\^2\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`E\_1\%2\)]],
  " in Table II), the table becomes C3K. Deleting the rows and columns \
starting with negated elements reduces this table to the bold face elements \
in Example 12b; they match Table II, which is therefore embedded in C3K:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Example 12b. J.J.Hamiltons's Table II is embedded in C3K.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[BoxData[
    \( (*\ \ \ \ \
1\ \ \ \ i\ \ \ i\^2\ \ \ h\ \ \ hi\ \ \ hi\^2\ \ a\ \ ai\ \ \ ai\^2\ \
ah\ \ ahi\ ahi\^2\ *) \)], "Input",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"jjh3", "=", 
      RowBox[{
        RowBox[{GridBox[{
              {"1", "i", 
                StyleBox[\(-1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic"], "h", "k", 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], "a", \(b\^*\), 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], \(a\^*\), "b", 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"]},
              {"i", \(-1\), 
                StyleBox["1",
                  FontWeight->"Plain",
                  FontSlant->"Italic"], "k", \(-h\), 
                StyleBox["h",
                  FontWeight->"Plain"], \(b\^*\), \(-a\), 
                StyleBox["a",
                  FontWeight->"Plain"], "b", \(-\(a\^*\)\), 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"]},
              {
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["i",
                  FontSlant->"Italic"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Plain"], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\),
                  FontWeight->"Plain"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox["b",
                  FontWeight->"Plain"]},
              {"h", "k", 
                StyleBox[\(-h\),
                  FontWeight->"Plain",
                  FontSlant->"Italic"], "1", "i", 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], \(a\^*\), "b", 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], "a", \(b\^*\), 
                StyleBox[\(-a\),
                  FontWeight->"Plain"]},
              {"k", \(-h\), 
                StyleBox["h",
                  FontWeight->"Plain",
                  FontSlant->"Italic"], "i", \(-1\), 
                StyleBox["1",
                  FontWeight->"Plain"], "b", \(-\(a\^*\)\), 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], \(b\^*\), \(-a\), 
                StyleBox["a",
                  FontWeight->"Plain"]},
              {
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Plain",
                  FontSlant->"Italic"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["i",
                  FontWeight->"Plain"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox["b",
                  FontWeight->"Plain"], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\),
                  FontWeight->"Plain"]},
              {"a", \(b\^*\), 
                StyleBox[\(-a\),
                  FontWeight->"Plain",
                  FontSlant->"Italic"], \(a\^*\), "b", 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], "1", "i", 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], "h", "k", 
                StyleBox[\(-h\),
                  FontWeight->"Plain"]},
              {\(b\^*\), \(-a\), 
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic"], "b", \(-\(a\^*\)\), 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], "i", \(-1\), 
                StyleBox["1",
                  FontWeight->"Plain"], "k", \(-h\), 
                StyleBox["h",
                  FontWeight->"Plain"]},
              {
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\),
                  FontWeight->"Plain",
                  FontSlant->"Italic"], 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox["b",
                  FontWeight->"Plain"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["i",
                  FontWeight->"Plain"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Plain"]},
              {\(a\^*\), "b", 
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain",
                  FontSlant->"Italic"], "a", \(b\^*\), 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], "h", "k", 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], "1", "i", 
                StyleBox[\(-1\),
                  FontWeight->"Plain"]},
              {"b", \(-\(a\^*\)\), 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain",
                  FontSlant->"Italic"], \(b\^*\), \(-a\), 
                StyleBox["a",
                  FontWeight->"Plain"], "k", \(-h\), 
                StyleBox["h",
                  FontWeight->"Plain"], "i", \(-1\), 
                StyleBox["1",
                  FontWeight->"Plain"]},
              {
                StyleBox[\(-\(a\^*\)\),
                  FontWeight->"Plain"], 
                StyleBox[\(a\^*\),
                  FontWeight->"Plain"], 
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic"], 
                StyleBox[\(-a\),
                  FontWeight->"Plain"], 
                StyleBox["a",
                  FontWeight->"Plain"], 
                StyleBox[\(b\^*\),
                  FontWeight->"Plain"], 
                StyleBox[\(-h\),
                  FontWeight->"Plain"], 
                StyleBox["h",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Plain"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"], 
                StyleBox["i",
                  FontWeight->"Plain"]}
              }], "/.", \(\(-1\) \[Rule] i\ i\)}], "//", "tf"}]}]], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "i", \(i\^2\), "h", "k", \(h\ i\^2\), 
              "a", \(b\^*\), \(a\ i\^2\), \(a\^*\), "b", \(i\^2\ \(a\^*\)\)},
            {"i", \(i\^2\), "1", "k", \(h\ i\^2\), "h", \(b\^*\), \(a\ i\^2\),
               "a", "b", \(i\^2\ \(a\^*\)\), \(a\^*\)},
            {\(i\^2\), "1", "i", \(h\ i\^2\), "h", "k", \(a\ i\^2\), 
              "a", \(b\^*\), \(i\^2\ \(a\^*\)\), \(a\^*\), "b"},
            {"h", "k", \(h\ i\^2\), "1", "i", \(i\^2\), \(a\^*\), 
              "b", \(i\^2\ \(a\^*\)\), "a", \(b\^*\), \(a\ i\^2\)},
            {"k", \(h\ i\^2\), "h", "i", \(i\^2\), "1", 
              "b", \(i\^2\ \(a\^*\)\), \(a\^*\), \(b\^*\), \(a\ i\^2\), "a"},
            {\(h\ i\^2\), "h", "k", \(i\^2\), "1", 
              "i", \(i\^2\ \(a\^*\)\), \(a\^*\), "b", \(a\ i\^2\), 
              "a", \(b\^*\)},
            {"a", \(b\^*\), \(a\ i\^2\), \(a\^*\), "b", \(i\^2\ \(a\^*\)\), 
              "1", "i", \(i\^2\), "h", "k", \(h\ i\^2\)},
            {\(b\^*\), \(a\ i\^2\), "a", "b", \(i\^2\ \(a\^*\)\), \(a\^*\), 
              "i", \(i\^2\), "1", "k", \(h\ i\^2\), "h"},
            {\(a\ i\^2\), "a", \(b\^*\), \(i\^2\ \(a\^*\)\), \(a\^*\), 
              "b", \(i\^2\), "1", "i", \(h\ i\^2\), "h", "k"},
            {\(a\^*\), "b", \(i\^2\ \(a\^*\)\), "a", \(b\^*\), \(a\ i\^2\), 
              "h", "k", \(h\ i\^2\), "1", "i", \(i\^2\)},
            {"b", \(i\^2\ \(a\^*\)\), \(a\^*\), \(b\^*\), \(a\ i\^2\), "a", 
              "k", \(h\ i\^2\), "h", "i", \(i\^2\), "1"},
            {\(i\^2\ \(a\^*\)\), \(a\^*\), "b", \(a\ i\^2\), 
              "a", \(b\^*\), \(h\ i\^2\), "h", "k", \(i\^2\), "1", "i"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth]
}, Closed]],

Cell[TextData[{
  "\tHence Hamilton's hypercomplex algebra can be interpreted as the C3K \
algebra if his ",
  StyleBox["i",
    FontSlant->"Italic"],
  " is a cube root of 1, with ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["h",
    FontSlant->"Italic"],
  " being different square roots of 1. His half-spin operators {",
  StyleBox["a, a*, -a\[Congruent]a**,b, b*, -b\[Congruent]b**\[Congruent]-a*",
    
    FontSlant->"Italic"],
  "} are {",
  StyleBox["a, a h, a i i, a h i, a i , a h i i",
    FontSlant->"Italic"],
  "}; conjugation is multiplication by ",
  StyleBox["h",
    FontSlant->"Italic"],
  " (with ",
  StyleBox["h h",
    FontSlant->"Italic"],
  " =1), but biconjugation becomes multiplication by ",
  StyleBox["i",
    FontSlant->"Italic"],
  " or ",
  StyleBox["i i",
    FontSlant->"Italic"],
  ". This introduces ternary symmetry, and defies the prejudice that there \
must be ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " elements in an algebra - which is only true for real algebras without \
divisors of zero."
}], "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["References.", "Section",
  PageWidth->WindowWidth,
  FontSize->12],

Cell[TextData[{
  "[1] http://library.wolfram.com/infocenter/",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  "/4894/"
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "[2] J.J.Hamilton, Hypercomplex numbers and the description of spin states, \
J.Math.Phys. ",
  StyleBox["38",
    FontWeight->"Bold"],
  "(10) Oct. 1997. pp4914-4928"
}], "Text",
  PageWidth->WindowWidth],

Cell["[3] Remoissenet, Waves called Solitons, 1997 p29,p33.", "Text",
  PageWidth->WindowWidth],

Cell["\<\
[4] G.P.Nagy & P.Vojtechovsky, Loops package in GAP,  www.gap-system.org\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{763, 563},
WindowMargins->{{48, Automatic}, {Automatic, 63}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "12/10/2006"]], Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3353843803-4044115"->{
    Cell[406797, 9713, 808, 13, 69, "Print",
      CellTags->"Info3353843803-4044115"]},
  "Info3353241802-8811303"->{
    Cell[408195, 9747, 786, 13, 69, "Print",
      CellTags->"Info3353241802-8811303"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3353843803-4044115", 491364, 11645},
  {"Info3353241802-8811303", 491483, 11648}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 103, 2, 170, "Title"],
Cell[1882, 57, 132, 4, 138, "Subtitle"],
Cell[2017, 63, 125, 2, 77, "Subsubtitle"],
Cell[2145, 67, 196, 4, 73, "Text"],

Cell[CellGroupData[{
Cell[2366, 75, 31, 0, 89, "Section"],
Cell[2400, 77, 300, 5, 99, "Text"],
Cell[2703, 84, 1693, 47, 333, "Text"],
Cell[4399, 133, 50, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4486, 139, 112, 3, 89, "Section"],

Cell[CellGroupData[{
Cell[4623, 146, 32, 0, 68, "Subsection"],
Cell[4658, 148, 2517, 52, 541, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7212, 205, 39, 0, 68, "Subsection"],
Cell[7254, 207, 2506, 67, 342, "Text"],
Cell[9763, 276, 1562, 31, 292, "Text"],
Cell[11328, 309, 266, 9, 69, "Text"],
Cell[11597, 320, 81964, 2072, 351, "Text"],

Cell[CellGroupData[{
Cell[93586, 2396, 110, 3, 36, "Input"],
Cell[93699, 2401, 296, 6, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94032, 2412, 110, 3, 36, "Input"],
Cell[94145, 2417, 119, 3, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94301, 2425, 129, 3, 36, "Input"],
Cell[94433, 2430, 265, 6, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94735, 2441, 110, 3, 36, "Input"],
Cell[94848, 2446, 76, 2, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94961, 2453, 106, 2, 36, "Input"],
Cell[95070, 2457, 163, 3, 42, "Output"]
}, Open  ]],
Cell[95248, 2463, 1978, 50, 168, "Text"],
Cell[97229, 2515, 157, 5, 45, "Text"],
Cell[97389, 2522, 36194, 913, 243, "Input",
  Evaluatable->False],
Cell[133586, 3437, 397, 7, 94, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[134020, 3449, 60, 0, 42, "Subsection"],
Cell[134083, 3451, 1437, 43, 193, "Text"],
Cell[135523, 3496, 566, 9, 144, "Text"],
Cell[136092, 3507, 2360, 66, 246, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[138489, 3578, 54, 0, 42, "Subsection"],
Cell[138546, 3580, 1059, 23, 168, "Text"],
Cell[139608, 3605, 1883, 37, 366, "Text"],
Cell[141494, 3644, 154, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[141673, 3653, 604, 12, 27, "Input",
  CellOpen->False],
Cell[142280, 3667, 471, 8, 249, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[142800, 3681, 46, 0, 42, "Subsection"],
Cell[142849, 3683, 690, 11, 168, "Text"],
Cell[143542, 3696, 553, 20, 69, "Text"],

Cell[CellGroupData[{
Cell[144120, 3720, 500, 12, 27, "Input",
  CellOpen->False],
Cell[144623, 3734, 612, 9, 207, "Output"]
}, Open  ]],
Cell[145250, 3746, 1148, 17, 243, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[146435, 3768, 117, 5, 42, "Subsection"],
Cell[146555, 3775, 1198, 30, 219, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[147802, 3811, 145, 4, 89, "Section"],

Cell[CellGroupData[{
Cell[147972, 3819, 91, 2, 64, "Subsection"],
Cell[148066, 3823, 548, 10, 120, "Text"],
Cell[148617, 3835, 3807, 103, 491, "Text"],
Cell[152427, 3940, 641, 14, 144, "Text"],

Cell[CellGroupData[{
Cell[153093, 3958, 58, 1, 40, "Input"],
Cell[153154, 3961, 847, 11, 194, "Output"]
}, Open  ]],
Cell[154016, 3975, 1358, 26, 268, "Text"],
Cell[155377, 4003, 468, 11, 95, "Text"],
Cell[155848, 4016, 242, 5, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[156127, 4026, 105, 2, 38, "Subsection"],
Cell[156235, 4030, 330, 10, 70, "Text"],
Cell[156568, 4042, 1077, 31, 144, "Text"],
Cell[157648, 4075, 273, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[157946, 4087, 437, 8, 28, "Input",
  CellOpen->False],
Cell[158386, 4097, 344, 5, 117, "Output"]
}, Open  ]],
Cell[158745, 4105, 950, 34, 169, "Text"],

Cell[CellGroupData[{
Cell[159720, 4143, 260, 6, 28, "Input",
  CellOpen->False],
Cell[159983, 4151, 969, 26, 129, "Output"]
}, Open  ]],
Cell[160967, 4180, 278, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[161270, 4191, 295, 6, 28, "Input",
  CellOpen->False],
Cell[161568, 4199, 338, 8, 137, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[161955, 4213, 103, 2, 38, "Subsection"],
Cell[162061, 4217, 567, 13, 120, "Text"],
Cell[162631, 4232, 794, 22, 144, "Text"],

Cell[CellGroupData[{
Cell[163450, 4258, 275, 6, 92, "Input"],
Cell[163728, 4266, 323, 6, 117, "Output"]
}, Open  ]],
Cell[164066, 4275, 1006, 28, 194, "Text"],

Cell[CellGroupData[{
Cell[165097, 4307, 885, 17, 28, "Input",
  CellOpen->False],
Cell[165985, 4326, 1013, 17, 448, "Output"]
}, Open  ]],
Cell[167013, 4346, 729, 12, 194, "Text"],

Cell[CellGroupData[{
Cell[167767, 4362, 921, 19, 28, "Input",
  CellOpen->False],
Cell[168691, 4383, 2765, 45, 889, "Output"]
}, Open  ]],
Cell[171471, 4431, 156, 4, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[171664, 4440, 97, 2, 38, "Subsection"],
Cell[171764, 4444, 518, 10, 120, "Text"],
Cell[172285, 4456, 1467, 31, 318, "Text"],

Cell[CellGroupData[{
Cell[173777, 4491, 513, 10, 28, "Input",
  CellOpen->False],
Cell[174293, 4503, 542, 9, 250, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[174884, 4518, 99, 2, 38, "Subsection"],
Cell[174986, 4522, 549, 10, 120, "Text"],
Cell[175538, 4534, 1048, 24, 194, "Text"],
Cell[176589, 4560, 1285, 23, 28, "Input",
  CellOpen->False],
Cell[177877, 4585, 308, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[178210, 4596, 191, 4, 28, "Input",
  CellOpen->False],
Cell[178404, 4602, 570, 13, 132, "Print"],
Cell[178977, 4617, 542, 13, 146, "Print"],
Cell[179522, 4632, 339, 7, 60, "Print"]
}, Open  ]],
Cell[179876, 4642, 208, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[180109, 4652, 186, 4, 28, "Input",
  CellOpen->False],
Cell[180298, 4658, 575, 13, 132, "Print"],
Cell[180876, 4673, 506, 13, 146, "Print"],
Cell[181385, 4688, 333, 7, 60, "Print"]
}, Open  ]],
Cell[181733, 4698, 641, 20, 95, "Text"],

Cell[CellGroupData[{
Cell[182399, 4722, 164, 4, 28, "Input",
  CellOpen->False],
Cell[182566, 4728, 572, 14, 123, "Print"],
Cell[183141, 4744, 452, 13, 146, "Print"],
Cell[183596, 4759, 277, 5, 60, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[183922, 4770, 96, 2, 38, "Subsection"],
Cell[184021, 4774, 549, 10, 120, "Text"],
Cell[184573, 4786, 738, 19, 120, "Text"],
Cell[185314, 4807, 169, 7, 45, "Text"],

Cell[CellGroupData[{
Cell[185508, 4818, 87, 2, 41, "Input"],
Cell[185598, 4822, 234, 5, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185869, 4832, 90, 2, 41, "Input"],
Cell[185962, 4836, 152, 3, 42, "Output"]
}, Open  ]],
Cell[186129, 4842, 369, 7, 95, "Text"],
Cell[186501, 4851, 150, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[186676, 4860, 2516, 50, 28, "Input",
  CellOpen->False],
Cell[189195, 4912, 317, 6, 87, "Output"],
Cell[189515, 4920, 2708, 44, 189, "Output"]
}, Open  ]],
Cell[192238, 4967, 1021, 23, 194, "Text"],
Cell[193262, 4992, 184, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[193471, 5002, 2101, 42, 28, "Input",
  CellOpen->False],
Cell[195575, 5046, 621, 12, 140, "Output"],
Cell[196199, 5060, 2489, 41, 189, "Output"]
}, Open  ]],
Cell[198703, 5104, 855, 13, 194, "Text"],
Cell[199561, 5119, 168, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[199754, 5128, 1092, 20, 28, "Input",
  CellOpen->False],
Cell[200849, 5150, 647, 9, 254, "Output"],
Cell[201499, 5161, 1807, 31, 285, "Output"]
}, Open  ]],
Cell[203321, 5195, 178, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[203524, 5204, 1146, 21, 28, "Input",
  CellOpen->False],
Cell[204673, 5227, 88, 1, 42, "Output"],
Cell[204764, 5230, 1688, 30, 359, "Output"]
}, Open  ]],
Cell[206467, 5263, 89, 2, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[206593, 5270, 104, 2, 38, "Subsection"],
Cell[206700, 5274, 428, 9, 95, "Text"],
Cell[207131, 5285, 935, 25, 144, "Text"],

Cell[CellGroupData[{
Cell[208091, 5314, 268, 6, 28, "Input",
  CellOpen->False],
Cell[208362, 5322, 269, 5, 100, "Output"]
}, Open  ]],
Cell[208646, 5330, 211, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[208882, 5342, 1617, 31, 28, "Input",
  CellOpen->False],
Cell[210502, 5375, 1900, 34, 350, "Output"]
}, Open  ]],
Cell[212417, 5412, 502, 14, 95, "Text"],
Cell[212922, 5428, 202, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[213149, 5438, 481, 11, 28, "Input",
  CellOpen->False],
Cell[213633, 5451, 1365, 22, 177, "Output"]
}, Open  ]],
Cell[215013, 5476, 966, 27, 144, "Text"],
Cell[215982, 5505, 177, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[216184, 5515, 843, 22, 28, "Input",
  CellOpen->False],
Cell[217030, 5539, 641, 11, 163, "Print"],
Cell[217674, 5552, 79, 1, 42, "Output"],
Cell[217756, 5555, 127, 2, 41, "Output"],
Cell[217886, 5559, 126, 2, 41, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[218061, 5567, 111, 2, 38, "Subsection"],
Cell[218175, 5571, 1227, 30, 169, "Text"],
Cell[219405, 5603, 2826, 87, 342, "Text"],
Cell[222234, 5692, 3126, 107, 199, "Input",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[225385, 5803, 1237, 33, 111, "Input",
  Evaluatable->False],
Cell[226625, 5838, 343, 7, 69, "Output"]
}, Closed]],
Cell[226983, 5848, 490, 10, 112, "Text"],

Cell[CellGroupData[{
Cell[227498, 5862, 661, 17, 28, "Input",
  CellOpen->False],
Cell[228162, 5881, 223, 3, 92, "Output"]
}, Open  ]],
Cell[228400, 5887, 847, 15, 194, "Text"],
Cell[229250, 5904, 187, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[229462, 5914, 476, 8, 168, "Input"],
Cell[229941, 5924, 121, 2, 41, "Output"]
}, Open  ]],
Cell[230077, 5929, 1043, 33, 144, "Text"],
Cell[231123, 5964, 203, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[231351, 5974, 232, 5, 28, "Input",
  CellOpen->False],
Cell[231586, 5981, 1687, 23, 528, "Output"]
}, Open  ]],
Cell[233288, 6007, 603, 9, 169, "Text"],
Cell[233894, 6018, 238, 7, 45, "Text"],

Cell[CellGroupData[{
Cell[234157, 6029, 214, 4, 66, "Input"],
Cell[234374, 6035, 58, 1, 41, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[234481, 6042, 139, 4, 38, "Subsection"],
Cell[234623, 6048, 1318, 34, 144, "Text"],
Cell[235944, 6084, 7027, 228, 590, "Text"],
Cell[242974, 6314, 191, 6, 45, "Text"],
Cell[243168, 6322, 14687, 367, 709, "Input",
  Evaluatable->False],
Cell[257858, 6691, 645, 12, 144, "Text"],
Cell[258506, 6705, 169, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[258700, 6714, 1499, 26, 222, "Input"],
Cell[260202, 6742, 3583, 56, 494, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[263834, 6804, 157, 4, 38, "Subsection"],
Cell[263994, 6810, 1037, 29, 101, "Text"],
Cell[265034, 6841, 1883, 60, 154, "Text"],
Cell[266920, 6903, 370, 12, 70, "Text"],

Cell[CellGroupData[{
Cell[267315, 6919, 1162, 21, 28, "Input",
  CellOpen->False],

Cell[CellGroupData[{
Cell[268502, 6944, 67501, 1352, 279, 11029, 649, "GraphicsData", \
"PostScript", "Graphics"],
Cell[336006, 8298, 69494, 1368, 279, 10884, 638, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[405527, 9670, 1044, 28, 194, "Text"],
Cell[406574, 9700, 125, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[406724, 9709, 70, 2, 41, "Input"],
Cell[406797, 9713, 808, 13, 69, "Print",
  CellTags->"Info3353843803-4044115"]
}, Closed]],
Cell[407620, 9729, 477, 10, 96, "Input"],

Cell[CellGroupData[{
Cell[408122, 9743, 70, 2, 41, "Input"],
Cell[408195, 9747, 786, 13, 69, "Print",
  CellTags->"Info3353241802-8811303"]
}, Closed]],
Cell[408996, 9763, 492, 11, 96, "Input"],
Cell[409491, 9776, 1116, 35, 144, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[410644, 9816, 97, 2, 38, "Subsection"],
Cell[410744, 9820, 288, 8, 70, "Text"],
Cell[411035, 9830, 2008, 34, 369, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[413080, 9869, 130, 3, 38, "Subsection"],
Cell[413213, 9874, 427, 9, 125, "Text"],

Cell[CellGroupData[{
Cell[413665, 9887, 124, 2, 61, "Subsubsection"],
Cell[413792, 9891, 1681, 29, 463, "Text"],
Cell[415476, 9922, 161, 6, 47, "Text"],

Cell[CellGroupData[{
Cell[415662, 9932, 1425, 30, 28, "Input",
  CellOpen->False],
Cell[417090, 9964, 1444, 23, 824, "Output"]
}, Open  ]],
Cell[418549, 9990, 661, 15, 177, "Text"],
Cell[419213, 10007, 119, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[419357, 10013, 914, 17, 28, "Input",
  CellOpen->False],
Cell[420274, 10032, 1523, 25, 752, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[421846, 10063, 128, 2, 61, "Subsubsection"],
Cell[421977, 10067, 1080, 20, 281, "Text"],
Cell[423060, 10089, 96, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[423181, 10095, 241, 8, 28, "Input",
  CellOpen->False],
Cell[423425, 10105, 685, 11, 259, "Output"]
}, Open  ]],
Cell[424125, 10119, 195, 4, 73, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[424369, 10129, 118, 2, 64, "Subsection"],
Cell[424490, 10133, 733, 13, 169, "Text"],
Cell[425226, 10148, 416, 7, 95, "Text"],
Cell[425645, 10157, 1338, 24, 194, "Text"],
Cell[426986, 10183, 176, 6, 45, "Text"],
Cell[427165, 10191, 131, 3, 41, "Input"],
Cell[427299, 10196, 1805, 28, 258, "Input"],
Cell[429107, 10226, 499, 9, 73, "Input"],
Cell[429609, 10237, 185, 6, 70, "Text"],
Cell[429797, 10245, 3089, 54, 270, "Input"],
Cell[432889, 10301, 680, 11, 144, "Text"],
Cell[433572, 10314, 141, 3, 40, "Input"],
Cell[433716, 10319, 1981, 35, 345, "Input"],
Cell[435700, 10356, 3590, 54, 251, "Input"],
Cell[439293, 10412, 185, 4, 70, "Text"],
Cell[439481, 10418, 95, 2, 45, "Text"],
Cell[439579, 10422, 2236, 38, 270, "Input"],
Cell[441818, 10462, 2092, 30, 299, "Input"],
Cell[443913, 10494, 119, 2, 45, "Text"],
Cell[444035, 10498, 1693, 30, 321, "Input"],
Cell[445731, 10530, 2668, 44, 295, "Input"],
Cell[448402, 10576, 466, 10, 95, "Text"],
Cell[448871, 10588, 400, 13, 40, "Input"],
Cell[449274, 10603, 6680, 119, 546, "Input"],
Cell[455957, 10724, 975, 14, 219, "Text"],
Cell[456935, 10740, 613, 21, 40, "Input"],
Cell[457551, 10763, 167, 4, 41, "Input"],
Cell[457721, 10769, 569, 11, 114, "Input"],
Cell[458293, 10782, 98, 2, 41, "Input"],
Cell[458394, 10786, 583, 12, 138, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[459014, 10803, 90, 2, 38, "Subsection"],
Cell[459107, 10807, 1073, 25, 392, "Text"],

Cell[CellGroupData[{
Cell[460205, 10836, 409, 11, 48, "Input"],
Cell[460617, 10849, 166, 3, 69, "Output"]
}, Closed]],
Cell[460798, 10855, 294, 7, 63, "Text"],
Cell[461095, 10864, 205, 5, 70, "Text"],
Cell[461303, 10871, 158, 3, 70, "Text"],
Cell[461464, 10876, 52, 1, 41, "Input"],
Cell[461519, 10879, 85, 1, 41, "Input"],

Cell[CellGroupData[{
Cell[461629, 10884, 91, 2, 66, "Input"],
Cell[461723, 10888, 214, 3, 99, "Output"],
Cell[461940, 10893, 214, 3, 99, "Output"]
}, Open  ]],
Cell[462169, 10899, 1981, 35, 345, "Input"],
Cell[464153, 10936, 3590, 54, 251, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[467780, 10995, 134, 4, 38, "Subsection"],
Cell[467917, 11001, 1311, 32, 333, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[469265, 11038, 90, 2, 64, "Subsection"],
Cell[469358, 11042, 321, 8, 99, "Text"],

Cell[CellGroupData[{
Cell[469704, 11054, 100, 2, 61, "Subsubsection"],
Cell[469807, 11058, 239, 6, 70, "Text"],
Cell[470049, 11066, 682, 10, 144, "Text"],
Cell[470734, 11078, 924, 17, 103, "Input"],

Cell[CellGroupData[{
Cell[471683, 11099, 131, 2, 66, "Input"],
Cell[471817, 11103, 278, 5, 127, "Output"],
Cell[472098, 11110, 524, 11, 200, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[472659, 11126, 129, 2, 66, "Input"],
Cell[472791, 11130, 214, 4, 84, "Output"],
Cell[473008, 11136, 501, 11, 163, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[473558, 11153, 99, 2, 38, "Subsubsection"],

Cell[CellGroupData[{
Cell[473682, 11159, 156, 4, 66, "Input"],
Cell[473841, 11165, 808, 12, 291, "Output"]
}, Open  ]],
Cell[474664, 11180, 135, 3, 41, "Input"],
Cell[474802, 11185, 61, 1, 41, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[474924, 11193, 106, 2, 81, "Section"],
Cell[475033, 11197, 1840, 47, 69, "Text"],
Cell[476876, 11246, 154, 5, 69, "Text"],
Cell[477033, 11253, 986, 21, 69, "Input",
  Evaluatable->False],
Cell[478022, 11276, 1133, 33, 69, "Text"],
Cell[479158, 11311, 121, 2, 69, "Text"],
Cell[479282, 11315, 166, 4, 69, "Input"],

Cell[CellGroupData[{
Cell[479473, 11323, 7151, 188, 69, "Input"],
Cell[486627, 11513, 1795, 29, 69, "Output"]
}, Closed]],
Cell[488437, 11545, 1109, 37, 69, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[489583, 11587, 72, 2, 49, "Section"],
Cell[489658, 11591, 163, 6, 47, "Text"],
Cell[489824, 11599, 223, 7, 73, "Text"],
Cell[490050, 11608, 95, 1, 47, "Text"],
Cell[490148, 11611, 122, 3, 47, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

