(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5791,        113]*)
(*NotebookOutlinePosition[      6434,        135]*)
(*  CellTagsIndexPosition[      6390,        131]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "GroupLoopHoop.m is a package of procedures to create, manipulate, \
identify, and use small Groups, Algebraic Loops, and \"Hoop Algebras\" (which \
are relevant to physics because their Moufang vector-division and Frobenius \
conservation properties provide the conserved symmetries that define forces \
and particles), together with a database that includes all groups with up to \
72 elements and over 80 hoops. GroupLoopTest.nb validates the database, \
HoopGlossary.nb explains the terms employed, GroupLoopDemo.nb and HoopDemo.nb \
demonstrate the procedures. ",
  StyleBox["MathSource/6198",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " is a much smaller and simpler database and explanation, restricted to \
Hoop algbras and omitting the background material on Groups & Loops. The \
simplifications make it incompatible with this notebook.\n\nThe notebooks are \
designed to be read by, and comprehensible to, non-",
  "Mathematica",
  " users who have downloaded ",
  "MathReader",
  "; ",
  "Mathematica",
  " users (Version 4.2 or later) can test them with their own data. They \
provide background material on algebraic loop and groups and then demonstrate \
\"Conservative Partial-fraction-division Algebras\" or \"Hoops\". Hoops unify \
most standard algebras - Complex, Cayley-Dickson, Clifford, Davenport, Dirac, \
non-commutative, Octonion, Pauli-sigma, Quaternion, Real, Octonion, Spinor, \
Wedge, etc., together with new \"terplex\" algebras. As all groups and \
octonions are Moufang Loops, a database of over 800 loops is provided. Many \
\"mathematical truths\" are only valid in the context of real and complex \
numbers because they are degenerate cases of more general \"Hoop\" \
relationships.\n\nThe key features of Hoop algebras are: A single operation \
\"hoopTimes\" provides Moufang Loop multiplication and division of \
\"directors\" (sets of unsigned \"Primal\" numbers). The Moufang division \
property ensures that every director has a multiplicative inverse, which is \
given by \"hoopInverse\". Generalised signs are provided by r'th roots of \
unity and r-fold negations, which \"fold\" Moufang Loops to Hoop Algebras \
(and directors to vectors) via equivalence relations. Real numbers are \
equivalence relations (with r=2) on pairs of primal numbers. These \
equivalence relations involve a loss of information. Hoops are algebras with \
\"sizes\" (symmetries) that are conserved on multiplication and division. \
Sizes are denominators for the partial-fraction formulation of multiplicative \
inverses. Multiplication and division by \"vectors with zero sizes\" must \
create remainders to maintain size conservation. The result is \"renormalized\
\" into a sub-algebra of reduced symmetry. This may be related to particle \
interactions and decay, and to supersymmetry. Some hoops have Polar-duals \
with additive angles, allowing the calculation of vector powers and roots, \
via \"hoopPower\".\nSome unital Polar-duals have (deBroglie-like) multi-phase \
orbits and intrinsic (Planck-like) areas. Their elements include half-spin \
quantum operators that are neither real nor complex. Hoop algebras give \
tantalizing suggestions about the re-interpretation of mathematical physics, \
which (at 77) I cannot expect to explore. They may describe bosons and \
fermions. Ternary (quark) symmetries occur without invoking octonion \
triality. Kaluza-Klein orbital velocities could provide mass. Unital orbits \
may explain the \"law of large numbers\". Hoop maths may underlie (and \
simplify) string maths, describing non-point-like particles with an intrinsic \
Planck scale. Complex numbers can express much of mathematics, but are a \
Procrustean bed; some parts relevant to physics do not fit on it. I have \
scratched the surface of a more fundamental mathematics, and found many \
features that may be relevant to mathematical physics, but \"Non omnia \
possumus omnes\" (Virgil).\n\nVersion 4. 12th October 2006.\:f35f"
}], "Text"]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
WindowSize->{499, 729},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 4033, 60, 888, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

